Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1AspectSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Information related to the source system of the aspect.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1AspectSource

Returns a new instance of GoogleCloudDataplexV1AspectSource.



433
434
435
# File 'lib/google/apis/dataplex_v1/classes.rb', line 433

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

The time the aspect was created in the source system. Corresponds to the JSON property createTime

Returns:

  • (String)


419
420
421
# File 'lib/google/apis/dataplex_v1/classes.rb', line 419

def create_time
  @create_time
end

#data_versionString

The version of the data format used to produce this data. This field is used to indicated when the underlying data format changes (e.g., schema modifications, changes to the source URL format definition, etc). Corresponds to the JSON property dataVersion

Returns:

  • (String)


426
427
428
# File 'lib/google/apis/dataplex_v1/classes.rb', line 426

def data_version
  @data_version
end

#update_timeString

The time the aspect was last updated in the source system. Corresponds to the JSON property updateTime

Returns:

  • (String)


431
432
433
# File 'lib/google/apis/dataplex_v1/classes.rb', line 431

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



438
439
440
441
442
# File 'lib/google/apis/dataplex_v1/classes.rb', line 438

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_version = args[:data_version] if args.key?(:data_version)
  @update_time = args[:update_time] if args.key?(:update_time)
end