Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1AspectType

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

AspectType is a template for creating Aspects, and represents the JSON-schema for a given Entry, for example, BigQuery Table Schema.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1AspectType

Returns a new instance of GoogleCloudDataplexV1AspectType.



515
516
517
# File 'lib/google/apis/dataplex_v1/classes.rb', line 515

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authorizationGoogle::Apis::DataplexV1::GoogleCloudDataplexV1AspectTypeAuthorization

Authorization for an AspectType. Corresponds to the JSON property authorization



453
454
455
# File 'lib/google/apis/dataplex_v1/classes.rb', line 453

def authorization
  @authorization
end

#create_timeString

Output only. The time when the AspectType was created. Corresponds to the JSON property createTime

Returns:

  • (String)


458
459
460
# File 'lib/google/apis/dataplex_v1/classes.rb', line 458

def create_time
  @create_time
end

#data_classificationString

Optional. Immutable. Stores data classification of the aspect. Corresponds to the JSON property dataClassification

Returns:

  • (String)


463
464
465
# File 'lib/google/apis/dataplex_v1/classes.rb', line 463

def data_classification
  @data_classification
end

#descriptionString

Optional. Description of the AspectType. Corresponds to the JSON property description

Returns:

  • (String)


468
469
470
# File 'lib/google/apis/dataplex_v1/classes.rb', line 468

def description
  @description
end

#display_nameString

Optional. User friendly display name. Corresponds to the JSON property displayName

Returns:

  • (String)


473
474
475
# File 'lib/google/apis/dataplex_v1/classes.rb', line 473

def display_name
  @display_name
end

#etagString

The service computes this checksum. The client may send it on update and delete requests to ensure it has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


479
480
481
# File 'lib/google/apis/dataplex_v1/classes.rb', line 479

def etag
  @etag
end

#labelsHash<String,String>

Optional. User-defined labels for the AspectType. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


484
485
486
# File 'lib/google/apis/dataplex_v1/classes.rb', line 484

def labels
  @labels
end

#metadata_templateGoogle::Apis::DataplexV1::GoogleCloudDataplexV1AspectTypeMetadataTemplate

MetadataTemplate definition for an AspectType. Corresponds to the JSON property metadataTemplate



489
490
491
# File 'lib/google/apis/dataplex_v1/classes.rb', line 489

def 
  @metadata_template
end

#nameString

Output only. The relative resource name of the AspectType, of the form: projects/project_number/locations/location_id/aspectTypes/aspect_type_id. Corresponds to the JSON property name

Returns:

  • (String)


495
496
497
# File 'lib/google/apis/dataplex_v1/classes.rb', line 495

def name
  @name
end

#transfer_statusString

Output only. Denotes the transfer status of the Aspect Type. It is unspecified for Aspect Types created from Dataplex API. Corresponds to the JSON property transferStatus

Returns:

  • (String)


501
502
503
# File 'lib/google/apis/dataplex_v1/classes.rb', line 501

def transfer_status
  @transfer_status
end

#uidString

Output only. System generated globally unique ID for the AspectType. If you delete and recreate the AspectType with the same name, then this ID will be different. Corresponds to the JSON property uid

Returns:

  • (String)


508
509
510
# File 'lib/google/apis/dataplex_v1/classes.rb', line 508

def uid
  @uid
end

#update_timeString

Output only. The time when the AspectType was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


513
514
515
# File 'lib/google/apis/dataplex_v1/classes.rb', line 513

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



520
521
522
523
524
525
526
527
528
529
530
531
532
533
# File 'lib/google/apis/dataplex_v1/classes.rb', line 520

def update!(**args)
  @authorization = args[:authorization] if args.key?(:authorization)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_classification = args[:data_classification] if args.key?(:data_classification)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @metadata_template = args[:metadata_template] if args.key?(:metadata_template)
  @name = args[:name] if args.key?(:name)
  @transfer_status = args[:transfer_status] if args.key?(:transfer_status)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end