Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1AspectTypeMetadataTemplateAnnotations

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Definition of the annotations of a field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1AspectTypeMetadataTemplateAnnotations

Returns a new instance of GoogleCloudDataplexV1AspectTypeMetadataTemplateAnnotations.



682
683
684
# File 'lib/google/apis/dataplex_v1/classes.rb', line 682

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deprecatedString

Optional. Marks a field as deprecated. You can include a deprecation message. Corresponds to the JSON property deprecated

Returns:

  • (String)


650
651
652
# File 'lib/google/apis/dataplex_v1/classes.rb', line 650

def deprecated
  @deprecated
end

#descriptionString

Optional. Description for a field. Corresponds to the JSON property description

Returns:

  • (String)


655
656
657
# File 'lib/google/apis/dataplex_v1/classes.rb', line 655

def description
  @description
end

#display_nameString

Optional. Display name for a field. Corresponds to the JSON property displayName

Returns:

  • (String)


660
661
662
# File 'lib/google/apis/dataplex_v1/classes.rb', line 660

def display_name
  @display_name
end

#display_orderFixnum

Optional. Display order for a field. You can use this to reorder where a field is rendered. Corresponds to the JSON property displayOrder

Returns:

  • (Fixnum)


666
667
668
# File 'lib/google/apis/dataplex_v1/classes.rb', line 666

def display_order
  @display_order
end

#string_typeString

Optional. You can use String Type annotations to specify special meaning to string fields. The following values are supported: richText: The field must be interpreted as a rich text field. url: A fully qualified URL link. resource: A service qualified resource reference. Corresponds to the JSON property stringType

Returns:

  • (String)


674
675
676
# File 'lib/google/apis/dataplex_v1/classes.rb', line 674

def string_type
  @string_type
end

#string_valuesArray<String>

Optional. Suggested hints for string fields. You can use them to suggest values to users through console. Corresponds to the JSON property stringValues

Returns:

  • (Array<String>)


680
681
682
# File 'lib/google/apis/dataplex_v1/classes.rb', line 680

def string_values
  @string_values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



687
688
689
690
691
692
693
694
# File 'lib/google/apis/dataplex_v1/classes.rb', line 687

def update!(**args)
  @deprecated = args[:deprecated] if args.key?(:deprecated)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @display_order = args[:display_order] if args.key?(:display_order)
  @string_type = args[:string_type] if args.key?(:string_type)
  @string_values = args[:string_values] if args.key?(:string_values)
end