Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1AspectTypeMetadataTemplateEnumValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Definition of Enumvalue, to be used for enum fields.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1AspectTypeMetadataTemplateEnumValue

Returns a new instance of GoogleCloudDataplexV1AspectTypeMetadataTemplateEnumValue.



744
745
746
# File 'lib/google/apis/dataplex_v1/classes.rb', line 744

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deprecatedString

Optional. You can set this message if you need to deprecate an enum value. Corresponds to the JSON property deprecated

Returns:

  • (String)


731
732
733
# File 'lib/google/apis/dataplex_v1/classes.rb', line 731

def deprecated
  @deprecated
end

#indexFixnum

Required. Index for the enum value. It can't be modified. Corresponds to the JSON property index

Returns:

  • (Fixnum)


736
737
738
# File 'lib/google/apis/dataplex_v1/classes.rb', line 736

def index
  @index
end

#nameString

Required. Name of the enumvalue. This is the actual value that the aspect can contain. Corresponds to the JSON property name

Returns:

  • (String)


742
743
744
# File 'lib/google/apis/dataplex_v1/classes.rb', line 742

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



749
750
751
752
753
# File 'lib/google/apis/dataplex_v1/classes.rb', line 749

def update!(**args)
  @deprecated = args[:deprecated] if args.key?(:deprecated)
  @index = args[:index] if args.key?(:index)
  @name = args[:name] if args.key?(:name)
end