Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1Asset
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1Asset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
An asset represents a cloud resource that is being managed within a lake as a member of a zone.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#discovery_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetDiscoverySpec
Settings to manage the metadata discovery and publishing for an asset.
-
#discovery_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetDiscoveryStatus
Status of discovery for an asset.
-
#display_name ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#resource_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetResourceSpec
Identifies the cloud resource that is referenced by this asset.
-
#resource_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetResourceStatus
Status of the resource referenced by an asset.
-
#security_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetSecurityStatus
Security policy status of the asset.
-
#state ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1Asset
constructor
A new instance of GoogleCloudDataplexV1Asset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1Asset
Returns a new instance of GoogleCloudDataplexV1Asset.
830 831 832 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 830 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time when the asset was created.
Corresponds to the JSON property createTime
764 765 766 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 764 def create_time @create_time end |
#description ⇒ String
Optional. Description of the asset.
Corresponds to the JSON property description
769 770 771 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 769 def description @description end |
#discovery_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetDiscoverySpec
Settings to manage the metadata discovery and publishing for an asset.
Corresponds to the JSON property discoverySpec
774 775 776 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 774 def discovery_spec @discovery_spec end |
#discovery_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetDiscoveryStatus
Status of discovery for an asset.
Corresponds to the JSON property discoveryStatus
779 780 781 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 779 def discovery_status @discovery_status end |
#display_name ⇒ String
Optional. User friendly display name.
Corresponds to the JSON property displayName
784 785 786 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 784 def display_name @display_name end |
#labels ⇒ Hash<String,String>
Optional. User defined labels for the asset.
Corresponds to the JSON property labels
789 790 791 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 789 def labels @labels end |
#name ⇒ String
Output only. The relative resource name of the asset, of the form: projects/
project_number/locations/location_id/lakes/lake_id/zones/zone_id/assets/
asset_id.
Corresponds to the JSON property name
796 797 798 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 796 def name @name end |
#resource_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetResourceSpec
Identifies the cloud resource that is referenced by this asset.
Corresponds to the JSON property resourceSpec
801 802 803 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 801 def resource_spec @resource_spec end |
#resource_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetResourceStatus
Status of the resource referenced by an asset.
Corresponds to the JSON property resourceStatus
806 807 808 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 806 def resource_status @resource_status end |
#security_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetSecurityStatus
Security policy status of the asset. Data security policy, i.e., readers,
writers & owners, should be specified in the lake/zone/asset IAM policy.
Corresponds to the JSON property securityStatus
812 813 814 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 812 def security_status @security_status end |
#state ⇒ String
Output only. Current state of the asset.
Corresponds to the JSON property state
817 818 819 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 817 def state @state end |
#uid ⇒ String
Output only. System generated globally unique ID for the asset. This ID will
be different if the asset is deleted and re-created with the same name.
Corresponds to the JSON property uid
823 824 825 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 823 def uid @uid end |
#update_time ⇒ String
Output only. The time when the asset was last updated.
Corresponds to the JSON property updateTime
828 829 830 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 828 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 835 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @discovery_spec = args[:discovery_spec] if args.key?(:discovery_spec) @discovery_status = args[:discovery_status] if args.key?(:discovery_status) @display_name = args[:display_name] if args.key?(:display_name) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @resource_spec = args[:resource_spec] if args.key?(:resource_spec) @resource_status = args[:resource_status] if args.key?(:resource_status) @security_status = args[:security_status] if args.key?(:security_status) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |