Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetDiscoverySpecJsonOptions
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetDiscoverySpecJsonOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Describe JSON data format.
Instance Attribute Summary collapse
-
#disable_type_inference ⇒ Boolean
(also: #disable_type_inference?)
Optional.
-
#encoding ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1AssetDiscoverySpecJsonOptions
constructor
A new instance of GoogleCloudDataplexV1AssetDiscoverySpecJsonOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1AssetDiscoverySpecJsonOptions
Returns a new instance of GoogleCloudDataplexV1AssetDiscoverySpecJsonOptions.
972 973 974 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 972 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disable_type_inference ⇒ Boolean Also known as: disable_type_inference?
Optional. Whether to disable the inference of data type for Json data. If true,
all columns will be registered as their primitive types (strings, number or
boolean).
Corresponds to the JSON property disableTypeInference
964 965 966 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 964 def disable_type_inference @disable_type_inference end |
#encoding ⇒ String
Optional. The character encoding of the data. The default is UTF-8.
Corresponds to the JSON property encoding
970 971 972 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 970 def encoding @encoding end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
977 978 979 980 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 977 def update!(**args) @disable_type_inference = args[:disable_type_inference] if args.key?(:disable_type_inference) @encoding = args[:encoding] if args.key?(:encoding) end |