Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetDiscoveryStatusStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

The aggregated data statistics for the asset reported by discovery.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1AssetDiscoveryStatusStats

Returns a new instance of GoogleCloudDataplexV1AssetDiscoveryStatusStats.



1049
1050
1051
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1049

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_itemsFixnum

The count of data items within the referenced resource. Corresponds to the JSON property dataItems

Returns:

  • (Fixnum)


1032
1033
1034
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1032

def data_items
  @data_items
end

#data_sizeFixnum

The number of stored data bytes within the referenced resource. Corresponds to the JSON property dataSize

Returns:

  • (Fixnum)


1037
1038
1039
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1037

def data_size
  @data_size
end

#filesetsFixnum

The count of fileset entities within the referenced resource. Corresponds to the JSON property filesets

Returns:

  • (Fixnum)


1042
1043
1044
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1042

def filesets
  @filesets
end

#tablesFixnum

The count of table entities within the referenced resource. Corresponds to the JSON property tables

Returns:

  • (Fixnum)


1047
1048
1049
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1047

def tables
  @tables
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1054
1055
1056
1057
1058
1059
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1054

def update!(**args)
  @data_items = args[:data_items] if args.key?(:data_items)
  @data_size = args[:data_size] if args.key?(:data_size)
  @filesets = args[:filesets] if args.key?(:filesets)
  @tables = args[:tables] if args.key?(:tables)
end