Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1ChangeRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Represents a proposed change to a metadata resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1ChangeRequest

Returns a new instance of GoogleCloudDataplexV1ChangeRequest.



1447
1448
1449
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1447

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approverString

Output only. The email address of the user who approved/rejected the ChangeRequest. Corresponds to the JSON property approver

Returns:

  • (String)


1295
1296
1297
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1295

def approver
  @approver
end

#authorString

Output only. The email address of the user who created the ChangeRequest. Corresponds to the JSON property author

Returns:

  • (String)


1300
1301
1302
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1300

def author
  @author
end

#change_typeString

Output only. The type of change represented by the change_payload. This field is derived from the populated field in the change_payload oneof. Corresponds to the JSON property changeType

Returns:

  • (String)


1306
1307
1308
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1306

def change_type
  @change_type
end

#create_entryGoogle::Apis::DataplexV1::GoogleCloudDataplexV1CreateEntryRequest

Create Entry request. Corresponds to the JSON property createEntry



1311
1312
1313
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1311

def create_entry
  @create_entry
end

#create_entry_linkGoogle::Apis::DataplexV1::GoogleCloudDataplexV1CreateEntryLinkRequest

Request message for CreateEntryLink. Corresponds to the JSON property createEntryLink



1316
1317
1318
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1316

def create_entry_link
  @create_entry_link
end

#create_glossaryGoogle::Apis::DataplexV1::GoogleCloudDataplexV1CreateGlossaryRequest

Create Glossary Request Corresponds to the JSON property createGlossary



1321
1322
1323
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1321

def create_glossary
  @create_glossary
end

#create_glossary_categoryGoogle::Apis::DataplexV1::GoogleCloudDataplexV1CreateGlossaryCategoryRequest

Creates a new GlossaryCategory under the specified Glossary. Corresponds to the JSON property createGlossaryCategory



1326
1327
1328
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1326

def create_glossary_category
  @create_glossary_category
end

#create_glossary_termGoogle::Apis::DataplexV1::GoogleCloudDataplexV1CreateGlossaryTermRequest

Creates a new GlossaryTerm under the specified Glossary. Corresponds to the JSON property createGlossaryTerm



1331
1332
1333
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1331

def create_glossary_term
  @create_glossary_term
end

#create_timeString

Output only. The time when the ChangeRequest was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1336
1337
1338
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1336

def create_time
  @create_time
end

#data_product_access_requestGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataProductAccessRequest

Message for requesting access to a Data Product. This will be used to create a ChangeRequest of type REQUEST_DATA_PRODUCT_ACCESS. Corresponds to the JSON property dataProductAccessRequest



1342
1343
1344
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1342

def data_product_access_request
  @data_product_access_request
end

#delete_entryGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DeleteEntryRequest

Delete Entry request. Corresponds to the JSON property deleteEntry



1347
1348
1349
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1347

def delete_entry
  @delete_entry
end

#delete_entry_linkGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DeleteEntryLinkRequest

Request message for DeleteEntryLink. Corresponds to the JSON property deleteEntryLink



1352
1353
1354
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1352

def delete_entry_link
  @delete_entry_link
end

#delete_glossaryGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DeleteGlossaryRequest

Delete Glossary Request Corresponds to the JSON property deleteGlossary



1357
1358
1359
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1357

def delete_glossary
  @delete_glossary
end

#delete_glossary_categoryGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DeleteGlossaryCategoryRequest

Delete GlossaryCategory Request Corresponds to the JSON property deleteGlossaryCategory



1362
1363
1364
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1362

def delete_glossary_category
  @delete_glossary_category
end

#delete_glossary_termGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DeleteGlossaryTermRequest

Delete GlossaryTerm Request Corresponds to the JSON property deleteGlossaryTerm



1367
1368
1369
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1367

def delete_glossary_term
  @delete_glossary_term
end

#etagString

Optional. This checksum is computed by the service. It can be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


1374
1375
1376
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1374

def etag
  @etag
end

#justificationString

Optional. Justification of the ChangeRequest. This should explain why the change is needed or why it should be approved. Corresponds to the JSON property justification

Returns:

  • (String)


1380
1381
1382
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1380

def justification
  @justification
end

#labelsHash<String,String>

Optional. User-defined labels for the ChangeRequest. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1385
1386
1387
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1385

def labels
  @labels
end

#nameString

Identifier. The relative resource name of the ChangeRequest, of the form: projects/project_number/locations/location_id/changeRequests/ change_request_id Corresponds to the JSON property name

Returns:

  • (String)


1392
1393
1394
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1392

def name
  @name
end

#rejection_commentString

Output only. The reason provided for rejecting the ChangeRequest. Corresponds to the JSON property rejectionComment

Returns:

  • (String)


1397
1398
1399
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1397

def rejection_comment
  @rejection_comment
end

#resourceString

Output only. The full resource name of the target resource to be modified. Example: //dataplex.googleapis.com/projects/my-project/locations/us-central1/ entryGroups/my-group/entries/my-entry Corresponds to the JSON property resource

Returns:

  • (String)


1404
1405
1406
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1404

def resource
  @resource
end

#reviewer_commentString

Output only. The comment provided by the reviewer when approving or rejecting the ChangeRequest. Maximum length is 1024 characters. Corresponds to the JSON property reviewerComment

Returns:

  • (String)


1410
1411
1412
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1410

def reviewer_comment
  @reviewer_comment
end

#stateString

Output only. The current state of the ChangeRequest. Corresponds to the JSON property state

Returns:

  • (String)


1415
1416
1417
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1415

def state
  @state
end

#uidString

Output only. System generated globally unique ID for the ChangeRequest. Corresponds to the JSON property uid

Returns:

  • (String)


1420
1421
1422
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1420

def uid
  @uid
end

#update_entryGoogle::Apis::DataplexV1::GoogleCloudDataplexV1UpdateEntryRequest

Update Entry request. Corresponds to the JSON property updateEntry



1425
1426
1427
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1425

def update_entry
  @update_entry
end

#update_glossaryGoogle::Apis::DataplexV1::GoogleCloudDataplexV1UpdateGlossaryRequest

Update Glossary Request Corresponds to the JSON property updateGlossary



1430
1431
1432
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1430

def update_glossary
  @update_glossary
end

#update_glossary_categoryGoogle::Apis::DataplexV1::GoogleCloudDataplexV1UpdateGlossaryCategoryRequest

Update GlossaryCategory Request Corresponds to the JSON property updateGlossaryCategory



1435
1436
1437
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1435

def update_glossary_category
  @update_glossary_category
end

#update_glossary_termGoogle::Apis::DataplexV1::GoogleCloudDataplexV1UpdateGlossaryTermRequest

Update GlossaryTerm Request Corresponds to the JSON property updateGlossaryTerm



1440
1441
1442
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1440

def update_glossary_term
  @update_glossary_term
end

#update_timeString

Output only. The time when the ChangeRequest was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1445
1446
1447
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1445

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1452

def update!(**args)
  @approver = args[:approver] if args.key?(:approver)
  @author = args[:author] if args.key?(:author)
  @change_type = args[:change_type] if args.key?(:change_type)
  @create_entry = args[:create_entry] if args.key?(:create_entry)
  @create_entry_link = args[:create_entry_link] if args.key?(:create_entry_link)
  @create_glossary = args[:create_glossary] if args.key?(:create_glossary)
  @create_glossary_category = args[:create_glossary_category] if args.key?(:create_glossary_category)
  @create_glossary_term = args[:create_glossary_term] if args.key?(:create_glossary_term)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_product_access_request = args[:data_product_access_request] if args.key?(:data_product_access_request)
  @delete_entry = args[:delete_entry] if args.key?(:delete_entry)
  @delete_entry_link = args[:delete_entry_link] if args.key?(:delete_entry_link)
  @delete_glossary = args[:delete_glossary] if args.key?(:delete_glossary)
  @delete_glossary_category = args[:delete_glossary_category] if args.key?(:delete_glossary_category)
  @delete_glossary_term = args[:delete_glossary_term] if args.key?(:delete_glossary_term)
  @etag = args[:etag] if args.key?(:etag)
  @justification = args[:justification] if args.key?(:justification)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @rejection_comment = args[:rejection_comment] if args.key?(:rejection_comment)
  @resource = args[:resource] if args.key?(:resource)
  @reviewer_comment = args[:reviewer_comment] if args.key?(:reviewer_comment)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @update_entry = args[:update_entry] if args.key?(:update_entry)
  @update_glossary = args[:update_glossary] if args.key?(:update_glossary)
  @update_glossary_category = args[:update_glossary_category] if args.key?(:update_glossary_category)
  @update_glossary_term = args[:update_glossary_term] if args.key?(:update_glossary_term)
  @update_time = args[:update_time] if args.key?(:update_time)
end