Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1Contacts

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Business contacts part of business context of a Data Domain. Corresponds to the Contacts Aspect in Dataplex Universal Catalog.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1Contacts

Returns a new instance of GoogleCloudDataplexV1Contacts.



1528
1529
1530
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1528

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#identitiesArray<Google::Apis::DataplexV1::GoogleCloudDataplexV1ContactIdentity>

Required. Identities of the business contacts. Corresponds to the JSON property identities



1526
1527
1528
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1526

def identities
  @identities
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1533
1534
1535
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1533

def update!(**args)
  @identities = args[:identities] if args.key?(:identities)
end