Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1Content
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1Content
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Content represents a user-visible notebook or a sql script
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#data_text ⇒ String
Required.
-
#description ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#notebook ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1ContentNotebook
Configuration for Notebook content.
-
#path ⇒ String
Required.
-
#sql_script ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1ContentSqlScript
Configuration for the Sql Script content.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1Content
constructor
A new instance of GoogleCloudDataplexV1Content.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1Content
Returns a new instance of GoogleCloudDataplexV1Content.
1293 1294 1295 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1293 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Content creation time.
Corresponds to the JSON property createTime
1242 1243 1244 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1242 def create_time @create_time end |
#data_text ⇒ String
Required. Content data in string format.
Corresponds to the JSON property dataText
1247 1248 1249 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1247 def data_text @data_text end |
#description ⇒ String
Optional. Description of the content.
Corresponds to the JSON property description
1252 1253 1254 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1252 def description @description end |
#labels ⇒ Hash<String,String>
Optional. User defined labels for the content.
Corresponds to the JSON property labels
1257 1258 1259 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1257 def labels @labels end |
#name ⇒ String
Output only. The relative resource name of the content, of the form: projects/
project_id/locations/location_id/lakes/lake_id/content/content_id
Corresponds to the JSON property name
1263 1264 1265 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1263 def name @name end |
#notebook ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1ContentNotebook
Configuration for Notebook content.
Corresponds to the JSON property notebook
1268 1269 1270 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1268 def notebook @notebook end |
#path ⇒ String
Required. The path for the Content file, represented as directory structure.
Unique within a lake. Limited to alphanumerics, hyphens, underscores, dots and
slashes.
Corresponds to the JSON property path
1275 1276 1277 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1275 def path @path end |
#sql_script ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1ContentSqlScript
Configuration for the Sql Script content.
Corresponds to the JSON property sqlScript
1280 1281 1282 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1280 def sql_script @sql_script end |
#uid ⇒ String
Output only. System generated globally unique ID for the content. This ID will
be different if the content is deleted and re-created with the same name.
Corresponds to the JSON property uid
1286 1287 1288 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1286 def uid @uid end |
#update_time ⇒ String
Output only. The time when the content was last updated.
Corresponds to the JSON property updateTime
1291 1292 1293 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1291 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1298 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @data_text = args[:data_text] if args.key?(:data_text) @description = args[:description] if args.key?(:description) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @notebook = args[:notebook] if args.key?(:notebook) @path = args[:path] if args.key?(:path) @sql_script = args[:sql_script] if args.key?(:sql_script) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |