Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataAssetAccessGroupConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataAssetAccessGroupConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Configuration for access group inherited from the parent data product.
Instance Attribute Summary collapse
-
#iam_roles ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataAssetAccessGroupConfig
constructor
A new instance of GoogleCloudDataplexV1DataAssetAccessGroupConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataAssetAccessGroupConfig
Returns a new instance of GoogleCloudDataplexV1DataAssetAccessGroupConfig.
1777 1778 1779 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1777 def initialize(**args) update!(**args) end |
Instance Attribute Details
#iam_roles ⇒ Array<String>
Optional. IAM roles granted on the resource to this access group. Role name
follows https://cloud.google.com/iam/docs/reference/rest/v1/roles.Example: [ "
roles/bigquery.dataViewer" ]
Corresponds to the JSON property iamRoles
1775 1776 1777 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1775 def iam_roles @iam_roles end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1782 1783 1784 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1782 def update!(**args) @iam_roles = args[:iam_roles] if args.key?(:iam_roles) end |