Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataAttribute

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Denotes one dataAttribute in a dataTaxonomy, for example, PII. DataAttribute resources can be defined in a hierarchy. A single dataAttribute resource can contain specs of multiple types PII - ResourceAccessSpec : - readers :foo@bar. com - DataAccessSpec : - readers :bar@foo.com

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataAttribute

Returns a new instance of GoogleCloudDataplexV1DataAttribute.



1921
1922
1923
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1921

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attribute_countFixnum

Output only. The number of child attributes present for this attribute. Corresponds to the JSON property attributeCount

Returns:

  • (Fixnum)


1850
1851
1852
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1850

def attribute_count
  @attribute_count
end

#create_timeString

Output only. The time when the DataAttribute was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1855
1856
1857
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1855

def create_time
  @create_time
end

#data_access_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataAccessSpec

DataAccessSpec holds the access control configuration to be enforced on data stored within resources (eg: rows, columns in BigQuery Tables). When associated with data, the data is only accessible to principals explicitly granted access through the DataAccessSpec. Principals with access to the containing resource are not implicitly granted access. Corresponds to the JSON property dataAccessSpec



1864
1865
1866
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1864

def data_access_spec
  @data_access_spec
end

#descriptionString

Optional. Description of the DataAttribute. Corresponds to the JSON property description

Returns:

  • (String)


1869
1870
1871
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1869

def description
  @description
end

#display_nameString

Optional. User friendly display name. Corresponds to the JSON property displayName

Returns:

  • (String)


1874
1875
1876
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1874

def display_name
  @display_name
end

#etagString

This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up- to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


1881
1882
1883
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1881

def etag
  @etag
end

#labelsHash<String,String>

Optional. User-defined labels for the DataAttribute. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1886
1887
1888
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1886

def labels
  @labels
end

#nameString

Output only. The relative resource name of the dataAttribute, of the form: projects/project_number/locations/location_id/dataTaxonomies/dataTaxonomy /attributes/data_attribute_id. Corresponds to the JSON property name

Returns:

  • (String)


1893
1894
1895
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1893

def name
  @name
end

#parent_idString

Optional. The ID of the parent DataAttribute resource, should belong to the same data taxonomy. Circular dependency in parent chain is not valid. Maximum depth of the hierarchy allowed is 4. a -> b -> c -> d -> e, depth = 4 Corresponds to the JSON property parentId

Returns:

  • (String)


1900
1901
1902
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1900

def parent_id
  @parent_id
end

#resource_access_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1ResourceAccessSpec

ResourceAccessSpec holds the access control configuration to be enforced on the resources, for example, Cloud Storage bucket, BigQuery dataset, BigQuery table. Corresponds to the JSON property resourceAccessSpec



1907
1908
1909
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1907

def resource_access_spec
  @resource_access_spec
end

#uidString

Output only. System generated globally unique ID for the DataAttribute. This ID will be different if the DataAttribute is deleted and re-created with the same name. Corresponds to the JSON property uid

Returns:

  • (String)


1914
1915
1916
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1914

def uid
  @uid
end

#update_timeString

Output only. The time when the DataAttribute was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1919
1920
1921
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1919

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1926

def update!(**args)
  @attribute_count = args[:attribute_count] if args.key?(:attribute_count)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_access_spec = args[:data_access_spec] if args.key?(:data_access_spec)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @parent_id = args[:parent_id] if args.key?(:parent_id)
  @resource_access_spec = args[:resource_access_spec] if args.key?(:resource_access_spec)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end