Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoveryResult
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoveryResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
The output of a data discovery scan.
Instance Attribute Summary collapse
-
#bigquery_publishing ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoveryResultBigQueryPublishing
Describes BigQuery publishing configurations.
-
#scan_statistics ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoveryResultScanStatistics
Describes result statistics of a data scan discovery job.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataDiscoveryResult
constructor
A new instance of GoogleCloudDataplexV1DataDiscoveryResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataDiscoveryResult
Returns a new instance of GoogleCloudDataplexV1DataDiscoveryResult.
2027 2028 2029 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2027 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery_publishing ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoveryResultBigQueryPublishing
Describes BigQuery publishing configurations.
Corresponds to the JSON property bigqueryPublishing
2020 2021 2022 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2020 def bigquery_publishing @bigquery_publishing end |
#scan_statistics ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoveryResultScanStatistics
Describes result statistics of a data scan discovery job.
Corresponds to the JSON property scanStatistics
2025 2026 2027 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2025 def scan_statistics @scan_statistics end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2032 2033 2034 2035 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2032 def update!(**args) @bigquery_publishing = args[:bigquery_publishing] if args.key?(:bigquery_publishing) @scan_statistics = args[:scan_statistics] if args.key?(:scan_statistics) end |