Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoverySpecBigQueryPublishingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Describes BigQuery publishing configurations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataDiscoverySpecBigQueryPublishingConfig

Returns a new instance of GoogleCloudDataplexV1DataDiscoverySpecBigQueryPublishingConfig.



2266
2267
2268
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2266

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connectionString

Optional. The BigQuery connection used to create BigLake tables. Must be in the form projects/project_id/locations/location_id/connections/ connection_id Corresponds to the JSON property connection

Returns:

  • (String)


2231
2232
2233
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2231

def connection
  @connection
end

#locationString

Optional. The location of the BigQuery dataset to publish BigLake external or non-BigLake external tables to. 1. If the Cloud Storage bucket is located in a multi-region bucket, then BigQuery dataset can be in the same multi-region bucket or any single region that is included in the same multi-region bucket. The datascan can be created in any single region that is included in the same multi-region bucket 2. If the Cloud Storage bucket is located in a dual-region bucket, then BigQuery dataset can be located in regions that are included in the dual-region bucket, or in a multi-region that includes the dual-region. The datascan can be created in any single region that is included in the same dual-region bucket. 3. If the Cloud Storage bucket is located in a single region, then BigQuery dataset can be in the same single region or any multi- region bucket that includes the same single region. The datascan will be created in the same single region as the bucket. 4. If the BigQuery dataset is in single region, it must be in the same single region as the datascan.For supported values, refer to https://cloud.google.com/bigquery/docs/locations# supported_locations. Corresponds to the JSON property location

Returns:

  • (String)


2251
2252
2253
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2251

def location
  @location
end

#projectString

Optional. The project of the BigQuery dataset to publish BigLake external or non-BigLake external tables to. If not specified, the project of the Cloud Storage bucket will be used. The format is "projects/project_id_or_number". Corresponds to the JSON property project

Returns:

  • (String)


2258
2259
2260
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2258

def project
  @project
end

#table_typeString

Optional. Determines whether to publish discovered tables as BigLake external tables or non-BigLake external tables. Corresponds to the JSON property tableType

Returns:

  • (String)


2264
2265
2266
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2264

def table_type
  @table_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2271
2272
2273
2274
2275
2276
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2271

def update!(**args)
  @connection = args[:connection] if args.key?(:connection)
  @location = args[:location] if args.key?(:location)
  @project = args[:project] if args.key?(:project)
  @table_type = args[:table_type] if args.key?(:table_type)
end