Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoverySpecStorageConfigCsvOptions
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoverySpecStorageConfigCsvOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Describes CSV and similar semi-structured data formats.
Instance Attribute Summary collapse
-
#delimiter ⇒ String
Optional.
-
#encoding ⇒ String
Optional.
-
#header_rows ⇒ Fixnum
Optional.
-
#quote ⇒ String
Optional.
-
#type_inference_disabled ⇒ Boolean
(also: #type_inference_disabled?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataDiscoverySpecStorageConfigCsvOptions
constructor
A new instance of GoogleCloudDataplexV1DataDiscoverySpecStorageConfigCsvOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataDiscoverySpecStorageConfigCsvOptions
Returns a new instance of GoogleCloudDataplexV1DataDiscoverySpecStorageConfigCsvOptions.
2351 2352 2353 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2351 def initialize(**args) update!(**args) end |
Instance Attribute Details
#delimiter ⇒ String
Optional. The delimiter that is used to separate values. The default is , (
comma).
Corresponds to the JSON property delimiter
2324 2325 2326 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2324 def delimiter @delimiter end |
#encoding ⇒ String
Optional. The character encoding of the data. The default is UTF-8.
Corresponds to the JSON property encoding
2329 2330 2331 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2329 def encoding @encoding end |
#header_rows ⇒ Fixnum
Optional. The number of rows to interpret as header rows that should be
skipped when reading data rows.
Corresponds to the JSON property headerRows
2335 2336 2337 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2335 def header_rows @header_rows end |
#quote ⇒ String
Optional. The character used to quote column values. Accepts " (double
quotation mark) or ' (single quotation mark). If unspecified, defaults to " (
double quotation mark).
Corresponds to the JSON property quote
2342 2343 2344 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2342 def quote @quote end |
#type_inference_disabled ⇒ Boolean Also known as: type_inference_disabled?
Optional. Whether to disable the inference of data types for CSV data. If true,
all columns are registered as strings.
Corresponds to the JSON property typeInferenceDisabled
2348 2349 2350 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2348 def type_inference_disabled @type_inference_disabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2356 2357 2358 2359 2360 2361 2362 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2356 def update!(**args) @delimiter = args[:delimiter] if args.key?(:delimiter) @encoding = args[:encoding] if args.key?(:encoding) @header_rows = args[:header_rows] if args.key?(:header_rows) @quote = args[:quote] if args.key?(:quote) @type_inference_disabled = args[:type_inference_disabled] if args.key?(:type_inference_disabled) end |