Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoverySpecStorageConfigJsonOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Describes JSON data format.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataDiscoverySpecStorageConfigJsonOptions

Returns a new instance of GoogleCloudDataplexV1DataDiscoverySpecStorageConfigJsonOptions.



2396
2397
2398
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2396

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encodingString

Optional. The character encoding of the data. The default is UTF-8. Corresponds to the JSON property encoding

Returns:

  • (String)


2386
2387
2388
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2386

def encoding
  @encoding
end

#type_inference_disabledBoolean Also known as: type_inference_disabled?

Optional. Whether to disable the inference of data types for JSON data. If true, all columns are registered as their primitive types (strings, number, or boolean). Corresponds to the JSON property typeInferenceDisabled

Returns:

  • (Boolean)


2393
2394
2395
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2393

def type_inference_disabled
  @type_inference_disabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2401
2402
2403
2404
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2401

def update!(**args)
  @encoding = args[:encoding] if args.key?(:encoding)
  @type_inference_disabled = args[:type_inference_disabled] if args.key?(:type_inference_disabled)
end