Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResultSchemaRelationship

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Details of the relationship between the schema of two resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataDocumentationResultSchemaRelationship

Returns a new instance of GoogleCloudDataplexV1DataDocumentationResultSchemaRelationship.



2577
2578
2579
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2577

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#left_schema_pathsGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResultSchemaRelationshipSchemaPaths

Represents an ordered set of paths within a table's schema. Corresponds to the JSON property leftSchemaPaths



2560
2561
2562
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2560

def left_schema_paths
  @left_schema_paths
end

#right_schema_pathsGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResultSchemaRelationshipSchemaPaths

Represents an ordered set of paths within a table's schema. Corresponds to the JSON property rightSchemaPaths



2565
2566
2567
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2565

def right_schema_paths
  @right_schema_paths
end

#sourcesArray<String>

Output only. Sources which generated the schema relation edge. Corresponds to the JSON property sources

Returns:

  • (Array<String>)


2570
2571
2572
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2570

def sources
  @sources
end

#typeString

Output only. The type of relationship between the schema paths. Corresponds to the JSON property type

Returns:

  • (String)


2575
2576
2577
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2575

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2582
2583
2584
2585
2586
2587
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2582

def update!(**args)
  @left_schema_paths = args[:left_schema_paths] if args.key?(:left_schema_paths)
  @right_schema_paths = args[:right_schema_paths] if args.key?(:right_schema_paths)
  @sources = args[:sources] if args.key?(:sources)
  @type = args[:type] if args.key?(:type)
end