Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResultSchemaRelationshipSchemaPaths

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Represents an ordered set of paths within a table's schema.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataDocumentationResultSchemaRelationshipSchemaPaths

Returns a new instance of GoogleCloudDataplexV1DataDocumentationResultSchemaRelationshipSchemaPaths.



2609
2610
2611
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2609

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pathsArray<String>

Output only. An ordered set of Paths to fields within the schema of the table. For fields nested within a top level field of type record, use '.' to separate field names. Examples: Top level field - top_level Nested field - top_level. child.sub_field Corresponds to the JSON property paths

Returns:

  • (Array<String>)


2600
2601
2602
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2600

def paths
  @paths
end

#table_fqnString

Output only. The service-qualified full resource name of the table Ex: // bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/ TABLE_ID Corresponds to the JSON property tableFqn

Returns:

  • (String)


2607
2608
2609
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2607

def table_fqn
  @table_fqn
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2614
2615
2616
2617
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2614

def update!(**args)
  @paths = args[:paths] if args.key?(:paths)
  @table_fqn = args[:table_fqn] if args.key?(:table_fqn)
end