Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResultTableResult
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResultTableResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Insights for a table resource.
Instance Attribute Summary collapse
-
#name ⇒ String
Output only.
-
#overview ⇒ String
Output only.
-
#queries ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResultQuery>
Output only.
-
#schema ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResultSchema
Schema of the table with generated metadata of columns.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataDocumentationResultTableResult
constructor
A new instance of GoogleCloudDataplexV1DataDocumentationResultTableResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataDocumentationResultTableResult
Returns a new instance of GoogleCloudDataplexV1DataDocumentationResultTableResult.
2586 2587 2588 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2586 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Output only. The service-qualified full resource name of the cloud resource.
Ex: //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/
TABLE_ID
Corresponds to the JSON property name
2569 2570 2571 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2569 def name @name end |
#overview ⇒ String
Output only. Generated description of the table.
Corresponds to the JSON property overview
2574 2575 2576 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2574 def overview @overview end |
#queries ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResultQuery>
Output only. Sample SQL queries for the table.
Corresponds to the JSON property queries
2579 2580 2581 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2579 def queries @queries end |
#schema ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResultSchema
Schema of the table with generated metadata of columns.
Corresponds to the JSON property schema
2584 2585 2586 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2584 def schema @schema end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2591 2592 2593 2594 2595 2596 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2591 def update!(**args) @name = args[:name] if args.key?(:name) @overview = args[:overview] if args.key?(:overview) @queries = args[:queries] if args.key?(:queries) @schema = args[:schema] if args.key?(:schema) end |