Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationSpec
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
DataDocumentation scan related spec.
Instance Attribute Summary collapse
-
#catalog_publishing_enabled ⇒ Boolean
(also: #catalog_publishing_enabled?)
Optional.
-
#generation_scopes ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataDocumentationSpec
constructor
A new instance of GoogleCloudDataplexV1DataDocumentationSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataDocumentationSpec
Returns a new instance of GoogleCloudDataplexV1DataDocumentationSpec.
2691 2692 2693 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2691 def initialize(**args) update!(**args) end |
Instance Attribute Details
#catalog_publishing_enabled ⇒ Boolean Also known as: catalog_publishing_enabled?
Optional. Whether to publish result to Dataplex Catalog.
Corresponds to the JSON property catalogPublishingEnabled
2680 2681 2682 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2680 def catalog_publishing_enabled @catalog_publishing_enabled end |
#generation_scopes ⇒ Array<String>
Optional. Specifies which components of the data documentation to generate.
Any component that is required to generate the specified components will also
be generated. If no generation scope is specified, all available documentation
components will be generated.
Corresponds to the JSON property generationScopes
2689 2690 2691 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2689 def generation_scopes @generation_scopes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2696 2697 2698 2699 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2696 def update!(**args) @catalog_publishing_enabled = args[:catalog_publishing_enabled] if args.key?(:catalog_publishing_enabled) @generation_scopes = args[:generation_scopes] if args.key?(:generation_scopes) end |