Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDomain

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

A DataDomain is a logical grouping of data resources for governance, discovery, and management at scale.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataDomain

Returns a new instance of GoogleCloudDataplexV1DataDomain.



2764
2765
2766
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2764

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contactsGoogle::Apis::DataplexV1::GoogleCloudDataplexV1Contacts

Business contacts part of business context of a Data Domain. Corresponds to the Contacts Aspect in Dataplex Universal Catalog. Corresponds to the JSON property contacts



2711
2712
2713
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2711

def contacts
  @contacts
end

#create_timeString

Output only. The time at which the DataDomain was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2716
2717
2718
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2716

def create_time
  @create_time
end

#descriptionString

Optional. User-provided description of the DataDomain. Corresponds to the JSON property description

Returns:

  • (String)


2721
2722
2723
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2721

def description
  @description
end

#display_nameString

Required. User-friendly display name. Corresponds to the JSON property displayName

Returns:

  • (String)


2726
2727
2728
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2726

def display_name
  @display_name
end

#labelsHash<String,String>

Optional. User-defined labels for the DataDomain. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2731
2732
2733
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2731

def labels
  @labels
end

#nameString

Identifier. The relative resource name of the DataDomain, of the form: projects/project_id_or_number/locations/location_id/dataDomains/ data_domain_id Corresponds to the JSON property name

Returns:

  • (String)


2738
2739
2740
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2738

def name
  @name
end

#parent_data_domainString

Optional. Immutable. The resource name of the parent DataDomain. Empty if this is a top-level DataDomain. Format: projects/project_id_or_number/locations/ location/dataDomains/parent_data_domain_id This field is immutable after creation. Corresponds to the JSON property parentDataDomain

Returns:

  • (String)


2746
2747
2748
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2746

def parent_data_domain
  @parent_data_domain
end

#policy_memberGoogle::Apis::DataplexV1::GoogleIamV1ResourcePolicyMember

Output-only policy member strings of a Google Cloud resource's built-in identity. Corresponds to the JSON property policyMember



2752
2753
2754
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2752

def policy_member
  @policy_member
end

#uidString

Output only. System-generated globally unique ID for the DataDomain. Corresponds to the JSON property uid

Returns:

  • (String)


2757
2758
2759
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2757

def uid
  @uid
end

#update_timeString

Output only. The time at which the DataDomain was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2762
2763
2764
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2762

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2769
2770
2771
2772
2773
2774
2775
2776
2777
2778
2779
2780
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2769

def update!(**args)
  @contacts = args[:contacts] if args.key?(:contacts)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @parent_data_domain = args[:parent_data_domain] if args.key?(:parent_data_domain)
  @policy_member = args[:policy_member] if args.key?(:policy_member)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end