Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDomainBinding
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDomainBinding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
DataDomainBinding represents a rule that includes a Google Cloud resource and its contents into a DataDomain.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#resource ⇒ String
Required.
-
#uid ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataDomainBinding
constructor
A new instance of GoogleCloudDataplexV1DataDomainBinding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataDomainBinding
Returns a new instance of GoogleCloudDataplexV1DataDomainBinding.
2824 2825 2826 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2824 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which the DataDomainBinding was created.
Corresponds to the JSON property createTime
2791 2792 2793 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2791 def create_time @create_time end |
#name ⇒ String
Identifier. The relative resource name of the DataDomainBinding. Format:
projects/project_id_or_number/locations/location/dataDomains/
data_domain_id/bindings/binding_id
Corresponds to the JSON property name
2798 2799 2800 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2798 def name @name end |
#resource ⇒ String
Required. Immutable. The full resource name of the Google Cloud resource to be
bound (i.e. included together with its contents) to the DataDomain.Format: IAM
Full resource name (https://docs.cloud.google.com/iam/docs/full-resource-names)
Examples: - GCP Project: //cloudresourcemanager.googleapis.com/projects/
project-id - BigQuery Dataset: //bigquery.googleapis.com/projects/project-id
/datasets/dataset-id - BigQuery Table: //bigquery.googleapis.com/projects/
project-id/datasets/dataset-id/tables/table-id - Dataplex Data Product: //
dataplex.googleapis.com/projects/project-number/locations/location/
dataProducts/data-product-idAuthorization: the resource to be bound must
first grant an IAM role with the resource-specific setIamPolicy permission to
the DataDomain. Example: - resource: //bigquery.googleapis.com/projects/
project-id/datasets/dataset-id - IAM role: with bigquery.datasets.
setIamPolicy permission (e.g. roles/owner) - IAM member: principal://dataplex.
googleapis.com/projects/project-number/name/locations/location/dataDomains/
data-domain-id
Corresponds to the JSON property resource
2817 2818 2819 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2817 def resource @resource end |
#uid ⇒ String
Output only. System-generated unique ID.
Corresponds to the JSON property uid
2822 2823 2824 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2822 def uid @uid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2829 2830 2831 2832 2833 2834 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2829 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @name = args[:name] if args.key?(:name) @resource = args[:resource] if args.key?(:resource) @uid = args[:uid] if args.key?(:uid) end |