Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProductAccessRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Message for requesting access to a Data Product. This will be used to create a ChangeRequest of type REQUEST_DATA_PRODUCT_ACCESS.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataProductAccessRequest

Returns a new instance of GoogleCloudDataplexV1DataProductAccessRequest.



3040
3041
3042
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3040

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_group_display_nameString

Output only. The display name of the access group defined in the Data Product for which access is being requested. Corresponds to the JSON property accessGroupDisplayName

Returns:

  • (String)


3017
3018
3019
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3017

def access_group_display_name
  @access_group_display_name
end

#access_group_idString

Required. The ID of the access group for which access is being requested. This corresponds to the unique identifier of the AccessGroup defined in the Data Product. Corresponds to the JSON property accessGroupId

Returns:

  • (String)


3024
3025
3026
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3024

def access_group_id
  @access_group_id
end

#parentString

Required. The resource name of the data product. Format: projects/ project_number/locations/location_id/dataProducts/data_product_id Corresponds to the JSON property parent

Returns:

  • (String)


3030
3031
3032
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3030

def parent
  @parent
end

#requested_principalString

Optional. The principal for which access is being requested in IAM format. If not specified, the requestor's principal will be used. Example: serviceAccount: my-sa@my-project.iam.gserviceaccount.com. Only service account principals are currently supported. https://cloud.google.com/iam/docs/principal-identifiers Corresponds to the JSON property requestedPrincipal

Returns:

  • (String)


3038
3039
3040
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3038

def requested_principal
  @requested_principal
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3045
3046
3047
3048
3049
3050
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3045

def update!(**args)
  @access_group_display_name = args[:access_group_display_name] if args.key?(:access_group_display_name)
  @access_group_id = args[:access_group_id] if args.key?(:access_group_id)
  @parent = args[:parent] if args.key?(:parent)
  @requested_principal = args[:requested_principal] if args.key?(:requested_principal)
end