Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Contains name, type, mode and field type specific profile information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataProfileResultProfile

Returns a new instance of GoogleCloudDataplexV1DataProfileResultProfile.



2160
2161
2162
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2160

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fieldsArray<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfileField>

Output only. List of fields with structural and profile information for each field. Corresponds to the JSON property fields



2158
2159
2160
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2158

def fields
  @fields
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2165
2166
2167
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2165

def update!(**args)
  @fields = args[:fields] if args.key?(:fields)
end