Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfileField

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

A field within a table.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataProfileResultProfileField

Returns a new instance of GoogleCloudDataplexV1DataProfileResultProfileField.



3221
3222
3223
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3221

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#modeString

Output only. The mode of the field. Possible values include: REQUIRED, if it is a required field. NULLABLE, if it is an optional field. REPEATED, if it is a repeated field. Corresponds to the JSON property mode

Returns:

  • (String)


3200
3201
3202
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3200

def mode
  @mode
end

#nameString

Output only. The name of the field. Corresponds to the JSON property name

Returns:

  • (String)


3205
3206
3207
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3205

def name
  @name
end

#profileGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfo

The profile information for each field type. Corresponds to the JSON property profile



3210
3211
3212
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3210

def profile
  @profile
end

#typeString

Output only. The data type retrieved from the schema of the data source. For instance, for a BigQuery native table, it is the BigQuery Table Schema (https:/ /cloud.google.com/bigquery/docs/reference/rest/v2/tables#tablefieldschema). For a Dataplex Universal Catalog Entity, it is the Entity Schema (https:// cloud.google.com/dataplex/docs/reference/rpc/google.cloud.dataplex.v1#type_3). Corresponds to the JSON property type

Returns:

  • (String)


3219
3220
3221
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3219

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3226
3227
3228
3229
3230
3231
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3226

def update!(**args)
  @mode = args[:mode] if args.key?(:mode)
  @name = args[:name] if args.key?(:name)
  @profile = args[:profile] if args.key?(:profile)
  @type = args[:type] if args.key?(:type)
end