Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoTopNValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Top N non-null values in the scanned data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoTopNValue

Returns a new instance of GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoTopNValue.



3438
3439
3440
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3438

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

Output only. Count of the corresponding value in the scanned data. Corresponds to the JSON property count

Returns:

  • (Fixnum)


3425
3426
3427
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3425

def count
  @count
end

#ratioFloat

Output only. Ratio of the corresponding value in the field against the total number of rows in the scanned data. Corresponds to the JSON property ratio

Returns:

  • (Float)


3431
3432
3433
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3431

def ratio
  @ratio
end

#valueString

Output only. String value of a top N non-null value. Corresponds to the JSON property value

Returns:

  • (String)


3436
3437
3438
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3436

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3443
3444
3445
3446
3447
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3443

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @ratio = args[:ratio] if args.key?(:ratio)
  @value = args[:value] if args.key?(:value)
end