Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

DataProfileScan related setting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataProfileSpec

Returns a new instance of GoogleCloudDataplexV1DataProfileSpec.



3510
3511
3512
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3510

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#catalog_publishing_enabledBoolean Also known as: catalog_publishing_enabled?

Optional. If set, the latest DataScan job result will be published as Dataplex Universal Catalog metadata. Corresponds to the JSON property catalogPublishingEnabled

Returns:

  • (Boolean)


3472
3473
3474
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3472

def catalog_publishing_enabled
  @catalog_publishing_enabled
end

#exclude_fieldsGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileSpecSelectedFields

The specification for fields to include or exclude in data profile scan. Corresponds to the JSON property excludeFields



3478
3479
3480
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3478

def exclude_fields
  @exclude_fields
end

#include_fieldsGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileSpecSelectedFields

The specification for fields to include or exclude in data profile scan. Corresponds to the JSON property includeFields



3483
3484
3485
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3483

def include_fields
  @include_fields
end

#modeString

Optional. The execution mode for the profile scan. Corresponds to the JSON property mode

Returns:

  • (String)


3488
3489
3490
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3488

def mode
  @mode
end

#post_scan_actionsGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileSpecPostScanActions

The configuration of post scan actions of DataProfileScan job. Corresponds to the JSON property postScanActions



3493
3494
3495
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3493

def post_scan_actions
  @post_scan_actions
end

#row_filterString

Optional. A filter applied to all rows in a single DataScan job. The filter needs to be a valid SQL expression for a WHERE clause in BigQuery standard SQL syntax. Example: col1 >= 0 AND col2 < 10 Corresponds to the JSON property rowFilter

Returns:

  • (String)


3500
3501
3502
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3500

def row_filter
  @row_filter
end

#sampling_percentFloat

Optional. The percentage of the records to be selected from the dataset for DataScan. Value can range between 0.0 and 100.0 with up to 3 significant decimal digits. Sampling is not applied if sampling_percent is not specified, 0 or 100. Corresponds to the JSON property samplingPercent

Returns:

  • (Float)


3508
3509
3510
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3508

def sampling_percent
  @sampling_percent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3515
3516
3517
3518
3519
3520
3521
3522
3523
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3515

def update!(**args)
  @catalog_publishing_enabled = args[:catalog_publishing_enabled] if args.key?(:catalog_publishing_enabled)
  @exclude_fields = args[:exclude_fields] if args.key?(:exclude_fields)
  @include_fields = args[:include_fields] if args.key?(:include_fields)
  @mode = args[:mode] if args.key?(:mode)
  @post_scan_actions = args[:post_scan_actions] if args.key?(:post_scan_actions)
  @row_filter = args[:row_filter] if args.key?(:row_filter)
  @sampling_percent = args[:sampling_percent] if args.key?(:sampling_percent)
end