Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityResultAnomalyDetectionGeneratedAssets

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

The assets generated by Anomaly Detection Data Scan.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityResultAnomalyDetectionGeneratedAssets

Returns a new instance of GoogleCloudDataplexV1DataQualityResultAnomalyDetectionGeneratedAssets.



3783
3784
3785
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3783

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_intermediate_tableString

Output only. The intermediate table for data anomaly detection. Format: PROJECT_ID.DATASET_ID.TABLE_ID Corresponds to the JSON property dataIntermediateTable

Returns:

  • (String)


3761
3762
3763
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3761

def data_intermediate_table
  @data_intermediate_table
end

#freshness_intermediate_tableString

Output only. The intermediate table for freshness anomaly detection. Format: PROJECT_ID.DATASET_ID.TABLE_ID Corresponds to the JSON property freshnessIntermediateTable

Returns:

  • (String)


3767
3768
3769
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3767

def freshness_intermediate_table
  @freshness_intermediate_table
end

#result_tableString

Output only. The result table for anomaly detection. Format: PROJECT_ID. DATASET_ID.TABLE_ID If the result table is set at AnomalyDetectionAssets, the result table here would be the same as the one set in the AnomalyDetectionAssets.result_table. Corresponds to the JSON property resultTable

Returns:

  • (String)


3775
3776
3777
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3775

def result_table
  @result_table
end

#volume_intermediate_tableString

Output only. The intermediate table for volume anomaly detection. Format: PROJECT_ID.DATASET_ID.TABLE_ID Corresponds to the JSON property volumeIntermediateTable

Returns:

  • (String)


3781
3782
3783
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3781

def volume_intermediate_table
  @volume_intermediate_table
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3788
3789
3790
3791
3792
3793
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3788

def update!(**args)
  @data_intermediate_table = args[:data_intermediate_table] if args.key?(:data_intermediate_table)
  @freshness_intermediate_table = args[:freshness_intermediate_table] if args.key?(:freshness_intermediate_table)
  @result_table = args[:result_table] if args.key?(:result_table)
  @volume_intermediate_table = args[:volume_intermediate_table] if args.key?(:volume_intermediate_table)
end