Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleDebugQuery
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleDebugQuery
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Specifies a SQL statement that is evaluated to return up to 10 scalar values
that are used to debug rules. If the rule fails, the values can help diagnose
the cause of the failure.The SQL statement must use GoogleSQL syntax (https://
cloud.google.com/bigquery/docs/reference/standard-sql/query-syntax), and must
not contain any semicolons.You can use the data reference parameter $data()
to reference the source table with all of its precondition filters applied.
Examples of precondition filters include row filters, incremental data filters,
and sampling. For more information, see Data reference parameter (https://
cloud.google.com/dataplex/docs/auto-data-quality-overview#data-reference-
parameter).You can also name results with an explicit alias using [AS] alias.
For more information, see BigQuery explicit aliases (https://docs.cloud.google.
com/bigquery/docs/reference/standard-sql/query-syntax#explicit_alias_syntax).
Example: SELECT MIN(col1) AS min_col1, MAX(col1) AS max_col1 FROM $data()
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#sql_statement ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityRuleDebugQuery
constructor
A new instance of GoogleCloudDataplexV1DataQualityRuleDebugQuery.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityRuleDebugQuery
Returns a new instance of GoogleCloudDataplexV1DataQualityRuleDebugQuery.
4046 4047 4048 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4046 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. Specifies the description of the debug query. The maximum length is
1,024 characters.
Corresponds to the JSON property description
4039 4040 4041 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4039 def description @description end |
#sql_statement ⇒ String
Required. Specifies the SQL statement to be executed.
Corresponds to the JSON property sqlStatement
4044 4045 4046 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4044 def sql_statement @sql_statement end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4051 4052 4053 4054 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4051 def update!(**args) @description = args[:description] if args.key?(:description) @sql_statement = args[:sql_statement] if args.key?(:sql_statement) end |