Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleResultDebugQueryResult
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleResultDebugQueryResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Contains a single result from the debug query.
Instance Attribute Summary collapse
-
#name ⇒ String
Specifies the name of the result.
-
#type ⇒ String
Indicates the data type of the result.
-
#value ⇒ String
Represents the value of the result as a string.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityRuleResultDebugQueryResult
constructor
A new instance of GoogleCloudDataplexV1DataQualityRuleResultDebugQueryResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityRuleResultDebugQueryResult
Returns a new instance of GoogleCloudDataplexV1DataQualityRuleResultDebugQueryResult.
4234 4235 4236 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4234 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Specifies the name of the result. Available if provided with an explicit alias
using [AS] alias.
Corresponds to the JSON property name
4220 4221 4222 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4220 def name @name end |
#type ⇒ String
Indicates the data type of the result. For more information, see BigQuery data
types (https://cloud.google.com/bigquery/docs/reference/standard-sql/data-
types).
Corresponds to the JSON property type
4227 4228 4229 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4227 def type @type end |
#value ⇒ String
Represents the value of the result as a string.
Corresponds to the JSON property value
4232 4233 4234 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4232 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4239 4240 4241 4242 4243 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4239 def update!(**args) @name = args[:name] if args.key?(:name) @type = args[:type] if args.key?(:type) @value = args[:value] if args.key?(:value) end |