Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleRuleSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Represents the rule source information from Catalog.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityRuleRuleSource

Returns a new instance of GoogleCloudDataplexV1DataQualityRuleRuleSource.



4298
4299
4300
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4298

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#rule_path_elementsArray<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleRuleSourceRulePathElement>

Output only. Rule path elements represent information about the individual items in the relationship path between the scan resource and rule origin in that order. Corresponds to the JSON property rulePathElements



4296
4297
4298
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4296

def rule_path_elements
  @rule_path_elements
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4303
4304
4305
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4303

def update!(**args)
  @rule_path_elements = args[:rule_path_elements] if args.key?(:rule_path_elements)
end