Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleRuleSourceRulePathElementEntryLinkSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Entry link source represents information about the entry link.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityRuleRuleSourceRulePathElementEntryLinkSource

Returns a new instance of GoogleCloudDataplexV1DataQualityRuleRuleSourceRulePathElementEntryLinkSource.



4147
4148
4149
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4147

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entry_linkString

Output only. The entry link name in the form of: projects/ project_id_or_number/locations/location_id/entryGroups/entry_group_id/ entryLinks/entry_link_id Corresponds to the JSON property entryLink

Returns:

  • (String)


4137
4138
4139
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4137

def entry_link
  @entry_link
end

#entry_link_typeString

Output only. The entry link type to represent the current relationship between the entry and the next entry in the path. In the form of: projects/ project_id_or_number/locations/location_id/entryLinkTypes/ entry_link_type_id Corresponds to the JSON property entryLinkType

Returns:

  • (String)


4145
4146
4147
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4145

def entry_link_type
  @entry_link_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4152
4153
4154
4155
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4152

def update!(**args)
  @entry_link = args[:entry_link] if args.key?(:entry_link)
  @entry_link_type = args[:entry_link_type] if args.key?(:entry_link_type)
end