Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleTemplateParameterDescription

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Description of the input parameter. It can include the type(s) supported by the parameter and intended usage. It is for information purposes only and does not affect the behavior of the rule template.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityRuleTemplateParameterDescription

Returns a new instance of GoogleCloudDataplexV1DataQualityRuleTemplateParameterDescription.



4588
4589
4590
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4588

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_valueString

Output only. The default value for the parameter if no value is provided. Corresponds to the JSON property defaultValue

Returns:

  • (String)


4579
4580
4581
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4579

def default_value
  @default_value
end

#descriptionString

Output only. Description of the input parameter. It can include the type(s) supported by the parameter and intended usage. It is for information purposes only and does not affect the behavior of the rule template. Corresponds to the JSON property description

Returns:

  • (String)


4586
4587
4588
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4586

def description
  @description
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4593
4594
4595
4596
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4593

def update!(**args)
  @default_value = args[:default_value] if args.key?(:default_value)
  @description = args[:description] if args.key?(:description)
end