Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleTemplateReference

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

A rule that constructs a SQL statement to evaluate using a rule template and parameter values. If the constructed statement returns any rows, this rule fails

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityRuleTemplateReference

Returns a new instance of GoogleCloudDataplexV1DataQualityRuleTemplateReference.



4619
4620
4621
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4619

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Required. The template entry name. Entry must be of EntryType projects/ dataplex-types/locations/global/entryTypes/data-quality-rule-template and contains top-level aspect of AspectType projects/dataplex-types/locations/ global/aspectTypes/data-quality-rule-template. The format is: projects/ project_id_or_number/locations/location_id/entryGroups/entry_group_id/ entries/entry_id Corresponds to the JSON property name

Returns:

  • (String)


4599
4600
4601
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4599

def name
  @name
end

#resolved_sqlString

Output only. The resolved SQL statement generated from the template with parameters substituted. It is only populated in the result. Corresponds to the JSON property resolvedSql

Returns:

  • (String)


4605
4606
4607
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4605

def resolved_sql
  @resolved_sql
end

#rule_templateGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleTemplate

DataQualityRuleTemplate represents a template which can be reused across multiple data quality rules. Corresponds to the JSON property ruleTemplate



4611
4612
4613
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4611

def rule_template
  @rule_template
end

#valuesHash<String,Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleTemplateReferenceParameterValue>

Optional. Provides the map of parameter name and value. The maximum size of the field is 120KB (encoded as UTF-8). Corresponds to the JSON property values



4617
4618
4619
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4617

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4624
4625
4626
4627
4628
4629
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4624

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @resolved_sql = args[:resolved_sql] if args.key?(:resolved_sql)
  @rule_template = args[:rule_template] if args.key?(:rule_template)
  @values = args[:values] if args.key?(:values)
end