Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityScanRuleResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Information about the result of a data quality rule for data quality scan. The monitored resource is 'DataScan'.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityScanRuleResult

Returns a new instance of GoogleCloudDataplexV1DataQualityScanRuleResult.



4757
4758
4759
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4757

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assertion_row_countFixnum

The number of rows returned by the SQL statement in a SQL assertion rule. This field is only valid for SQL assertion rules. Corresponds to the JSON property assertionRowCount

Returns:

  • (Fixnum)


4693
4694
4695
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4693

def assertion_row_count
  @assertion_row_count
end

#columnString

The column which this rule is evaluated against. Corresponds to the JSON property column

Returns:

  • (String)


4698
4699
4700
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4698

def column
  @column
end

#data_sourceString

The data source of the data scan (e.g. BigQuery table name). Corresponds to the JSON property dataSource

Returns:

  • (String)


4703
4704
4705
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4703

def data_source
  @data_source
end

#evaluated_row_countFixnum

The number of rows evaluated against the data quality rule. This field is only valid for rules of PER_ROW evaluation type. Corresponds to the JSON property evaluatedRowCount

Returns:

  • (Fixnum)


4709
4710
4711
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4709

def evaluated_row_count
  @evaluated_row_count
end

#evalution_typeString

The evaluation type of the data quality rule. Corresponds to the JSON property evalutionType

Returns:

  • (String)


4714
4715
4716
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4714

def evalution_type
  @evalution_type
end

#job_idString

Identifier of the specific data scan job this log entry is for. Corresponds to the JSON property jobId

Returns:

  • (String)


4719
4720
4721
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4719

def job_id
  @job_id
end

#null_row_countFixnum

The number of rows with null values in the specified column. Corresponds to the JSON property nullRowCount

Returns:

  • (Fixnum)


4724
4725
4726
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4724

def null_row_count
  @null_row_count
end

#passed_row_countFixnum

The number of rows which passed a rule evaluation. This field is only valid for rules of PER_ROW evaluation type. Corresponds to the JSON property passedRowCount

Returns:

  • (Fixnum)


4730
4731
4732
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4730

def passed_row_count
  @passed_row_count
end

#resultString

The result of the data quality rule. Corresponds to the JSON property result

Returns:

  • (String)


4735
4736
4737
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4735

def result
  @result
end

#rule_dimensionString

The dimension of the data quality rule. Corresponds to the JSON property ruleDimension

Returns:

  • (String)


4740
4741
4742
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4740

def rule_dimension
  @rule_dimension
end

#rule_nameString

The name of the data quality rule. Corresponds to the JSON property ruleName

Returns:

  • (String)


4745
4746
4747
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4745

def rule_name
  @rule_name
end

#rule_typeString

The type of the data quality rule. Corresponds to the JSON property ruleType

Returns:

  • (String)


4750
4751
4752
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4750

def rule_type
  @rule_type
end

#threshold_percentFloat

The passing threshold (0.0, 100.0) of the data quality rule. Corresponds to the JSON property thresholdPercent

Returns:

  • (Float)


4755
4756
4757
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4755

def threshold_percent
  @threshold_percent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4762
4763
4764
4765
4766
4767
4768
4769
4770
4771
4772
4773
4774
4775
4776
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4762

def update!(**args)
  @assertion_row_count = args[:assertion_row_count] if args.key?(:assertion_row_count)
  @column = args[:column] if args.key?(:column)
  @data_source = args[:data_source] if args.key?(:data_source)
  @evaluated_row_count = args[:evaluated_row_count] if args.key?(:evaluated_row_count)
  @evalution_type = args[:evalution_type] if args.key?(:evalution_type)
  @job_id = args[:job_id] if args.key?(:job_id)
  @null_row_count = args[:null_row_count] if args.key?(:null_row_count)
  @passed_row_count = args[:passed_row_count] if args.key?(:passed_row_count)
  @result = args[:result] if args.key?(:result)
  @rule_dimension = args[:rule_dimension] if args.key?(:rule_dimension)
  @rule_name = args[:rule_name] if args.key?(:rule_name)
  @rule_type = args[:rule_type] if args.key?(:rule_type)
  @threshold_percent = args[:threshold_percent] if args.key?(:threshold_percent)
end