Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpecPostScanActionsNotificationReport
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpecPostScanActionsNotificationReport
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
The configuration of notification report post scan action.
Instance Attribute Summary collapse
-
#job_end_trigger ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpecPostScanActionsJobEndTrigger
This trigger is triggered whenever a scan job run ends, regardless of the result.
-
#job_failure_trigger ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpecPostScanActionsJobFailureTrigger
This trigger is triggered when the scan job itself fails, regardless of the result.
-
#recipients ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpecPostScanActionsRecipients
The individuals or groups who are designated to receive notifications upon triggers.
-
#score_threshold_trigger ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpecPostScanActionsScoreThresholdTrigger
This trigger is triggered when the DQ score in the job result is less than a specified input score.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualitySpecPostScanActionsNotificationReport
constructor
A new instance of GoogleCloudDataplexV1DataQualitySpecPostScanActionsNotificationReport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualitySpecPostScanActionsNotificationReport
Returns a new instance of GoogleCloudDataplexV1DataQualitySpecPostScanActionsNotificationReport.
4975 4976 4977 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4975 def initialize(**args) update!(**args) end |
Instance Attribute Details
#job_end_trigger ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpecPostScanActionsJobEndTrigger
This trigger is triggered whenever a scan job run ends, regardless of the
result.
Corresponds to the JSON property jobEndTrigger
4955 4956 4957 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4955 def job_end_trigger @job_end_trigger end |
#job_failure_trigger ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpecPostScanActionsJobFailureTrigger
This trigger is triggered when the scan job itself fails, regardless of the
result.
Corresponds to the JSON property jobFailureTrigger
4961 4962 4963 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4961 def job_failure_trigger @job_failure_trigger end |
#recipients ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpecPostScanActionsRecipients
The individuals or groups who are designated to receive notifications upon
triggers.
Corresponds to the JSON property recipients
4967 4968 4969 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4967 def recipients @recipients end |
#score_threshold_trigger ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpecPostScanActionsScoreThresholdTrigger
This trigger is triggered when the DQ score in the job result is less than a
specified input score.
Corresponds to the JSON property scoreThresholdTrigger
4973 4974 4975 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4973 def score_threshold_trigger @score_threshold_trigger end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4980 4981 4982 4983 4984 4985 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4980 def update!(**args) @job_end_trigger = args[:job_end_trigger] if args.key?(:job_end_trigger) @job_failure_trigger = args[:job_failure_trigger] if args.key?(:job_failure_trigger) @recipients = args[:recipients] if args.key?(:recipients) @score_threshold_trigger = args[:score_threshold_trigger] if args.key?(:score_threshold_trigger) end |