Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataQualityAppliedConfigs

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Applied configs for data quality type data scan job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataScanEventDataQualityAppliedConfigs

Returns a new instance of GoogleCloudDataplexV1DataScanEventDataQualityAppliedConfigs.



5410
5411
5412
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5410

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#row_filter_appliedBoolean Also known as: row_filter_applied?

Boolean indicating whether a row filter was applied in the DataScan job. Corresponds to the JSON property rowFilterApplied

Returns:

  • (Boolean)


5400
5401
5402
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5400

def row_filter_applied
  @row_filter_applied
end

#sampling_percentFloat

The percentage of the records selected from the dataset for DataScan. Value ranges between 0.0 and 100.0. Value 0.0 or 100.0 imply that sampling was not applied. Corresponds to the JSON property samplingPercent

Returns:

  • (Float)


5408
5409
5410
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5408

def sampling_percent
  @sampling_percent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5415
5416
5417
5418
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5415

def update!(**args)
  @row_filter_applied = args[:row_filter_applied] if args.key?(:row_filter_applied)
  @sampling_percent = args[:sampling_percent] if args.key?(:sampling_percent)
end