Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

A DataScanJob represents an instance of DataScan execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataScanJob

Returns a new instance of GoogleCloudDataplexV1DataScanJob.



5683
5684
5685
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5683

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time when the DataScanJob was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5587
5588
5589
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5587

def create_time
  @create_time
end

#data_discovery_resultGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoveryResult

The output of a data discovery scan. Corresponds to the JSON property dataDiscoveryResult



5592
5593
5594
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5592

def data_discovery_result
  @data_discovery_result
end

#data_discovery_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoverySpec

Spec for a data discovery scan. Corresponds to the JSON property dataDiscoverySpec



5597
5598
5599
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5597

def data_discovery_spec
  @data_discovery_spec
end

#data_documentation_resultGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResult

The output of a DataDocumentation scan. Corresponds to the JSON property dataDocumentationResult



5602
5603
5604
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5602

def data_documentation_result
  @data_documentation_result
end

#data_documentation_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationSpec

DataDocumentation scan related spec. Corresponds to the JSON property dataDocumentationSpec



5607
5608
5609
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5607

def data_documentation_spec
  @data_documentation_spec
end

#data_profile_resultGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResult

DataProfileResult defines the output of DataProfileScan. Each field of the table will have field type specific profile result. Corresponds to the JSON property dataProfileResult



5613
5614
5615
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5613

def data_profile_result
  @data_profile_result
end

#data_profile_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileSpec

DataProfileScan related setting. Corresponds to the JSON property dataProfileSpec



5618
5619
5620
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5618

def data_profile_spec
  @data_profile_spec
end

#data_quality_resultGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityResult

The output of a DataQualityScan. Corresponds to the JSON property dataQualityResult



5623
5624
5625
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5623

def data_quality_result
  @data_quality_result
end

#data_quality_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpec

DataQualityScan related setting. Corresponds to the JSON property dataQualitySpec



5628
5629
5630
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5628

def data_quality_spec
  @data_quality_spec
end

#end_timeString

Output only. The time when the DataScanJob ended. Corresponds to the JSON property endTime

Returns:

  • (String)


5633
5634
5635
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5633

def end_time
  @end_time
end

#messageString

Output only. Additional information about the current state. Corresponds to the JSON property message

Returns:

  • (String)


5638
5639
5640
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5638

def message
  @message
end

#nameString

Output only. Identifier. The relative resource name of the DataScanJob, of the form: projects/project/locations/location_id/dataScans/datascan_id/jobs/ job_id, where project refers to a project_id or project_number and location_id refers to a Google Cloud region. Corresponds to the JSON property name

Returns:

  • (String)


5646
5647
5648
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5646

def name
  @name
end

#partial_failure_messageString

Output only. A message indicating partial failure details. Corresponds to the JSON property partialFailureMessage

Returns:

  • (String)


5651
5652
5653
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5651

def partial_failure_message
  @partial_failure_message
end

#start_timeString

Output only. The time when the DataScanJob was started. Corresponds to the JSON property startTime

Returns:

  • (String)


5656
5657
5658
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5656

def start_time
  @start_time
end

#stateString

Output only. Execution state for the DataScanJob. Corresponds to the JSON property state

Returns:

  • (String)


5661
5662
5663
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5661

def state
  @state
end

#typeString

Output only. The type of the parent DataScan. Corresponds to the JSON property type

Returns:

  • (String)


5666
5667
5668
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5666

def type
  @type
end

#uidString

Output only. System generated globally unique ID for the DataScanJob. Corresponds to the JSON property uid

Returns:

  • (String)


5671
5672
5673
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5671

def uid
  @uid
end

#unstructured_data_profile_resultGoogle::Apis::DataplexV1::GoogleCloudDataplexV1UnstructuredDataProfileResult

Contains the result of an unstructured data profile scan. Corresponds to the JSON property unstructuredDataProfileResult



5676
5677
5678
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5676

def unstructured_data_profile_result
  @unstructured_data_profile_result
end

#unstructured_data_profile_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1UnstructuredDataProfileSpec

Contains the specification for an unstructured data profile scan. Corresponds to the JSON property unstructuredDataProfileSpec



5681
5682
5683
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5681

def unstructured_data_profile_spec
  @unstructured_data_profile_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5688
5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
5699
5700
5701
5702
5703
5704
5705
5706
5707
5708
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5688

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_discovery_result = args[:data_discovery_result] if args.key?(:data_discovery_result)
  @data_discovery_spec = args[:data_discovery_spec] if args.key?(:data_discovery_spec)
  @data_documentation_result = args[:data_documentation_result] if args.key?(:data_documentation_result)
  @data_documentation_spec = args[:data_documentation_spec] if args.key?(:data_documentation_spec)
  @data_profile_result = args[:data_profile_result] if args.key?(:data_profile_result)
  @data_profile_spec = args[:data_profile_spec] if args.key?(:data_profile_spec)
  @data_quality_result = args[:data_quality_result] if args.key?(:data_quality_result)
  @data_quality_spec = args[:data_quality_spec] if args.key?(:data_quality_spec)
  @end_time = args[:end_time] if args.key?(:end_time)
  @message = args[:message] if args.key?(:message)
  @name = args[:name] if args.key?(:name)
  @partial_failure_message = args[:partial_failure_message] if args.key?(:partial_failure_message)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
  @uid = args[:uid] if args.key?(:uid)
  @unstructured_data_profile_result = args[:unstructured_data_profile_result] if args.key?(:unstructured_data_profile_result)
  @unstructured_data_profile_spec = args[:unstructured_data_profile_spec] if args.key?(:unstructured_data_profile_spec)
end