Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

The data source for DataScan.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataSource

Returns a new instance of GoogleCloudDataplexV1DataSource.



4226
4227
4228
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4226

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entityString

Immutable. The Dataplex Universal Catalog entity that represents the data source (e.g. BigQuery table) for DataScan, of the form: projects/ project_number/locations/location_id/lakes/lake_id/zones/zone_id/ entities/entity_id. Corresponds to the JSON property entity

Returns:

  • (String)


4214
4215
4216
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4214

def entity
  @entity
end

#resourceString

Immutable. The service-qualified full resource name of the cloud resource for a DataScan job to scan against. The field could either be: Cloud Storage bucket for DataDiscoveryScan Format: //storage.googleapis.com/projects/ PROJECT_ID/buckets/BUCKET_ID or BigQuery table of type "TABLE" for DataProfileScan/DataQualityScan/DataDocumentationScan Format: //bigquery. googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID Corresponds to the JSON property resource

Returns:

  • (String)


4224
4225
4226
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4224

def resource
  @resource
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4231
4232
4233
4234
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4231

def update!(**args)
  @entity = args[:entity] if args.key?(:entity)
  @resource = args[:resource] if args.key?(:resource)
end