Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataTaxonomy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

DataTaxonomy represents a set of hierarchical DataAttributes resources, grouped with a common theme Eg: 'SensitiveDataTaxonomy' can have attributes to manage PII data. It is defined at project level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataTaxonomy

Returns a new instance of GoogleCloudDataplexV1DataTaxonomy.



5808
5809
5810
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5808

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attribute_countFixnum

Output only. The number of attributes in the DataTaxonomy. Corresponds to the JSON property attributeCount

Returns:

  • (Fixnum)


5755
5756
5757
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5755

def attribute_count
  @attribute_count
end

#class_countFixnum

Output only. The number of classes in the DataTaxonomy. Corresponds to the JSON property classCount

Returns:

  • (Fixnum)


5760
5761
5762
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5760

def class_count
  @class_count
end

#create_timeString

Output only. The time when the DataTaxonomy was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5765
5766
5767
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5765

def create_time
  @create_time
end

#descriptionString

Optional. Description of the DataTaxonomy. Corresponds to the JSON property description

Returns:

  • (String)


5770
5771
5772
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5770

def description
  @description
end

#display_nameString

Optional. User friendly display name. Corresponds to the JSON property displayName

Returns:

  • (String)


5775
5776
5777
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5775

def display_name
  @display_name
end

#etagString

This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up- to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


5782
5783
5784
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5782

def etag
  @etag
end

#labelsHash<String,String>

Optional. User-defined labels for the DataTaxonomy. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5787
5788
5789
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5787

def labels
  @labels
end

#nameString

Output only. The relative resource name of the DataTaxonomy, of the form: projects/project_number/locations/location_id/dataTaxonomies/ data_taxonomy_id. Corresponds to the JSON property name

Returns:

  • (String)


5794
5795
5796
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5794

def name
  @name
end

#uidString

Output only. System generated globally unique ID for the dataTaxonomy. This ID will be different if the DataTaxonomy is deleted and re-created with the same name. Corresponds to the JSON property uid

Returns:

  • (String)


5801
5802
5803
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5801

def uid
  @uid
end

#update_timeString

Output only. The time when the DataTaxonomy was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


5806
5807
5808
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5806

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5813
5814
5815
5816
5817
5818
5819
5820
5821
5822
5823
5824
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5813

def update!(**args)
  @attribute_count = args[:attribute_count] if args.key?(:attribute_count)
  @class_count = args[:class_count] if args.key?(:class_count)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end