Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DeleteGlossaryRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Delete Glossary Request

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DeleteGlossaryRequest

Returns a new instance of GoogleCloudDataplexV1DeleteGlossaryRequest.



5892
5893
5894
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5892

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Optional. The etag of the Glossary. If this is provided, it must match the server's etag. If the etag is provided and does not match the server-computed etag, the request must fail with a ABORTED error code. Corresponds to the JSON property etag

Returns:

  • (String)


5884
5885
5886
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5884

def etag
  @etag
end

#nameString

Required. The name of the Glossary to delete. Format: projects/ project_id_or_number/locations/location_id/glossaries/glossary_id Corresponds to the JSON property name

Returns:

  • (String)


5890
5891
5892
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5890

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5897
5898
5899
5900
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5897

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
end