Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEvent
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
The payload associated with Discovery data processing.
Instance Attribute Summary collapse
-
#action ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEventActionDetails
Details about the action.
-
#asset_id ⇒ String
The id of the associated asset.
-
#config ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEventConfigDetails
Details about configuration events.
-
#data_location ⇒ String
The data location associated with the event.
-
#datascan_id ⇒ String
The id of the associated datascan for standalone discovery.
-
#entity ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEventEntityDetails
Details about the entity.
-
#lake_id ⇒ String
The id of the associated lake.
-
#message ⇒ String
The log message.
-
#partition ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEventPartitionDetails
Details about the partition.
-
#table ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEventTableDetails
Details about the published table.
-
#type ⇒ String
The type of the event being logged.
-
#zone_id ⇒ String
The id of the associated zone.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DiscoveryEvent
constructor
A new instance of GoogleCloudDataplexV1DiscoveryEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DiscoveryEvent
Returns a new instance of GoogleCloudDataplexV1DiscoveryEvent.
6002 6003 6004 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6002 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEventActionDetails
Details about the action.
Corresponds to the JSON property action
5945 5946 5947 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5945 def action @action end |
#asset_id ⇒ String
The id of the associated asset.
Corresponds to the JSON property assetId
5950 5951 5952 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5950 def asset_id @asset_id end |
#config ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEventConfigDetails
Details about configuration events.
Corresponds to the JSON property config
5955 5956 5957 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5955 def config @config end |
#data_location ⇒ String
The data location associated with the event.
Corresponds to the JSON property dataLocation
5960 5961 5962 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5960 def data_location @data_location end |
#datascan_id ⇒ String
The id of the associated datascan for standalone discovery.
Corresponds to the JSON property datascanId
5965 5966 5967 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5965 def datascan_id @datascan_id end |
#entity ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEventEntityDetails
Details about the entity.
Corresponds to the JSON property entity
5970 5971 5972 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5970 def entity @entity end |
#lake_id ⇒ String
The id of the associated lake.
Corresponds to the JSON property lakeId
5975 5976 5977 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5975 def lake_id @lake_id end |
#message ⇒ String
The log message.
Corresponds to the JSON property message
5980 5981 5982 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5980 def @message end |
#partition ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEventPartitionDetails
Details about the partition.
Corresponds to the JSON property partition
5985 5986 5987 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5985 def partition @partition end |
#table ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEventTableDetails
Details about the published table.
Corresponds to the JSON property table
5990 5991 5992 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5990 def table @table end |
#type ⇒ String
The type of the event being logged.
Corresponds to the JSON property type
5995 5996 5997 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5995 def type @type end |
#zone_id ⇒ String
The id of the associated zone.
Corresponds to the JSON property zoneId
6000 6001 6002 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6000 def zone_id @zone_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6007 def update!(**args) @action = args[:action] if args.key?(:action) @asset_id = args[:asset_id] if args.key?(:asset_id) @config = args[:config] if args.key?(:config) @data_location = args[:data_location] if args.key?(:data_location) @datascan_id = args[:datascan_id] if args.key?(:datascan_id) @entity = args[:entity] if args.key?(:entity) @lake_id = args[:lake_id] if args.key?(:lake_id) @message = args[:message] if args.key?(:message) @partition = args[:partition] if args.key?(:partition) @table = args[:table] if args.key?(:table) @type = args[:type] if args.key?(:type) @zone_id = args[:zone_id] if args.key?(:zone_id) end |