Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1Entry
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1Entry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
An entry is a representation of a data resource that can be described by various metadata.
Instance Attribute Summary collapse
-
#aspects ⇒ Hash<String,Google::Apis::DataplexV1::GoogleCloudDataplexV1Aspect>
Optional.
-
#create_time ⇒ String
Output only.
-
#entry_source ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1EntrySource
Information related to the source system of the data resource that is represented by the entry.
-
#entry_type ⇒ String
Required.
-
#fully_qualified_name ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#parent_entry ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1Entry
constructor
A new instance of GoogleCloudDataplexV1Entry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1Entry
Returns a new instance of GoogleCloudDataplexV1Entry.
6501 6502 6503 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6501 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aspects ⇒ Hash<String,Google::Apis::DataplexV1::GoogleCloudDataplexV1Aspect>
Optional. The aspects that are attached to the entry. Depending on how the
aspect is attached to the entry, the format of the aspect key can be one of
the following: If the aspect is attached directly to the entry:
project_id_or_number.location_id.aspect_type_id If the aspect is attached
to an entry's path: project_id_or_number.location_id.aspect_type_id@
path
Corresponds to the JSON property aspects
6453 6454 6455 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6453 def aspects @aspects end |
#create_time ⇒ String
Output only. The time when the entry was created in Dataplex Universal Catalog.
Corresponds to the JSON property createTime
6458 6459 6460 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6458 def create_time @create_time end |
#entry_source ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1EntrySource
Information related to the source system of the data resource that is
represented by the entry.
Corresponds to the JSON property entrySource
6464 6465 6466 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6464 def entry_source @entry_source end |
#entry_type ⇒ String
Required. Immutable. The relative resource name of the entry type that was
used to create this entry, in the format projects/project_id_or_number/
locations/location_id/entryTypes/entry_type_id.
Corresponds to the JSON property entryType
6471 6472 6473 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6471 def entry_type @entry_type end |
#fully_qualified_name ⇒ String
Optional. A name for the entry that can be referenced by an external system.
For more information, see Fully qualified names (https://cloud.google.com/data-
catalog/docs/fully-qualified-names). The maximum size of the field is 4000
characters.
Corresponds to the JSON property fullyQualifiedName
6479 6480 6481 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6479 def fully_qualified_name @fully_qualified_name end |
#name ⇒ String
Identifier. The relative resource name of the entry, in the format projects/
project_id_or_number/locations/location_id/entryGroups/entry_group_id/
entries/entry_id.
Corresponds to the JSON property name
6486 6487 6488 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6486 def name @name end |
#parent_entry ⇒ String
Optional. Immutable. The resource name of the parent entry, in the format
projects/project_id_or_number/locations/location_id/entryGroups/
entry_group_id/entries/entry_id.
Corresponds to the JSON property parentEntry
6493 6494 6495 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6493 def parent_entry @parent_entry end |
#update_time ⇒ String
Output only. The time when the entry was last updated in Dataplex Universal
Catalog.
Corresponds to the JSON property updateTime
6499 6500 6501 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6499 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6506 6507 6508 6509 6510 6511 6512 6513 6514 6515 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6506 def update!(**args) @aspects = args[:aspects] if args.key?(:aspects) @create_time = args[:create_time] if args.key?(:create_time) @entry_source = args[:entry_source] if args.key?(:entry_source) @entry_type = args[:entry_type] if args.key?(:entry_type) @fully_qualified_name = args[:fully_qualified_name] if args.key?(:fully_qualified_name) @name = args[:name] if args.key?(:name) @parent_entry = args[:parent_entry] if args.key?(:parent_entry) @update_time = args[:update_time] if args.key?(:update_time) end |