Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1EntryLink

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

EntryLink represents a link between two Entries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1EntryLink

Returns a new instance of GoogleCloudDataplexV1EntryLink.



6623
6624
6625
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6623

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aspectsHash<String,Google::Apis::DataplexV1::GoogleCloudDataplexV1Aspect>

Optional. The aspects that are attached to the entry link. The format of the aspect key has to be the following: project_id_or_number.location_id. aspect_type_id Currently, only a single aspect of a Dataplex-owned Aspect Type is allowed. Corresponds to the JSON property aspects



6587
6588
6589
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6587

def aspects
  @aspects
end

#create_timeString

Output only. The time when the Entry Link was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6592
6593
6594
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6592

def create_time
  @create_time
end

#entry_link_typeString

Required. Immutable. Relative resource name of the Entry Link Type used to create this Entry Link. For example: Entry link between synonym terms in a glossary: projects/dataplex-types/locations/global/entryLinkTypes/synonym Entry link between related terms in a glossary: projects/dataplex-types/ locations/global/entryLinkTypes/related Entry link between glossary terms and data assets: projects/dataplex-types/locations/global/entryLinkTypes/ definition Corresponds to the JSON property entryLinkType

Returns:

  • (String)


6603
6604
6605
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6603

def entry_link_type
  @entry_link_type
end

#entry_referencesArray<Google::Apis::DataplexV1::GoogleCloudDataplexV1EntryLinkEntryReference>

Required. Immutable. Specifies the Entries referenced in the Entry Link. There should be exactly two entry references. Corresponds to the JSON property entryReferences



6609
6610
6611
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6609

def entry_references
  @entry_references
end

#nameString

Output only. Immutable. Identifier. The relative resource name of the Entry Link, of the form: projects/project_id_or_number/locations/location_id/ entryGroups/entry_group_id/entryLinks/entry_link_id Corresponds to the JSON property name

Returns:

  • (String)


6616
6617
6618
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6616

def name
  @name
end

#update_timeString

Output only. The time when the Entry Link was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


6621
6622
6623
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6621

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6628
6629
6630
6631
6632
6633
6634
6635
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6628

def update!(**args)
  @aspects = args[:aspects] if args.key?(:aspects)
  @create_time = args[:create_time] if args.key?(:create_time)
  @entry_link_type = args[:entry_link_type] if args.key?(:entry_link_type)
  @entry_references = args[:entry_references] if args.key?(:entry_references)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end