Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1EntryType

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Entry Type is a template for creating Entries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1EntryType

Returns a new instance of GoogleCloudDataplexV1EntryType.



5273
5274
5275
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5273

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authorizationGoogle::Apis::DataplexV1::GoogleCloudDataplexV1EntryTypeAuthorization

Authorization for an Entry Type. Corresponds to the JSON property authorization



5204
5205
5206
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5204

def authorization
  @authorization
end

#create_timeString

Output only. The time when the EntryType was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5209
5210
5211
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5209

def create_time
  @create_time
end

#descriptionString

Optional. Description of the EntryType. Corresponds to the JSON property description

Returns:

  • (String)


5214
5215
5216
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5214

def description
  @description
end

#display_nameString

Optional. User friendly display name. Corresponds to the JSON property displayName

Returns:

  • (String)


5219
5220
5221
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5219

def display_name
  @display_name
end

#etagString

Optional. This checksum is computed by the service, and might be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


5226
5227
5228
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5226

def etag
  @etag
end

#labelsHash<String,String>

Optional. User-defined labels for the EntryType. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5231
5232
5233
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5231

def labels
  @labels
end

#nameString

Output only. The relative resource name of the EntryType, of the form: projects/project_number/locations/location_id/entryTypes/entry_type_id. Corresponds to the JSON property name

Returns:

  • (String)


5237
5238
5239
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5237

def name
  @name
end

#platformString

Optional. The platform that Entries of this type belongs to. Corresponds to the JSON property platform

Returns:

  • (String)


5242
5243
5244
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5242

def platform
  @platform
end

#required_aspectsArray<Google::Apis::DataplexV1::GoogleCloudDataplexV1EntryTypeAspectInfo>

AspectInfo for the entry type. Corresponds to the JSON property requiredAspects



5247
5248
5249
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5247

def required_aspects
  @required_aspects
end

#systemString

Optional. The system that Entries of this type belongs to. Examples include CloudSQL, MariaDB etc Corresponds to the JSON property system

Returns:

  • (String)


5253
5254
5255
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5253

def system
  @system
end

#type_aliasesArray<String>

Optional. Indicates the classes this Entry Type belongs to, for example, TABLE, DATABASE, MODEL. Corresponds to the JSON property typeAliases

Returns:

  • (Array<String>)


5259
5260
5261
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5259

def type_aliases
  @type_aliases
end

#uidString

Output only. System generated globally unique ID for the EntryType. This ID will be different if the EntryType is deleted and re-created with the same name. Corresponds to the JSON property uid

Returns:

  • (String)


5266
5267
5268
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5266

def uid
  @uid
end

#update_timeString

Output only. The time when the EntryType was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


5271
5272
5273
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5271

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5278
5279
5280
5281
5282
5283
5284
5285
5286
5287
5288
5289
5290
5291
5292
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5278

def update!(**args)
  @authorization = args[:authorization] if args.key?(:authorization)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @platform = args[:platform] if args.key?(:platform)
  @required_aspects = args[:required_aspects] if args.key?(:required_aspects)
  @system = args[:system] if args.key?(:system)
  @type_aliases = args[:type_aliases] if args.key?(:type_aliases)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end