Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1Environment
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1Environment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Environment represents a user-visible compute infrastructure for analytics within a lake.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#endpoints ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1EnvironmentEndpoints
URI Endpoints to access sessions associated with the Environment.
-
#infrastructure_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1EnvironmentInfrastructureSpec
Configuration for the underlying infrastructure used to run workloads.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#session_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1EnvironmentSessionSpec
Configuration for sessions created for this environment.
-
#session_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1EnvironmentSessionStatus
Status of sessions created for this environment.
-
#state ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1Environment
constructor
A new instance of GoogleCloudDataplexV1Environment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1Environment
Returns a new instance of GoogleCloudDataplexV1Environment.
5404 5405 5406 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5404 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Environment creation time.
Corresponds to the JSON property createTime
5343 5344 5345 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5343 def create_time @create_time end |
#description ⇒ String
Optional. Description of the environment.
Corresponds to the JSON property description
5348 5349 5350 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5348 def description @description end |
#display_name ⇒ String
Optional. User friendly display name.
Corresponds to the JSON property displayName
5353 5354 5355 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5353 def display_name @display_name end |
#endpoints ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1EnvironmentEndpoints
URI Endpoints to access sessions associated with the Environment.
Corresponds to the JSON property endpoints
5358 5359 5360 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5358 def endpoints @endpoints end |
#infrastructure_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1EnvironmentInfrastructureSpec
Configuration for the underlying infrastructure used to run workloads.
Corresponds to the JSON property infrastructureSpec
5363 5364 5365 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5363 def infrastructure_spec @infrastructure_spec end |
#labels ⇒ Hash<String,String>
Optional. User defined labels for the environment.
Corresponds to the JSON property labels
5368 5369 5370 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5368 def labels @labels end |
#name ⇒ String
Output only. The relative resource name of the environment, of the form:
projects/project_id/locations/location_id/lakes/lake_id/environment/
environment_id
Corresponds to the JSON property name
5375 5376 5377 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5375 def name @name end |
#session_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1EnvironmentSessionSpec
Configuration for sessions created for this environment.
Corresponds to the JSON property sessionSpec
5380 5381 5382 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5380 def session_spec @session_spec end |
#session_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1EnvironmentSessionStatus
Status of sessions created for this environment.
Corresponds to the JSON property sessionStatus
5385 5386 5387 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5385 def session_status @session_status end |
#state ⇒ String
Output only. Current state of the environment.
Corresponds to the JSON property state
5390 5391 5392 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5390 def state @state end |
#uid ⇒ String
Output only. System generated globally unique ID for the environment. This ID
will be different if the environment is deleted and re-created with the same
name.
Corresponds to the JSON property uid
5397 5398 5399 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5397 def uid @uid end |
#update_time ⇒ String
Output only. The time when the environment was last updated.
Corresponds to the JSON property updateTime
5402 5403 5404 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5402 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5409 5410 5411 5412 5413 5414 5415 5416 5417 5418 5419 5420 5421 5422 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5409 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @endpoints = args[:endpoints] if args.key?(:endpoints) @infrastructure_spec = args[:infrastructure_spec] if args.key?(:infrastructure_spec) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @session_spec = args[:session_spec] if args.key?(:session_spec) @session_status = args[:session_status] if args.key?(:session_status) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |