Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1EnvironmentSessionSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Configuration for sessions created for this environment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1EnvironmentSessionSpec

Returns a new instance of GoogleCloudDataplexV1EnvironmentSessionSpec.



5570
5571
5572
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5570

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_fast_startupBoolean Also known as: enable_fast_startup?

Optional. If True, this causes sessions to be pre-created and available for faster startup to enable interactive exploration use-cases. This defaults to False to avoid additional billed charges. These can only be set to True for the environment with name set to "default", and with default configuration. Corresponds to the JSON property enableFastStartup

Returns:

  • (Boolean)


5561
5562
5563
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5561

def enable_fast_startup
  @enable_fast_startup
end

#max_idle_durationString

Optional. The idle time configuration of the session. The session will be auto- terminated at the end of this period. Corresponds to the JSON property maxIdleDuration

Returns:

  • (String)


5568
5569
5570
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5568

def max_idle_duration
  @max_idle_duration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5575
5576
5577
5578
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5575

def update!(**args)
  @enable_fast_startup = args[:enable_fast_startup] if args.key?(:enable_fast_startup)
  @max_idle_duration = args[:max_idle_duration] if args.key?(:max_idle_duration)
end