Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1ExecutionIdentityServiceAccount

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

The service account

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1ExecutionIdentityServiceAccount

Returns a new instance of GoogleCloudDataplexV1ExecutionIdentityServiceAccount.



7052
7053
7054
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7052

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#emailString

Required. Service account email. The datascan will execute with this service account's credentials. The user calling this API must have permissions to act as this service account. Dataplex service agent must be granted iam. serviceAccounts.getAccessToken permission on this service account, for example, through the iam.serviceAccountTokenCreator role . Corresponds to the JSON property email

Returns:

  • (String)


7050
7051
7052
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7050

def email
  @email
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7057
7058
7059
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7057

def update!(**args)
  @email = args[:email] if args.key?(:email)
end