Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1GenerateDataQualityRulesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Response details for data quality rule recommendations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1GenerateDataQualityRulesResponse

Returns a new instance of GoogleCloudDataplexV1GenerateDataQualityRulesResponse.



7053
7054
7055
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7053

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ruleArray<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRule>

The data quality rules that Dataplex Universal Catalog generates based on the results of a data profiling scan. Corresponds to the JSON property rule



7051
7052
7053
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7051

def rule
  @rule
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7058
7059
7060
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7058

def update!(**args)
  @rule = args[:rule] if args.key?(:rule)
end