Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1Glossary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

A Glossary represents a collection of GlossaryCategories and GlossaryTerms defined by the user. Glossary is a top level resource and is the Google Cloud parent resource of all the GlossaryCategories and GlossaryTerms within it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1Glossary

Returns a new instance of GoogleCloudDataplexV1Glossary.



7170
7171
7172
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7170

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#category_countFixnum

Output only. The number of GlossaryCategories in the Glossary. Corresponds to the JSON property categoryCount

Returns:

  • (Fixnum)


7117
7118
7119
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7117

def category_count
  @category_count
end

#create_timeString

Output only. The time at which the Glossary was created. Corresponds to the JSON property createTime

Returns:

  • (String)


7122
7123
7124
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7122

def create_time
  @create_time
end

#descriptionString

Optional. The user-mutable description of the Glossary. Corresponds to the JSON property description

Returns:

  • (String)


7127
7128
7129
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7127

def description
  @description
end

#display_nameString

Optional. User friendly display name of the Glossary. This is user-mutable. This will be same as the GlossaryId, if not specified. Corresponds to the JSON property displayName

Returns:

  • (String)


7133
7134
7135
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7133

def display_name
  @display_name
end

#etagString

Optional. Needed for resource freshness validation. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


7141
7142
7143
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7141

def etag
  @etag
end

#labelsHash<String,String>

Optional. User-defined labels for the Glossary. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


7146
7147
7148
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7146

def labels
  @labels
end

#nameString

Output only. Identifier. The resource name of the Glossary. Format: projects/ project_id_or_number/locations/location_id/glossaries/glossary_id Corresponds to the JSON property name

Returns:

  • (String)


7152
7153
7154
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7152

def name
  @name
end

#term_countFixnum

Output only. The number of GlossaryTerms in the Glossary. Corresponds to the JSON property termCount

Returns:

  • (Fixnum)


7157
7158
7159
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7157

def term_count
  @term_count
end

#uidString

Output only. System generated unique id for the Glossary. This ID will be different if the Glossary is deleted and re-created with the same name. Corresponds to the JSON property uid

Returns:

  • (String)


7163
7164
7165
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7163

def uid
  @uid
end

#update_timeString

Output only. The time at which the Glossary was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


7168
7169
7170
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7168

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7175
7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7175

def update!(**args)
  @category_count = args[:category_count] if args.key?(:category_count)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @term_count = args[:term_count] if args.key?(:term_count)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end