Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1GlossaryCategory

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

A GlossaryCategory represents a collection of GlossaryCategories and GlossaryTerms within a Glossary that are related to each other.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1GlossaryCategory

Returns a new instance of GoogleCloudDataplexV1GlossaryCategory.



7243
7244
7245
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7243

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which the GlossaryCategory was created. Corresponds to the JSON property createTime

Returns:

  • (String)


7197
7198
7199
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7197

def create_time
  @create_time
end

#descriptionString

Optional. The user-mutable description of the GlossaryCategory. Corresponds to the JSON property description

Returns:

  • (String)


7202
7203
7204
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7202

def description
  @description
end

#display_nameString

Optional. User friendly display name of the GlossaryCategory. This is user- mutable. This will be same as the GlossaryCategoryId, if not specified. Corresponds to the JSON property displayName

Returns:

  • (String)


7208
7209
7210
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7208

def display_name
  @display_name
end

#labelsHash<String,String>

Optional. User-defined labels for the GlossaryCategory. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


7213
7214
7215
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7213

def labels
  @labels
end

#nameString

Output only. Identifier. The resource name of the GlossaryCategory. Format: projects/project_id_or_number/locations/location_id/glossaries/ glossary_id/categories/category_id Corresponds to the JSON property name

Returns:

  • (String)


7220
7221
7222
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7220

def name
  @name
end

#parentString

Required. The immediate parent of the GlossaryCategory in the resource- hierarchy. It can either be a Glossary or a GlossaryCategory. Format: projects/ project_id_or_number/locations/location_id/glossaries/glossary_id OR projects/project_id_or_number/locations/location_id/glossaries/ glossary_id/categories/category_id Corresponds to the JSON property parent

Returns:

  • (String)


7229
7230
7231
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7229

def parent
  @parent
end

#uidString

Output only. System generated unique id for the GlossaryCategory. This ID will be different if the GlossaryCategory is deleted and re-created with the same name. Corresponds to the JSON property uid

Returns:

  • (String)


7236
7237
7238
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7236

def uid
  @uid
end

#update_timeString

Output only. The time at which the GlossaryCategory was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


7241
7242
7243
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7241

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7248
7249
7250
7251
7252
7253
7254
7255
7256
7257
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7248

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @parent = args[:parent] if args.key?(:parent)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end