Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1GlossaryTerm

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

GlossaryTerms are the core of Glossary. A GlossaryTerm holds a rich text description that can be attached to Entries or specific columns to enrich them.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1GlossaryTerm

Returns a new instance of GoogleCloudDataplexV1GlossaryTerm.



7313
7314
7315
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7313

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which the GlossaryTerm was created. Corresponds to the JSON property createTime

Returns:

  • (String)


7268
7269
7270
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7268

def create_time
  @create_time
end

#descriptionString

Optional. The user-mutable description of the GlossaryTerm. Corresponds to the JSON property description

Returns:

  • (String)


7273
7274
7275
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7273

def description
  @description
end

#display_nameString

Optional. User friendly display name of the GlossaryTerm. This is user-mutable. This will be same as the GlossaryTermId, if not specified. Corresponds to the JSON property displayName

Returns:

  • (String)


7279
7280
7281
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7279

def display_name
  @display_name
end

#labelsHash<String,String>

Optional. User-defined labels for the GlossaryTerm. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


7284
7285
7286
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7284

def labels
  @labels
end

#nameString

Output only. Identifier. The resource name of the GlossaryTerm. Format: projects/project_id_or_number/locations/location_id/glossaries/ glossary_id/terms/term_id Corresponds to the JSON property name

Returns:

  • (String)


7291
7292
7293
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7291

def name
  @name
end

#parentString

Required. The immediate parent of the GlossaryTerm in the resource-hierarchy. It can either be a Glossary or a GlossaryCategory. Format: projects/ project_id_or_number/locations/location_id/glossaries/glossary_id OR projects/project_id_or_number/locations/location_id/glossaries/ glossary_id/categories/category_id Corresponds to the JSON property parent

Returns:

  • (String)


7300
7301
7302
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7300

def parent
  @parent
end

#uidString

Output only. System generated unique id for the GlossaryTerm. This ID will be different if the GlossaryTerm is deleted and re-created with the same name. Corresponds to the JSON property uid

Returns:

  • (String)


7306
7307
7308
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7306

def uid
  @uid
end

#update_timeString

Output only. The time at which the GlossaryTerm was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


7311
7312
7313
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7311

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7318
7319
7320
7321
7322
7323
7324
7325
7326
7327
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7318

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @parent = args[:parent] if args.key?(:parent)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end