Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1GovernanceEvent
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1GovernanceEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Payload associated with Governance related log events.
Instance Attribute Summary collapse
-
#entity ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1GovernanceEventEntity
Information about Entity resource that the log event is associated with.
-
#event_type ⇒ String
The type of the event.
-
#message ⇒ String
The log message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1GovernanceEvent
constructor
A new instance of GoogleCloudDataplexV1GovernanceEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1GovernanceEvent
Returns a new instance of GoogleCloudDataplexV1GovernanceEvent.
7304 7305 7306 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7304 def initialize(**args) update!(**args) end |
Instance Attribute Details
#entity ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1GovernanceEventEntity
Information about Entity resource that the log event is associated with.
Corresponds to the JSON property entity
7292 7293 7294 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7292 def entity @entity end |
#event_type ⇒ String
The type of the event.
Corresponds to the JSON property eventType
7297 7298 7299 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7297 def event_type @event_type end |
#message ⇒ String
The log message.
Corresponds to the JSON property message
7302 7303 7304 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7302 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7309 7310 7311 7312 7313 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7309 def update!(**args) @entity = args[:entity] if args.key?(:entity) @event_type = args[:event_type] if args.key?(:event_type) @message = args[:message] if args.key?(:message) end |