Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1Job

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

A job represents an instance of a task.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1Job

Returns a new instance of GoogleCloudDataplexV1Job.



7787
7788
7789
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7787

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

Output only. The time when the job ended. Corresponds to the JSON property endTime

Returns:

  • (String)


7727
7728
7729
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7727

def end_time
  @end_time
end

#execution_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1TaskExecutionSpec

Execution related settings, like retry and service_account. Corresponds to the JSON property executionSpec



7732
7733
7734
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7732

def execution_spec
  @execution_spec
end

#labelsHash<String,String>

Output only. User-defined labels for the task. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


7737
7738
7739
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7737

def labels
  @labels
end

#messageString

Output only. Additional information about the current state. Corresponds to the JSON property message

Returns:

  • (String)


7742
7743
7744
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7742

def message
  @message
end

#nameString

Output only. The relative resource name of the job, of the form: projects/ project_number/locations/location_id/lakes/lake_id/tasks/task_id/jobs/ job_id. Corresponds to the JSON property name

Returns:

  • (String)


7749
7750
7751
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7749

def name
  @name
end

#retry_countFixnum

Output only. The number of times the job has been retried (excluding the initial attempt). Corresponds to the JSON property retryCount

Returns:

  • (Fixnum)


7755
7756
7757
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7755

def retry_count
  @retry_count
end

#serviceString

Output only. The underlying service running a job. Corresponds to the JSON property service

Returns:

  • (String)


7760
7761
7762
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7760

def service
  @service
end

#service_jobString

Output only. The full resource name for the job run under a particular service. Corresponds to the JSON property serviceJob

Returns:

  • (String)


7765
7766
7767
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7765

def service_job
  @service_job
end

#start_timeString

Output only. The time when the job was started. Corresponds to the JSON property startTime

Returns:

  • (String)


7770
7771
7772
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7770

def start_time
  @start_time
end

#stateString

Output only. Execution state for the job. Corresponds to the JSON property state

Returns:

  • (String)


7775
7776
7777
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7775

def state
  @state
end

#triggerString

Output only. Job execution trigger. Corresponds to the JSON property trigger

Returns:

  • (String)


7780
7781
7782
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7780

def trigger
  @trigger
end

#uidString

Output only. System generated globally unique ID for the job. Corresponds to the JSON property uid

Returns:

  • (String)


7785
7786
7787
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7785

def uid
  @uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7792
7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
7805
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7792

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @execution_spec = args[:execution_spec] if args.key?(:execution_spec)
  @labels = args[:labels] if args.key?(:labels)
  @message = args[:message] if args.key?(:message)
  @name = args[:name] if args.key?(:name)
  @retry_count = args[:retry_count] if args.key?(:retry_count)
  @service = args[:service] if args.key?(:service)
  @service_job = args[:service_job] if args.key?(:service_job)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @trigger = args[:trigger] if args.key?(:trigger)
  @uid = args[:uid] if args.key?(:uid)
end