Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1JobEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

The payload associated with Job logs that contains events describing jobs that have run within a Lake.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1JobEvent

Returns a new instance of GoogleCloudDataplexV1JobEvent.



7863
7864
7865
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7863

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

The time when the job ended running. Corresponds to the JSON property endTime

Returns:

  • (String)


7816
7817
7818
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7816

def end_time
  @end_time
end

#execution_triggerString

Job execution trigger. Corresponds to the JSON property executionTrigger

Returns:

  • (String)


7821
7822
7823
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7821

def execution_trigger
  @execution_trigger
end

#job_idString

The unique id identifying the job. Corresponds to the JSON property jobId

Returns:

  • (String)


7826
7827
7828
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7826

def job_id
  @job_id
end

#messageString

The log message. Corresponds to the JSON property message

Returns:

  • (String)


7831
7832
7833
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7831

def message
  @message
end

#retriesFixnum

The number of retries. Corresponds to the JSON property retries

Returns:

  • (Fixnum)


7836
7837
7838
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7836

def retries
  @retries
end

#serviceString

The service used to execute the job. Corresponds to the JSON property service

Returns:

  • (String)


7841
7842
7843
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7841

def service
  @service
end

#service_jobString

The reference to the job within the service. Corresponds to the JSON property serviceJob

Returns:

  • (String)


7846
7847
7848
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7846

def service_job
  @service_job
end

#start_timeString

The time when the job started running. Corresponds to the JSON property startTime

Returns:

  • (String)


7851
7852
7853
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7851

def start_time
  @start_time
end

#stateString

The job state on completion. Corresponds to the JSON property state

Returns:

  • (String)


7856
7857
7858
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7856

def state
  @state
end

#typeString

The type of the job. Corresponds to the JSON property type

Returns:

  • (String)


7861
7862
7863
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7861

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7868
7869
7870
7871
7872
7873
7874
7875
7876
7877
7878
7879
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7868

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @execution_trigger = args[:execution_trigger] if args.key?(:execution_trigger)
  @job_id = args[:job_id] if args.key?(:job_id)
  @message = args[:message] if args.key?(:message)
  @retries = args[:retries] if args.key?(:retries)
  @service = args[:service] if args.key?(:service)
  @service_job = args[:service_job] if args.key?(:service_job)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
end