Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1LakeMetastoreStatus
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1LakeMetastoreStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Status of Lake and Dataproc Metastore service instance association.
Instance Attribute Summary collapse
-
#endpoint ⇒ String
The URI of the endpoint used to access the Metastore service.
-
#message ⇒ String
Additional information about the current status.
-
#state ⇒ String
Current state of association.
-
#update_time ⇒ String
Last update time of the metastore status of the lake.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1LakeMetastoreStatus
constructor
A new instance of GoogleCloudDataplexV1LakeMetastoreStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1LakeMetastoreStatus
Returns a new instance of GoogleCloudDataplexV1LakeMetastoreStatus.
8022 8023 8024 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8022 def initialize(**args) update!(**args) end |
Instance Attribute Details
#endpoint ⇒ String
The URI of the endpoint used to access the Metastore service.
Corresponds to the JSON property endpoint
8005 8006 8007 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8005 def endpoint @endpoint end |
#message ⇒ String
Additional information about the current status.
Corresponds to the JSON property message
8010 8011 8012 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8010 def @message end |
#state ⇒ String
Current state of association.
Corresponds to the JSON property state
8015 8016 8017 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8015 def state @state end |
#update_time ⇒ String
Last update time of the metastore status of the lake.
Corresponds to the JSON property updateTime
8020 8021 8022 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8020 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8027 8028 8029 8030 8031 8032 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8027 def update!(**args) @endpoint = args[:endpoint] if args.key?(:endpoint) @message = args[:message] if args.key?(:message) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |