Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1ListJobsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

List jobs response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1ListJobsResponse

Returns a new instance of GoogleCloudDataplexV1ListJobsResponse.



8716
8717
8718
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8716

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#jobsArray<Google::Apis::DataplexV1::GoogleCloudDataplexV1Job>

Jobs under a given task. Corresponds to the JSON property jobs



8708
8709
8710
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8708

def jobs
  @jobs
end

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


8714
8715
8716
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8714

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8721
8722
8723
8724
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8721

def update!(**args)
  @jobs = args[:jobs] if args.key?(:jobs)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end