Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1ListLakesResponse
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1ListLakesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
List lakes response.
Instance Attribute Summary collapse
-
#lakes ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1Lake>
Lakes under the given parent location.
-
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more results in the list.
-
#unreachable_locations ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1ListLakesResponse
constructor
A new instance of GoogleCloudDataplexV1ListLakesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1ListLakesResponse
Returns a new instance of GoogleCloudDataplexV1ListLakesResponse.
8747 8748 8749 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8747 def initialize(**args) update!(**args) end |
Instance Attribute Details
#lakes ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1Lake>
Lakes under the given parent location.
Corresponds to the JSON property lakes
8734 8735 8736 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8734 def lakes @lakes end |
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more
results in the list.
Corresponds to the JSON property nextPageToken
8740 8741 8742 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8740 def next_page_token @next_page_token end |
#unreachable_locations ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachableLocations
8745 8746 8747 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8745 def unreachable_locations @unreachable_locations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8752 8753 8754 8755 8756 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8752 def update!(**args) @lakes = args[:lakes] if args.key?(:lakes) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable_locations = args[:unreachable_locations] if args.key?(:unreachable_locations) end |