Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1ListMetadataFeedsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1ListMetadataFeedsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Response message for ListMetadataFeeds.
Instance Attribute Summary collapse
-
#metadata_feeds ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataFeed>
List of metadata feeds under the specified parent location.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1ListMetadataFeedsResponse
constructor
A new instance of GoogleCloudDataplexV1ListMetadataFeedsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1ListMetadataFeedsResponse
Returns a new instance of GoogleCloudDataplexV1ListMetadataFeedsResponse.
8779 8780 8781 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8779 def initialize(**args) update!(**args) end |
Instance Attribute Details
#metadata_feeds ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataFeed>
List of metadata feeds under the specified parent location.
Corresponds to the JSON property metadataFeeds
8766 8767 8768 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8766 def @metadata_feeds end |
#next_page_token ⇒ String
A token to retrieve the next page of results. If there are no more results in
the list, the value is empty.
Corresponds to the JSON property nextPageToken
8772 8773 8774 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8772 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Unordered list. Locations that the service couldn't reach.
Corresponds to the JSON property unreachable
8777 8778 8779 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8777 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8784 8785 8786 8787 8788 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8784 def update!(**args) @metadata_feeds = args[:metadata_feeds] if args.key?(:metadata_feeds) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |