Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1ListMetadataJobsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

List metadata jobs response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1ListMetadataJobsResponse

Returns a new instance of GoogleCloudDataplexV1ListMetadataJobsResponse.



8811
8812
8813
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8811

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#metadata_jobsArray<Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJob>

Metadata jobs under the specified parent location. Corresponds to the JSON property metadataJobs



8798
8799
8800
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8798

def 
  @metadata_jobs
end

#next_page_tokenString

A token to retrieve the next page of results. If there are no more results in the list, the value is empty. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


8804
8805
8806
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8804

def next_page_token
  @next_page_token
end

#unreachable_locationsArray<String>

Locations that the service couldn't reach. Corresponds to the JSON property unreachableLocations

Returns:

  • (Array<String>)


8809
8810
8811
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8809

def unreachable_locations
  @unreachable_locations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8816
8817
8818
8819
8820
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8816

def update!(**args)
  @metadata_jobs = args[:metadata_jobs] if args.key?(:metadata_jobs)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable_locations = args[:unreachable_locations] if args.key?(:unreachable_locations)
end