Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1ListPartitionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

List metadata partitions response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1ListPartitionsResponse

Returns a new instance of GoogleCloudDataplexV1ListPartitionsResponse.



8838
8839
8840
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8838

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no remaining results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


8831
8832
8833
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8831

def next_page_token
  @next_page_token
end

#partitionsArray<Google::Apis::DataplexV1::GoogleCloudDataplexV1Partition>

Partitions under the specified parent entity. Corresponds to the JSON property partitions



8836
8837
8838
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8836

def partitions
  @partitions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8843
8844
8845
8846
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8843

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @partitions = args[:partitions] if args.key?(:partitions)
end