Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1ListTasksResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

List tasks response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1ListTasksResponse

Returns a new instance of GoogleCloudDataplexV1ListTasksResponse.



8869
8870
8871
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8869

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


8857
8858
8859
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8857

def next_page_token
  @next_page_token
end

#tasksArray<Google::Apis::DataplexV1::GoogleCloudDataplexV1Task>

Tasks under the given parent lake. Corresponds to the JSON property tasks



8862
8863
8864
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8862

def tasks
  @tasks
end

#unreachable_locationsArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachableLocations

Returns:

  • (Array<String>)


8867
8868
8869
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8867

def unreachable_locations
  @unreachable_locations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8874
8875
8876
8877
8878
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8874

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @tasks = args[:tasks] if args.key?(:tasks)
  @unreachable_locations = args[:unreachable_locations] if args.key?(:unreachable_locations)
end