Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1ListZonesResponse
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1ListZonesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
List zones response.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more results in the list.
-
#zones ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1Zone>
Zones under the given parent lake.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1ListZonesResponse
constructor
A new instance of GoogleCloudDataplexV1ListZonesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1ListZonesResponse
Returns a new instance of GoogleCloudDataplexV1ListZonesResponse.
7019 7020 7021 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7019 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more
results in the list.
Corresponds to the JSON property nextPageToken
7012 7013 7014 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7012 def next_page_token @next_page_token end |
#zones ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1Zone>
Zones under the given parent lake.
Corresponds to the JSON property zones
7017 7018 7019 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7017 def zones @zones end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7024 7025 7026 7027 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7024 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @zones = args[:zones] if args.key?(:zones) end |