Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1LookupContextRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Lookup Context using permissions in the source system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1LookupContextRequest

Returns a new instance of GoogleCloudDataplexV1LookupContextRequest.



8885
8886
8887
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8885

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#optionsHash<String,String>

Optional. Allows to configure the context.Supported options: format - The format of the context (one of yaml, xml, json, default is yaml). context_budget - If provided, the output will be intelligently truncated on a best-effort basis to contain approximately the desired amount of characters. There is no guarantee to achieve the specific amount. all_schema_fields - If set to true, all schema fields will be returned in the context (regardless of context_budget value). Otherwise, the list of schema fields is truncated. Default is false. Corresponds to the JSON property options

Returns:

  • (Hash<String,String>)


8876
8877
8878
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8876

def options
  @options
end

#resourcesArray<String>

Required. The entry names to look up the context for. The maximum number of resources for a request is limited to 10.Examples:projects/project/locations/ location/entryGroups/entry_group/entries/entry Corresponds to the JSON property resources

Returns:

  • (Array<String>)


8883
8884
8885
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8883

def resources
  @resources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8890
8891
8892
8893
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8890

def update!(**args)
  @options = args[:options] if args.key?(:options)
  @resources = args[:resources] if args.key?(:resources)
end