Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1LookupContextResponse
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1LookupContextResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Lookup Context response.
Instance Attribute Summary collapse
-
#context ⇒ String
Pre-formatted block of text containing the context for the requested resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1LookupContextResponse
constructor
A new instance of GoogleCloudDataplexV1LookupContextResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1LookupContextResponse
Returns a new instance of GoogleCloudDataplexV1LookupContextResponse.
8912 8913 8914 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8912 def initialize(**args) update!(**args) end |
Instance Attribute Details
#context ⇒ String
Pre-formatted block of text containing the context for the requested resources.
Corresponds to the JSON property context
8910 8911 8912 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8910 def context @context end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8917 8918 8919 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8917 def update!(**args) @context = args[:context] if args.key?(:context) end |