Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1LookupEntryLinksResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Response message for LookupEntryLinks.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1LookupEntryLinksResponse

Returns a new instance of GoogleCloudDataplexV1LookupEntryLinksResponse.



8930
8931
8932
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8930

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entry_linksArray<Google::Apis::DataplexV1::GoogleCloudDataplexV1EntryLink>

List of entry links that reference the specified entry. Corresponds to the JSON property entryLinks



8922
8923
8924
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8922

def entry_links
  @entry_links
end

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


8928
8929
8930
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8928

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8935
8936
8937
8938
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8935

def update!(**args)
  @entry_links = args[:entry_links] if args.key?(:entry_links)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end