Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataFeed

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

MetadataFeed contains information related to the metadata feed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataFeed

Returns a new instance of GoogleCloudDataplexV1MetadataFeed.



9041
9042
9043
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9041

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time when the feed was created. Corresponds to the JSON property createTime

Returns:

  • (String)


8993
8994
8995
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8993

def create_time
  @create_time
end

#filtersGoogle::Apis::DataplexV1::GoogleCloudDataplexV1MetadataFeedFilters

Filters defines the type of changes that you want to listen to. You can have multiple entry type filters and multiple aspect type filters. All of the entry type filters are OR'ed together. All of the aspect type filters are OR'ed together. All of the entry type filters and aspect type filters are AND'ed together. Corresponds to the JSON property filters



9002
9003
9004
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9002

def filters
  @filters
end

#labelsHash<String,String>

Optional. User-defined labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


9007
9008
9009
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9007

def labels
  @labels
end

#nameString

Identifier. The resource name of the metadata feed, in the format projects/ project_id_or_number/locations/location_id/metadataFeeds/metadata_feed_id. Corresponds to the JSON property name

Returns:

  • (String)


9013
9014
9015
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9013

def name
  @name
end

#pubsub_topicString

Optional. The pubsub topic that you want the metadata feed messages to publish to. Please grant Dataplex service account the permission to publish messages to the topic. The service account is: service-PROJECT_NUMBER@gcp-sa-dataplex. iam.gserviceaccount.com. Corresponds to the JSON property pubsubTopic

Returns:

  • (String)


9021
9022
9023
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9021

def pubsub_topic
  @pubsub_topic
end

#scopeGoogle::Apis::DataplexV1::GoogleCloudDataplexV1MetadataFeedScope

Scope defines the scope of the metadata feed. Scopes are exclusive. Only one of the scopes can be specified. Corresponds to the JSON property scope



9027
9028
9029
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9027

def scope
  @scope
end

#uidString

Output only. A system-generated, globally unique ID for the metadata job. If the metadata job is deleted and then re-created with the same name, this ID is different. Corresponds to the JSON property uid

Returns:

  • (String)


9034
9035
9036
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9034

def uid
  @uid
end

#update_timeString

Output only. The time when the feed was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


9039
9040
9041
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9039

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9046
9047
9048
9049
9050
9051
9052
9053
9054
9055
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9046

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @filters = args[:filters] if args.key?(:filters)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @pubsub_topic = args[:pubsub_topic] if args.key?(:pubsub_topic)
  @scope = args[:scope] if args.key?(:scope)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end