Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataFeedFilters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Filters defines the type of changes that you want to listen to. You can have multiple entry type filters and multiple aspect type filters. All of the entry type filters are OR'ed together. All of the aspect type filters are OR'ed together. All of the entry type filters and aspect type filters are AND'ed together.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataFeedFilters

Returns a new instance of GoogleCloudDataplexV1MetadataFeedFilters.



9087
9088
9089
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9087

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aspect_typesArray<String>

Optional. The aspect types that you want to listen to. Depending on how the aspect is attached to the entry, in the format: projects/project_id_or_number /locations/location/aspectTypes/aspect_type_id. Corresponds to the JSON property aspectTypes

Returns:

  • (Array<String>)


9071
9072
9073
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9071

def aspect_types
  @aspect_types
end

#change_typesArray<String>

Optional. The type of change that you want to listen to. If not specified, all changes are published. Corresponds to the JSON property changeTypes

Returns:

  • (Array<String>)


9077
9078
9079
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9077

def change_types
  @change_types
end

#entry_typesArray<String>

Optional. The entry types that you want to listen to, specified as relative resource names in the format projects/project_id_or_number/locations/ location/entryTypes/entry_type_id. Only entries that belong to the specified entry types are published. Corresponds to the JSON property entryTypes

Returns:

  • (Array<String>)


9085
9086
9087
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9085

def entry_types
  @entry_types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9092
9093
9094
9095
9096
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9092

def update!(**args)
  @aspect_types = args[:aspect_types] if args.key?(:aspect_types)
  @change_types = args[:change_types] if args.key?(:change_types)
  @entry_types = args[:entry_types] if args.key?(:entry_types)
end