Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataFeedScope

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Scope defines the scope of the metadata feed. Scopes are exclusive. Only one of the scopes can be specified.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataFeedScope

Returns a new instance of GoogleCloudDataplexV1MetadataFeedScope.



9089
9090
9091
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9089

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entry_groupsArray<String>

Optional. The entry groups whose entries you want to listen to. Must be in the format: projects/project_id_or_number/locations/location_id/entryGroups/ entry_group_id. Corresponds to the JSON property entryGroups

Returns:

  • (Array<String>)


9071
9072
9073
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9071

def entry_groups
  @entry_groups
end

#organization_levelBoolean Also known as: organization_level?

Optional. Whether the metadata feed is at the organization-level. If true, all changes happened to the entries in the same organization as the feed are published. If false, you must specify a list of projects or a list of entry groups whose entries you want to listen to.The default is false. Corresponds to the JSON property organizationLevel

Returns:

  • (Boolean)


9079
9080
9081
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9079

def organization_level
  @organization_level
end

#projectsArray<String>

Optional. The projects whose entries you want to listen to. Must be in the same organization as the feed. Must be in the format: projects/ project_id_or_number. Corresponds to the JSON property projects

Returns:

  • (Array<String>)


9087
9088
9089
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9087

def projects
  @projects
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9094
9095
9096
9097
9098
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9094

def update!(**args)
  @entry_groups = args[:entry_groups] if args.key?(:entry_groups)
  @organization_level = args[:organization_level] if args.key?(:organization_level)
  @projects = args[:projects] if args.key?(:projects)
end