Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobExportJobSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Job specification for a metadata export job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataJobExportJobSpec

Returns a new instance of GoogleCloudDataplexV1MetadataJobExportJobSpec.



9276
9277
9278
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9276

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#output_pathString

Required. The root path of the Cloud Storage bucket to export the metadata to, in the format gs://bucket/. You can optionally specify a custom prefix after the bucket name, in the format gs://bucket/prefix/. The maximum length of the custom prefix is 128 characters. Dataplex Universal Catalog constructs the object path for the exported files by using the bucket name and prefix that you provide, followed by a system-generated path.The bucket must be in the same VPC Service Controls perimeter as the job. Corresponds to the JSON property outputPath

Returns:

  • (String)


9269
9270
9271
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9269

def output_path
  @output_path
end

#scopeGoogle::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobExportJobSpecExportJobScope

The scope of the export job. Corresponds to the JSON property scope



9274
9275
9276
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9274

def scope
  @scope
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9281
9282
9283
9284
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9281

def update!(**args)
  @output_path = args[:output_path] if args.key?(:output_path)
  @scope = args[:scope] if args.key?(:scope)
end