Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1ModifyEntryRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1ModifyEntryRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Modify Entry request using permissions in the source system.
Instance Attribute Summary collapse
-
#aspect_keys ⇒ Array<String>
Optional.
-
#delete_missing_aspects ⇒ Boolean
(also: #delete_missing_aspects?)
Optional.
-
#entry ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1Entry
An entry is a representation of a data resource that can be described by various metadata.
-
#update_mask ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1ModifyEntryRequest
constructor
A new instance of GoogleCloudDataplexV1ModifyEntryRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1ModifyEntryRequest
Returns a new instance of GoogleCloudDataplexV1ModifyEntryRequest.
9647 9648 9649 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9647 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aspect_keys ⇒ Array<String>
Optional. The aspect keys which the service should modify. It supports the
following syntaxes: - matches an aspect of the given type and empty path. @
path - matches an aspect of the given type and specified path. For example, to
attach an aspect to a field that is specified by the schema aspect, the path
should have the format Schema.. @* - matches aspects of the given type for all
paths. *@path - matches aspects of all types on the given path.The service
will not remove existing aspects matching the syntax unless
delete_missing_aspects is set to true.If this field is left empty, the service
treats it as specifying exactly those Aspects present in the request.
Corresponds to the JSON property aspectKeys
9625 9626 9627 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9625 def aspect_keys @aspect_keys end |
#delete_missing_aspects ⇒ Boolean Also known as: delete_missing_aspects?
Optional. If set to true, any aspects not specified in the request will be
deleted. The default is false.
Corresponds to the JSON property deleteMissingAspects
9631 9632 9633 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9631 def delete_missing_aspects @delete_missing_aspects end |
#entry ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1Entry
An entry is a representation of a data resource that can be described by
various metadata.
Corresponds to the JSON property entry
9638 9639 9640 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9638 def entry @entry end |
#update_mask ⇒ String
Optional. Mask of fields to update. To update Aspects, the update_mask must
contain the value "aspects".If the update_mask is empty, the service will
update all modifiable fields present in the request.
Corresponds to the JSON property updateMask
9645 9646 9647 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9645 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9652 9653 9654 9655 9656 9657 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9652 def update!(**args) @aspect_keys = args[:aspect_keys] if args.key?(:aspect_keys) @delete_missing_aspects = args[:delete_missing_aspects] if args.key?(:delete_missing_aspects) @entry = args[:entry] if args.key?(:entry) @update_mask = args[:update_mask] if args.key?(:update_mask) end |