Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1ResourceAccessSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

ResourceAccessSpec holds the access control configuration to be enforced on the resources, for example, Cloud Storage bucket, BigQuery dataset, BigQuery table.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1ResourceAccessSpec

Returns a new instance of GoogleCloudDataplexV1ResourceAccessSpec.



9857
9858
9859
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9857

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ownersArray<String>

Optional. The set of principals to be granted owner role on the resource. Corresponds to the JSON property owners

Returns:

  • (Array<String>)


9843
9844
9845
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9843

def owners
  @owners
end

#readersArray<String>

Optional. The format of strings follows the pattern followed by IAM in the bindings. user:email, serviceAccount:email group:email. The set of principals to be granted reader role on the resource. Corresponds to the JSON property readers

Returns:

  • (Array<String>)


9850
9851
9852
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9850

def readers
  @readers
end

#writersArray<String>

Optional. The set of principals to be granted writer role on the resource. Corresponds to the JSON property writers

Returns:

  • (Array<String>)


9855
9856
9857
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9855

def writers
  @writers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9862
9863
9864
9865
9866
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9862

def update!(**args)
  @owners = args[:owners] if args.key?(:owners)
  @readers = args[:readers] if args.key?(:readers)
  @writers = args[:writers] if args.key?(:writers)
end