Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1RunTaskRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1RunTaskRequest

Returns a new instance of GoogleCloudDataplexV1RunTaskRequest.



9927
9928
9929
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9927

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsHash<String,String>

Optional. Execution spec arguments. If the map is left empty, the task will run with existing execution spec args from task definition. If the map contains an entry with a new key, the same will be added to existing set of args. If the map contains an entry with an existing arg key in task definition, the task will run with new arg value for that entry. Clearing an existing arg will require arg value to be explicitly set to a hyphen "-". The arg value cannot be empty. Corresponds to the JSON property args

Returns:

  • (Hash<String,String>)


9914
9915
9916
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9914

def args
  @args
end

#labelsHash<String,String>

Optional. User-defined labels for the task. If the map is left empty, the task will run with existing labels from task definition. If the map contains an entry with a new key, the same will be added to existing set of labels. If the map contains an entry with an existing label key in task definition, the task will run with new label value for that entry. Clearing an existing label will require label value to be explicitly set to a hyphen "-". The label value cannot be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


9925
9926
9927
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9925

def labels
  @labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9932
9933
9934
9935
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9932

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @labels = args[:labels] if args.key?(:labels)
end