Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1ScannedDataIncrementalField

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

A data range denoted by a pair of start/end values of a field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1ScannedDataIncrementalField

Returns a new instance of GoogleCloudDataplexV1ScannedDataIncrementalField.



9996
9997
9998
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9996

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endString

Output only. Value that marks the end of the range. Corresponds to the JSON property end

Returns:

  • (String)


9983
9984
9985
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9983

def end
  @end
end

#fieldString

Output only. The field that contains values which monotonically increases over time (e.g. a timestamp column). Corresponds to the JSON property field

Returns:

  • (String)


9989
9990
9991
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9989

def field
  @field
end

#startString

Output only. Value that marks the start of the range. Corresponds to the JSON property start

Returns:

  • (String)


9994
9995
9996
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9994

def start
  @start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10001
10002
10003
10004
10005
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10001

def update!(**args)
  @end = args[:end] if args.key?(:end)
  @field = args[:field] if args.key?(:field)
  @start = args[:start] if args.key?(:start)
end