Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1Schema
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1Schema
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Schema information describing the structure and layout of the data.
Instance Attribute Summary collapse
-
#fields ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1SchemaSchemaField>
Optional.
-
#partition_fields ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1SchemaPartitionField>
Optional.
-
#partition_style ⇒ String
Optional.
-
#user_managed ⇒ Boolean
(also: #user_managed?)
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1Schema
constructor
A new instance of GoogleCloudDataplexV1Schema.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1Schema
Returns a new instance of GoogleCloudDataplexV1Schema.
10044 10045 10046 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10044 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fields ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1SchemaSchemaField>
Optional. The sequence of fields describing data in table entities. Note:
BigQuery SchemaFields are immutable.
Corresponds to the JSON property fields
10016 10017 10018 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10016 def fields @fields end |
#partition_fields ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1SchemaPartitionField>
Optional. The sequence of fields describing the partition structure in
entities. If this field is empty, there are no partitions within the data.
Corresponds to the JSON property partitionFields
10022 10023 10024 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10022 def partition_fields @partition_fields end |
#partition_style ⇒ String
Optional. The structure of paths containing partition data within the entity.
Corresponds to the JSON property partitionStyle
10027 10028 10029 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10027 def partition_style @partition_style end |
#user_managed ⇒ Boolean Also known as: user_managed?
Required. Set to true if user-managed or false if managed by Dataplex
Universal Catalog. The default is false (managed by Dataplex Universal Catalog)
. Set to falseto enable Dataplex Universal Catalog discovery to update the
schema. including new data discovery, schema inference, and schema evolution.
Users retain the ability to input and edit the schema. Dataplex Universal
Catalog treats schema input by the user as though produced by a previous
Dataplex Universal Catalog discovery operation, and it will evolve the schema
and take action based on that treatment. Set to true to fully manage the
entity schema. This setting guarantees that Dataplex Universal Catalog will
not change schema fields.
Corresponds to the JSON property userManaged
10041 10042 10043 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10041 def user_managed @user_managed end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10049 10050 10051 10052 10053 10054 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10049 def update!(**args) @fields = args[:fields] if args.key?(:fields) @partition_fields = args[:partition_fields] if args.key?(:partition_fields) @partition_style = args[:partition_style] if args.key?(:partition_style) @user_managed = args[:user_managed] if args.key?(:user_managed) end |