Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1SchemaSchemaField

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Represents a column field within a table schema.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1SchemaSchemaField

Returns a new instance of GoogleCloudDataplexV1SchemaSchemaField.



10118
10119
10120
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10118

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. User friendly field description. Must be less than or equal to 1024 characters. Corresponds to the JSON property description

Returns:

  • (String)


10094
10095
10096
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10094

def description
  @description
end

#fieldsArray<Google::Apis::DataplexV1::GoogleCloudDataplexV1SchemaSchemaField>

Optional. Any nested field for complex types. Corresponds to the JSON property fields



10099
10100
10101
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10099

def fields
  @fields
end

#modeString

Required. Additional field semantics. Corresponds to the JSON property mode

Returns:

  • (String)


10104
10105
10106
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10104

def mode
  @mode
end

#nameString

Required. The name of the field. Must contain only letters, numbers and underscores, with a maximum length of 767 characters, and must begin with a letter or underscore. Corresponds to the JSON property name

Returns:

  • (String)


10111
10112
10113
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10111

def name
  @name
end

#typeString

Required. The type of field. Corresponds to the JSON property type

Returns:

  • (String)


10116
10117
10118
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10116

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10123
10124
10125
10126
10127
10128
10129
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10123

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @fields = args[:fields] if args.key?(:fields)
  @mode = args[:mode] if args.key?(:mode)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end