Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1SearchEntriesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1SearchEntriesResponse

Returns a new instance of GoogleCloudDataplexV1SearchEntriesResponse.



7928
7929
7930
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7928

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7909
7910
7911
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7909

def next_page_token
  @next_page_token
end

#resultsArray<Google::Apis::DataplexV1::GoogleCloudDataplexV1SearchEntriesResult>

The results matching the search query. Corresponds to the JSON property results



7914
7915
7916
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7914

def results
  @results
end

#total_sizeFixnum

The estimated total number of matching entries. This number isn't guaranteed to be accurate. Corresponds to the JSON property totalSize

Returns:

  • (Fixnum)


7920
7921
7922
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7920

def total_size
  @total_size
end

#unreachableArray<String>

Locations that the service couldn't reach. Search results don't include data from these locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


7926
7927
7928
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7926

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7933
7934
7935
7936
7937
7938
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7933

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @results = args[:results] if args.key?(:results)
  @total_size = args[:total_size] if args.key?(:total_size)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end