Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1SearchEntriesResult
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1SearchEntriesResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
A single result of a SearchEntries request.
Instance Attribute Summary collapse
-
#dataplex_entry ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1Entry
An entry is a representation of a data resource that can be described by various metadata.
-
#linked_resource ⇒ String
Linked resource name.
-
#snippets ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1SearchEntriesResultSnippets
Snippets for the entry, contains HTML-style highlighting for matched tokens, will be used in UI.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1SearchEntriesResult
constructor
A new instance of GoogleCloudDataplexV1SearchEntriesResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1SearchEntriesResult
Returns a new instance of GoogleCloudDataplexV1SearchEntriesResult.
9910 9911 9912 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9910 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dataplex_entry ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1Entry
An entry is a representation of a data resource that can be described by
various metadata.
Corresponds to the JSON property dataplexEntry
9897 9898 9899 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9897 def dataplex_entry @dataplex_entry end |
#linked_resource ⇒ String
Linked resource name.
Corresponds to the JSON property linkedResource
9902 9903 9904 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9902 def linked_resource @linked_resource end |
#snippets ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1SearchEntriesResultSnippets
Snippets for the entry, contains HTML-style highlighting for matched tokens,
will be used in UI.
Corresponds to the JSON property snippets
9908 9909 9910 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9908 def snippets @snippets end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9915 9916 9917 9918 9919 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9915 def update!(**args) @dataplex_entry = args[:dataplex_entry] if args.key?(:dataplex_entry) @linked_resource = args[:linked_resource] if args.key?(:linked_resource) @snippets = args[:snippets] if args.key?(:snippets) end |