Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1SessionEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

These messages contain information about sessions within an environment. The monitored resource is 'Environment'.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1SessionEvent

Returns a new instance of GoogleCloudDataplexV1SessionEvent.



10237
10238
10239
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10237

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#event_succeededBoolean Also known as: event_succeeded?

The status of the event. Corresponds to the JSON property eventSucceeded

Returns:

  • (Boolean)


10196
10197
10198
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10196

def event_succeeded
  @event_succeeded
end

#fast_startup_enabledBoolean Also known as: fast_startup_enabled?

If the session is associated with an environment with fast startup enabled, and was created before being assigned to a user. Corresponds to the JSON property fastStartupEnabled

Returns:

  • (Boolean)


10203
10204
10205
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10203

def fast_startup_enabled
  @fast_startup_enabled
end

#messageString

The log message. Corresponds to the JSON property message

Returns:

  • (String)


10209
10210
10211
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10209

def message
  @message
end

#queryGoogle::Apis::DataplexV1::GoogleCloudDataplexV1SessionEventQueryDetail

Execution details of the query. Corresponds to the JSON property query



10214
10215
10216
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10214

def query
  @query
end

#session_idString

Unique identifier for the session. Corresponds to the JSON property sessionId

Returns:

  • (String)


10219
10220
10221
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10219

def session_id
  @session_id
end

#typeString

The type of the event. Corresponds to the JSON property type

Returns:

  • (String)


10224
10225
10226
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10224

def type
  @type
end

#unassigned_durationString

The idle duration of a warm pooled session before it is assigned to user. Corresponds to the JSON property unassignedDuration

Returns:

  • (String)


10229
10230
10231
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10229

def unassigned_duration
  @unassigned_duration
end

#user_idString

The information about the user that created the session. It will be the email address of the user. Corresponds to the JSON property userId

Returns:

  • (String)


10235
10236
10237
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10235

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10242
10243
10244
10245
10246
10247
10248
10249
10250
10251
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10242

def update!(**args)
  @event_succeeded = args[:event_succeeded] if args.key?(:event_succeeded)
  @fast_startup_enabled = args[:fast_startup_enabled] if args.key?(:fast_startup_enabled)
  @message = args[:message] if args.key?(:message)
  @query = args[:query] if args.key?(:query)
  @session_id = args[:session_id] if args.key?(:session_id)
  @type = args[:type] if args.key?(:type)
  @unassigned_duration = args[:unassigned_duration] if args.key?(:unassigned_duration)
  @user_id = args[:user_id] if args.key?(:user_id)
end