Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1StorageFormat
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1StorageFormat
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Describes the format of the data within its storage location.
Instance Attribute Summary collapse
-
#compression_format ⇒ String
Optional.
-
#csv ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1StorageFormatCsvOptions
Describes CSV and similar semi-structured data formats.
-
#format ⇒ String
Output only.
-
#iceberg ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1StorageFormatIcebergOptions
Describes Iceberg data format.
-
#json ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1StorageFormatJsonOptions
Describes JSON data format.
-
#mime_type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1StorageFormat
constructor
A new instance of GoogleCloudDataplexV1StorageFormat.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1StorageFormat
Returns a new instance of GoogleCloudDataplexV1StorageFormat.
10402 10403 10404 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10402 def initialize(**args) update!(**args) end |
Instance Attribute Details
#compression_format ⇒ String
Optional. The compression type associated with the stored data. If unspecified,
the data is uncompressed.
Corresponds to the JSON property compressionFormat
10369 10370 10371 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10369 def compression_format @compression_format end |
#csv ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1StorageFormatCsvOptions
Describes CSV and similar semi-structured data formats.
Corresponds to the JSON property csv
10374 10375 10376 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10374 def csv @csv end |
#format ⇒ String
Output only. The data format associated with the stored data, which represents
content type values. The value is inferred from mime type.
Corresponds to the JSON property format
10380 10381 10382 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10380 def format @format end |
#iceberg ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1StorageFormatIcebergOptions
Describes Iceberg data format.
Corresponds to the JSON property iceberg
10385 10386 10387 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10385 def iceberg @iceberg end |
#json ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1StorageFormatJsonOptions
Describes JSON data format.
Corresponds to the JSON property json
10390 10391 10392 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10390 def json @json end |
#mime_type ⇒ String
Required. The mime type descriptor for the data. Must match the pattern type/
subtype. Supported values: application/x-parquet application/x-avro
application/x-orc application/x-tfrecord application/x-parquet+iceberg
application/x-avro+iceberg application/x-orc+iceberg application/json
application/subtypes text/csv text/ image/image subtype video/video
subtype audio/audio subtype
Corresponds to the JSON property mimeType
10400 10401 10402 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10400 def mime_type @mime_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10407 10408 10409 10410 10411 10412 10413 10414 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10407 def update!(**args) @compression_format = args[:compression_format] if args.key?(:compression_format) @csv = args[:csv] if args.key?(:csv) @format = args[:format] if args.key?(:format) @iceberg = args[:iceberg] if args.key?(:iceberg) @json = args[:json] if args.key?(:json) @mime_type = args[:mime_type] if args.key?(:mime_type) end |