Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1StorageFormatCsvOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Describes CSV and similar semi-structured data formats.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1StorageFormatCsvOptions

Returns a new instance of GoogleCloudDataplexV1StorageFormatCsvOptions.



10445
10446
10447
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10445

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#delimiterString

Optional. The delimiter used to separate values. Defaults to ','. Corresponds to the JSON property delimiter

Returns:

  • (String)


10424
10425
10426
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10424

def delimiter
  @delimiter
end

#encodingString

Optional. The character encoding of the data. Accepts "US-ASCII", "UTF-8", and "ISO-8859-1". Defaults to UTF-8 if unspecified. Corresponds to the JSON property encoding

Returns:

  • (String)


10430
10431
10432
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10430

def encoding
  @encoding
end

#header_rowsFixnum

Optional. The number of rows to interpret as header rows that should be skipped when reading data rows. Defaults to 0. Corresponds to the JSON property headerRows

Returns:

  • (Fixnum)


10436
10437
10438
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10436

def header_rows
  @header_rows
end

#quoteString

Optional. The character used to quote column values. Accepts '"' (double quotation mark) or ''' (single quotation mark). Defaults to '"' (double quotation mark) if unspecified. Corresponds to the JSON property quote

Returns:

  • (String)


10443
10444
10445
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10443

def quote
  @quote
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10450
10451
10452
10453
10454
10455
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10450

def update!(**args)
  @delimiter = args[:delimiter] if args.key?(:delimiter)
  @encoding = args[:encoding] if args.key?(:encoding)
  @header_rows = args[:header_rows] if args.key?(:header_rows)
  @quote = args[:quote] if args.key?(:quote)
end