Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1Task

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

A task represents a user-visible job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1Task

Returns a new instance of GoogleCloudDataplexV1Task.



10569
10570
10571
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10569

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time when the task was created. Corresponds to the JSON property createTime

Returns:

  • (String)


10505
10506
10507
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10505

def create_time
  @create_time
end

#descriptionString

Optional. Description of the task. Corresponds to the JSON property description

Returns:

  • (String)


10510
10511
10512
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10510

def description
  @description
end

#display_nameString

Optional. User friendly display name. Corresponds to the JSON property displayName

Returns:

  • (String)


10515
10516
10517
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10515

def display_name
  @display_name
end

#execution_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1TaskExecutionSpec

Execution related settings, like retry and service_account. Corresponds to the JSON property executionSpec



10520
10521
10522
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10520

def execution_spec
  @execution_spec
end

#execution_statusGoogle::Apis::DataplexV1::GoogleCloudDataplexV1TaskExecutionStatus

Status of the task execution (e.g. Jobs). Corresponds to the JSON property executionStatus



10525
10526
10527
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10525

def execution_status
  @execution_status
end

#labelsHash<String,String>

Optional. User-defined labels for the task. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


10530
10531
10532
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10530

def labels
  @labels
end

#nameString

Output only. The relative resource name of the task, of the form: projects/ project_number/locations/location_id/lakes/lake_id/ tasks/task_id. Corresponds to the JSON property name

Returns:

  • (String)


10536
10537
10538
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10536

def name
  @name
end

#notebookGoogle::Apis::DataplexV1::GoogleCloudDataplexV1TaskNotebookTaskConfig

Config for running scheduled notebooks. Corresponds to the JSON property notebook



10541
10542
10543
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10541

def notebook
  @notebook
end

#sparkGoogle::Apis::DataplexV1::GoogleCloudDataplexV1TaskSparkTaskConfig

User-specified config for running a Spark task. Corresponds to the JSON property spark



10546
10547
10548
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10546

def spark
  @spark
end

#stateString

Output only. Current state of the task. Corresponds to the JSON property state

Returns:

  • (String)


10551
10552
10553
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10551

def state
  @state
end

#trigger_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1TaskTriggerSpec

Task scheduling and trigger settings. Corresponds to the JSON property triggerSpec



10556
10557
10558
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10556

def trigger_spec
  @trigger_spec
end

#uidString

Output only. System generated globally unique ID for the task. This ID will be different if the task is deleted and re-created with the same name. Corresponds to the JSON property uid

Returns:

  • (String)


10562
10563
10564
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10562

def uid
  @uid
end

#update_timeString

Output only. The time when the task was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


10567
10568
10569
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10567

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10574
10575
10576
10577
10578
10579
10580
10581
10582
10583
10584
10585
10586
10587
10588
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10574

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @execution_spec = args[:execution_spec] if args.key?(:execution_spec)
  @execution_status = args[:execution_status] if args.key?(:execution_status)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @notebook = args[:notebook] if args.key?(:notebook)
  @spark = args[:spark] if args.key?(:spark)
  @state = args[:state] if args.key?(:state)
  @trigger_spec = args[:trigger_spec] if args.key?(:trigger_spec)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end