Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1TaskSparkTaskConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

User-specified config for running a Spark task.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1TaskSparkTaskConfig

Returns a new instance of GoogleCloudDataplexV1TaskSparkTaskConfig.



10867
10868
10869
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10867

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#archive_urisArray<String>

Optional. Cloud Storage URIs of archives to be extracted into the working directory of each executor. Supported file types: .jar, .tar, .tar.gz, .tgz, and .zip. Corresponds to the JSON property archiveUris

Returns:

  • (Array<String>)


10820
10821
10822
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10820

def archive_uris
  @archive_uris
end

#file_urisArray<String>

Optional. Cloud Storage URIs of files to be placed in the working directory of each executor. Corresponds to the JSON property fileUris

Returns:

  • (Array<String>)


10826
10827
10828
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10826

def file_uris
  @file_uris
end

#infrastructure_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1TaskInfrastructureSpec

Configuration for the underlying infrastructure used to run workloads. Corresponds to the JSON property infrastructureSpec



10831
10832
10833
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10831

def infrastructure_spec
  @infrastructure_spec
end

#main_classString

The name of the driver's main class. The jar file that contains the class must be in the default CLASSPATH or specified in jar_file_uris. The execution args are passed in as a sequence of named process arguments (--key=value). Corresponds to the JSON property mainClass

Returns:

  • (String)


10838
10839
10840
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10838

def main_class
  @main_class
end

#main_jar_file_uriString

The Cloud Storage URI of the jar file that contains the main class. The execution args are passed in as a sequence of named process arguments (--key= value). Corresponds to the JSON property mainJarFileUri

Returns:

  • (String)


10845
10846
10847
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10845

def main_jar_file_uri
  @main_jar_file_uri
end

#python_script_fileString

The Gcloud Storage URI of the main Python file to use as the driver. Must be a .py file. The execution args are passed in as a sequence of named process arguments (--key=value). Corresponds to the JSON property pythonScriptFile

Returns:

  • (String)


10852
10853
10854
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10852

def python_script_file
  @python_script_file
end

#sql_scriptString

The query text. The execution args are used to declare a set of script variables (set key="value";). Corresponds to the JSON property sqlScript

Returns:

  • (String)


10858
10859
10860
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10858

def sql_script
  @sql_script
end

#sql_script_fileString

A reference to a query file. This should be the Cloud Storage URI of the query file. The execution args are used to declare a set of script variables (set key="value";). Corresponds to the JSON property sqlScriptFile

Returns:

  • (String)


10865
10866
10867
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10865

def sql_script_file
  @sql_script_file
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10872
10873
10874
10875
10876
10877
10878
10879
10880
10881
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10872

def update!(**args)
  @archive_uris = args[:archive_uris] if args.key?(:archive_uris)
  @file_uris = args[:file_uris] if args.key?(:file_uris)
  @infrastructure_spec = args[:infrastructure_spec] if args.key?(:infrastructure_spec)
  @main_class = args[:main_class] if args.key?(:main_class)
  @main_jar_file_uri = args[:main_jar_file_uri] if args.key?(:main_jar_file_uri)
  @python_script_file = args[:python_script_file] if args.key?(:python_script_file)
  @sql_script = args[:sql_script] if args.key?(:sql_script)
  @sql_script_file = args[:sql_script_file] if args.key?(:sql_script_file)
end