Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1TaskTriggerSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Task scheduling and trigger settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1TaskTriggerSpec

Returns a new instance of GoogleCloudDataplexV1TaskTriggerSpec.



10961
10962
10963
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10961

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disabledBoolean Also known as: disabled?

Optional. Prevent the task from executing. This does not cancel already running tasks. It is intended to temporarily disable RECURRING tasks. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


10930
10931
10932
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10930

def disabled
  @disabled
end

#max_retriesFixnum

Optional. Number of retry attempts before aborting. Set to zero to never attempt to retry a failed task. Corresponds to the JSON property maxRetries

Returns:

  • (Fixnum)


10937
10938
10939
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10937

def max_retries
  @max_retries
end

#scheduleString

Optional. Cron schedule (https://en.wikipedia.org/wiki/Cron) for running tasks periodically. To explicitly set a timezone to the cron tab, apply a prefix in the cron tab: "CRON_TZ=$IANA_TIME_ZONE" or "TZ=$IANA_TIME_ZONE". The $ IANA_TIME_ZONE may only be a valid string from IANA time zone database. For example, CRON_TZ=America/New_York 1 * * * *, or TZ=America/New_York 1 * * * *. This field is required for RECURRING tasks. Corresponds to the JSON property schedule

Returns:

  • (String)


10947
10948
10949
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10947

def schedule
  @schedule
end

#start_timeString

Optional. The first run of the task will be after this time. If not specified, the task will run shortly after being submitted if ON_DEMAND and based on the schedule if RECURRING. Corresponds to the JSON property startTime

Returns:

  • (String)


10954
10955
10956
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10954

def start_time
  @start_time
end

#typeString

Required. Immutable. Trigger type of the user-specified Task. Corresponds to the JSON property type

Returns:

  • (String)


10959
10960
10961
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10959

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10966
10967
10968
10969
10970
10971
10972
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10966

def update!(**args)
  @disabled = args[:disabled] if args.key?(:disabled)
  @max_retries = args[:max_retries] if args.key?(:max_retries)
  @schedule = args[:schedule] if args.key?(:schedule)
  @start_time = args[:start_time] if args.key?(:start_time)
  @type = args[:type] if args.key?(:type)
end