Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1TriggerOneTime

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

The scan runs once using create API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1TriggerOneTime

Returns a new instance of GoogleCloudDataplexV1TriggerOneTime.



10994
10995
10996
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10994

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ttl_after_scan_completionString

Optional. Time to live for OneTime scans. default value is 24 hours, minimum value is 0 seconds, and maximum value is 365 days. The time is calculated from the data scan job completion time. If value is set as 0 seconds, the scan will be immediately deleted upon job completion, regardless of whether the job succeeded or failed. Corresponds to the JSON property ttlAfterScanCompletion

Returns:

  • (String)


10992
10993
10994
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10992

def ttl_after_scan_completion
  @ttl_after_scan_completion
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10999
11000
11001
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10999

def update!(**args)
  @ttl_after_scan_completion = args[:ttl_after_scan_completion] if args.key?(:ttl_after_scan_completion)
end