Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1UpdateGlossaryCategoryRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1UpdateGlossaryCategoryRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Update GlossaryCategory Request
Instance Attribute Summary collapse
-
#category ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1GlossaryCategory
A GlossaryCategory represents a collection of GlossaryCategories and GlossaryTerms within a Glossary that are related to each other.
-
#update_mask ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1UpdateGlossaryCategoryRequest
constructor
A new instance of GoogleCloudDataplexV1UpdateGlossaryCategoryRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1UpdateGlossaryCategoryRequest
Returns a new instance of GoogleCloudDataplexV1UpdateGlossaryCategoryRequest.
10926 10927 10928 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10926 def initialize(**args) update!(**args) end |
Instance Attribute Details
#category ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1GlossaryCategory
A GlossaryCategory represents a collection of GlossaryCategories and
GlossaryTerms within a Glossary that are related to each other.
Corresponds to the JSON property category
10919 10920 10921 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10919 def category @category end |
#update_mask ⇒ String
Required. The list of fields to update.
Corresponds to the JSON property updateMask
10924 10925 10926 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10924 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10931 10932 10933 10934 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10931 def update!(**args) @category = args[:category] if args.key?(:category) @update_mask = args[:update_mask] if args.key?(:update_mask) end |