Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1Zone

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

A zone represents a logical group of related assets within a lake. A zone can be used to map to organizational structure or represent stages of data readiness from raw to curated. It provides managing behavior that is shared or inherited by all contained assets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1Zone

Returns a new instance of GoogleCloudDataplexV1Zone.



11350
11351
11352
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11350

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asset_statusGoogle::Apis::DataplexV1::GoogleCloudDataplexV1AssetStatus

Aggregated status of the underlying assets of a lake or zone. Corresponds to the JSON property assetStatus



11291
11292
11293
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11291

def asset_status
  @asset_status
end

#create_timeString

Output only. The time when the zone was created. Corresponds to the JSON property createTime

Returns:

  • (String)


11296
11297
11298
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11296

def create_time
  @create_time
end

#descriptionString

Optional. Description of the zone. Corresponds to the JSON property description

Returns:

  • (String)


11301
11302
11303
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11301

def description
  @description
end

#discovery_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1ZoneDiscoverySpec

Settings to manage the metadata discovery and publishing in a zone. Corresponds to the JSON property discoverySpec



11306
11307
11308
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11306

def discovery_spec
  @discovery_spec
end

#display_nameString

Optional. User friendly display name. Corresponds to the JSON property displayName

Returns:

  • (String)


11311
11312
11313
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11311

def display_name
  @display_name
end

#labelsHash<String,String>

Optional. User defined labels for the zone. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


11316
11317
11318
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11316

def labels
  @labels
end

#nameString

Output only. The relative resource name of the zone, of the form: projects/ project_number/locations/location_id/lakes/lake_id/zones/zone_id. Corresponds to the JSON property name

Returns:

  • (String)


11322
11323
11324
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11322

def name
  @name
end

#resource_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1ZoneResourceSpec

Settings for resources attached as assets within a zone. Corresponds to the JSON property resourceSpec



11327
11328
11329
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11327

def resource_spec
  @resource_spec
end

#stateString

Output only. Current state of the zone. Corresponds to the JSON property state

Returns:

  • (String)


11332
11333
11334
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11332

def state
  @state
end

#typeString

Required. Immutable. The type of the zone. Corresponds to the JSON property type

Returns:

  • (String)


11337
11338
11339
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11337

def type
  @type
end

#uidString

Output only. System generated globally unique ID for the zone. This ID will be different if the zone is deleted and re-created with the same name. Corresponds to the JSON property uid

Returns:

  • (String)


11343
11344
11345
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11343

def uid
  @uid
end

#update_timeString

Output only. The time when the zone was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


11348
11349
11350
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11348

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11355
11356
11357
11358
11359
11360
11361
11362
11363
11364
11365
11366
11367
11368
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11355

def update!(**args)
  @asset_status = args[:asset_status] if args.key?(:asset_status)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @discovery_spec = args[:discovery_spec] if args.key?(:discovery_spec)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @resource_spec = args[:resource_spec] if args.key?(:resource_spec)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end