Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1ZoneDiscoverySpecCsvOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Describe CSV and similar semi-structured data formats.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1ZoneDiscoverySpecCsvOptions

Returns a new instance of GoogleCloudDataplexV1ZoneDiscoverySpecCsvOptions.



11178
11179
11180
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11178

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#delimiterString

Optional. The delimiter being used to separate values. This defaults to ','. Corresponds to the JSON property delimiter

Returns:

  • (String)


11158
11159
11160
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11158

def delimiter
  @delimiter
end

#disable_type_inferenceBoolean Also known as: disable_type_inference?

Optional. Whether to disable the inference of data type for CSV data. If true, all columns will be registered as strings. Corresponds to the JSON property disableTypeInference

Returns:

  • (Boolean)


11164
11165
11166
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11164

def disable_type_inference
  @disable_type_inference
end

#encodingString

Optional. The character encoding of the data. The default is UTF-8. Corresponds to the JSON property encoding

Returns:

  • (String)


11170
11171
11172
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11170

def encoding
  @encoding
end

#header_rowsFixnum

Optional. The number of rows to interpret as header rows that should be skipped when reading data rows. Corresponds to the JSON property headerRows

Returns:

  • (Fixnum)


11176
11177
11178
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11176

def header_rows
  @header_rows
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11183
11184
11185
11186
11187
11188
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11183

def update!(**args)
  @delimiter = args[:delimiter] if args.key?(:delimiter)
  @disable_type_inference = args[:disable_type_inference] if args.key?(:disable_type_inference)
  @encoding = args[:encoding] if args.key?(:encoding)
  @header_rows = args[:header_rows] if args.key?(:header_rows)
end