Class: Google::Apis::DataplexV1::GoogleIamV1ResourcePolicyMember

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Output-only policy member strings of a Google Cloud resource's built-in identity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleIamV1ResourcePolicyMember

Returns a new instance of GoogleIamV1ResourcePolicyMember.



11836
11837
11838
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11836

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#iam_policy_name_principalString

Output only. IAM policy binding member referring to a Google Cloud resource by user-assigned name (https://google.aip.dev/122). If a resource is deleted and recreated with the same name, the binding will be applicable to the new resource.Example: principal://parametermanager.googleapis.com/projects/12345/ name/locations/us-central1-a/parameters/my-parameter Corresponds to the JSON property iamPolicyNamePrincipal

Returns:

  • (String)


11825
11826
11827
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11825

def iam_policy_name_principal
  @iam_policy_name_principal
end

#iam_policy_uid_principalString

Output only. IAM policy binding member referring to a Google Cloud resource by system-assigned unique identifier (https://google.aip.dev/148#uid). If a resource is deleted and recreated with the same name, the binding will not be applicable to the new resourceExample: principal://parametermanager.googleapis. com/projects/12345/uid/locations/us-central1-a/parameters/a918fed5 Corresponds to the JSON property iamPolicyUidPrincipal

Returns:

  • (String)


11834
11835
11836
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11834

def iam_policy_uid_principal
  @iam_policy_uid_principal
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11841
11842
11843
11844
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11841

def update!(**args)
  @iam_policy_name_principal = args[:iam_policy_name_principal] if args.key?(:iam_policy_name_principal)
  @iam_policy_uid_principal = args[:iam_policy_uid_principal] if args.key?(:iam_policy_uid_principal)
end