Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1Aspect
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1Aspect
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Represents a single piece of metadata describing an entry or entry link.
Instance Attribute Summary collapse
-
#aspect_source ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AspectSource
Information related to the source system of the aspect.
-
#aspect_type ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#data ⇒ Hash<String,Object>
Required.
-
#path ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1Aspect
constructor
A new instance of GoogleCloudDataplexV1Aspect.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1Aspect
Returns a new instance of GoogleCloudDataplexV1Aspect.
390 391 392 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 390 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aspect_source ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AspectSource
Information related to the source system of the aspect.
Corresponds to the JSON property aspectSource
362 363 364 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 362 def aspect_source @aspect_source end |
#aspect_type ⇒ String
Output only. The resource name of the type used to create this Aspect.
Corresponds to the JSON property aspectType
367 368 369 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 367 def aspect_type @aspect_type end |
#create_time ⇒ String
Output only. The time when the Aspect was created.
Corresponds to the JSON property createTime
372 373 374 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 372 def create_time @create_time end |
#data ⇒ Hash<String,Object>
Required. The content of the aspect, according to its aspect type schema. The
maximum size of the field is 120KB (encoded as UTF-8).
Corresponds to the JSON property data
378 379 380 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 378 def data @data end |
#path ⇒ String
Output only. The path in the entry under which the aspect is attached.
Corresponds to the JSON property path
383 384 385 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 383 def path @path end |
#update_time ⇒ String
Output only. The time when the Aspect was last updated.
Corresponds to the JSON property updateTime
388 389 390 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 388 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
395 396 397 398 399 400 401 402 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 395 def update!(**args) @aspect_source = args[:aspect_source] if args.key?(:aspect_source) @aspect_type = args[:aspect_type] if args.key?(:aspect_type) @create_time = args[:create_time] if args.key?(:create_time) @data = args[:data] if args.key?(:data) @path = args[:path] if args.key?(:path) @update_time = args[:update_time] if args.key?(:update_time) end |