Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1Asset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

An asset represents a cloud resource that is being managed within a lake as a member of a zone.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1Asset

Returns a new instance of GoogleCloudDataplexV1Asset.



823
824
825
# File 'lib/google/apis/dataplex_v1/classes.rb', line 823

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time when the asset was created. Corresponds to the JSON property createTime

Returns:

  • (String)


757
758
759
# File 'lib/google/apis/dataplex_v1/classes.rb', line 757

def create_time
  @create_time
end

#descriptionString

Optional. Description of the asset. Corresponds to the JSON property description

Returns:

  • (String)


762
763
764
# File 'lib/google/apis/dataplex_v1/classes.rb', line 762

def description
  @description
end

#discovery_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1AssetDiscoverySpec

Settings to manage the metadata discovery and publishing for an asset. Corresponds to the JSON property discoverySpec



767
768
769
# File 'lib/google/apis/dataplex_v1/classes.rb', line 767

def discovery_spec
  @discovery_spec
end

#discovery_statusGoogle::Apis::DataplexV1::GoogleCloudDataplexV1AssetDiscoveryStatus

Status of discovery for an asset. Corresponds to the JSON property discoveryStatus



772
773
774
# File 'lib/google/apis/dataplex_v1/classes.rb', line 772

def discovery_status
  @discovery_status
end

#display_nameString

Optional. User friendly display name. Corresponds to the JSON property displayName

Returns:

  • (String)


777
778
779
# File 'lib/google/apis/dataplex_v1/classes.rb', line 777

def display_name
  @display_name
end

#labelsHash<String,String>

Optional. User defined labels for the asset. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


782
783
784
# File 'lib/google/apis/dataplex_v1/classes.rb', line 782

def labels
  @labels
end

#nameString

Output only. The relative resource name of the asset, of the form: projects/ project_number/locations/location_id/lakes/lake_id/zones/zone_id/assets/ asset_id. Corresponds to the JSON property name

Returns:

  • (String)


789
790
791
# File 'lib/google/apis/dataplex_v1/classes.rb', line 789

def name
  @name
end

#resource_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1AssetResourceSpec

Identifies the cloud resource that is referenced by this asset. Corresponds to the JSON property resourceSpec



794
795
796
# File 'lib/google/apis/dataplex_v1/classes.rb', line 794

def resource_spec
  @resource_spec
end

#resource_statusGoogle::Apis::DataplexV1::GoogleCloudDataplexV1AssetResourceStatus

Status of the resource referenced by an asset. Corresponds to the JSON property resourceStatus



799
800
801
# File 'lib/google/apis/dataplex_v1/classes.rb', line 799

def resource_status
  @resource_status
end

#security_statusGoogle::Apis::DataplexV1::GoogleCloudDataplexV1AssetSecurityStatus

Security policy status of the asset. Data security policy, i.e., readers, writers & owners, should be specified in the lake/zone/asset IAM policy. Corresponds to the JSON property securityStatus



805
806
807
# File 'lib/google/apis/dataplex_v1/classes.rb', line 805

def security_status
  @security_status
end

#stateString

Output only. Current state of the asset. Corresponds to the JSON property state

Returns:

  • (String)


810
811
812
# File 'lib/google/apis/dataplex_v1/classes.rb', line 810

def state
  @state
end

#uidString

Output only. System generated globally unique ID for the asset. This ID will be different if the asset is deleted and re-created with the same name. Corresponds to the JSON property uid

Returns:

  • (String)


816
817
818
# File 'lib/google/apis/dataplex_v1/classes.rb', line 816

def uid
  @uid
end

#update_timeString

Output only. The time when the asset was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


821
822
823
# File 'lib/google/apis/dataplex_v1/classes.rb', line 821

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
# File 'lib/google/apis/dataplex_v1/classes.rb', line 828

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @discovery_spec = args[:discovery_spec] if args.key?(:discovery_spec)
  @discovery_status = args[:discovery_status] if args.key?(:discovery_status)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @resource_spec = args[:resource_spec] if args.key?(:resource_spec)
  @resource_status = args[:resource_status] if args.key?(:resource_status)
  @security_status = args[:security_status] if args.key?(:security_status)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end