Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1Asset
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1Asset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
An asset represents a cloud resource that is being managed within a lake as a member of a zone.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#discovery_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetDiscoverySpec
Settings to manage the metadata discovery and publishing for an asset.
-
#discovery_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetDiscoveryStatus
Status of discovery for an asset.
-
#display_name ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#resource_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetResourceSpec
Identifies the cloud resource that is referenced by this asset.
-
#resource_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetResourceStatus
Status of the resource referenced by an asset.
-
#security_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetSecurityStatus
Security policy status of the asset.
-
#state ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1Asset
constructor
A new instance of GoogleCloudDataplexV1Asset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1Asset
Returns a new instance of GoogleCloudDataplexV1Asset.
804 805 806 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 804 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time when the asset was created.
Corresponds to the JSON property createTime
738 739 740 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 738 def create_time @create_time end |
#description ⇒ String
Optional. Description of the asset.
Corresponds to the JSON property description
743 744 745 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 743 def description @description end |
#discovery_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetDiscoverySpec
Settings to manage the metadata discovery and publishing for an asset.
Corresponds to the JSON property discoverySpec
748 749 750 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 748 def discovery_spec @discovery_spec end |
#discovery_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetDiscoveryStatus
Status of discovery for an asset.
Corresponds to the JSON property discoveryStatus
753 754 755 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 753 def discovery_status @discovery_status end |
#display_name ⇒ String
Optional. User friendly display name.
Corresponds to the JSON property displayName
758 759 760 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 758 def display_name @display_name end |
#labels ⇒ Hash<String,String>
Optional. User defined labels for the asset.
Corresponds to the JSON property labels
763 764 765 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 763 def labels @labels end |
#name ⇒ String
Output only. The relative resource name of the asset, of the form: projects/
project_number/locations/location_id/lakes/lake_id/zones/zone_id/assets/
asset_id.
Corresponds to the JSON property name
770 771 772 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 770 def name @name end |
#resource_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetResourceSpec
Identifies the cloud resource that is referenced by this asset.
Corresponds to the JSON property resourceSpec
775 776 777 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 775 def resource_spec @resource_spec end |
#resource_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetResourceStatus
Status of the resource referenced by an asset.
Corresponds to the JSON property resourceStatus
780 781 782 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 780 def resource_status @resource_status end |
#security_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetSecurityStatus
Security policy status of the asset. Data security policy, i.e., readers,
writers & owners, should be specified in the lake/zone/asset IAM policy.
Corresponds to the JSON property securityStatus
786 787 788 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 786 def security_status @security_status end |
#state ⇒ String
Output only. Current state of the asset.
Corresponds to the JSON property state
791 792 793 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 791 def state @state end |
#uid ⇒ String
Output only. System generated globally unique ID for the asset. This ID will
be different if the asset is deleted and re-created with the same name.
Corresponds to the JSON property uid
797 798 799 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 797 def uid @uid end |
#update_time ⇒ String
Output only. The time when the asset was last updated.
Corresponds to the JSON property updateTime
802 803 804 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 802 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 809 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @discovery_spec = args[:discovery_spec] if args.key?(:discovery_spec) @discovery_status = args[:discovery_status] if args.key?(:discovery_status) @display_name = args[:display_name] if args.key?(:display_name) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @resource_spec = args[:resource_spec] if args.key?(:resource_spec) @resource_status = args[:resource_status] if args.key?(:resource_status) @security_status = args[:security_status] if args.key?(:security_status) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |