Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetDiscoverySpec
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetDiscoverySpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Settings to manage the metadata discovery and publishing for an asset.
Instance Attribute Summary collapse
-
#csv_options ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetDiscoverySpecCsvOptions
Describe CSV and similar semi-structured data formats.
-
#enabled ⇒ Boolean
(also: #enabled?)
Optional.
-
#exclude_patterns ⇒ Array<String>
Optional.
-
#include_patterns ⇒ Array<String>
Optional.
-
#json_options ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetDiscoverySpecJsonOptions
Describe JSON data format.
-
#schedule ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1AssetDiscoverySpec
constructor
A new instance of GoogleCloudDataplexV1AssetDiscoverySpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1AssetDiscoverySpec
Returns a new instance of GoogleCloudDataplexV1AssetDiscoverySpec.
874 875 876 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 874 def initialize(**args) update!(**args) end |
Instance Attribute Details
#csv_options ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetDiscoverySpecCsvOptions
Describe CSV and similar semi-structured data formats.
Corresponds to the JSON property csvOptions
833 834 835 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 833 def @csv_options end |
#enabled ⇒ Boolean Also known as: enabled?
Optional. Whether discovery is enabled.
Corresponds to the JSON property enabled
838 839 840 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 838 def enabled @enabled end |
#exclude_patterns ⇒ Array<String>
Optional. The list of patterns to apply for selecting data to exclude during
discovery. For Cloud Storage bucket assets, these are interpreted as glob
patterns used to match object names. For BigQuery dataset assets, these are
interpreted as patterns to match table names.
Corresponds to the JSON property excludePatterns
847 848 849 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 847 def exclude_patterns @exclude_patterns end |
#include_patterns ⇒ Array<String>
Optional. The list of patterns to apply for selecting data to include during
discovery if only a subset of the data should considered. For Cloud Storage
bucket assets, these are interpreted as glob patterns used to match object
names. For BigQuery dataset assets, these are interpreted as patterns to match
table names.
Corresponds to the JSON property includePatterns
856 857 858 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 856 def include_patterns @include_patterns end |
#json_options ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetDiscoverySpecJsonOptions
Describe JSON data format.
Corresponds to the JSON property jsonOptions
861 862 863 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 861 def @json_options end |
#schedule ⇒ String
Optional. Cron schedule (https://en.wikipedia.org/wiki/Cron) for running
discovery periodically. Successive discovery runs must be scheduled at least
60 minutes apart. The default value is to run discovery every 60 minutes.To
explicitly set a timezone to the cron tab, apply a prefix in the cron tab: "
CRON_TZ=$IANA_TIME_ZONE" or TZ=$IANA_TIME_ZONE". The $IANA_TIME_ZONE may
only be a valid string from IANA time zone database. For example, CRON_TZ=
America/New_York 1 * * * *, or TZ=America/New_York 1 * * * *.
Corresponds to the JSON property schedule
872 873 874 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 872 def schedule @schedule end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
879 880 881 882 883 884 885 886 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 879 def update!(**args) @csv_options = args[:csv_options] if args.key?(:csv_options) @enabled = args[:enabled] if args.key?(:enabled) @exclude_patterns = args[:exclude_patterns] if args.key?(:exclude_patterns) @include_patterns = args[:include_patterns] if args.key?(:include_patterns) @json_options = args[:json_options] if args.key?(:json_options) @schedule = args[:schedule] if args.key?(:schedule) end |