Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetDiscoveryStatusStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

The aggregated data statistics for the asset reported by discovery.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1AssetDiscoveryStatusStats

Returns a new instance of GoogleCloudDataplexV1AssetDiscoveryStatusStats.



1030
1031
1032
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1030

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_itemsFixnum

The count of data items within the referenced resource. Corresponds to the JSON property dataItems

Returns:

  • (Fixnum)


1013
1014
1015
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1013

def data_items
  @data_items
end

#data_sizeFixnum

The number of stored data bytes within the referenced resource. Corresponds to the JSON property dataSize

Returns:

  • (Fixnum)


1018
1019
1020
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1018

def data_size
  @data_size
end

#filesetsFixnum

The count of fileset entities within the referenced resource. Corresponds to the JSON property filesets

Returns:

  • (Fixnum)


1023
1024
1025
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1023

def filesets
  @filesets
end

#tablesFixnum

The count of table entities within the referenced resource. Corresponds to the JSON property tables

Returns:

  • (Fixnum)


1028
1029
1030
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1028

def tables
  @tables
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1035
1036
1037
1038
1039
1040
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1035

def update!(**args)
  @data_items = args[:data_items] if args.key?(:data_items)
  @data_size = args[:data_size] if args.key?(:data_size)
  @filesets = args[:filesets] if args.key?(:filesets)
  @tables = args[:tables] if args.key?(:tables)
end