Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1ChangeRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1ChangeRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Represents a proposed change to a metadata resource.
Instance Attribute Summary collapse
-
#approver ⇒ String
Output only.
-
#author ⇒ String
Output only.
-
#change_type ⇒ String
Output only.
-
#create_entry ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1CreateEntryRequest
Create Entry request.
-
#create_entry_link ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1CreateEntryLinkRequest
Request message for CreateEntryLink.
-
#create_glossary ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1CreateGlossaryRequest
Create Glossary Request Corresponds to the JSON property
createGlossary. -
#create_glossary_category ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1CreateGlossaryCategoryRequest
Creates a new GlossaryCategory under the specified Glossary.
-
#create_glossary_term ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1CreateGlossaryTermRequest
Creates a new GlossaryTerm under the specified Glossary.
-
#create_time ⇒ String
Output only.
-
#data_product_access_request ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProductAccessRequest
Message for requesting access to a Data Product.
-
#delete_entry ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DeleteEntryRequest
Delete Entry request.
-
#delete_entry_link ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DeleteEntryLinkRequest
Request message for DeleteEntryLink.
-
#delete_glossary ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DeleteGlossaryRequest
Delete Glossary Request Corresponds to the JSON property
deleteGlossary. -
#delete_glossary_category ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DeleteGlossaryCategoryRequest
Delete GlossaryCategory Request Corresponds to the JSON property
deleteGlossaryCategory. -
#delete_glossary_term ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DeleteGlossaryTermRequest
Delete GlossaryTerm Request Corresponds to the JSON property
deleteGlossaryTerm. -
#etag ⇒ String
Optional.
-
#justification ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#rejection_comment ⇒ String
Output only.
-
#resource ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_entry ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1UpdateEntryRequest
Update Entry request.
-
#update_glossary ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1UpdateGlossaryRequest
Update Glossary Request Corresponds to the JSON property
updateGlossary. -
#update_glossary_category ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1UpdateGlossaryCategoryRequest
Update GlossaryCategory Request Corresponds to the JSON property
updateGlossaryCategory. -
#update_glossary_term ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1UpdateGlossaryTermRequest
Update GlossaryTerm Request Corresponds to the JSON property
updateGlossaryTerm. -
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1ChangeRequest
constructor
A new instance of GoogleCloudDataplexV1ChangeRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1ChangeRequest
Returns a new instance of GoogleCloudDataplexV1ChangeRequest.
1434 1435 1436 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1434 def initialize(**args) update!(**args) end |
Instance Attribute Details
#approver ⇒ String
Output only. The email address of the user who approved/rejected the
ChangeRequest.
Corresponds to the JSON property approver
1288 1289 1290 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1288 def approver @approver end |
#author ⇒ String
Output only. The email address of the user who created the ChangeRequest.
Corresponds to the JSON property author
1293 1294 1295 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1293 def @author end |
#change_type ⇒ String
Output only. The type of change represented by the change_payload. This field
is derived from the populated field in the change_payload oneof.
Corresponds to the JSON property changeType
1299 1300 1301 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1299 def change_type @change_type end |
#create_entry ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1CreateEntryRequest
Create Entry request.
Corresponds to the JSON property createEntry
1304 1305 1306 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1304 def create_entry @create_entry end |
#create_entry_link ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1CreateEntryLinkRequest
Request message for CreateEntryLink.
Corresponds to the JSON property createEntryLink
1309 1310 1311 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1309 def create_entry_link @create_entry_link end |
#create_glossary ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1CreateGlossaryRequest
Create Glossary Request
Corresponds to the JSON property createGlossary
1314 1315 1316 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1314 def create_glossary @create_glossary end |
#create_glossary_category ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1CreateGlossaryCategoryRequest
Creates a new GlossaryCategory under the specified Glossary.
Corresponds to the JSON property createGlossaryCategory
1319 1320 1321 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1319 def create_glossary_category @create_glossary_category end |
#create_glossary_term ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1CreateGlossaryTermRequest
Creates a new GlossaryTerm under the specified Glossary.
Corresponds to the JSON property createGlossaryTerm
1324 1325 1326 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1324 def create_glossary_term @create_glossary_term end |
#create_time ⇒ String
Output only. The time when the ChangeRequest was created.
Corresponds to the JSON property createTime
1329 1330 1331 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1329 def create_time @create_time end |
#data_product_access_request ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProductAccessRequest
Message for requesting access to a Data Product. This will be used to create a
ChangeRequest of type REQUEST_DATA_PRODUCT_ACCESS.
Corresponds to the JSON property dataProductAccessRequest
1335 1336 1337 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1335 def data_product_access_request @data_product_access_request end |
#delete_entry ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DeleteEntryRequest
Delete Entry request.
Corresponds to the JSON property deleteEntry
1340 1341 1342 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1340 def delete_entry @delete_entry end |
#delete_entry_link ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DeleteEntryLinkRequest
Request message for DeleteEntryLink.
Corresponds to the JSON property deleteEntryLink
1345 1346 1347 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1345 def delete_entry_link @delete_entry_link end |
#delete_glossary ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DeleteGlossaryRequest
Delete Glossary Request
Corresponds to the JSON property deleteGlossary
1350 1351 1352 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1350 def delete_glossary @delete_glossary end |
#delete_glossary_category ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DeleteGlossaryCategoryRequest
Delete GlossaryCategory Request
Corresponds to the JSON property deleteGlossaryCategory
1355 1356 1357 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1355 def delete_glossary_category @delete_glossary_category end |
#delete_glossary_term ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DeleteGlossaryTermRequest
Delete GlossaryTerm Request
Corresponds to the JSON property deleteGlossaryTerm
1360 1361 1362 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1360 def delete_glossary_term @delete_glossary_term end |
#etag ⇒ String
Optional. This checksum is computed by the service. It can be sent on update
and delete requests to ensure the client has an up-to-date value before
proceeding.
Corresponds to the JSON property etag
1367 1368 1369 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1367 def etag @etag end |
#justification ⇒ String
Optional. Justification of the ChangeRequest. This should explain why the
change is needed or why it should be approved.
Corresponds to the JSON property justification
1373 1374 1375 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1373 def justification @justification end |
#labels ⇒ Hash<String,String>
Optional. User-defined labels for the ChangeRequest.
Corresponds to the JSON property labels
1378 1379 1380 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1378 def labels @labels end |
#name ⇒ String
Identifier. The relative resource name of the ChangeRequest, of the form:
projects/project_number/locations/location_id/changeRequests/
change_request_id
Corresponds to the JSON property name
1385 1386 1387 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1385 def name @name end |
#rejection_comment ⇒ String
Output only. The reason provided for rejecting the ChangeRequest.
Corresponds to the JSON property rejectionComment
1390 1391 1392 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1390 def rejection_comment @rejection_comment end |
#resource ⇒ String
Output only. The full resource name of the target resource to be modified.
Example: //dataplex.googleapis.com/projects/my-project/locations/us-central1/
entryGroups/my-group/entries/my-entry
Corresponds to the JSON property resource
1397 1398 1399 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1397 def resource @resource end |
#state ⇒ String
Output only. The current state of the ChangeRequest.
Corresponds to the JSON property state
1402 1403 1404 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1402 def state @state end |
#uid ⇒ String
Output only. System generated globally unique ID for the ChangeRequest.
Corresponds to the JSON property uid
1407 1408 1409 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1407 def uid @uid end |
#update_entry ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1UpdateEntryRequest
Update Entry request.
Corresponds to the JSON property updateEntry
1412 1413 1414 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1412 def update_entry @update_entry end |
#update_glossary ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1UpdateGlossaryRequest
Update Glossary Request
Corresponds to the JSON property updateGlossary
1417 1418 1419 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1417 def update_glossary @update_glossary end |
#update_glossary_category ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1UpdateGlossaryCategoryRequest
Update GlossaryCategory Request
Corresponds to the JSON property updateGlossaryCategory
1422 1423 1424 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1422 def update_glossary_category @update_glossary_category end |
#update_glossary_term ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1UpdateGlossaryTermRequest
Update GlossaryTerm Request
Corresponds to the JSON property updateGlossaryTerm
1427 1428 1429 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1427 def update_glossary_term @update_glossary_term end |
#update_time ⇒ String
Output only. The time when the ChangeRequest was last updated.
Corresponds to the JSON property updateTime
1432 1433 1434 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1432 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1439 def update!(**args) @approver = args[:approver] if args.key?(:approver) @author = args[:author] if args.key?(:author) @change_type = args[:change_type] if args.key?(:change_type) @create_entry = args[:create_entry] if args.key?(:create_entry) @create_entry_link = args[:create_entry_link] if args.key?(:create_entry_link) @create_glossary = args[:create_glossary] if args.key?(:create_glossary) @create_glossary_category = args[:create_glossary_category] if args.key?(:create_glossary_category) @create_glossary_term = args[:create_glossary_term] if args.key?(:create_glossary_term) @create_time = args[:create_time] if args.key?(:create_time) @data_product_access_request = args[:data_product_access_request] if args.key?(:data_product_access_request) @delete_entry = args[:delete_entry] if args.key?(:delete_entry) @delete_entry_link = args[:delete_entry_link] if args.key?(:delete_entry_link) @delete_glossary = args[:delete_glossary] if args.key?(:delete_glossary) @delete_glossary_category = args[:delete_glossary_category] if args.key?(:delete_glossary_category) @delete_glossary_term = args[:delete_glossary_term] if args.key?(:delete_glossary_term) @etag = args[:etag] if args.key?(:etag) @justification = args[:justification] if args.key?(:justification) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @rejection_comment = args[:rejection_comment] if args.key?(:rejection_comment) @resource = args[:resource] if args.key?(:resource) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) @update_entry = args[:update_entry] if args.key?(:update_entry) @update_glossary = args[:update_glossary] if args.key?(:update_glossary) @update_glossary_category = args[:update_glossary_category] if args.key?(:update_glossary_category) @update_glossary_term = args[:update_glossary_term] if args.key?(:update_glossary_term) @update_time = args[:update_time] if args.key?(:update_time) end |