Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1Contacts
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1Contacts
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Business contacts part of business context of a Data Domain. Corresponds to the Contacts Aspect in Dataplex Universal Catalog.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1Contacts
constructor
A new instance of GoogleCloudDataplexV1Contacts.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1Contacts
Returns a new instance of GoogleCloudDataplexV1Contacts.
1514 1515 1516 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1514 def initialize(**args) update!(**args) end |
Instance Attribute Details
#identities ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1ContactIdentity>
Required. Identities of the business contacts.
Corresponds to the JSON property identities
1512 1513 1514 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1512 def identities @identities end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1519 1520 1521 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1519 def update!(**args) @identities = args[:identities] if args.key?(:identities) end |