Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1CreateEntryRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Create Entry request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1CreateEntryRequest

Returns a new instance of GoogleCloudDataplexV1CreateEntryRequest.



1537
1538
1539
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1537

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entryGoogle::Apis::DataplexV1::GoogleCloudDataplexV1Entry

An entry is a representation of a data resource that can be described by various metadata. Corresponds to the JSON property entry



1513
1514
1515
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1513

def entry
  @entry
end

#entry_idString

Required. Entry identifier. It has to be unique within an Entry Group.Entries corresponding to Google Cloud resources use an Entry ID format based on full resource names (https://cloud.google.com/apis/design/resource_names# full_resource_name). The format is a full resource name of the resource without the prefix double slashes in the API service name part of the full resource name. This allows retrieval of entries using their associated resource name.For example, if the full resource name of a resource is // library.googleapis.com/shelves/shelf1/books/book2, then the suggested entry_id is library.googleapis.com/shelves/shelf1/books/book2.It is also suggested to follow the same convention for entries corresponding to resources from providers or systems other than Google Cloud.The maximum size of the field is 4000 characters. Corresponds to the JSON property entryId

Returns:

  • (String)


1529
1530
1531
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1529

def entry_id
  @entry_id
end

#parentString

Required. The resource name of the parent Entry Group: projects/project/ locations/location/entryGroups/entry_group. Corresponds to the JSON property parent

Returns:

  • (String)


1535
1536
1537
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1535

def parent
  @parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1542
1543
1544
1545
1546
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1542

def update!(**args)
  @entry = args[:entry] if args.key?(:entry)
  @entry_id = args[:entry_id] if args.key?(:entry_id)
  @parent = args[:parent] if args.key?(:parent)
end