Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1CreateGlossaryCategoryRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1CreateGlossaryCategoryRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Creates a new GlossaryCategory under the specified Glossary.
Instance Attribute Summary collapse
-
#category ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1GlossaryCategory
A GlossaryCategory represents a collection of GlossaryCategories and GlossaryTerms within a Glossary that are related to each other.
-
#category_id ⇒ String
Required.
-
#parent ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1CreateGlossaryCategoryRequest
constructor
A new instance of GoogleCloudDataplexV1CreateGlossaryCategoryRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1CreateGlossaryCategoryRequest
Returns a new instance of GoogleCloudDataplexV1CreateGlossaryCategoryRequest.
1624 1625 1626 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1624 def initialize(**args) update!(**args) end |
Instance Attribute Details
#category ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1GlossaryCategory
A GlossaryCategory represents a collection of GlossaryCategories and
GlossaryTerms within a Glossary that are related to each other.
Corresponds to the JSON property category
1610 1611 1612 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1610 def category @category end |
#category_id ⇒ String
Required. GlossaryCategory identifier.
Corresponds to the JSON property categoryId
1615 1616 1617 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1615 def category_id @category_id end |
#parent ⇒ String
Required. The parent resource where this GlossaryCategory will be created.
Format: projects/project_id_or_number/locations/location_id/glossaries/
glossary_id where locationId refers to a Google Cloud region.
Corresponds to the JSON property parent
1622 1623 1624 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1622 def parent @parent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1629 1630 1631 1632 1633 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1629 def update!(**args) @category = args[:category] if args.key?(:category) @category_id = args[:category_id] if args.key?(:category_id) @parent = args[:parent] if args.key?(:parent) end |