Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1CreateGlossaryCategoryRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1CreateGlossaryCategoryRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Creates a new GlossaryCategory under the specified Glossary.
Instance Attribute Summary collapse
-
#category ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1GlossaryCategory
A GlossaryCategory represents a collection of GlossaryCategories and GlossaryTerms within a Glossary that are related to each other.
-
#category_id ⇒ String
Required.
-
#parent ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1CreateGlossaryCategoryRequest
constructor
A new instance of GoogleCloudDataplexV1CreateGlossaryCategoryRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1CreateGlossaryCategoryRequest
Returns a new instance of GoogleCloudDataplexV1CreateGlossaryCategoryRequest.
1571 1572 1573 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1571 def initialize(**args) update!(**args) end |
Instance Attribute Details
#category ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1GlossaryCategory
A GlossaryCategory represents a collection of GlossaryCategories and
GlossaryTerms within a Glossary that are related to each other.
Corresponds to the JSON property category
1557 1558 1559 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1557 def category @category end |
#category_id ⇒ String
Required. GlossaryCategory identifier.
Corresponds to the JSON property categoryId
1562 1563 1564 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1562 def category_id @category_id end |
#parent ⇒ String
Required. The parent resource where this GlossaryCategory will be created.
Format: projects/project_id_or_number/locations/location_id/glossaries/
glossary_id where locationId refers to a Google Cloud region.
Corresponds to the JSON property parent
1569 1570 1571 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1569 def parent @parent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1576 1577 1578 1579 1580 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1576 def update!(**args) @category = args[:category] if args.key?(:category) @category_id = args[:category_id] if args.key?(:category_id) @parent = args[:parent] if args.key?(:parent) end |