Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1CreateGlossaryRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Create Glossary Request

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1CreateGlossaryRequest

Returns a new instance of GoogleCloudDataplexV1CreateGlossaryRequest.



1613
1614
1615
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1613

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#glossaryGoogle::Apis::DataplexV1::GoogleCloudDataplexV1Glossary

A Glossary represents a collection of GlossaryCategories and GlossaryTerms defined by the user. Glossary is a top level resource and is the Google Cloud parent resource of all the GlossaryCategories and GlossaryTerms within it. Corresponds to the JSON property glossary



1592
1593
1594
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1592

def glossary
  @glossary
end

#glossary_idString

Required. Glossary ID: Glossary identifier. Corresponds to the JSON property glossaryId

Returns:

  • (String)


1597
1598
1599
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1597

def glossary_id
  @glossary_id
end

#parentString

Required. The parent resource where this Glossary will be created. Format: projects/project_id_or_number/locations/location_id where location_id refers to a Google Cloud region. Corresponds to the JSON property parent

Returns:

  • (String)


1604
1605
1606
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1604

def parent
  @parent
end

#validate_onlyBoolean Also known as: validate_only?

Optional. Validates the request without actually creating the Glossary. Default: false. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


1610
1611
1612
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1610

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1618
1619
1620
1621
1622
1623
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1618

def update!(**args)
  @glossary = args[:glossary] if args.key?(:glossary)
  @glossary_id = args[:glossary_id] if args.key?(:glossary_id)
  @parent = args[:parent] if args.key?(:parent)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end