Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1CreateGlossaryTermRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Creates a new GlossaryTerm under the specified Glossary.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1CreateGlossaryTermRequest

Returns a new instance of GoogleCloudDataplexV1CreateGlossaryTermRequest.



1648
1649
1650
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1648

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#parentString

Required. The parent resource where the GlossaryTerm will be created. Format: projects/project_id_or_number/locations/location_id/glossaries/ glossary_id where location_id refers to a Google Cloud region. Corresponds to the JSON property parent

Returns:

  • (String)


1635
1636
1637
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1635

def parent
  @parent
end

#termGoogle::Apis::DataplexV1::GoogleCloudDataplexV1GlossaryTerm

GlossaryTerms are the core of Glossary. A GlossaryTerm holds a rich text description that can be attached to Entries or specific columns to enrich them. Corresponds to the JSON property term



1641
1642
1643
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1641

def term
  @term
end

#term_idString

Required. GlossaryTerm identifier. Corresponds to the JSON property termId

Returns:

  • (String)


1646
1647
1648
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1646

def term_id
  @term_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1653
1654
1655
1656
1657
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1653

def update!(**args)
  @parent = args[:parent] if args.key?(:parent)
  @term = args[:term] if args.key?(:term)
  @term_id = args[:term_id] if args.key?(:term_id)
end