Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataAccessSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

DataAccessSpec holds the access control configuration to be enforced on data stored within resources (eg: rows, columns in BigQuery Tables). When associated with data, the data is only accessible to principals explicitly granted access through the DataAccessSpec. Principals with access to the containing resource are not implicitly granted access.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataAccessSpec

Returns a new instance of GoogleCloudDataplexV1DataAccessSpec.



1675
1676
1677
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1675

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#readersArray<String>

Optional. The format of strings follows the pattern followed by IAM in the bindings. user:email, serviceAccount:email group:email. The set of principals to be granted reader role on data stored within resources. Corresponds to the JSON property readers

Returns:

  • (Array<String>)


1673
1674
1675
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1673

def readers
  @readers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1680
1681
1682
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1680

def update!(**args)
  @readers = args[:readers] if args.key?(:readers)
end