Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataAsset
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Represents a data asset resource that can be packaged and shared via a data product.
Instance Attribute Summary collapse
-
#access_group_configs ⇒ Hash<String,Google::Apis::DataplexV1::GoogleCloudDataplexV1DataAssetAccessGroupConfig>
Optional.
-
#create_time ⇒ String
Output only.
-
#etag ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#resource ⇒ String
Required.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataAsset
constructor
A new instance of GoogleCloudDataplexV1DataAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataAsset
Returns a new instance of GoogleCloudDataplexV1DataAsset.
1816 1817 1818 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1816 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_group_configs ⇒ Hash<String,Google::Apis::DataplexV1::GoogleCloudDataplexV1DataAssetAccessGroupConfig>
Optional. Access groups configurations for this data asset.The key is
DataProduct.AccessGroup.id and the value is AccessGroupConfig.Example: "
analyst": "iamRoles": ["roles/bigquery.dataViewer"] Currently, at most
one IAM role is allowed per access group. For providing multiple predefined
IAM roles, wrap them in a custom IAM role as per https://cloud.google.com/iam/
docs/creating-custom-roles.
Corresponds to the JSON property accessGroupConfigs
1765 1766 1767 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1765 def access_group_configs @access_group_configs end |
#create_time ⇒ String
Output only. The time at which the data asset was created.
Corresponds to the JSON property createTime
1770 1771 1772 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1770 def create_time @create_time end |
#etag ⇒ String
Optional. This checksum is computed by the server based on the value of other
fields, and may be sent on update and delete requests to ensure the client has
an up-to-date value before proceeding.
Corresponds to the JSON property etag
1777 1778 1779 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1777 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. User-defined labels for the data asset.Example: "environment": "
production", "billing": "marketing-department"
Corresponds to the JSON property labels
1783 1784 1785 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1783 def labels @labels end |
#name ⇒ String
Identifier. Resource name of the data asset. Format: projects/
project_id_or_number/locations/location_id/dataProducts/data_product_id/
dataAssets/data_asset_id
Corresponds to the JSON property name
1790 1791 1792 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1790 def name @name end |
#resource ⇒ String
Required. Immutable. Full resource name of the cloud resource represented by
the data asset. This must follow https://cloud.google.com/iam/docs/full-
resource-names. Example: //bigquery.googleapis.com/projects/my_project_123/
datasets/dataset_456/tables/table_789 Only BigQuery tables and datasets are
currently supported. Data asset creator must have getIamPolicy and
setIamPolicy permissions on the resource. Data asset creator must also have
resource specific get permission, for instance, bigquery.tables.get for
BigQuery tables.
Corresponds to the JSON property resource
1802 1803 1804 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1802 def resource @resource end |
#uid ⇒ String
Output only. System generated globally unique ID for the data asset. This ID
will be different if the data asset is deleted and re-created with the same
name.
Corresponds to the JSON property uid
1809 1810 1811 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1809 def uid @uid end |
#update_time ⇒ String
Output only. The time at which the data asset was last updated.
Corresponds to the JSON property updateTime
1814 1815 1816 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1814 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1821 def update!(**args) @access_group_configs = args[:access_group_configs] if args.key?(:access_group_configs) @create_time = args[:create_time] if args.key?(:create_time) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @resource = args[:resource] if args.key?(:resource) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |