Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Represents a data asset resource that can be packaged and shared via a data product.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataAsset

Returns a new instance of GoogleCloudDataplexV1DataAsset.



1749
1750
1751
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1749

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_group_configsHash<String,Google::Apis::DataplexV1::GoogleCloudDataplexV1DataAssetAccessGroupConfig>

Optional. Access groups configurations for this data asset.The key is DataProduct.AccessGroup.id and the value is AccessGroupConfig.Example: " analyst": "iamRoles": ["roles/bigquery.dataViewer"] Currently, at most one IAM role is allowed per access group. For providing multiple predefined IAM roles, wrap them in a custom IAM role as per https://cloud.google.com/iam/ docs/creating-custom-roles. Corresponds to the JSON property accessGroupConfigs



1698
1699
1700
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1698

def access_group_configs
  @access_group_configs
end

#create_timeString

Output only. The time at which the data asset was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1703
1704
1705
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1703

def create_time
  @create_time
end

#etagString

Optional. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


1710
1711
1712
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1710

def etag
  @etag
end

#labelsHash<String,String>

Optional. User-defined labels for the data asset.Example: "environment": " production", "billing": "marketing-department" Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1716
1717
1718
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1716

def labels
  @labels
end

#nameString

Identifier. Resource name of the data asset. Format: projects/ project_id_or_number/locations/location_id/dataProducts/data_product_id/ dataAssets/data_asset_id Corresponds to the JSON property name

Returns:

  • (String)


1723
1724
1725
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1723

def name
  @name
end

#resourceString

Required. Immutable. Full resource name of the cloud resource represented by the data asset. This must follow https://cloud.google.com/iam/docs/full- resource-names. Example: //bigquery.googleapis.com/projects/my_project_123/ datasets/dataset_456/tables/table_789 Only BigQuery tables and datasets are currently supported. Data asset creator must have getIamPolicy and setIamPolicy permissions on the resource. Data asset creator must also have resource specific get permission, for instance, bigquery.tables.get for BigQuery tables. Corresponds to the JSON property resource

Returns:

  • (String)


1735
1736
1737
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1735

def resource
  @resource
end

#uidString

Output only. System generated globally unique ID for the data asset. This ID will be different if the data asset is deleted and re-created with the same name. Corresponds to the JSON property uid

Returns:

  • (String)


1742
1743
1744
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1742

def uid
  @uid
end

#update_timeString

Output only. The time at which the data asset was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1747
1748
1749
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1747

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1754
1755
1756
1757
1758
1759
1760
1761
1762
1763
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1754

def update!(**args)
  @access_group_configs = args[:access_group_configs] if args.key?(:access_group_configs)
  @create_time = args[:create_time] if args.key?(:create_time)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @resource = args[:resource] if args.key?(:resource)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end