Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataAttribute
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataAttribute
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Denotes one dataAttribute in a dataTaxonomy, for example, PII. DataAttribute resources can be defined in a hierarchy. A single dataAttribute resource can contain specs of multiple types PII - ResourceAccessSpec : - readers :foo@bar. com - DataAccessSpec : - readers :bar@foo.com
Instance Attribute Summary collapse
-
#attribute_count ⇒ Fixnum
Output only.
-
#create_time ⇒ String
Output only.
-
#data_access_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataAccessSpec
DataAccessSpec holds the access control configuration to be enforced on data stored within resources (eg: rows, columns in BigQuery Tables).
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up- to-date value before proceeding.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#parent_id ⇒ String
Optional.
-
#resource_access_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1ResourceAccessSpec
ResourceAccessSpec holds the access control configuration to be enforced on the resources, for example, Cloud Storage bucket, BigQuery dataset, BigQuery table.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataAttribute
constructor
A new instance of GoogleCloudDataplexV1DataAttribute.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataAttribute
Returns a new instance of GoogleCloudDataplexV1DataAttribute.
1456 1457 1458 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1456 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attribute_count ⇒ Fixnum
Output only. The number of child attributes present for this attribute.
Corresponds to the JSON property attributeCount
1385 1386 1387 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1385 def attribute_count @attribute_count end |
#create_time ⇒ String
Output only. The time when the DataAttribute was created.
Corresponds to the JSON property createTime
1390 1391 1392 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1390 def create_time @create_time end |
#data_access_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataAccessSpec
DataAccessSpec holds the access control configuration to be enforced on data
stored within resources (eg: rows, columns in BigQuery Tables). When
associated with data, the data is only accessible to principals explicitly
granted access through the DataAccessSpec. Principals with access to the
containing resource are not implicitly granted access.
Corresponds to the JSON property dataAccessSpec
1399 1400 1401 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1399 def data_access_spec @data_access_spec end |
#description ⇒ String
Optional. Description of the DataAttribute.
Corresponds to the JSON property description
1404 1405 1406 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1404 def description @description end |
#display_name ⇒ String
Optional. User friendly display name.
Corresponds to the JSON property displayName
1409 1410 1411 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1409 def display_name @display_name end |
#etag ⇒ String
This checksum is computed by the server based on the value of other fields,
and may be sent on update and delete requests to ensure the client has an up-
to-date value before proceeding.
Corresponds to the JSON property etag
1416 1417 1418 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1416 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. User-defined labels for the DataAttribute.
Corresponds to the JSON property labels
1421 1422 1423 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1421 def labels @labels end |
#name ⇒ String
Output only. The relative resource name of the dataAttribute, of the form:
projects/project_number/locations/location_id/dataTaxonomies/dataTaxonomy
/attributes/data_attribute_id.
Corresponds to the JSON property name
1428 1429 1430 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1428 def name @name end |
#parent_id ⇒ String
Optional. The ID of the parent DataAttribute resource, should belong to the
same data taxonomy. Circular dependency in parent chain is not valid. Maximum
depth of the hierarchy allowed is 4. a -> b -> c -> d -> e, depth = 4
Corresponds to the JSON property parentId
1435 1436 1437 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1435 def parent_id @parent_id end |
#resource_access_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1ResourceAccessSpec
ResourceAccessSpec holds the access control configuration to be enforced on
the resources, for example, Cloud Storage bucket, BigQuery dataset, BigQuery
table.
Corresponds to the JSON property resourceAccessSpec
1442 1443 1444 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1442 def resource_access_spec @resource_access_spec end |
#uid ⇒ String
Output only. System generated globally unique ID for the DataAttribute. This
ID will be different if the DataAttribute is deleted and re-created with the
same name.
Corresponds to the JSON property uid
1449 1450 1451 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1449 def uid @uid end |
#update_time ⇒ String
Output only. The time when the DataAttribute was last updated.
Corresponds to the JSON property updateTime
1454 1455 1456 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1454 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1461 def update!(**args) @attribute_count = args[:attribute_count] if args.key?(:attribute_count) @create_time = args[:create_time] if args.key?(:create_time) @data_access_spec = args[:data_access_spec] if args.key?(:data_access_spec) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @parent_id = args[:parent_id] if args.key?(:parent_id) @resource_access_spec = args[:resource_access_spec] if args.key?(:resource_access_spec) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |