Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataAttributeBinding
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataAttributeBinding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
DataAttributeBinding represents binding of attributes to resources. Eg: Bind ' CustomerInfo' entity with 'PII' attribute.
Instance Attribute Summary collapse
-
#attributes ⇒ Array<String>
Optional.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up- to-date value before proceeding.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#paths ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataAttributeBindingPath>
Optional.
-
#resource ⇒ String
Optional.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataAttributeBinding
constructor
A new instance of GoogleCloudDataplexV1DataAttributeBinding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataAttributeBinding
Returns a new instance of GoogleCloudDataplexV1DataAttributeBinding.
2016 2017 2018 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2016 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes ⇒ Array<String>
Optional. List of attributes to be associated with the resource, provided in
the form: projects/project/locations/location/dataTaxonomies/dataTaxonomy
/attributes/data_attribute_id
Corresponds to the JSON property attributes
1952 1953 1954 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1952 def attributes @attributes end |
#create_time ⇒ String
Output only. The time when the DataAttributeBinding was created.
Corresponds to the JSON property createTime
1957 1958 1959 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1957 def create_time @create_time end |
#description ⇒ String
Optional. Description of the DataAttributeBinding.
Corresponds to the JSON property description
1962 1963 1964 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1962 def description @description end |
#display_name ⇒ String
Optional. User friendly display name.
Corresponds to the JSON property displayName
1967 1968 1969 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1967 def display_name @display_name end |
#etag ⇒ String
This checksum is computed by the server based on the value of other fields,
and may be sent on update and delete requests to ensure the client has an up-
to-date value before proceeding. Etags must be used when calling the
DeleteDataAttributeBinding and the UpdateDataAttributeBinding method.
Corresponds to the JSON property etag
1975 1976 1977 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1975 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. User-defined labels for the DataAttributeBinding.
Corresponds to the JSON property labels
1980 1981 1982 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1980 def labels @labels end |
#name ⇒ String
Output only. The relative resource name of the Data Attribute Binding, of the
form: projects/project_number/locations/location/dataAttributeBindings/
data_attribute_binding_id
Corresponds to the JSON property name
1987 1988 1989 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1987 def name @name end |
#paths ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataAttributeBindingPath>
Optional. The list of paths for items within the associated resource (eg.
columns and partitions within a table) along with attribute bindings.
Corresponds to the JSON property paths
1993 1994 1995 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1993 def paths @paths end |
#resource ⇒ String
Optional. Immutable. The resource name of the resource that is associated to
attributes. Presently, only entity resource is supported in the form: projects/
project/locations/location/lakes/lake/zones/zone/entities/entity_id
Must belong in the same project and region as the attribute binding, and there
can only exist one active binding for a resource.
Corresponds to the JSON property resource
2002 2003 2004 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2002 def resource @resource end |
#uid ⇒ String
Output only. System generated globally unique ID for the DataAttributeBinding.
This ID will be different if the DataAttributeBinding is deleted and re-
created with the same name.
Corresponds to the JSON property uid
2009 2010 2011 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2009 def uid @uid end |
#update_time ⇒ String
Output only. The time when the DataAttributeBinding was last updated.
Corresponds to the JSON property updateTime
2014 2015 2016 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2014 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 2032 2033 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2021 def update!(**args) @attributes = args[:attributes] if args.key?(:attributes) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @paths = args[:paths] if args.key?(:paths) @resource = args[:resource] if args.key?(:resource) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |