Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataAttributeBinding
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataAttributeBinding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
DataAttributeBinding represents binding of attributes to resources. Eg: Bind ' CustomerInfo' entity with 'PII' attribute.
Instance Attribute Summary collapse
-
#attributes ⇒ Array<String>
Optional.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up- to-date value before proceeding.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#paths ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataAttributeBindingPath>
Optional.
-
#resource ⇒ String
Optional.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataAttributeBinding
constructor
A new instance of GoogleCloudDataplexV1DataAttributeBinding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataAttributeBinding
Returns a new instance of GoogleCloudDataplexV1DataAttributeBinding.
1963 1964 1965 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1963 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes ⇒ Array<String>
Optional. List of attributes to be associated with the resource, provided in
the form: projects/project/locations/location/dataTaxonomies/dataTaxonomy
/attributes/data_attribute_id
Corresponds to the JSON property attributes
1899 1900 1901 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1899 def attributes @attributes end |
#create_time ⇒ String
Output only. The time when the DataAttributeBinding was created.
Corresponds to the JSON property createTime
1904 1905 1906 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1904 def create_time @create_time end |
#description ⇒ String
Optional. Description of the DataAttributeBinding.
Corresponds to the JSON property description
1909 1910 1911 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1909 def description @description end |
#display_name ⇒ String
Optional. User friendly display name.
Corresponds to the JSON property displayName
1914 1915 1916 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1914 def display_name @display_name end |
#etag ⇒ String
This checksum is computed by the server based on the value of other fields,
and may be sent on update and delete requests to ensure the client has an up-
to-date value before proceeding. Etags must be used when calling the
DeleteDataAttributeBinding and the UpdateDataAttributeBinding method.
Corresponds to the JSON property etag
1922 1923 1924 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1922 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. User-defined labels for the DataAttributeBinding.
Corresponds to the JSON property labels
1927 1928 1929 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1927 def labels @labels end |
#name ⇒ String
Output only. The relative resource name of the Data Attribute Binding, of the
form: projects/project_number/locations/location/dataAttributeBindings/
data_attribute_binding_id
Corresponds to the JSON property name
1934 1935 1936 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1934 def name @name end |
#paths ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataAttributeBindingPath>
Optional. The list of paths for items within the associated resource (eg.
columns and partitions within a table) along with attribute bindings.
Corresponds to the JSON property paths
1940 1941 1942 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1940 def paths @paths end |
#resource ⇒ String
Optional. Immutable. The resource name of the resource that is associated to
attributes. Presently, only entity resource is supported in the form: projects/
project/locations/location/lakes/lake/zones/zone/entities/entity_id
Must belong in the same project and region as the attribute binding, and there
can only exist one active binding for a resource.
Corresponds to the JSON property resource
1949 1950 1951 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1949 def resource @resource end |
#uid ⇒ String
Output only. System generated globally unique ID for the DataAttributeBinding.
This ID will be different if the DataAttributeBinding is deleted and re-
created with the same name.
Corresponds to the JSON property uid
1956 1957 1958 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1956 def uid @uid end |
#update_time ⇒ String
Output only. The time when the DataAttributeBinding was last updated.
Corresponds to the JSON property updateTime
1961 1962 1963 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1961 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1968 def update!(**args) @attributes = args[:attributes] if args.key?(:attributes) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @paths = args[:paths] if args.key?(:paths) @resource = args[:resource] if args.key?(:resource) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |