Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataAttributeBindingPath

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Represents a subresource of the given resource, and associated bindings with it. Currently supported subresources are column and partition schema fields within a table.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataAttributeBindingPath

Returns a new instance of GoogleCloudDataplexV1DataAttributeBindingPath.



2002
2003
2004
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2002

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributesArray<String>

Optional. List of attributes to be associated with the path of the resource, provided in the form: projects/project/locations/location/dataTaxonomies/ dataTaxonomy/attributes/data_attribute_id Corresponds to the JSON property attributes

Returns:

  • (Array<String>)


1994
1995
1996
# File 'lib/google/apis/dataplex_v1/classes.rb', line 1994

def attributes
  @attributes
end

#nameString

Required. The name identifier of the path. Nested columns should be of the form: 'address.city'. Corresponds to the JSON property name

Returns:

  • (String)


2000
2001
2002
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2000

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2007
2008
2009
2010
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2007

def update!(**args)
  @attributes = args[:attributes] if args.key?(:attributes)
  @name = args[:name] if args.key?(:name)
end