Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoverySpecStorageConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoverySpecStorageConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Configurations related to Cloud Storage as the data source.
Instance Attribute Summary collapse
-
#csv_options ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoverySpecStorageConfigCsvOptions
Describes CSV and similar semi-structured data formats.
-
#exclude_patterns ⇒ Array<String>
Optional.
-
#include_patterns ⇒ Array<String>
Optional.
-
#json_options ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoverySpecStorageConfigJsonOptions
Describes JSON data format.
-
#unstructured_data_options ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoverySpecStorageConfigUnstructuredDataOptions
Describes options for unstructured data discovery.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataDiscoverySpecStorageConfig
constructor
A new instance of GoogleCloudDataplexV1DataDiscoverySpecStorageConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataDiscoverySpecStorageConfig
Returns a new instance of GoogleCloudDataplexV1DataDiscoverySpecStorageConfig.
2316 2317 2318 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2316 def initialize(**args) update!(**args) end |
Instance Attribute Details
#csv_options ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoverySpecStorageConfigCsvOptions
Describes CSV and similar semi-structured data formats.
Corresponds to the JSON property csvOptions
2286 2287 2288 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2286 def @csv_options end |
#exclude_patterns ⇒ Array<String>
Optional. Defines the data to exclude during discovery. Provide a list of
patterns that identify the data to exclude. For Cloud Storage bucket assets,
these patterns are interpreted as glob patterns used to match object names.
For BigQuery dataset assets, these patterns are interpreted as patterns to
match table names.
Corresponds to the JSON property excludePatterns
2295 2296 2297 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2295 def exclude_patterns @exclude_patterns end |
#include_patterns ⇒ Array<String>
Optional. Defines the data to include during discovery when only a subset of
the data should be considered. Provide a list of patterns that identify the
data to include. For Cloud Storage bucket assets, these patterns are
interpreted as glob patterns used to match object names. For BigQuery dataset
assets, these patterns are interpreted as patterns to match table names.
Corresponds to the JSON property includePatterns
2304 2305 2306 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2304 def include_patterns @include_patterns end |
#json_options ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoverySpecStorageConfigJsonOptions
Describes JSON data format.
Corresponds to the JSON property jsonOptions
2309 2310 2311 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2309 def @json_options end |
#unstructured_data_options ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoverySpecStorageConfigUnstructuredDataOptions
Describes options for unstructured data discovery.
Corresponds to the JSON property unstructuredDataOptions
2314 2315 2316 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2314 def @unstructured_data_options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2321 2322 2323 2324 2325 2326 2327 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2321 def update!(**args) @csv_options = args[:csv_options] if args.key?(:csv_options) @exclude_patterns = args[:exclude_patterns] if args.key?(:exclude_patterns) @include_patterns = args[:include_patterns] if args.key?(:include_patterns) @json_options = args[:json_options] if args.key?(:json_options) @unstructured_data_options = args[:unstructured_data_options] if args.key?(:unstructured_data_options) end |