Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoverySpecStorageConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Configurations related to Cloud Storage as the data source.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataDiscoverySpecStorageConfig

Returns a new instance of GoogleCloudDataplexV1DataDiscoverySpecStorageConfig.



2302
2303
2304
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2302

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#csv_optionsGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoverySpecStorageConfigCsvOptions

Describes CSV and similar semi-structured data formats. Corresponds to the JSON property csvOptions



2272
2273
2274
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2272

def csv_options
  @csv_options
end

#exclude_patternsArray<String>

Optional. Defines the data to exclude during discovery. Provide a list of patterns that identify the data to exclude. For Cloud Storage bucket assets, these patterns are interpreted as glob patterns used to match object names. For BigQuery dataset assets, these patterns are interpreted as patterns to match table names. Corresponds to the JSON property excludePatterns

Returns:

  • (Array<String>)


2281
2282
2283
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2281

def exclude_patterns
  @exclude_patterns
end

#include_patternsArray<String>

Optional. Defines the data to include during discovery when only a subset of the data should be considered. Provide a list of patterns that identify the data to include. For Cloud Storage bucket assets, these patterns are interpreted as glob patterns used to match object names. For BigQuery dataset assets, these patterns are interpreted as patterns to match table names. Corresponds to the JSON property includePatterns

Returns:

  • (Array<String>)


2290
2291
2292
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2290

def include_patterns
  @include_patterns
end

#json_optionsGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoverySpecStorageConfigJsonOptions

Describes JSON data format. Corresponds to the JSON property jsonOptions



2295
2296
2297
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2295

def json_options
  @json_options
end

#unstructured_data_optionsGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoverySpecStorageConfigUnstructuredDataOptions

Describes options for unstructured data discovery. Corresponds to the JSON property unstructuredDataOptions



2300
2301
2302
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2300

def unstructured_data_options
  @unstructured_data_options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2307
2308
2309
2310
2311
2312
2313
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2307

def update!(**args)
  @csv_options = args[:csv_options] if args.key?(:csv_options)
  @exclude_patterns = args[:exclude_patterns] if args.key?(:exclude_patterns)
  @include_patterns = args[:include_patterns] if args.key?(:include_patterns)
  @json_options = args[:json_options] if args.key?(:json_options)
  @unstructured_data_options = args[:unstructured_data_options] if args.key?(:unstructured_data_options)
end