Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoverySpecStorageConfigJsonOptions
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoverySpecStorageConfigJsonOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Describes JSON data format.
Instance Attribute Summary collapse
-
#encoding ⇒ String
Optional.
-
#type_inference_disabled ⇒ Boolean
(also: #type_inference_disabled?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataDiscoverySpecStorageConfigJsonOptions
constructor
A new instance of GoogleCloudDataplexV1DataDiscoverySpecStorageConfigJsonOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataDiscoverySpecStorageConfigJsonOptions
Returns a new instance of GoogleCloudDataplexV1DataDiscoverySpecStorageConfigJsonOptions.
2382 2383 2384 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2382 def initialize(**args) update!(**args) end |
Instance Attribute Details
#encoding ⇒ String
Optional. The character encoding of the data. The default is UTF-8.
Corresponds to the JSON property encoding
2372 2373 2374 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2372 def encoding @encoding end |
#type_inference_disabled ⇒ Boolean Also known as: type_inference_disabled?
Optional. Whether to disable the inference of data types for JSON data. If
true, all columns are registered as their primitive types (strings, number, or
boolean).
Corresponds to the JSON property typeInferenceDisabled
2379 2380 2381 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2379 def type_inference_disabled @type_inference_disabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2387 2388 2389 2390 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2387 def update!(**args) @encoding = args[:encoding] if args.key?(:encoding) @type_inference_disabled = args[:type_inference_disabled] if args.key?(:type_inference_disabled) end |