Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoverySpecStorageConfigJsonOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Describes JSON data format.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataDiscoverySpecStorageConfigJsonOptions

Returns a new instance of GoogleCloudDataplexV1DataDiscoverySpecStorageConfigJsonOptions.



2329
2330
2331
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2329

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encodingString

Optional. The character encoding of the data. The default is UTF-8. Corresponds to the JSON property encoding

Returns:

  • (String)


2319
2320
2321
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2319

def encoding
  @encoding
end

#type_inference_disabledBoolean Also known as: type_inference_disabled?

Optional. Whether to disable the inference of data types for JSON data. If true, all columns are registered as their primitive types (strings, number, or boolean). Corresponds to the JSON property typeInferenceDisabled

Returns:

  • (Boolean)


2326
2327
2328
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2326

def type_inference_disabled
  @type_inference_disabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2334
2335
2336
2337
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2334

def update!(**args)
  @encoding = args[:encoding] if args.key?(:encoding)
  @type_inference_disabled = args[:type_inference_disabled] if args.key?(:type_inference_disabled)
end