Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResultSchemaRelationship
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResultSchemaRelationship
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Details of the relationship between the schema of two resources.
Instance Attribute Summary collapse
-
#left_schema_paths ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResultSchemaRelationshipSchemaPaths
Represents an ordered set of paths within a table's schema.
-
#right_schema_paths ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResultSchemaRelationshipSchemaPaths
Represents an ordered set of paths within a table's schema.
-
#sources ⇒ Array<String>
Output only.
-
#type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataDocumentationResultSchemaRelationship
constructor
A new instance of GoogleCloudDataplexV1DataDocumentationResultSchemaRelationship.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataDocumentationResultSchemaRelationship
Returns a new instance of GoogleCloudDataplexV1DataDocumentationResultSchemaRelationship.
2577 2578 2579 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2577 def initialize(**args) update!(**args) end |
Instance Attribute Details
#left_schema_paths ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResultSchemaRelationshipSchemaPaths
Represents an ordered set of paths within a table's schema.
Corresponds to the JSON property leftSchemaPaths
2560 2561 2562 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2560 def left_schema_paths @left_schema_paths end |
#right_schema_paths ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResultSchemaRelationshipSchemaPaths
Represents an ordered set of paths within a table's schema.
Corresponds to the JSON property rightSchemaPaths
2565 2566 2567 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2565 def right_schema_paths @right_schema_paths end |
#sources ⇒ Array<String>
Output only. Sources which generated the schema relation edge.
Corresponds to the JSON property sources
2570 2571 2572 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2570 def sources @sources end |
#type ⇒ String
Output only. The type of relationship between the schema paths.
Corresponds to the JSON property type
2575 2576 2577 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2575 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2582 2583 2584 2585 2586 2587 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2582 def update!(**args) @left_schema_paths = args[:left_schema_paths] if args.key?(:left_schema_paths) @right_schema_paths = args[:right_schema_paths] if args.key?(:right_schema_paths) @sources = args[:sources] if args.key?(:sources) @type = args[:type] if args.key?(:type) end |