Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResultSchemaRelationshipSchemaPaths

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Represents an ordered set of paths within a table's schema.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataDocumentationResultSchemaRelationshipSchemaPaths

Returns a new instance of GoogleCloudDataplexV1DataDocumentationResultSchemaRelationshipSchemaPaths.



2549
2550
2551
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2549

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pathsArray<String>

Output only. An ordered set of Paths to fields within the schema of the table. For fields nested within a top level field of type record, use '.' to separate field names. Examples: Top level field - top_level Nested field - top_level. child.sub_field Corresponds to the JSON property paths

Returns:

  • (Array<String>)


2540
2541
2542
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2540

def paths
  @paths
end

#table_fqnString

Output only. The service-qualified full resource name of the table Ex: // bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/ TABLE_ID Corresponds to the JSON property tableFqn

Returns:

  • (String)


2547
2548
2549
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2547

def table_fqn
  @table_fqn
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2554
2555
2556
2557
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2554

def update!(**args)
  @paths = args[:paths] if args.key?(:paths)
  @table_fqn = args[:table_fqn] if args.key?(:table_fqn)
end