Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResultTableResult
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResultTableResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Generated metadata about the table.
Instance Attribute Summary collapse
-
#name ⇒ String
Output only.
-
#overview ⇒ String
Output only.
-
#queries ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResultQuery>
Output only.
-
#schema ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResultSchema
Schema of the table with generated metadata of columns.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataDocumentationResultTableResult
constructor
A new instance of GoogleCloudDataplexV1DataDocumentationResultTableResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataDocumentationResultTableResult
Returns a new instance of GoogleCloudDataplexV1DataDocumentationResultTableResult.
2042 2043 2044 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2042 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Output only. The service-qualified full resource name of the cloud resource.
Ex: //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/
TABLE_ID
Corresponds to the JSON property name
2025 2026 2027 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2025 def name @name end |
#overview ⇒ String
Output only. Generated description of the table.
Corresponds to the JSON property overview
2030 2031 2032 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2030 def overview @overview end |
#queries ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResultQuery>
Output only. Sample SQL queries for the table.
Corresponds to the JSON property queries
2035 2036 2037 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2035 def queries @queries end |
#schema ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResultSchema
Schema of the table with generated metadata of columns.
Corresponds to the JSON property schema
2040 2041 2042 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2040 def schema @schema end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2047 2048 2049 2050 2051 2052 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2047 def update!(**args) @name = args[:name] if args.key?(:name) @overview = args[:overview] if args.key?(:overview) @queries = args[:queries] if args.key?(:queries) @schema = args[:schema] if args.key?(:schema) end |