Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDomain
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDomain
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
A DataDomain is a logical grouping of data resources for governance, discovery, and management at scale.
Instance Attribute Summary collapse
-
#contacts ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1Contacts
Business contacts part of business context of a Data Domain.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#parent_data_domain ⇒ String
Optional.
-
#policy_member ⇒ Google::Apis::DataplexV1::GoogleIamV1ResourcePolicyMember
Output-only policy member strings of a Google Cloud resource's built-in identity.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataDomain
constructor
A new instance of GoogleCloudDataplexV1DataDomain.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataDomain
Returns a new instance of GoogleCloudDataplexV1DataDomain.
2750 2751 2752 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2750 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contacts ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1Contacts
Business contacts part of business context of a Data Domain. Corresponds to
the Contacts Aspect in Dataplex Universal Catalog.
Corresponds to the JSON property contacts
2697 2698 2699 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2697 def contacts @contacts end |
#create_time ⇒ String
Output only. The time at which the DataDomain was created.
Corresponds to the JSON property createTime
2702 2703 2704 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2702 def create_time @create_time end |
#description ⇒ String
Optional. User-provided description of the DataDomain.
Corresponds to the JSON property description
2707 2708 2709 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2707 def description @description end |
#display_name ⇒ String
Required. User-friendly display name.
Corresponds to the JSON property displayName
2712 2713 2714 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2712 def display_name @display_name end |
#labels ⇒ Hash<String,String>
Optional. User-defined labels for the DataDomain.
Corresponds to the JSON property labels
2717 2718 2719 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2717 def labels @labels end |
#name ⇒ String
Identifier. The relative resource name of the DataDomain, of the form:
projects/project_id_or_number/locations/location_id/dataDomains/
data_domain_id
Corresponds to the JSON property name
2724 2725 2726 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2724 def name @name end |
#parent_data_domain ⇒ String
Optional. Immutable. The resource name of the parent DataDomain. Empty if this
is a top-level DataDomain. Format: projects/project_id_or_number/locations/
location/dataDomains/parent_data_domain_id This field is immutable after
creation.
Corresponds to the JSON property parentDataDomain
2732 2733 2734 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2732 def parent_data_domain @parent_data_domain end |
#policy_member ⇒ Google::Apis::DataplexV1::GoogleIamV1ResourcePolicyMember
Output-only policy member strings of a Google Cloud resource's built-in
identity.
Corresponds to the JSON property policyMember
2738 2739 2740 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2738 def policy_member @policy_member end |
#uid ⇒ String
Output only. System-generated globally unique ID for the DataDomain.
Corresponds to the JSON property uid
2743 2744 2745 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2743 def uid @uid end |
#update_time ⇒ String
Output only. The time at which the DataDomain was last updated.
Corresponds to the JSON property updateTime
2748 2749 2750 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2748 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2755 2756 2757 2758 2759 2760 2761 2762 2763 2764 2765 2766 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2755 def update!(**args) @contacts = args[:contacts] if args.key?(:contacts) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @parent_data_domain = args[:parent_data_domain] if args.key?(:parent_data_domain) @policy_member = args[:policy_member] if args.key?(:policy_member) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |