Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProductAccessApprovalConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProductAccessApprovalConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Configuration for access approval for the data product.
Instance Attribute Summary collapse
-
#approver_emails ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataProductAccessApprovalConfig
constructor
A new instance of GoogleCloudDataplexV1DataProductAccessApprovalConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataProductAccessApprovalConfig
Returns a new instance of GoogleCloudDataplexV1DataProductAccessApprovalConfig.
2747 2748 2749 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2747 def initialize(**args) update!(**args) end |
Instance Attribute Details
#approver_emails ⇒ Array<String>
Optional. Specifies the email addresses of users who are potential approvers
and are notified when an access request is made for the data product. The
maximum number of emails allowed is 10.
Corresponds to the JSON property approverEmails
2745 2746 2747 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2745 def approver_emails @approver_emails end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2752 2753 2754 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2752 def update!(**args) @approver_emails = args[:approver_emails] if args.key?(:approver_emails) end |