Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProductAccessGroup
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProductAccessGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Custom user defined access groups at the data product level. These are used for granting different levels of access (IAM roles) on the individual data product's data assets.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#id ⇒ String
Required.
-
#principal ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProductPrincipal
Represents the principal entity associated with an access group, as per https:/ /cloud.google.com/iam/docs/principals-overview.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataProductAccessGroup
constructor
A new instance of GoogleCloudDataplexV1DataProductAccessGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataProductAccessGroup
Returns a new instance of GoogleCloudDataplexV1DataProductAccessGroup.
2995 2996 2997 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2995 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. Description of the access group.
Corresponds to the JSON property description
2975 2976 2977 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2975 def description @description end |
#display_name ⇒ String
Required. User friendly display name of the access group. Eg. "Analyst", "
Developer", etc.
Corresponds to the JSON property displayName
2981 2982 2983 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2981 def display_name @display_name end |
#id ⇒ String
Required. Unique identifier of the access group within the data product. User
defined. Eg. "analyst", "developer", etc.
Corresponds to the JSON property id
2987 2988 2989 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2987 def id @id end |
#principal ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProductPrincipal
Represents the principal entity associated with an access group, as per https:/
/cloud.google.com/iam/docs/principals-overview.
Corresponds to the JSON property principal
2993 2994 2995 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2993 def principal @principal end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3000 3001 3002 3003 3004 3005 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3000 def update!(**args) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @id = args[:id] if args.key?(:id) @principal = args[:principal] if args.key?(:principal) end |