Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProductAccessGroup
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProductAccessGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Custom user defined access groups at the data product level. These are used for granting different levels of access (IAM roles) on the individual data product's data assets.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#id ⇒ String
Required.
-
#principal ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProductPrincipal
Represents the principal entity associated with an access group, as per https:/ /cloud.google.com/iam/docs/principals-overview.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataProductAccessGroup
constructor
A new instance of GoogleCloudDataplexV1DataProductAccessGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataProductAccessGroup
Returns a new instance of GoogleCloudDataplexV1DataProductAccessGroup.
2981 2982 2983 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2981 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. Description of the access group.
Corresponds to the JSON property description
2961 2962 2963 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2961 def description @description end |
#display_name ⇒ String
Required. User friendly display name of the access group. Eg. "Analyst", "
Developer", etc.
Corresponds to the JSON property displayName
2967 2968 2969 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2967 def display_name @display_name end |
#id ⇒ String
Required. Unique identifier of the access group within the data product. User
defined. Eg. "analyst", "developer", etc.
Corresponds to the JSON property id
2973 2974 2975 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2973 def id @id end |
#principal ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProductPrincipal
Represents the principal entity associated with an access group, as per https:/
/cloud.google.com/iam/docs/principals-overview.
Corresponds to the JSON property principal
2979 2980 2981 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2979 def principal @principal end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2986 2987 2988 2989 2990 2991 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2986 def update!(**args) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @id = args[:id] if args.key?(:id) @principal = args[:principal] if args.key?(:principal) end |