Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProductAccessGroup
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProductAccessGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Custom user defined access groups at the data product level. These are used for granting different levels of access (IAM roles) on the individual data product's data assets.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#id ⇒ String
Required.
-
#principal ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProductPrincipal
Represents the principal entity associated with an access group, as per https:/ /cloud.google.com/iam/docs/principals-overview.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataProductAccessGroup
constructor
A new instance of GoogleCloudDataplexV1DataProductAccessGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataProductAccessGroup
Returns a new instance of GoogleCloudDataplexV1DataProductAccessGroup.
2786 2787 2788 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2786 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. Description of the access group.
Corresponds to the JSON property description
2766 2767 2768 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2766 def description @description end |
#display_name ⇒ String
Required. User friendly display name of the access group. Eg. "Analyst", "
Developer", etc.
Corresponds to the JSON property displayName
2772 2773 2774 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2772 def display_name @display_name end |
#id ⇒ String
Required. Unique identifier of the access group within the data product. User
defined. Eg. "analyst", "developer", etc.
Corresponds to the JSON property id
2778 2779 2780 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2778 def id @id end |
#principal ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProductPrincipal
Represents the principal entity associated with an access group, as per https:/
/cloud.google.com/iam/docs/principals-overview.
Corresponds to the JSON property principal
2784 2785 2786 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2784 def principal @principal end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2791 2792 2793 2794 2795 2796 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2791 def update!(**args) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @id = args[:id] if args.key?(:id) @principal = args[:principal] if args.key?(:principal) end |