Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProductPrincipal
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProductPrincipal
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Represents the principal entity associated with an access group, as per https:/ /cloud.google.com/iam/docs/principals-overview.
Instance Attribute Summary collapse
-
#google_group ⇒ String
Optional.
-
#service_account ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataProductPrincipal
constructor
A new instance of GoogleCloudDataplexV1DataProductPrincipal.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataProductPrincipal
Returns a new instance of GoogleCloudDataplexV1DataProductPrincipal.
2861 2862 2863 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2861 def initialize(**args) update!(**args) end |
Instance Attribute Details
#google_group ⇒ String
Optional. Email of the Google Group, as per https://cloud.google.com/iam/docs/
principals-overview#google-group.
Corresponds to the JSON property googleGroup
2853 2854 2855 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2853 def google_group @google_group end |
#service_account ⇒ String
Optional. Specifies the email of the producer service account, as per https://
cloud.google.com/iam/docs/principals-overview#service-account.
Corresponds to the JSON property serviceAccount
2859 2860 2861 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2859 def service_account @service_account end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2866 2867 2868 2869 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2866 def update!(**args) @google_group = args[:google_group] if args.key?(:google_group) @service_account = args[:service_account] if args.key?(:service_account) end |