Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

DataProfileResult defines the output of DataProfileScan. Each field of the table will have field type specific profile result.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataProfileResult

Returns a new instance of GoogleCloudDataplexV1DataProfileResult.



3099
3100
3101
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3099

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#catalog_publishing_statusGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataScanCatalogPublishingStatus

The status of publishing the data scan result as Dataplex Universal Catalog metadata. Multiple DataScan log events may exist, each with different publishing information depending on the type of publishing triggered. Corresponds to the JSON property catalogPublishingStatus



3077
3078
3079
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3077

def catalog_publishing_status
  @catalog_publishing_status
end

#post_scan_actions_resultGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultPostScanActionsResult

The result of post scan actions of DataProfileScan job. Corresponds to the JSON property postScanActionsResult



3082
3083
3084
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3082

def post_scan_actions_result
  @post_scan_actions_result
end

#profileGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfile

Contains name, type, mode and field type specific profile information. Corresponds to the JSON property profile



3087
3088
3089
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3087

def profile
  @profile
end

#row_countFixnum

Output only. The count of rows scanned. Corresponds to the JSON property rowCount

Returns:

  • (Fixnum)


3092
3093
3094
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3092

def row_count
  @row_count
end

#scanned_dataGoogle::Apis::DataplexV1::GoogleCloudDataplexV1ScannedData

The data scanned during processing (e.g. in incremental DataScan) Corresponds to the JSON property scannedData



3097
3098
3099
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3097

def scanned_data
  @scanned_data
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3104
3105
3106
3107
3108
3109
3110
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3104

def update!(**args)
  @catalog_publishing_status = args[:catalog_publishing_status] if args.key?(:catalog_publishing_status)
  @post_scan_actions_result = args[:post_scan_actions_result] if args.key?(:post_scan_actions_result)
  @profile = args[:profile] if args.key?(:profile)
  @row_count = args[:row_count] if args.key?(:row_count)
  @scanned_data = args[:scanned_data] if args.key?(:scanned_data)
end