Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

DataProfileResult defines the output of DataProfileScan. Each field of the table will have field type specific profile result.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataProfileResult

Returns a new instance of GoogleCloudDataplexV1DataProfileResult.



2093
2094
2095
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2093

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#post_scan_actions_resultGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultPostScanActionsResult

The result of post scan actions of DataProfileScan job. Corresponds to the JSON property postScanActionsResult



2076
2077
2078
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2076

def post_scan_actions_result
  @post_scan_actions_result
end

#profileGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfile

Contains name, type, mode and field type specific profile information. Corresponds to the JSON property profile



2081
2082
2083
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2081

def profile
  @profile
end

#row_countFixnum

Output only. The count of rows scanned. Corresponds to the JSON property rowCount

Returns:

  • (Fixnum)


2086
2087
2088
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2086

def row_count
  @row_count
end

#scanned_dataGoogle::Apis::DataplexV1::GoogleCloudDataplexV1ScannedData

The data scanned during processing (e.g. in incremental DataScan) Corresponds to the JSON property scannedData



2091
2092
2093
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2091

def scanned_data
  @scanned_data
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2098
2099
2100
2101
2102
2103
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2098

def update!(**args)
  @post_scan_actions_result = args[:post_scan_actions_result] if args.key?(:post_scan_actions_result)
  @profile = args[:profile] if args.key?(:profile)
  @row_count = args[:row_count] if args.key?(:row_count)
  @scanned_data = args[:scanned_data] if args.key?(:scanned_data)
end