Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfileField
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfileField
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
A field within a table.
Instance Attribute Summary collapse
-
#mode ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#profile ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfo
The profile information for each field type.
-
#type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataProfileResultProfileField
constructor
A new instance of GoogleCloudDataplexV1DataProfileResultProfileField.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataProfileResultProfileField
Returns a new instance of GoogleCloudDataplexV1DataProfileResultProfileField.
2200 2201 2202 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2200 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mode ⇒ String
Output only. The mode of the field. Possible values include: REQUIRED, if it
is a required field. NULLABLE, if it is an optional field. REPEATED, if it is
a repeated field.
Corresponds to the JSON property mode
2179 2180 2181 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2179 def mode @mode end |
#name ⇒ String
Output only. The name of the field.
Corresponds to the JSON property name
2184 2185 2186 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2184 def name @name end |
#profile ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfo
The profile information for each field type.
Corresponds to the JSON property profile
2189 2190 2191 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2189 def profile @profile end |
#type ⇒ String
Output only. The data type retrieved from the schema of the data source. For
instance, for a BigQuery native table, it is the BigQuery Table Schema (https:/
/cloud.google.com/bigquery/docs/reference/rest/v2/tables#tablefieldschema).
For a Dataplex Universal Catalog Entity, it is the Entity Schema (https://
cloud.google.com/dataplex/docs/reference/rpc/google.cloud.dataplex.v1#type_3).
Corresponds to the JSON property type
2198 2199 2200 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2198 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2205 2206 2207 2208 2209 2210 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2205 def update!(**args) @mode = args[:mode] if args.key?(:mode) @name = args[:name] if args.key?(:name) @profile = args[:profile] if args.key?(:profile) @type = args[:type] if args.key?(:type) end |