Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfo
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
The profile information for each field type.
Instance Attribute Summary collapse
-
#distinct_ratio ⇒ Float
Output only.
-
#double_profile ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoDoubleFieldInfo
The profile information for a double type field.
-
#integer_profile ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoIntegerFieldInfo
The profile information for an integer type field.
-
#null_ratio ⇒ Float
Output only.
-
#string_profile ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoStringFieldInfo
The profile information for a string type field.
-
#top_n_values ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoTopNValue>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfo
constructor
A new instance of GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfo
Returns a new instance of GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfo.
3065 3066 3067 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3065 def initialize(**args) update!(**args) end |
Instance Attribute Details
#distinct_ratio ⇒ Float
Output only. Ratio of rows with distinct values against total scanned rows.
Not available for complex non-groupable field type, including RECORD, ARRAY,
GEOGRAPHY, and JSON, as well as fields with REPEATABLE mode.
Corresponds to the JSON property distinctRatio
3034 3035 3036 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3034 def distinct_ratio @distinct_ratio end |
#double_profile ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoDoubleFieldInfo
The profile information for a double type field.
Corresponds to the JSON property doubleProfile
3039 3040 3041 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3039 def double_profile @double_profile end |
#integer_profile ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoIntegerFieldInfo
The profile information for an integer type field.
Corresponds to the JSON property integerProfile
3044 3045 3046 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3044 def integer_profile @integer_profile end |
#null_ratio ⇒ Float
Output only. Ratio of rows with null value against total scanned rows.
Corresponds to the JSON property nullRatio
3049 3050 3051 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3049 def null_ratio @null_ratio end |
#string_profile ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoStringFieldInfo
The profile information for a string type field.
Corresponds to the JSON property stringProfile
3054 3055 3056 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3054 def string_profile @string_profile end |
#top_n_values ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoTopNValue>
Output only. The list of top N non-null values, frequency and ratio with which
they occur in the scanned data. N is 10 or equal to the number of distinct
values in the field, whichever is smaller. Not available for complex non-
groupable field type, including RECORD, ARRAY, GEOGRAPHY, and JSON, as well as
fields with REPEATABLE mode.
Corresponds to the JSON property topNValues
3063 3064 3065 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3063 def top_n_values @top_n_values end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3070 3071 3072 3073 3074 3075 3076 3077 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3070 def update!(**args) @distinct_ratio = args[:distinct_ratio] if args.key?(:distinct_ratio) @double_profile = args[:double_profile] if args.key?(:double_profile) @integer_profile = args[:integer_profile] if args.key?(:integer_profile) @null_ratio = args[:null_ratio] if args.key?(:null_ratio) @string_profile = args[:string_profile] if args.key?(:string_profile) @top_n_values = args[:top_n_values] if args.key?(:top_n_values) end |