Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoDoubleFieldInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

The profile information for a double type field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoDoubleFieldInfo

Returns a new instance of GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoDoubleFieldInfo.



3317
3318
3319
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3317

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#averageFloat

Output only. Average of non-null values in the scanned data. NaN, if the field has a NaN. Corresponds to the JSON property average

Returns:

  • (Float)


3283
3284
3285
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3283

def average
  @average
end

#maxFloat

Output only. Maximum of non-null values in the scanned data. NaN, if the field has a NaN. Corresponds to the JSON property max

Returns:

  • (Float)


3289
3290
3291
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3289

def max
  @max
end

#minFloat

Output only. Minimum of non-null values in the scanned data. NaN, if the field has a NaN. Corresponds to the JSON property min

Returns:

  • (Float)


3295
3296
3297
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3295

def min
  @min
end

#quartilesArray<Float>

Output only. A quartile divides the number of data points into four parts, or quarters, of more-or-less equal size. Three main quartiles used are: The first quartile (Q1) splits off the lowest 25% of data from the highest 75%. It is also known as the lower or 25th empirical quartile, as 25% of the data is below this point. The second quartile (Q2) is the median of a data set. So, 50% of the data lies below this point. The third quartile (Q3) splits off the highest 25% of data from the lowest 75%. It is known as the upper or 75th empirical quartile, as 75% of the data lies below this point. Here, the quartiles is provided as an ordered list of quartile values for the scanned data, occurring in order Q1, median, Q3. Corresponds to the JSON property quartiles

Returns:

  • (Array<Float>)


3309
3310
3311
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3309

def quartiles
  @quartiles
end

#standard_deviationFloat

Output only. Standard deviation of non-null values in the scanned data. NaN, if the field has a NaN. Corresponds to the JSON property standardDeviation

Returns:

  • (Float)


3315
3316
3317
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3315

def standard_deviation
  @standard_deviation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3322
3323
3324
3325
3326
3327
3328
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3322

def update!(**args)
  @average = args[:average] if args.key?(:average)
  @max = args[:max] if args.key?(:max)
  @min = args[:min] if args.key?(:min)
  @quartiles = args[:quartiles] if args.key?(:quartiles)
  @standard_deviation = args[:standard_deviation] if args.key?(:standard_deviation)
end