Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoDoubleFieldInfo
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoDoubleFieldInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
The profile information for a double type field.
Instance Attribute Summary collapse
-
#average ⇒ Float
Output only.
-
#max ⇒ Float
Output only.
-
#min ⇒ Float
Output only.
-
#quartiles ⇒ Array<Float>
Output only.
-
#standard_deviation ⇒ Float
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoDoubleFieldInfo
constructor
A new instance of GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoDoubleFieldInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoDoubleFieldInfo
Returns a new instance of GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoDoubleFieldInfo.
3122 3123 3124 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3122 def initialize(**args) update!(**args) end |
Instance Attribute Details
#average ⇒ Float
Output only. Average of non-null values in the scanned data. NaN, if the field
has a NaN.
Corresponds to the JSON property average
3088 3089 3090 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3088 def average @average end |
#max ⇒ Float
Output only. Maximum of non-null values in the scanned data. NaN, if the field
has a NaN.
Corresponds to the JSON property max
3094 3095 3096 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3094 def max @max end |
#min ⇒ Float
Output only. Minimum of non-null values in the scanned data. NaN, if the field
has a NaN.
Corresponds to the JSON property min
3100 3101 3102 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3100 def min @min end |
#quartiles ⇒ Array<Float>
Output only. A quartile divides the number of data points into four parts, or
quarters, of more-or-less equal size. Three main quartiles used are: The first
quartile (Q1) splits off the lowest 25% of data from the highest 75%. It is
also known as the lower or 25th empirical quartile, as 25% of the data is
below this point. The second quartile (Q2) is the median of a data set. So, 50%
of the data lies below this point. The third quartile (Q3) splits off the
highest 25% of data from the lowest 75%. It is known as the upper or 75th
empirical quartile, as 75% of the data lies below this point. Here, the
quartiles is provided as an ordered list of quartile values for the scanned
data, occurring in order Q1, median, Q3.
Corresponds to the JSON property quartiles
3114 3115 3116 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3114 def quartiles @quartiles end |
#standard_deviation ⇒ Float
Output only. Standard deviation of non-null values in the scanned data. NaN,
if the field has a NaN.
Corresponds to the JSON property standardDeviation
3120 3121 3122 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3120 def standard_deviation @standard_deviation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3127 3128 3129 3130 3131 3132 3133 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3127 def update!(**args) @average = args[:average] if args.key?(:average) @max = args[:max] if args.key?(:max) @min = args[:min] if args.key?(:min) @quartiles = args[:quartiles] if args.key?(:quartiles) @standard_deviation = args[:standard_deviation] if args.key?(:standard_deviation) end |