Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoIntegerFieldInfo
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoIntegerFieldInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
The profile information for an integer type field.
Instance Attribute Summary collapse
-
#average ⇒ Float
Output only.
-
#max ⇒ Fixnum
Output only.
-
#min ⇒ Fixnum
Output only.
-
#quartiles ⇒ Array<Fixnum>
Output only.
-
#standard_deviation ⇒ Float
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoIntegerFieldInfo
constructor
A new instance of GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoIntegerFieldInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoIntegerFieldInfo
Returns a new instance of GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoIntegerFieldInfo.
3387 3388 3389 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3387 def initialize(**args) update!(**args) end |
Instance Attribute Details
#average ⇒ Float
Output only. Average of non-null values in the scanned data. NaN, if the field
has a NaN.
Corresponds to the JSON property average
3353 3354 3355 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3353 def average @average end |
#max ⇒ Fixnum
Output only. Maximum of non-null values in the scanned data. NaN, if the field
has a NaN.
Corresponds to the JSON property max
3359 3360 3361 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3359 def max @max end |
#min ⇒ Fixnum
Output only. Minimum of non-null values in the scanned data. NaN, if the field
has a NaN.
Corresponds to the JSON property min
3365 3366 3367 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3365 def min @min end |
#quartiles ⇒ Array<Fixnum>
Output only. A quartile divides the number of data points into four parts, or
quarters, of more-or-less equal size. Three main quartiles used are: The first
quartile (Q1) splits off the lowest 25% of data from the highest 75%. It is
also known as the lower or 25th empirical quartile, as 25% of the data is
below this point. The second quartile (Q2) is the median of a data set. So, 50%
of the data lies below this point. The third quartile (Q3) splits off the
highest 25% of data from the lowest 75%. It is known as the upper or 75th
empirical quartile, as 75% of the data lies below this point. Here, the
quartiles is provided as an ordered list of approximate quartile values for
the scanned data, occurring in order Q1, median, Q3.
Corresponds to the JSON property quartiles
3379 3380 3381 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3379 def quartiles @quartiles end |
#standard_deviation ⇒ Float
Output only. Standard deviation of non-null values in the scanned data. NaN,
if the field has a NaN.
Corresponds to the JSON property standardDeviation
3385 3386 3387 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3385 def standard_deviation @standard_deviation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3392 3393 3394 3395 3396 3397 3398 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3392 def update!(**args) @average = args[:average] if args.key?(:average) @max = args[:max] if args.key?(:max) @min = args[:min] if args.key?(:min) @quartiles = args[:quartiles] if args.key?(:quartiles) @standard_deviation = args[:standard_deviation] if args.key?(:standard_deviation) end |