Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoIntegerFieldInfo
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoIntegerFieldInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
The profile information for an integer type field.
Instance Attribute Summary collapse
-
#average ⇒ Float
Output only.
-
#max ⇒ Fixnum
Output only.
-
#min ⇒ Fixnum
Output only.
-
#quartiles ⇒ Array<Fixnum>
Output only.
-
#standard_deviation ⇒ Float
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoIntegerFieldInfo
constructor
A new instance of GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoIntegerFieldInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoIntegerFieldInfo
Returns a new instance of GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoIntegerFieldInfo.
3373 3374 3375 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3373 def initialize(**args) update!(**args) end |
Instance Attribute Details
#average ⇒ Float
Output only. Average of non-null values in the scanned data. NaN, if the field
has a NaN.
Corresponds to the JSON property average
3339 3340 3341 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3339 def average @average end |
#max ⇒ Fixnum
Output only. Maximum of non-null values in the scanned data. NaN, if the field
has a NaN.
Corresponds to the JSON property max
3345 3346 3347 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3345 def max @max end |
#min ⇒ Fixnum
Output only. Minimum of non-null values in the scanned data. NaN, if the field
has a NaN.
Corresponds to the JSON property min
3351 3352 3353 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3351 def min @min end |
#quartiles ⇒ Array<Fixnum>
Output only. A quartile divides the number of data points into four parts, or
quarters, of more-or-less equal size. Three main quartiles used are: The first
quartile (Q1) splits off the lowest 25% of data from the highest 75%. It is
also known as the lower or 25th empirical quartile, as 25% of the data is
below this point. The second quartile (Q2) is the median of a data set. So, 50%
of the data lies below this point. The third quartile (Q3) splits off the
highest 25% of data from the lowest 75%. It is known as the upper or 75th
empirical quartile, as 75% of the data lies below this point. Here, the
quartiles is provided as an ordered list of approximate quartile values for
the scanned data, occurring in order Q1, median, Q3.
Corresponds to the JSON property quartiles
3365 3366 3367 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3365 def quartiles @quartiles end |
#standard_deviation ⇒ Float
Output only. Standard deviation of non-null values in the scanned data. NaN,
if the field has a NaN.
Corresponds to the JSON property standardDeviation
3371 3372 3373 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3371 def standard_deviation @standard_deviation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3378 3379 3380 3381 3382 3383 3384 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3378 def update!(**args) @average = args[:average] if args.key?(:average) @max = args[:max] if args.key?(:max) @min = args[:min] if args.key?(:min) @quartiles = args[:quartiles] if args.key?(:quartiles) @standard_deviation = args[:standard_deviation] if args.key?(:standard_deviation) end |