Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoIntegerFieldInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

The profile information for an integer type field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoIntegerFieldInfo

Returns a new instance of GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoIntegerFieldInfo.



2366
2367
2368
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2366

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#averageFloat

Output only. Average of non-null values in the scanned data. NaN, if the field has a NaN. Corresponds to the JSON property average

Returns:

  • (Float)


2332
2333
2334
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2332

def average
  @average
end

#maxFixnum

Output only. Maximum of non-null values in the scanned data. NaN, if the field has a NaN. Corresponds to the JSON property max

Returns:

  • (Fixnum)


2338
2339
2340
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2338

def max
  @max
end

#minFixnum

Output only. Minimum of non-null values in the scanned data. NaN, if the field has a NaN. Corresponds to the JSON property min

Returns:

  • (Fixnum)


2344
2345
2346
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2344

def min
  @min
end

#quartilesArray<Fixnum>

Output only. A quartile divides the number of data points into four parts, or quarters, of more-or-less equal size. Three main quartiles used are: The first quartile (Q1) splits off the lowest 25% of data from the highest 75%. It is also known as the lower or 25th empirical quartile, as 25% of the data is below this point. The second quartile (Q2) is the median of a data set. So, 50% of the data lies below this point. The third quartile (Q3) splits off the highest 25% of data from the lowest 75%. It is known as the upper or 75th empirical quartile, as 75% of the data lies below this point. Here, the quartiles is provided as an ordered list of approximate quartile values for the scanned data, occurring in order Q1, median, Q3. Corresponds to the JSON property quartiles

Returns:

  • (Array<Fixnum>)


2358
2359
2360
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2358

def quartiles
  @quartiles
end

#standard_deviationFloat

Output only. Standard deviation of non-null values in the scanned data. NaN, if the field has a NaN. Corresponds to the JSON property standardDeviation

Returns:

  • (Float)


2364
2365
2366
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2364

def standard_deviation
  @standard_deviation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2371
2372
2373
2374
2375
2376
2377
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2371

def update!(**args)
  @average = args[:average] if args.key?(:average)
  @max = args[:max] if args.key?(:max)
  @min = args[:min] if args.key?(:min)
  @quartiles = args[:quartiles] if args.key?(:quartiles)
  @standard_deviation = args[:standard_deviation] if args.key?(:standard_deviation)
end