Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoTopNValue
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoTopNValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Top N non-null values in the scanned data.
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
Output only.
-
#ratio ⇒ Float
Output only.
-
#value ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoTopNValue
constructor
A new instance of GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoTopNValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoTopNValue
Returns a new instance of GoogleCloudDataplexV1DataProfileResultProfileFieldProfileInfoTopNValue.
3243 3244 3245 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3243 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
Output only. Count of the corresponding value in the scanned data.
Corresponds to the JSON property count
3230 3231 3232 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3230 def count @count end |
#ratio ⇒ Float
Output only. Ratio of the corresponding value in the field against the total
number of rows in the scanned data.
Corresponds to the JSON property ratio
3236 3237 3238 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3236 def ratio @ratio end |
#value ⇒ String
Output only. String value of a top N non-null value.
Corresponds to the JSON property value
3241 3242 3243 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3241 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3248 3249 3250 3251 3252 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3248 def update!(**args) @count = args[:count] if args.key?(:count) @ratio = args[:ratio] if args.key?(:ratio) @value = args[:value] if args.key?(:value) end |