Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileSpec
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
DataProfileScan related setting.
Instance Attribute Summary collapse
-
#catalog_publishing_enabled ⇒ Boolean
(also: #catalog_publishing_enabled?)
Optional.
-
#exclude_fields ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileSpecSelectedFields
The specification for fields to include or exclude in data profile scan.
-
#include_fields ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileSpecSelectedFields
The specification for fields to include or exclude in data profile scan.
-
#mode ⇒ String
Optional.
-
#post_scan_actions ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileSpecPostScanActions
The configuration of post scan actions of DataProfileScan job.
-
#row_filter ⇒ String
Optional.
-
#sampling_percent ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataProfileSpec
constructor
A new instance of GoogleCloudDataplexV1DataProfileSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataProfileSpec
Returns a new instance of GoogleCloudDataplexV1DataProfileSpec.
3496 3497 3498 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3496 def initialize(**args) update!(**args) end |
Instance Attribute Details
#catalog_publishing_enabled ⇒ Boolean Also known as: catalog_publishing_enabled?
Optional. If set, the latest DataScan job result will be published as Dataplex
Universal Catalog metadata.
Corresponds to the JSON property catalogPublishingEnabled
3458 3459 3460 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3458 def catalog_publishing_enabled @catalog_publishing_enabled end |
#exclude_fields ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileSpecSelectedFields
The specification for fields to include or exclude in data profile scan.
Corresponds to the JSON property excludeFields
3464 3465 3466 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3464 def exclude_fields @exclude_fields end |
#include_fields ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileSpecSelectedFields
The specification for fields to include or exclude in data profile scan.
Corresponds to the JSON property includeFields
3469 3470 3471 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3469 def include_fields @include_fields end |
#mode ⇒ String
Optional. The execution mode for the profile scan.
Corresponds to the JSON property mode
3474 3475 3476 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3474 def mode @mode end |
#post_scan_actions ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileSpecPostScanActions
The configuration of post scan actions of DataProfileScan job.
Corresponds to the JSON property postScanActions
3479 3480 3481 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3479 def post_scan_actions @post_scan_actions end |
#row_filter ⇒ String
Optional. A filter applied to all rows in a single DataScan job. The filter
needs to be a valid SQL expression for a WHERE clause in BigQuery standard SQL
syntax. Example: col1 >= 0 AND col2 < 10
Corresponds to the JSON property rowFilter
3486 3487 3488 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3486 def row_filter @row_filter end |
#sampling_percent ⇒ Float
Optional. The percentage of the records to be selected from the dataset for
DataScan. Value can range between 0.0 and 100.0 with up to 3 significant
decimal digits. Sampling is not applied if sampling_percent is not specified,
0 or 100.
Corresponds to the JSON property samplingPercent
3494 3495 3496 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3494 def sampling_percent @sampling_percent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3501 3502 3503 3504 3505 3506 3507 3508 3509 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3501 def update!(**args) @catalog_publishing_enabled = args[:catalog_publishing_enabled] if args.key?(:catalog_publishing_enabled) @exclude_fields = args[:exclude_fields] if args.key?(:exclude_fields) @include_fields = args[:include_fields] if args.key?(:include_fields) @mode = args[:mode] if args.key?(:mode) @post_scan_actions = args[:post_scan_actions] if args.key?(:post_scan_actions) @row_filter = args[:row_filter] if args.key?(:row_filter) @sampling_percent = args[:sampling_percent] if args.key?(:sampling_percent) end |