Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

DataProfileScan related setting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataProfileSpec

Returns a new instance of GoogleCloudDataplexV1DataProfileSpec.



2477
2478
2479
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2477

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exclude_fieldsGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileSpecSelectedFields

The specification for fields to include or exclude in data profile scan. Corresponds to the JSON property excludeFields



2450
2451
2452
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2450

def exclude_fields
  @exclude_fields
end

#include_fieldsGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileSpecSelectedFields

The specification for fields to include or exclude in data profile scan. Corresponds to the JSON property includeFields



2455
2456
2457
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2455

def include_fields
  @include_fields
end

#post_scan_actionsGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileSpecPostScanActions

The configuration of post scan actions of DataProfileScan job. Corresponds to the JSON property postScanActions



2460
2461
2462
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2460

def post_scan_actions
  @post_scan_actions
end

#row_filterString

Optional. A filter applied to all rows in a single DataScan job. The filter needs to be a valid SQL expression for a WHERE clause in BigQuery standard SQL syntax. Example: col1 >= 0 AND col2 < 10 Corresponds to the JSON property rowFilter

Returns:

  • (String)


2467
2468
2469
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2467

def row_filter
  @row_filter
end

#sampling_percentFloat

Optional. The percentage of the records to be selected from the dataset for DataScan. Value can range between 0.0 and 100.0 with up to 3 significant decimal digits. Sampling is not applied if sampling_percent is not specified, 0 or 100. Corresponds to the JSON property samplingPercent

Returns:

  • (Float)


2475
2476
2477
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2475

def sampling_percent
  @sampling_percent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2482
2483
2484
2485
2486
2487
2488
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2482

def update!(**args)
  @exclude_fields = args[:exclude_fields] if args.key?(:exclude_fields)
  @include_fields = args[:include_fields] if args.key?(:include_fields)
  @post_scan_actions = args[:post_scan_actions] if args.key?(:post_scan_actions)
  @row_filter = args[:row_filter] if args.key?(:row_filter)
  @sampling_percent = args[:sampling_percent] if args.key?(:sampling_percent)
end