Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileSpecSelectedFields

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

The specification for fields to include or exclude in data profile scan.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataProfileSpecSelectedFields

Returns a new instance of GoogleCloudDataplexV1DataProfileSpecSelectedFields.



3564
3565
3566
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3564

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#field_namesArray<String>

Optional. Expected input is a list of fully qualified names of fields as in the schema.Only top-level field names for nested fields are supported. For instance, if 'x' is of nested field type, listing 'x' is supported but 'x.y.z' is not supported. Here 'y' and 'y.z' are nested fields of 'x'. Corresponds to the JSON property fieldNames

Returns:

  • (Array<String>)


3562
3563
3564
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3562

def field_names
  @field_names
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3569
3570
3571
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3569

def update!(**args)
  @field_names = args[:field_names] if args.key?(:field_names)
end