Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileSpecSelectedFields
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileSpecSelectedFields
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
The specification for fields to include or exclude in data profile scan.
Instance Attribute Summary collapse
-
#field_names ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataProfileSpecSelectedFields
constructor
A new instance of GoogleCloudDataplexV1DataProfileSpecSelectedFields.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataProfileSpecSelectedFields
Returns a new instance of GoogleCloudDataplexV1DataProfileSpecSelectedFields.
3369 3370 3371 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3369 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field_names ⇒ Array<String>
Optional. Expected input is a list of fully qualified names of fields as in
the schema.Only top-level field names for nested fields are supported. For
instance, if 'x' is of nested field type, listing 'x' is supported but 'x.y.z'
is not supported. Here 'y' and 'y.z' are nested fields of 'x'.
Corresponds to the JSON property fieldNames
3367 3368 3369 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3367 def field_names @field_names end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3374 3375 3376 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3374 def update!(**args) @field_names = args[:field_names] if args.key?(:field_names) end |