Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityDimensionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

DataQualityDimensionResult provides a more detailed, per-dimension view of the results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityDimensionResult

Returns a new instance of GoogleCloudDataplexV1DataQualityDimensionResult.



3465
3466
3467
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3465

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimensionGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityDimension

A dimension captures data quality intent about a defined subset of the rules specified. Corresponds to the JSON property dimension



3450
3451
3452
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3450

def dimension
  @dimension
end

#passedBoolean Also known as: passed?

Output only. Whether the dimension passed or failed. Corresponds to the JSON property passed

Returns:

  • (Boolean)


3455
3456
3457
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3455

def passed
  @passed
end

#scoreFloat

Output only. The dimension-level data quality score for this data scan job if and only if the 'dimension' field is set.The score ranges between 0, 100 (up to two decimal points). Corresponds to the JSON property score

Returns:

  • (Float)


3463
3464
3465
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3463

def score
  @score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3470
3471
3472
3473
3474
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3470

def update!(**args)
  @dimension = args[:dimension] if args.key?(:dimension)
  @passed = args[:passed] if args.key?(:passed)
  @score = args[:score] if args.key?(:score)
end