Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityDimensionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

DataQualityDimensionResult provides a more detailed, per-dimension view of the results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityDimensionResult

Returns a new instance of GoogleCloudDataplexV1DataQualityDimensionResult.



2639
2640
2641
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2639

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimensionGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityDimension

A dimension captures data quality intent about a defined subset of the rules specified. Corresponds to the JSON property dimension



2624
2625
2626
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2624

def dimension
  @dimension
end

#passedBoolean Also known as: passed?

Output only. Whether the dimension passed or failed. Corresponds to the JSON property passed

Returns:

  • (Boolean)


2629
2630
2631
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2629

def passed
  @passed
end

#scoreFloat

Output only. The dimension-level data quality score for this data scan job if and only if the 'dimension' field is set.The score ranges between 0, 100 (up to two decimal points). Corresponds to the JSON property score

Returns:

  • (Float)


2637
2638
2639
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2637

def score
  @score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2644
2645
2646
2647
2648
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2644

def update!(**args)
  @dimension = args[:dimension] if args.key?(:dimension)
  @passed = args[:passed] if args.key?(:passed)
  @score = args[:score] if args.key?(:score)
end