Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityResult
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
The output of a DataQualityScan.
Instance Attribute Summary collapse
-
#anomaly_detection_generated_assets ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityResultAnomalyDetectionGeneratedAssets
The assets generated by Anomaly Detection Data Scan.
-
#catalog_publishing_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanCatalogPublishingStatus
The status of publishing the data scan result as Dataplex Universal Catalog metadata.
-
#columns ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityColumnResult>
Output only.
-
#dimensions ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityDimensionResult>
Output only.
-
#passed ⇒ Boolean
(also: #passed?)
Output only.
-
#post_scan_actions_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityResultPostScanActionsResult
The result of post scan actions of DataQualityScan job.
-
#row_count ⇒ Fixnum
Output only.
-
#rules ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleResult>
Output only.
-
#scanned_data ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1ScannedData
The data scanned during processing (e.g. in incremental DataScan) Corresponds to the JSON property
scannedData. -
#score ⇒ Float
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityResult
constructor
A new instance of GoogleCloudDataplexV1DataQualityResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityResult
Returns a new instance of GoogleCloudDataplexV1DataQualityResult.
3734 3735 3736 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3734 def initialize(**args) update!(**args) end |
Instance Attribute Details
#anomaly_detection_generated_assets ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityResultAnomalyDetectionGeneratedAssets
The assets generated by Anomaly Detection Data Scan.
Corresponds to the JSON property anomalyDetectionGeneratedAssets
3679 3680 3681 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3679 def anomaly_detection_generated_assets @anomaly_detection_generated_assets end |
#catalog_publishing_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanCatalogPublishingStatus
The status of publishing the data scan result as Dataplex Universal Catalog
metadata. Multiple DataScan log events may exist, each with different
publishing information depending on the type of publishing triggered.
Corresponds to the JSON property catalogPublishingStatus
3686 3687 3688 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3686 def catalog_publishing_status @catalog_publishing_status end |
#columns ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityColumnResult>
Output only. A list of results at the column level.A column will have a
corresponding DataQualityColumnResult if and only if there is at least one
rule with the 'column' field set to it.
Corresponds to the JSON property columns
3693 3694 3695 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3693 def columns @columns end |
#dimensions ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityDimensionResult>
Output only. A list of results at the dimension level.A dimension will have a
corresponding DataQualityDimensionResult if and only if there is at least one
rule with the 'dimension' field set to it.
Corresponds to the JSON property dimensions
3700 3701 3702 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3700 def dimensions @dimensions end |
#passed ⇒ Boolean Also known as: passed?
Output only. Overall data quality result -- true if all rules passed.
Corresponds to the JSON property passed
3705 3706 3707 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3705 def passed @passed end |
#post_scan_actions_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityResultPostScanActionsResult
The result of post scan actions of DataQualityScan job.
Corresponds to the JSON property postScanActionsResult
3711 3712 3713 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3711 def post_scan_actions_result @post_scan_actions_result end |
#row_count ⇒ Fixnum
Output only. The count of rows processed.
Corresponds to the JSON property rowCount
3716 3717 3718 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3716 def row_count @row_count end |
#rules ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleResult>
Output only. A list of all the rules in a job, and their results.
Corresponds to the JSON property rules
3721 3722 3723 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3721 def rules @rules end |
#scanned_data ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1ScannedData
The data scanned during processing (e.g. in incremental DataScan)
Corresponds to the JSON property scannedData
3726 3727 3728 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3726 def scanned_data @scanned_data end |
#score ⇒ Float
Output only. The overall data quality score.The score ranges between 0, 100 (
up to two decimal points).
Corresponds to the JSON property score
3732 3733 3734 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3732 def score @score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3739 3740 3741 3742 3743 3744 3745 3746 3747 3748 3749 3750 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3739 def update!(**args) @anomaly_detection_generated_assets = args[:anomaly_detection_generated_assets] if args.key?(:anomaly_detection_generated_assets) @catalog_publishing_status = args[:catalog_publishing_status] if args.key?(:catalog_publishing_status) @columns = args[:columns] if args.key?(:columns) @dimensions = args[:dimensions] if args.key?(:dimensions) @passed = args[:passed] if args.key?(:passed) @post_scan_actions_result = args[:post_scan_actions_result] if args.key?(:post_scan_actions_result) @row_count = args[:row_count] if args.key?(:row_count) @rules = args[:rules] if args.key?(:rules) @scanned_data = args[:scanned_data] if args.key?(:scanned_data) @score = args[:score] if args.key?(:score) end |