Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

The output of a DataQualityScan.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityResult

Returns a new instance of GoogleCloudDataplexV1DataQualityResult.



2712
2713
2714
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2712

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#anomaly_detection_generated_assetsGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityResultAnomalyDetectionGeneratedAssets

The assets generated by Anomaly Detection Data Scan. Corresponds to the JSON property anomalyDetectionGeneratedAssets



2658
2659
2660
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2658

def anomaly_detection_generated_assets
  @anomaly_detection_generated_assets
end

#catalog_publishing_statusGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataScanCatalogPublishingStatus

The status of publishing the data scan result as Dataplex Universal Catalog metadata. Corresponds to the JSON property catalogPublishingStatus



2664
2665
2666
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2664

def catalog_publishing_status
  @catalog_publishing_status
end

#columnsArray<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityColumnResult>

Output only. A list of results at the column level.A column will have a corresponding DataQualityColumnResult if and only if there is at least one rule with the 'column' field set to it. Corresponds to the JSON property columns



2671
2672
2673
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2671

def columns
  @columns
end

#dimensionsArray<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityDimensionResult>

Output only. A list of results at the dimension level.A dimension will have a corresponding DataQualityDimensionResult if and only if there is at least one rule with the 'dimension' field set to it. Corresponds to the JSON property dimensions



2678
2679
2680
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2678

def dimensions
  @dimensions
end

#passedBoolean Also known as: passed?

Output only. Overall data quality result -- true if all rules passed. Corresponds to the JSON property passed

Returns:

  • (Boolean)


2683
2684
2685
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2683

def passed
  @passed
end

#post_scan_actions_resultGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityResultPostScanActionsResult

The result of post scan actions of DataQualityScan job. Corresponds to the JSON property postScanActionsResult



2689
2690
2691
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2689

def post_scan_actions_result
  @post_scan_actions_result
end

#row_countFixnum

Output only. The count of rows processed. Corresponds to the JSON property rowCount

Returns:

  • (Fixnum)


2694
2695
2696
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2694

def row_count
  @row_count
end

#rulesArray<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleResult>

Output only. A list of all the rules in a job, and their results. Corresponds to the JSON property rules



2699
2700
2701
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2699

def rules
  @rules
end

#scanned_dataGoogle::Apis::DataplexV1::GoogleCloudDataplexV1ScannedData

The data scanned during processing (e.g. in incremental DataScan) Corresponds to the JSON property scannedData



2704
2705
2706
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2704

def scanned_data
  @scanned_data
end

#scoreFloat

Output only. The overall data quality score.The score ranges between 0, 100 ( up to two decimal points). Corresponds to the JSON property score

Returns:

  • (Float)


2710
2711
2712
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2710

def score
  @score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2717
2718
2719
2720
2721
2722
2723
2724
2725
2726
2727
2728
# File 'lib/google/apis/dataplex_v1/classes.rb', line 2717

def update!(**args)
  @anomaly_detection_generated_assets = args[:anomaly_detection_generated_assets] if args.key?(:anomaly_detection_generated_assets)
  @catalog_publishing_status = args[:catalog_publishing_status] if args.key?(:catalog_publishing_status)
  @columns = args[:columns] if args.key?(:columns)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @passed = args[:passed] if args.key?(:passed)
  @post_scan_actions_result = args[:post_scan_actions_result] if args.key?(:post_scan_actions_result)
  @row_count = args[:row_count] if args.key?(:row_count)
  @rules = args[:rules] if args.key?(:rules)
  @scanned_data = args[:scanned_data] if args.key?(:scanned_data)
  @score = args[:score] if args.key?(:score)
end