Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityResultAnomalyDetectionGeneratedAssets
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityResultAnomalyDetectionGeneratedAssets
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
The assets generated by Anomaly Detection Data Scan.
Instance Attribute Summary collapse
-
#data_intermediate_table ⇒ String
Output only.
-
#freshness_intermediate_table ⇒ String
Output only.
-
#result_table ⇒ String
Output only.
-
#volume_intermediate_table ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityResultAnomalyDetectionGeneratedAssets
constructor
A new instance of GoogleCloudDataplexV1DataQualityResultAnomalyDetectionGeneratedAssets.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityResultAnomalyDetectionGeneratedAssets
Returns a new instance of GoogleCloudDataplexV1DataQualityResultAnomalyDetectionGeneratedAssets.
3588 3589 3590 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3588 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_intermediate_table ⇒ String
Output only. The intermediate table for data anomaly detection. Format:
PROJECT_ID.DATASET_ID.TABLE_ID
Corresponds to the JSON property dataIntermediateTable
3566 3567 3568 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3566 def data_intermediate_table @data_intermediate_table end |
#freshness_intermediate_table ⇒ String
Output only. The intermediate table for freshness anomaly detection. Format:
PROJECT_ID.DATASET_ID.TABLE_ID
Corresponds to the JSON property freshnessIntermediateTable
3572 3573 3574 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3572 def freshness_intermediate_table @freshness_intermediate_table end |
#result_table ⇒ String
Output only. The result table for anomaly detection. Format: PROJECT_ID.
DATASET_ID.TABLE_ID If the result table is set at AnomalyDetectionAssets, the
result table here would be the same as the one set in the
AnomalyDetectionAssets.result_table.
Corresponds to the JSON property resultTable
3580 3581 3582 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3580 def result_table @result_table end |
#volume_intermediate_table ⇒ String
Output only. The intermediate table for volume anomaly detection. Format:
PROJECT_ID.DATASET_ID.TABLE_ID
Corresponds to the JSON property volumeIntermediateTable
3586 3587 3588 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3586 def volume_intermediate_table @volume_intermediate_table end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3593 3594 3595 3596 3597 3598 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3593 def update!(**args) @data_intermediate_table = args[:data_intermediate_table] if args.key?(:data_intermediate_table) @freshness_intermediate_table = args[:freshness_intermediate_table] if args.key?(:freshness_intermediate_table) @result_table = args[:result_table] if args.key?(:result_table) @volume_intermediate_table = args[:volume_intermediate_table] if args.key?(:volume_intermediate_table) end |