Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleResult
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
DataQualityRuleResult provides a more detailed, per-rule view of the results.
Instance Attribute Summary collapse
-
#assertion_row_count ⇒ Fixnum
Output only.
-
#debug_queries_result_sets ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleResultDebugQueryResultSet>
Output only.
-
#evaluated_count ⇒ Fixnum
Output only.
-
#failing_rows_query ⇒ String
Output only.
-
#null_count ⇒ Fixnum
Output only.
-
#pass_ratio ⇒ Float
Output only.
-
#passed ⇒ Boolean
(also: #passed?)
Output only.
-
#passed_count ⇒ Fixnum
Output only.
-
#rule ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRule
A rule captures data quality intent about a data source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityRuleResult
constructor
A new instance of GoogleCloudDataplexV1DataQualityRuleResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityRuleResult
Returns a new instance of GoogleCloudDataplexV1DataQualityRuleResult.
3985 3986 3987 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3985 def initialize(**args) update!(**args) end |
Instance Attribute Details
#assertion_row_count ⇒ Fixnum
Output only. The number of rows returned by the SQL statement in a SQL
assertion rule.This field is only valid for SQL assertion rules.
Corresponds to the JSON property assertionRowCount
3933 3934 3935 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3933 def assertion_row_count @assertion_row_count end |
#debug_queries_result_sets ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleResultDebugQueryResultSet>
Output only. Contains the results of all debug queries for this rule. The
number of result sets will correspond to the number of debug_queries.
Corresponds to the JSON property debugQueriesResultSets
3939 3940 3941 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3939 def debug_queries_result_sets @debug_queries_result_sets end |
#evaluated_count ⇒ Fixnum
Output only. The number of rows a rule was evaluated against.This field is
only valid for row-level type rules.Evaluated count can be configured to
either include all rows (default) - with null rows automatically failing rule
evaluation, or exclude null rows from the evaluated_count, by setting
ignore_nulls = true.This field is not set for rule SqlAssertion.
Corresponds to the JSON property evaluatedCount
3948 3949 3950 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3948 def evaluated_count @evaluated_count end |
#failing_rows_query ⇒ String
Output only. The query to find rows that did not pass this rule.This field is
only valid for row-level type rules.
Corresponds to the JSON property failingRowsQuery
3954 3955 3956 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3954 def failing_rows_query @failing_rows_query end |
#null_count ⇒ Fixnum
Output only. The number of rows with null values in the specified column.
Corresponds to the JSON property nullCount
3959 3960 3961 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3959 def null_count @null_count end |
#pass_ratio ⇒ Float
Output only. The ratio of passed_count / evaluated_count.This field is only
valid for row-level type rules.
Corresponds to the JSON property passRatio
3965 3966 3967 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3965 def pass_ratio @pass_ratio end |
#passed ⇒ Boolean Also known as: passed?
Output only. Whether the rule passed or failed.
Corresponds to the JSON property passed
3970 3971 3972 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3970 def passed @passed end |
#passed_count ⇒ Fixnum
Output only. The number of rows which passed a rule evaluation.This field is
only valid for row-level type rules.This field is not set for rule
SqlAssertion.
Corresponds to the JSON property passedCount
3978 3979 3980 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3978 def passed_count @passed_count end |
#rule ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRule
A rule captures data quality intent about a data source.
Corresponds to the JSON property rule
3983 3984 3985 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3983 def rule @rule end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3990 3991 3992 3993 3994 3995 3996 3997 3998 3999 4000 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3990 def update!(**args) @assertion_row_count = args[:assertion_row_count] if args.key?(:assertion_row_count) @debug_queries_result_sets = args[:debug_queries_result_sets] if args.key?(:debug_queries_result_sets) @evaluated_count = args[:evaluated_count] if args.key?(:evaluated_count) @failing_rows_query = args[:failing_rows_query] if args.key?(:failing_rows_query) @null_count = args[:null_count] if args.key?(:null_count) @pass_ratio = args[:pass_ratio] if args.key?(:pass_ratio) @passed = args[:passed] if args.key?(:passed) @passed_count = args[:passed_count] if args.key?(:passed_count) @rule = args[:rule] if args.key?(:rule) end |