Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleResultDebugQueryResult
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleResultDebugQueryResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Contains a single result from the debug query.
Instance Attribute Summary collapse
-
#name ⇒ String
Specifies the name of the result.
-
#type ⇒ String
Indicates the data type of the result.
-
#value ⇒ String
Represents the value of the result as a string.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityRuleResultDebugQueryResult
constructor
A new instance of GoogleCloudDataplexV1DataQualityRuleResultDebugQueryResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityRuleResultDebugQueryResult
Returns a new instance of GoogleCloudDataplexV1DataQualityRuleResultDebugQueryResult.
4025 4026 4027 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4025 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Specifies the name of the result. Available if provided with an explicit alias
using [AS] alias.
Corresponds to the JSON property name
4011 4012 4013 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4011 def name @name end |
#type ⇒ String
Indicates the data type of the result. For more information, see BigQuery data
types (https://cloud.google.com/bigquery/docs/reference/standard-sql/data-
types).
Corresponds to the JSON property type
4018 4019 4020 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4018 def type @type end |
#value ⇒ String
Represents the value of the result as a string.
Corresponds to the JSON property value
4023 4024 4025 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4023 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4030 4031 4032 4033 4034 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4030 def update!(**args) @name = args[:name] if args.key?(:name) @type = args[:type] if args.key?(:type) @value = args[:value] if args.key?(:value) end |