Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleRuleSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Represents the rule source information from Catalog.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityRuleRuleSource

Returns a new instance of GoogleCloudDataplexV1DataQualityRuleRuleSource.



4284
4285
4286
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4284

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#rule_path_elementsArray<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleRuleSourceRulePathElement>

Output only. Rule path elements represent information about the individual items in the relationship path between the scan resource and rule origin in that order. Corresponds to the JSON property rulePathElements



4282
4283
4284
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4282

def rule_path_elements
  @rule_path_elements
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4289
4290
4291
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4289

def update!(**args)
  @rule_path_elements = args[:rule_path_elements] if args.key?(:rule_path_elements)
end