Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleRuleSourceRulePathElement
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleRuleSourceRulePathElement
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Path Element represents the direct relationship between the rule origin ( aspects) to the BigQuery Entry. Ordering of the rule relationship will be maintained such that the first entry in the list is the closest ancestor ( BigQuery table itself). A blank source denotes that the rule is derived directly from the DataScan itself.
Instance Attribute Summary collapse
-
#entry_link_source ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleRuleSourceRulePathElementEntryLinkSource
Entry link source represents information about the entry link.
-
#entry_source ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleRuleSourceRulePathElementEntrySource
Entry source represents information about the related source entry.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityRuleRuleSourceRulePathElement
constructor
A new instance of GoogleCloudDataplexV1DataQualityRuleRuleSourceRulePathElement.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityRuleRuleSourceRulePathElement
Returns a new instance of GoogleCloudDataplexV1DataQualityRuleRuleSourceRulePathElement.
4117 4118 4119 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4117 def initialize(**args) update!(**args) end |
Instance Attribute Details
#entry_link_source ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleRuleSourceRulePathElementEntryLinkSource
Entry link source represents information about the entry link.
Corresponds to the JSON property entryLinkSource
4110 4111 4112 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4110 def entry_link_source @entry_link_source end |
#entry_source ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleRuleSourceRulePathElementEntrySource
Entry source represents information about the related source entry.
Corresponds to the JSON property entrySource
4115 4116 4117 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4115 def entry_source @entry_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4122 4123 4124 4125 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4122 def update!(**args) @entry_link_source = args[:entry_link_source] if args.key?(:entry_link_source) @entry_source = args[:entry_source] if args.key?(:entry_source) end |