Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleRuleSourceRulePathElementEntrySource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Entry source represents information about the related source entry.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityRuleRuleSourceRulePathElementEntrySource

Returns a new instance of GoogleCloudDataplexV1DataQualityRuleRuleSourceRulePathElementEntrySource.



4180
4181
4182
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4180

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. The display name of the entry. Corresponds to the JSON property displayName

Returns:

  • (String)


4165
4166
4167
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4165

def display_name
  @display_name
end

#entryString

Output only. The entry name in the form of: projects/project_id_or_number/ locations/location_id/entryGroups/entry_group_id/entries/entry_id Corresponds to the JSON property entry

Returns:

  • (String)


4171
4172
4173
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4171

def entry
  @entry
end

#entry_typeString

Output only. The entry type to represent the current characteristics of the entry in the form of: projects/project_id_or_number/locations/location_id/ entryTypes/entry-type-id. Corresponds to the JSON property entryType

Returns:

  • (String)


4178
4179
4180
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4178

def entry_type
  @entry_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4185
4186
4187
4188
4189
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4185

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entry = args[:entry] if args.key?(:entry)
  @entry_type = args[:entry_type] if args.key?(:entry_type)
end