Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleSqlAssertion
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleSqlAssertion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
A SQL statement that is evaluated to return rows that match an invalid state.
If any rows are are returned, this rule fails.The SQL statement must use
GoogleSQL syntax (https://cloud.google.com/bigquery/docs/reference/standard-
sql/query-syntax), and must not contain any semicolons.You can use the data
reference parameter $data() to reference the source table with all of its
precondition filters applied. Examples of precondition filters include row
filters, incremental data filters, and sampling. For more information, see
Data reference parameter (https://cloud.google.com/dataplex/docs/auto-data-
quality-overview#data-reference-parameter).Example: SELECT * FROM $data()
WHERE price < 0
Instance Attribute Summary collapse
-
#sql_statement ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityRuleSqlAssertion
constructor
A new instance of GoogleCloudDataplexV1DataQualityRuleSqlAssertion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityRuleSqlAssertion
Returns a new instance of GoogleCloudDataplexV1DataQualityRuleSqlAssertion.
3161 3162 3163 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3161 def initialize(**args) update!(**args) end |
Instance Attribute Details
#sql_statement ⇒ String
Optional. The SQL statement.
Corresponds to the JSON property sqlStatement
3159 3160 3161 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3159 def sql_statement @sql_statement end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3166 3167 3168 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3166 def update!(**args) @sql_statement = args[:sql_statement] if args.key?(:sql_statement) end |