Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleTemplate
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleTemplate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
DataQualityRuleTemplate represents a template which can be reused across multiple data quality rules.
Instance Attribute Summary collapse
-
#capabilities ⇒ Array<String>
Output only.
-
#dimension ⇒ String
Output only.
-
#input_parameters ⇒ Hash<String,Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleTemplateParameterDescription>
Output only.
-
#name ⇒ String
Output only.
-
#sql_collection ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleTemplateSql>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityRuleTemplate
constructor
A new instance of GoogleCloudDataplexV1DataQualityRuleTemplate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityRuleTemplate
Returns a new instance of GoogleCloudDataplexV1DataQualityRuleTemplate.
4347 4348 4349 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4347 def initialize(**args) update!(**args) end |
Instance Attribute Details
#capabilities ⇒ Array<String>
Output only. A list of features or properties supported by this rule template.
Corresponds to the JSON property capabilities
4321 4322 4323 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4321 def capabilities @capabilities end |
#dimension ⇒ String
Output only. The dimension a rule template belongs to. Rule level results are
also aggregated at the dimension level.
Corresponds to the JSON property dimension
4327 4328 4329 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4327 def dimension @dimension end |
#input_parameters ⇒ Hash<String,Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleTemplateParameterDescription>
Output only. Description for input parameters
Corresponds to the JSON property inputParameters
4332 4333 4334 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4332 def input_parameters @input_parameters end |
#name ⇒ String
Output only. The name of the rule template in the format: projects/
project_id_or_number/locations/location_id/entryGroups/entry_group_id/
entries/entry_id
Corresponds to the JSON property name
4339 4340 4341 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4339 def name @name end |
#sql_collection ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleTemplateSql>
Output only. Collection of SQLs for data quality rules. Currently only one SQL
is supported.
Corresponds to the JSON property sqlCollection
4345 4346 4347 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4345 def sql_collection @sql_collection end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4352 4353 4354 4355 4356 4357 4358 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4352 def update!(**args) @capabilities = args[:capabilities] if args.key?(:capabilities) @dimension = args[:dimension] if args.key?(:dimension) @input_parameters = args[:input_parameters] if args.key?(:input_parameters) @name = args[:name] if args.key?(:name) @sql_collection = args[:sql_collection] if args.key?(:sql_collection) end |