Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleTemplateParameterDescription
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleTemplateParameterDescription
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Description of the input parameter. It can include the type(s) supported by the parameter and intended usage. It is for information purposes only and does not affect the behavior of the rule template.
Instance Attribute Summary collapse
-
#default_value ⇒ String
Output only.
-
#description ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityRuleTemplateParameterDescription
constructor
A new instance of GoogleCloudDataplexV1DataQualityRuleTemplateParameterDescription.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityRuleTemplateParameterDescription
Returns a new instance of GoogleCloudDataplexV1DataQualityRuleTemplateParameterDescription.
4574 4575 4576 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4574 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_value ⇒ String
Output only. The default value for the parameter if no value is provided.
Corresponds to the JSON property defaultValue
4565 4566 4567 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4565 def default_value @default_value end |
#description ⇒ String
Output only. Description of the input parameter. It can include the type(s)
supported by the parameter and intended usage. It is for information purposes
only and does not affect the behavior of the rule template.
Corresponds to the JSON property description
4572 4573 4574 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4572 def description @description end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4579 4580 4581 4582 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4579 def update!(**args) @default_value = args[:default_value] if args.key?(:default_value) @description = args[:description] if args.key?(:description) end |