Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleTemplateParameterDescription

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Description of the input parameter. It can include the type(s) supported by the parameter and intended usage. It is for information purposes only and does not affect the behavior of the rule template.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityRuleTemplateParameterDescription

Returns a new instance of GoogleCloudDataplexV1DataQualityRuleTemplateParameterDescription.



4379
4380
4381
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4379

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_valueString

Output only. The default value for the parameter if no value is provided. Corresponds to the JSON property defaultValue

Returns:

  • (String)


4370
4371
4372
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4370

def default_value
  @default_value
end

#descriptionString

Output only. Description of the input parameter. It can include the type(s) supported by the parameter and intended usage. It is for information purposes only and does not affect the behavior of the rule template. Corresponds to the JSON property description

Returns:

  • (String)


4377
4378
4379
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4377

def description
  @description
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4384
4385
4386
4387
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4384

def update!(**args)
  @default_value = args[:default_value] if args.key?(:default_value)
  @description = args[:description] if args.key?(:description)
end