Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleTemplateParameterDescription
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleTemplateParameterDescription
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Description of the input parameter. It can include the type(s) supported by the parameter and intended usage. It is for information purposes only and does not affect the behavior of the rule template.
Instance Attribute Summary collapse
-
#default_value ⇒ String
Output only.
-
#description ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityRuleTemplateParameterDescription
constructor
A new instance of GoogleCloudDataplexV1DataQualityRuleTemplateParameterDescription.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityRuleTemplateParameterDescription
Returns a new instance of GoogleCloudDataplexV1DataQualityRuleTemplateParameterDescription.
4379 4380 4381 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4379 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_value ⇒ String
Output only. The default value for the parameter if no value is provided.
Corresponds to the JSON property defaultValue
4370 4371 4372 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4370 def default_value @default_value end |
#description ⇒ String
Output only. Description of the input parameter. It can include the type(s)
supported by the parameter and intended usage. It is for information purposes
only and does not affect the behavior of the rule template.
Corresponds to the JSON property description
4377 4378 4379 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4377 def description @description end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4384 4385 4386 4387 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4384 def update!(**args) @default_value = args[:default_value] if args.key?(:default_value) @description = args[:description] if args.key?(:description) end |