Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleTemplateSql
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRuleTemplateSql
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Templatized SQL query for data quality rules. It can have parameters that can be substituted with values when a rule is created using this template.
Instance Attribute Summary collapse
-
#query ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityRuleTemplateSql
constructor
A new instance of GoogleCloudDataplexV1DataQualityRuleTemplateSql.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityRuleTemplateSql
Returns a new instance of GoogleCloudDataplexV1DataQualityRuleTemplateSql.
4466 4467 4468 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4466 def initialize(**args) update!(**args) end |
Instance Attribute Details
#query ⇒ String
Output only. Templatized SQL query for data quality rules.
Corresponds to the JSON property query
4464 4465 4466 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4464 def query @query end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4471 4472 4473 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4471 def update!(**args) @query = args[:query] if args.key?(:query) end |