Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityScanRuleResult
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityScanRuleResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Information about the result of a data quality rule for data quality scan. The monitored resource is 'DataScan'.
Instance Attribute Summary collapse
-
#assertion_row_count ⇒ Fixnum
The number of rows returned by the SQL statement in a SQL assertion rule.
-
#column ⇒ String
The column which this rule is evaluated against.
-
#data_source ⇒ String
The data source of the data scan (e.g. BigQuery table name).
-
#evaluated_row_count ⇒ Fixnum
The number of rows evaluated against the data quality rule.
-
#evalution_type ⇒ String
The evaluation type of the data quality rule.
-
#job_id ⇒ String
Identifier of the specific data scan job this log entry is for.
-
#null_row_count ⇒ Fixnum
The number of rows with null values in the specified column.
-
#passed_row_count ⇒ Fixnum
The number of rows which passed a rule evaluation.
-
#result ⇒ String
The result of the data quality rule.
-
#rule_dimension ⇒ String
The dimension of the data quality rule.
-
#rule_name ⇒ String
The name of the data quality rule.
-
#rule_type ⇒ String
The type of the data quality rule.
-
#threshold_percent ⇒ Float
The passing threshold (0.0, 100.0) of the data quality rule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityScanRuleResult
constructor
A new instance of GoogleCloudDataplexV1DataQualityScanRuleResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualityScanRuleResult
Returns a new instance of GoogleCloudDataplexV1DataQualityScanRuleResult.
4562 4563 4564 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4562 def initialize(**args) update!(**args) end |
Instance Attribute Details
#assertion_row_count ⇒ Fixnum
The number of rows returned by the SQL statement in a SQL assertion rule. This
field is only valid for SQL assertion rules.
Corresponds to the JSON property assertionRowCount
4498 4499 4500 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4498 def assertion_row_count @assertion_row_count end |
#column ⇒ String
The column which this rule is evaluated against.
Corresponds to the JSON property column
4503 4504 4505 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4503 def column @column end |
#data_source ⇒ String
The data source of the data scan (e.g. BigQuery table name).
Corresponds to the JSON property dataSource
4508 4509 4510 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4508 def data_source @data_source end |
#evaluated_row_count ⇒ Fixnum
The number of rows evaluated against the data quality rule. This field is only
valid for rules of PER_ROW evaluation type.
Corresponds to the JSON property evaluatedRowCount
4514 4515 4516 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4514 def evaluated_row_count @evaluated_row_count end |
#evalution_type ⇒ String
The evaluation type of the data quality rule.
Corresponds to the JSON property evalutionType
4519 4520 4521 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4519 def evalution_type @evalution_type end |
#job_id ⇒ String
Identifier of the specific data scan job this log entry is for.
Corresponds to the JSON property jobId
4524 4525 4526 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4524 def job_id @job_id end |
#null_row_count ⇒ Fixnum
The number of rows with null values in the specified column.
Corresponds to the JSON property nullRowCount
4529 4530 4531 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4529 def null_row_count @null_row_count end |
#passed_row_count ⇒ Fixnum
The number of rows which passed a rule evaluation. This field is only valid
for rules of PER_ROW evaluation type.
Corresponds to the JSON property passedRowCount
4535 4536 4537 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4535 def passed_row_count @passed_row_count end |
#result ⇒ String
The result of the data quality rule.
Corresponds to the JSON property result
4540 4541 4542 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4540 def result @result end |
#rule_dimension ⇒ String
The dimension of the data quality rule.
Corresponds to the JSON property ruleDimension
4545 4546 4547 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4545 def rule_dimension @rule_dimension end |
#rule_name ⇒ String
The name of the data quality rule.
Corresponds to the JSON property ruleName
4550 4551 4552 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4550 def rule_name @rule_name end |
#rule_type ⇒ String
The type of the data quality rule.
Corresponds to the JSON property ruleType
4555 4556 4557 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4555 def rule_type @rule_type end |
#threshold_percent ⇒ Float
The passing threshold (0.0, 100.0) of the data quality rule.
Corresponds to the JSON property thresholdPercent
4560 4561 4562 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4560 def threshold_percent @threshold_percent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 4578 4579 4580 4581 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4567 def update!(**args) @assertion_row_count = args[:assertion_row_count] if args.key?(:assertion_row_count) @column = args[:column] if args.key?(:column) @data_source = args[:data_source] if args.key?(:data_source) @evaluated_row_count = args[:evaluated_row_count] if args.key?(:evaluated_row_count) @evalution_type = args[:evalution_type] if args.key?(:evalution_type) @job_id = args[:job_id] if args.key?(:job_id) @null_row_count = args[:null_row_count] if args.key?(:null_row_count) @passed_row_count = args[:passed_row_count] if args.key?(:passed_row_count) @result = args[:result] if args.key?(:result) @rule_dimension = args[:rule_dimension] if args.key?(:rule_dimension) @rule_name = args[:rule_name] if args.key?(:rule_name) @rule_type = args[:rule_type] if args.key?(:rule_type) @threshold_percent = args[:threshold_percent] if args.key?(:threshold_percent) end |