Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpec
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
DataQualityScan related setting.
Instance Attribute Summary collapse
-
#catalog_publishing_enabled ⇒ Boolean
(also: #catalog_publishing_enabled?)
Optional.
-
#enable_catalog_based_rules ⇒ Boolean
(also: #enable_catalog_based_rules?)
Optional.
-
#filter ⇒ String
Optional.
-
#post_scan_actions ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpecPostScanActions
The configuration of post scan actions of DataQualityScan.
-
#row_filter ⇒ String
Optional.
-
#rules ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRule>
Required.
-
#sampling_percent ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualitySpec
constructor
A new instance of GoogleCloudDataplexV1DataQualitySpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualitySpec
Returns a new instance of GoogleCloudDataplexV1DataQualitySpec.
4857 4858 4859 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4857 def initialize(**args) update!(**args) end |
Instance Attribute Details
#catalog_publishing_enabled ⇒ Boolean Also known as: catalog_publishing_enabled?
Optional. If set, the latest DataScan job result will be published as Dataplex
Universal Catalog metadata.
Corresponds to the JSON property catalogPublishingEnabled
4801 4802 4803 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4801 def catalog_publishing_enabled @catalog_publishing_enabled end |
#enable_catalog_based_rules ⇒ Boolean Also known as: enable_catalog_based_rules?
Optional. If enabled, the data scan will retrieve rules defined in the
dataplex-types.global.data-rules aspect on all paths of the catalog entry
corresponding to the BigQuery table resource and all attached glossary terms.
The path that data-rules aspect is attached on the table entry defines the
column that the rule will be evaluated against. For glossary terms, the path
that the terms are attached on the table entry defines the column that the
rule will be evaluated against. At the start of scan execution, the rules
reflect the latest state retrieved from the catalog entry and any updates on
the rules thereafter are ignored for that execution. The updates will be
reflected from the next execution. Rules defined in the datascan must be empty
if this field is enabled.
Corresponds to the JSON property enableCatalogBasedRules
4817 4818 4819 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4817 def enable_catalog_based_rules @enable_catalog_based_rules end |
#filter ⇒ String
Optional. Filter for selectively running a subset of rules. You can filter the
request by the name or attribute key-value pairs defined on the rule. If not
specified, all rules are run. The filter is applicable to both, the rules
retrieved from catalog and explicitly defined rules in the scan. Please see
filter syntax (https://docs.cloud.google.com/dataplex/docs/auto-data-quality-
overview#rule-filtering) for more details.
Corresponds to the JSON property filter
4828 4829 4830 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4828 def filter @filter end |
#post_scan_actions ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpecPostScanActions
The configuration of post scan actions of DataQualityScan.
Corresponds to the JSON property postScanActions
4833 4834 4835 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4833 def post_scan_actions @post_scan_actions end |
#row_filter ⇒ String
Optional. A filter applied to all rows in a single DataScan job. The filter
needs to be a valid SQL expression for a WHERE clause in GoogleSQL syntax (
https://cloud.google.com/bigquery/docs/reference/standard-sql/query-syntax#
where_clause).Example: col1 >= 0 AND col2 < 10
Corresponds to the JSON property rowFilter
4841 4842 4843 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4841 def row_filter @row_filter end |
#rules ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRule>
Required. The list of rules to evaluate against a data source. At least one
rule is required.
Corresponds to the JSON property rules
4847 4848 4849 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4847 def rules @rules end |
#sampling_percent ⇒ Float
Optional. The percentage of the records to be selected from the dataset for
DataScan. Value can range between 0.0 and 100.0 with up to 3 significant
decimal digits. Sampling is not applied if sampling_percent is not specified,
0 or 100.
Corresponds to the JSON property samplingPercent
4855 4856 4857 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4855 def sampling_percent @sampling_percent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4862 4863 4864 4865 4866 4867 4868 4869 4870 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4862 def update!(**args) @catalog_publishing_enabled = args[:catalog_publishing_enabled] if args.key?(:catalog_publishing_enabled) @enable_catalog_based_rules = args[:enable_catalog_based_rules] if args.key?(:enable_catalog_based_rules) @filter = args[:filter] if args.key?(:filter) @post_scan_actions = args[:post_scan_actions] if args.key?(:post_scan_actions) @row_filter = args[:row_filter] if args.key?(:row_filter) @rules = args[:rules] if args.key?(:rules) @sampling_percent = args[:sampling_percent] if args.key?(:sampling_percent) end |