Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

DataQualityScan related setting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualitySpec

Returns a new instance of GoogleCloudDataplexV1DataQualitySpec.



3391
3392
3393
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3391

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#catalog_publishing_enabledBoolean Also known as: catalog_publishing_enabled?

Optional. If set, the latest DataScan job result will be published as Dataplex Universal Catalog metadata. Corresponds to the JSON property catalogPublishingEnabled

Returns:

  • (Boolean)


3361
3362
3363
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3361

def catalog_publishing_enabled
  @catalog_publishing_enabled
end

#post_scan_actionsGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpecPostScanActions

The configuration of post scan actions of DataQualityScan. Corresponds to the JSON property postScanActions



3367
3368
3369
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3367

def post_scan_actions
  @post_scan_actions
end

#row_filterString

Optional. A filter applied to all rows in a single DataScan job. The filter needs to be a valid SQL expression for a WHERE clause in GoogleSQL syntax ( https://cloud.google.com/bigquery/docs/reference/standard-sql/query-syntax# where_clause).Example: col1 >= 0 AND col2 < 10 Corresponds to the JSON property rowFilter

Returns:

  • (String)


3375
3376
3377
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3375

def row_filter
  @row_filter
end

#rulesArray<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRule>

Required. The list of rules to evaluate against a data source. At least one rule is required. Corresponds to the JSON property rules



3381
3382
3383
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3381

def rules
  @rules
end

#sampling_percentFloat

Optional. The percentage of the records to be selected from the dataset for DataScan. Value can range between 0.0 and 100.0 with up to 3 significant decimal digits. Sampling is not applied if sampling_percent is not specified, 0 or 100. Corresponds to the JSON property samplingPercent

Returns:

  • (Float)


3389
3390
3391
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3389

def sampling_percent
  @sampling_percent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3396
3397
3398
3399
3400
3401
3402
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3396

def update!(**args)
  @catalog_publishing_enabled = args[:catalog_publishing_enabled] if args.key?(:catalog_publishing_enabled)
  @post_scan_actions = args[:post_scan_actions] if args.key?(:post_scan_actions)
  @row_filter = args[:row_filter] if args.key?(:row_filter)
  @rules = args[:rules] if args.key?(:rules)
  @sampling_percent = args[:sampling_percent] if args.key?(:sampling_percent)
end