Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpecPostScanActionsNotificationReport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

The configuration of notification report post scan action.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualitySpecPostScanActionsNotificationReport

Returns a new instance of GoogleCloudDataplexV1DataQualitySpecPostScanActionsNotificationReport.



4961
4962
4963
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4961

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#job_end_triggerGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpecPostScanActionsJobEndTrigger

This trigger is triggered whenever a scan job run ends, regardless of the result. Corresponds to the JSON property jobEndTrigger



4941
4942
4943
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4941

def job_end_trigger
  @job_end_trigger
end

#job_failure_triggerGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpecPostScanActionsJobFailureTrigger

This trigger is triggered when the scan job itself fails, regardless of the result. Corresponds to the JSON property jobFailureTrigger



4947
4948
4949
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4947

def job_failure_trigger
  @job_failure_trigger
end

#recipientsGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpecPostScanActionsRecipients

The individuals or groups who are designated to receive notifications upon triggers. Corresponds to the JSON property recipients



4953
4954
4955
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4953

def recipients
  @recipients
end

#score_threshold_triggerGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpecPostScanActionsScoreThresholdTrigger

This trigger is triggered when the DQ score in the job result is less than a specified input score. Corresponds to the JSON property scoreThresholdTrigger



4959
4960
4961
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4959

def score_threshold_trigger
  @score_threshold_trigger
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4966
4967
4968
4969
4970
4971
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4966

def update!(**args)
  @job_end_trigger = args[:job_end_trigger] if args.key?(:job_end_trigger)
  @job_failure_trigger = args[:job_failure_trigger] if args.key?(:job_failure_trigger)
  @recipients = args[:recipients] if args.key?(:recipients)
  @score_threshold_trigger = args[:score_threshold_trigger] if args.key?(:score_threshold_trigger)
end