Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpecPostScanActionsNotificationReport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

The configuration of notification report post scan action.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualitySpecPostScanActionsNotificationReport

Returns a new instance of GoogleCloudDataplexV1DataQualitySpecPostScanActionsNotificationReport.



4766
4767
4768
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4766

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#job_end_triggerGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpecPostScanActionsJobEndTrigger

This trigger is triggered whenever a scan job run ends, regardless of the result. Corresponds to the JSON property jobEndTrigger



4746
4747
4748
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4746

def job_end_trigger
  @job_end_trigger
end

#job_failure_triggerGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpecPostScanActionsJobFailureTrigger

This trigger is triggered when the scan job itself fails, regardless of the result. Corresponds to the JSON property jobFailureTrigger



4752
4753
4754
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4752

def job_failure_trigger
  @job_failure_trigger
end

#recipientsGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpecPostScanActionsRecipients

The individuals or groups who are designated to receive notifications upon triggers. Corresponds to the JSON property recipients



4758
4759
4760
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4758

def recipients
  @recipients
end

#score_threshold_triggerGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpecPostScanActionsScoreThresholdTrigger

This trigger is triggered when the DQ score in the job result is less than a specified input score. Corresponds to the JSON property scoreThresholdTrigger



4764
4765
4766
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4764

def score_threshold_trigger
  @score_threshold_trigger
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4771
4772
4773
4774
4775
4776
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4771

def update!(**args)
  @job_end_trigger = args[:job_end_trigger] if args.key?(:job_end_trigger)
  @job_failure_trigger = args[:job_failure_trigger] if args.key?(:job_failure_trigger)
  @recipients = args[:recipients] if args.key?(:recipients)
  @score_threshold_trigger = args[:score_threshold_trigger] if args.key?(:score_threshold_trigger)
end