Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpecPostScanActionsNotificationReport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

The configuration of notification report post scan action.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataQualitySpecPostScanActionsNotificationReport

Returns a new instance of GoogleCloudDataplexV1DataQualitySpecPostScanActionsNotificationReport.



3507
3508
3509
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3507

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#job_end_triggerGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpecPostScanActionsJobEndTrigger

This trigger is triggered whenever a scan job run ends, regardless of the result. Corresponds to the JSON property jobEndTrigger



3487
3488
3489
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3487

def job_end_trigger
  @job_end_trigger
end

#job_failure_triggerGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpecPostScanActionsJobFailureTrigger

This trigger is triggered when the scan job itself fails, regardless of the result. Corresponds to the JSON property jobFailureTrigger



3493
3494
3495
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3493

def job_failure_trigger
  @job_failure_trigger
end

#recipientsGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpecPostScanActionsRecipients

The individuals or groups who are designated to receive notifications upon triggers. Corresponds to the JSON property recipients



3499
3500
3501
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3499

def recipients
  @recipients
end

#score_threshold_triggerGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpecPostScanActionsScoreThresholdTrigger

This trigger is triggered when the DQ score in the job result is less than a specified input score. Corresponds to the JSON property scoreThresholdTrigger



3505
3506
3507
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3505

def score_threshold_trigger
  @score_threshold_trigger
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3512
3513
3514
3515
3516
3517
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3512

def update!(**args)
  @job_end_trigger = args[:job_end_trigger] if args.key?(:job_end_trigger)
  @job_failure_trigger = args[:job_failure_trigger] if args.key?(:job_failure_trigger)
  @recipients = args[:recipients] if args.key?(:recipients)
  @score_threshold_trigger = args[:score_threshold_trigger] if args.key?(:score_threshold_trigger)
end