Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScan
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScan
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Represents a user-visible job which provides the insights for the related data source.For example: Data quality: generates queries based on the rules and runs against the data to get data quality check results. For more information, see Auto data quality overview (https://cloud.google.com/dataplex/docs/auto- data-quality-overview). Data profile: analyzes the data in tables and generates insights about the structure, content and relationships (such as null percent, cardinality, min/max/mean, etc). For more information, see About data profiling (https://cloud.google.com/dataplex/docs/data-profiling-overview) . Data discovery: scans data in Cloud Storage buckets to extract and then catalog metadata. For more information, see Discover and catalog Cloud Storage data (https://cloud.google.com/bigquery/docs/automatic-discovery). Data documentation: analyzes the table or dataset metadata and generates insights. For tables, insights include descriptions and sample SQL queries. For datasets, insights include descriptions, schema relationships and sample SQL queries. For more information, see Generate data insights in BigQuery (https://cloud. google.com/bigquery/docs/data-insights).
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#data ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataSource
The data source for DataScan.
-
#data_discovery_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoveryResult
The output of a data discovery scan.
-
#data_discovery_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoverySpec
Spec for a data discovery scan.
-
#data_documentation_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResult
The output of a DataDocumentation scan.
-
#data_documentation_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationSpec
DataDocumentation scan related spec.
-
#data_profile_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResult
DataProfileResult defines the output of DataProfileScan.
-
#data_profile_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileSpec
DataProfileScan related setting.
-
#data_quality_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityResult
The output of a DataQualityScan.
-
#data_quality_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpec
DataQualityScan related setting.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#execution_identity ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1ExecutionIdentity
The identity to run the datascan.
-
#execution_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanExecutionSpec
DataScan execution settings.
-
#execution_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanExecutionStatus
Status of the data scan execution.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#type ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#unstructured_data_profile_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1UnstructuredDataProfileResult
Contains the result of an unstructured data profile scan.
-
#unstructured_data_profile_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1UnstructuredDataProfileSpec
Contains the specification for an unstructured data profile scan.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataScan
constructor
A new instance of GoogleCloudDataplexV1DataScan.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataScan
Returns a new instance of GoogleCloudDataplexV1DataScan.
5168 5169 5170 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5168 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time when the scan was created.
Corresponds to the JSON property createTime
5051 5052 5053 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5051 def create_time @create_time end |
#data ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataSource
The data source for DataScan.
Corresponds to the JSON property data
5056 5057 5058 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5056 def data @data end |
#data_discovery_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoveryResult
The output of a data discovery scan.
Corresponds to the JSON property dataDiscoveryResult
5061 5062 5063 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5061 def data_discovery_result @data_discovery_result end |
#data_discovery_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoverySpec
Spec for a data discovery scan.
Corresponds to the JSON property dataDiscoverySpec
5066 5067 5068 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5066 def data_discovery_spec @data_discovery_spec end |
#data_documentation_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResult
The output of a DataDocumentation scan.
Corresponds to the JSON property dataDocumentationResult
5071 5072 5073 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5071 def data_documentation_result @data_documentation_result end |
#data_documentation_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationSpec
DataDocumentation scan related spec.
Corresponds to the JSON property dataDocumentationSpec
5076 5077 5078 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5076 def data_documentation_spec @data_documentation_spec end |
#data_profile_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResult
DataProfileResult defines the output of DataProfileScan. Each field of the
table will have field type specific profile result.
Corresponds to the JSON property dataProfileResult
5082 5083 5084 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5082 def data_profile_result @data_profile_result end |
#data_profile_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileSpec
DataProfileScan related setting.
Corresponds to the JSON property dataProfileSpec
5087 5088 5089 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5087 def data_profile_spec @data_profile_spec end |
#data_quality_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityResult
The output of a DataQualityScan.
Corresponds to the JSON property dataQualityResult
5092 5093 5094 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5092 def data_quality_result @data_quality_result end |
#data_quality_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpec
DataQualityScan related setting.
Corresponds to the JSON property dataQualitySpec
5097 5098 5099 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5097 def data_quality_spec @data_quality_spec end |
#description ⇒ String
Optional. Description of the scan. Must be between 1-1024 characters.
Corresponds to the JSON property description
5102 5103 5104 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5102 def description @description end |
#display_name ⇒ String
Optional. User friendly display name. Must be between 1-256 characters.
Corresponds to the JSON property displayName
5107 5108 5109 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5107 def display_name @display_name end |
#execution_identity ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1ExecutionIdentity
The identity to run the datascan.
Corresponds to the JSON property executionIdentity
5112 5113 5114 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5112 def execution_identity @execution_identity end |
#execution_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanExecutionSpec
DataScan execution settings.
Corresponds to the JSON property executionSpec
5117 5118 5119 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5117 def execution_spec @execution_spec end |
#execution_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanExecutionStatus
Status of the data scan execution.
Corresponds to the JSON property executionStatus
5122 5123 5124 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5122 def execution_status @execution_status end |
#labels ⇒ Hash<String,String>
Optional. User-defined labels for the scan.
Corresponds to the JSON property labels
5127 5128 5129 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5127 def labels @labels end |
#name ⇒ String
Output only. Identifier. The relative resource name of the scan, of the form:
projects/project/locations/location_id/dataScans/datascan_id, where
project refers to a project_id or project_number and location_id refers to a
Google Cloud region.
Corresponds to the JSON property name
5135 5136 5137 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5135 def name @name end |
#state ⇒ String
Output only. Current state of the DataScan.
Corresponds to the JSON property state
5140 5141 5142 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5140 def state @state end |
#type ⇒ String
Output only. The type of DataScan.
Corresponds to the JSON property type
5145 5146 5147 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5145 def type @type end |
#uid ⇒ String
Output only. System generated globally unique ID for the scan. This ID will be
different if the scan is deleted and re-created with the same name.
Corresponds to the JSON property uid
5151 5152 5153 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5151 def uid @uid end |
#unstructured_data_profile_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1UnstructuredDataProfileResult
Contains the result of an unstructured data profile scan.
Corresponds to the JSON property unstructuredDataProfileResult
5156 5157 5158 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5156 def unstructured_data_profile_result @unstructured_data_profile_result end |
#unstructured_data_profile_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1UnstructuredDataProfileSpec
Contains the specification for an unstructured data profile scan.
Corresponds to the JSON property unstructuredDataProfileSpec
5161 5162 5163 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5161 def unstructured_data_profile_spec @unstructured_data_profile_spec end |
#update_time ⇒ String
Output only. The time when the scan was last updated.
Corresponds to the JSON property updateTime
5166 5167 5168 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5166 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5173 5174 5175 5176 5177 5178 5179 5180 5181 5182 5183 5184 5185 5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5173 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @data = args[:data] if args.key?(:data) @data_discovery_result = args[:data_discovery_result] if args.key?(:data_discovery_result) @data_discovery_spec = args[:data_discovery_spec] if args.key?(:data_discovery_spec) @data_documentation_result = args[:data_documentation_result] if args.key?(:data_documentation_result) @data_documentation_spec = args[:data_documentation_spec] if args.key?(:data_documentation_spec) @data_profile_result = args[:data_profile_result] if args.key?(:data_profile_result) @data_profile_spec = args[:data_profile_spec] if args.key?(:data_profile_spec) @data_quality_result = args[:data_quality_result] if args.key?(:data_quality_result) @data_quality_spec = args[:data_quality_spec] if args.key?(:data_quality_spec) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @execution_identity = args[:execution_identity] if args.key?(:execution_identity) @execution_spec = args[:execution_spec] if args.key?(:execution_spec) @execution_status = args[:execution_status] if args.key?(:execution_status) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @type = args[:type] if args.key?(:type) @uid = args[:uid] if args.key?(:uid) @unstructured_data_profile_result = args[:unstructured_data_profile_result] if args.key?(:unstructured_data_profile_result) @unstructured_data_profile_spec = args[:unstructured_data_profile_spec] if args.key?(:unstructured_data_profile_spec) @update_time = args[:update_time] if args.key?(:update_time) end |