Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScan

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Represents a user-visible job which provides the insights for the related data source.For example: Data quality: generates queries based on the rules and runs against the data to get data quality check results. For more information, see Auto data quality overview (https://cloud.google.com/dataplex/docs/auto- data-quality-overview). Data profile: analyzes the data in tables and generates insights about the structure, content and relationships (such as null percent, cardinality, min/max/mean, etc). For more information, see About data profiling (https://cloud.google.com/dataplex/docs/data-profiling-overview) . Data discovery: scans data in Cloud Storage buckets to extract and then catalog metadata. For more information, see Discover and catalog Cloud Storage data (https://cloud.google.com/bigquery/docs/automatic-discovery). Data documentation: analyzes the table or dataset metadata and generates insights. For tables, insights include descriptions and sample SQL queries. For datasets, insights include descriptions, schema relationships and sample SQL queries. For more information, see Generate data insights in BigQuery (https://cloud. google.com/bigquery/docs/data-insights).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataScan

Returns a new instance of GoogleCloudDataplexV1DataScan.



4959
4960
4961
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4959

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time when the scan was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4842
4843
4844
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4842

def create_time
  @create_time
end

#dataGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataSource

The data source for DataScan. Corresponds to the JSON property data



4847
4848
4849
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4847

def data
  @data
end

#data_discovery_resultGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoveryResult

The output of a data discovery scan. Corresponds to the JSON property dataDiscoveryResult



4852
4853
4854
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4852

def data_discovery_result
  @data_discovery_result
end

#data_discovery_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoverySpec

Spec for a data discovery scan. Corresponds to the JSON property dataDiscoverySpec



4857
4858
4859
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4857

def data_discovery_spec
  @data_discovery_spec
end

#data_documentation_resultGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResult

The output of a DataDocumentation scan. Corresponds to the JSON property dataDocumentationResult



4862
4863
4864
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4862

def data_documentation_result
  @data_documentation_result
end

#data_documentation_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationSpec

DataDocumentation scan related spec. Corresponds to the JSON property dataDocumentationSpec



4867
4868
4869
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4867

def data_documentation_spec
  @data_documentation_spec
end

#data_profile_resultGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResult

DataProfileResult defines the output of DataProfileScan. Each field of the table will have field type specific profile result. Corresponds to the JSON property dataProfileResult



4873
4874
4875
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4873

def data_profile_result
  @data_profile_result
end

#data_profile_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileSpec

DataProfileScan related setting. Corresponds to the JSON property dataProfileSpec



4878
4879
4880
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4878

def data_profile_spec
  @data_profile_spec
end

#data_quality_resultGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityResult

The output of a DataQualityScan. Corresponds to the JSON property dataQualityResult



4883
4884
4885
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4883

def data_quality_result
  @data_quality_result
end

#data_quality_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpec

DataQualityScan related setting. Corresponds to the JSON property dataQualitySpec



4888
4889
4890
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4888

def data_quality_spec
  @data_quality_spec
end

#descriptionString

Optional. Description of the scan. Must be between 1-1024 characters. Corresponds to the JSON property description

Returns:

  • (String)


4893
4894
4895
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4893

def description
  @description
end

#display_nameString

Optional. User friendly display name. Must be between 1-256 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


4898
4899
4900
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4898

def display_name
  @display_name
end

#execution_identityGoogle::Apis::DataplexV1::GoogleCloudDataplexV1ExecutionIdentity

The identity to run the datascan. Corresponds to the JSON property executionIdentity



4903
4904
4905
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4903

def execution_identity
  @execution_identity
end

#execution_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataScanExecutionSpec

DataScan execution settings. Corresponds to the JSON property executionSpec



4908
4909
4910
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4908

def execution_spec
  @execution_spec
end

#execution_statusGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataScanExecutionStatus

Status of the data scan execution. Corresponds to the JSON property executionStatus



4913
4914
4915
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4913

def execution_status
  @execution_status
end

#labelsHash<String,String>

Optional. User-defined labels for the scan. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4918
4919
4920
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4918

def labels
  @labels
end

#nameString

Output only. Identifier. The relative resource name of the scan, of the form: projects/project/locations/location_id/dataScans/datascan_id, where project refers to a project_id or project_number and location_id refers to a Google Cloud region. Corresponds to the JSON property name

Returns:

  • (String)


4926
4927
4928
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4926

def name
  @name
end

#stateString

Output only. Current state of the DataScan. Corresponds to the JSON property state

Returns:

  • (String)


4931
4932
4933
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4931

def state
  @state
end

#typeString

Output only. The type of DataScan. Corresponds to the JSON property type

Returns:

  • (String)


4936
4937
4938
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4936

def type
  @type
end

#uidString

Output only. System generated globally unique ID for the scan. This ID will be different if the scan is deleted and re-created with the same name. Corresponds to the JSON property uid

Returns:

  • (String)


4942
4943
4944
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4942

def uid
  @uid
end

#unstructured_data_profile_resultGoogle::Apis::DataplexV1::GoogleCloudDataplexV1UnstructuredDataProfileResult

Contains the result of an unstructured data profile scan. Corresponds to the JSON property unstructuredDataProfileResult



4947
4948
4949
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4947

def unstructured_data_profile_result
  @unstructured_data_profile_result
end

#unstructured_data_profile_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1UnstructuredDataProfileSpec

Contains the specification for an unstructured data profile scan. Corresponds to the JSON property unstructuredDataProfileSpec



4952
4953
4954
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4952

def unstructured_data_profile_spec
  @unstructured_data_profile_spec
end

#update_timeString

Output only. The time when the scan was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4957
4958
4959
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4957

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4964
4965
4966
4967
4968
4969
4970
4971
4972
4973
4974
4975
4976
4977
4978
4979
4980
4981
4982
4983
4984
4985
4986
4987
4988
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4964

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data = args[:data] if args.key?(:data)
  @data_discovery_result = args[:data_discovery_result] if args.key?(:data_discovery_result)
  @data_discovery_spec = args[:data_discovery_spec] if args.key?(:data_discovery_spec)
  @data_documentation_result = args[:data_documentation_result] if args.key?(:data_documentation_result)
  @data_documentation_spec = args[:data_documentation_spec] if args.key?(:data_documentation_spec)
  @data_profile_result = args[:data_profile_result] if args.key?(:data_profile_result)
  @data_profile_spec = args[:data_profile_spec] if args.key?(:data_profile_spec)
  @data_quality_result = args[:data_quality_result] if args.key?(:data_quality_result)
  @data_quality_spec = args[:data_quality_spec] if args.key?(:data_quality_spec)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @execution_identity = args[:execution_identity] if args.key?(:execution_identity)
  @execution_spec = args[:execution_spec] if args.key?(:execution_spec)
  @execution_status = args[:execution_status] if args.key?(:execution_status)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
  @uid = args[:uid] if args.key?(:uid)
  @unstructured_data_profile_result = args[:unstructured_data_profile_result] if args.key?(:unstructured_data_profile_result)
  @unstructured_data_profile_spec = args[:unstructured_data_profile_spec] if args.key?(:unstructured_data_profile_spec)
  @update_time = args[:update_time] if args.key?(:update_time)
end