Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScan
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScan
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Represents a user-visible job which provides the insights for the related data source.For example: Data quality: generates queries based on the rules and runs against the data to get data quality check results. For more information, see Auto data quality overview (https://cloud.google.com/dataplex/docs/auto- data-quality-overview). Data profile: analyzes the data in tables and generates insights about the structure, content and relationships (such as null percent, cardinality, min/max/mean, etc). For more information, see About data profiling (https://cloud.google.com/dataplex/docs/data-profiling-overview) . Data discovery: scans data in Cloud Storage buckets to extract and then catalog metadata. For more information, see Discover and catalog Cloud Storage data (https://cloud.google.com/bigquery/docs/automatic-discovery). Data documentation: analyzes the table details and generates insights including descriptions and sample SQL queries for the table. For more information, see Generate data insights in BigQuery (https://cloud.google.com/bigquery/docs/ data-insights).
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#data ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataSource
The data source for DataScan.
-
#data_discovery_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoveryResult
The output of a data discovery scan.
-
#data_discovery_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoverySpec
Spec for a data discovery scan.
-
#data_documentation_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResult
The output of a DataDocumentation scan.
-
#data_documentation_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationSpec
DataDocumentation scan related spec.
-
#data_profile_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResult
DataProfileResult defines the output of DataProfileScan.
-
#data_profile_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileSpec
DataProfileScan related setting.
-
#data_quality_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityResult
The output of a DataQualityScan.
-
#data_quality_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpec
DataQualityScan related setting.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#execution_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanExecutionSpec
DataScan execution settings.
-
#execution_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanExecutionStatus
Status of the data scan execution.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#type ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataScan
constructor
A new instance of GoogleCloudDataplexV1DataScan.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataScan
Returns a new instance of GoogleCloudDataplexV1DataScan.
3684 3685 3686 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3684 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time when the scan was created.
Corresponds to the JSON property createTime
3582 3583 3584 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3582 def create_time @create_time end |
#data ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataSource
The data source for DataScan.
Corresponds to the JSON property data
3587 3588 3589 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3587 def data @data end |
#data_discovery_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoveryResult
The output of a data discovery scan.
Corresponds to the JSON property dataDiscoveryResult
3592 3593 3594 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3592 def data_discovery_result @data_discovery_result end |
#data_discovery_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoverySpec
Spec for a data discovery scan.
Corresponds to the JSON property dataDiscoverySpec
3597 3598 3599 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3597 def data_discovery_spec @data_discovery_spec end |
#data_documentation_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResult
The output of a DataDocumentation scan.
Corresponds to the JSON property dataDocumentationResult
3602 3603 3604 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3602 def data_documentation_result @data_documentation_result end |
#data_documentation_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationSpec
DataDocumentation scan related spec.
Corresponds to the JSON property dataDocumentationSpec
3607 3608 3609 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3607 def data_documentation_spec @data_documentation_spec end |
#data_profile_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResult
DataProfileResult defines the output of DataProfileScan. Each field of the
table will have field type specific profile result.
Corresponds to the JSON property dataProfileResult
3613 3614 3615 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3613 def data_profile_result @data_profile_result end |
#data_profile_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileSpec
DataProfileScan related setting.
Corresponds to the JSON property dataProfileSpec
3618 3619 3620 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3618 def data_profile_spec @data_profile_spec end |
#data_quality_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityResult
The output of a DataQualityScan.
Corresponds to the JSON property dataQualityResult
3623 3624 3625 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3623 def data_quality_result @data_quality_result end |
#data_quality_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpec
DataQualityScan related setting.
Corresponds to the JSON property dataQualitySpec
3628 3629 3630 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3628 def data_quality_spec @data_quality_spec end |
#description ⇒ String
Optional. Description of the scan. Must be between 1-1024 characters.
Corresponds to the JSON property description
3633 3634 3635 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3633 def description @description end |
#display_name ⇒ String
Optional. User friendly display name. Must be between 1-256 characters.
Corresponds to the JSON property displayName
3638 3639 3640 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3638 def display_name @display_name end |
#execution_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanExecutionSpec
DataScan execution settings.
Corresponds to the JSON property executionSpec
3643 3644 3645 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3643 def execution_spec @execution_spec end |
#execution_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanExecutionStatus
Status of the data scan execution.
Corresponds to the JSON property executionStatus
3648 3649 3650 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3648 def execution_status @execution_status end |
#labels ⇒ Hash<String,String>
Optional. User-defined labels for the scan.
Corresponds to the JSON property labels
3653 3654 3655 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3653 def labels @labels end |
#name ⇒ String
Output only. Identifier. The relative resource name of the scan, of the form:
projects/project/locations/location_id/dataScans/datascan_id, where
project refers to a project_id or project_number and location_id refers to a
Google Cloud region.
Corresponds to the JSON property name
3661 3662 3663 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3661 def name @name end |
#state ⇒ String
Output only. Current state of the DataScan.
Corresponds to the JSON property state
3666 3667 3668 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3666 def state @state end |
#type ⇒ String
Output only. The type of DataScan.
Corresponds to the JSON property type
3671 3672 3673 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3671 def type @type end |
#uid ⇒ String
Output only. System generated globally unique ID for the scan. This ID will be
different if the scan is deleted and re-created with the same name.
Corresponds to the JSON property uid
3677 3678 3679 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3677 def uid @uid end |
#update_time ⇒ String
Output only. The time when the scan was last updated.
Corresponds to the JSON property updateTime
3682 3683 3684 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3682 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3689 3690 3691 3692 3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 3708 3709 3710 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3689 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @data = args[:data] if args.key?(:data) @data_discovery_result = args[:data_discovery_result] if args.key?(:data_discovery_result) @data_discovery_spec = args[:data_discovery_spec] if args.key?(:data_discovery_spec) @data_documentation_result = args[:data_documentation_result] if args.key?(:data_documentation_result) @data_documentation_spec = args[:data_documentation_spec] if args.key?(:data_documentation_spec) @data_profile_result = args[:data_profile_result] if args.key?(:data_profile_result) @data_profile_spec = args[:data_profile_spec] if args.key?(:data_profile_spec) @data_quality_result = args[:data_quality_result] if args.key?(:data_quality_result) @data_quality_spec = args[:data_quality_spec] if args.key?(:data_quality_spec) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @execution_spec = args[:execution_spec] if args.key?(:execution_spec) @execution_status = args[:execution_status] if args.key?(:execution_status) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @type = args[:type] if args.key?(:type) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |