Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanCatalogPublishingStatus
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanCatalogPublishingStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
The status of publishing the data scan result as Dataplex Universal Catalog metadata. Multiple DataScan log events may exist, each with different publishing information depending on the type of publishing triggered.
Instance Attribute Summary collapse
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataScanCatalogPublishingStatus
constructor
A new instance of GoogleCloudDataplexV1DataScanCatalogPublishingStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataScanCatalogPublishingStatus
Returns a new instance of GoogleCloudDataplexV1DataScanCatalogPublishingStatus.
5211 5212 5213 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5211 def initialize(**args) update!(**args) end |
Instance Attribute Details
#state ⇒ String
Output only. Execution state for publishing.
Corresponds to the JSON property state
5209 5210 5211 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5209 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5216 5217 5218 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5216 def update!(**args) @state = args[:state] if args.key?(:state) end |