Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanCatalogPublishingStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

The status of publishing the data scan result as Dataplex Universal Catalog metadata. Multiple DataScan log events may exist, each with different publishing information depending on the type of publishing triggered.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataScanCatalogPublishingStatus

Returns a new instance of GoogleCloudDataplexV1DataScanCatalogPublishingStatus.



5002
5003
5004
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5002

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#stateString

Output only. Execution state for publishing. Corresponds to the JSON property state

Returns:

  • (String)


5000
5001
5002
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5000

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5007
5008
5009
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5007

def update!(**args)
  @state = args[:state] if args.key?(:state)
end