Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEvent
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
These messages contain information about the execution of a datascan. The monitored resource is 'DataScan'
Instance Attribute Summary collapse
-
#catalog_publishing_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanCatalogPublishingStatus
The status of publishing the data scan result as Dataplex Universal Catalog metadata.
-
#create_time ⇒ String
The time when the data scan job was created.
-
#data_profile ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataProfileResult
Data profile result for data scan job.
-
#data_profile_configs ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataProfileAppliedConfigs
Applied configs for data profile type data scan job.
-
#data_quality ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataQualityResult
Data quality result for data scan job.
-
#data_quality_configs ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataQualityAppliedConfigs
Applied configs for data quality type data scan job.
-
#data_source ⇒ String
The data source of the data scan Corresponds to the JSON property
dataSource. -
#end_time ⇒ String
The time when the data scan job finished.
-
#job_id ⇒ String
The identifier of the specific data scan job this log entry is for.
-
#message ⇒ String
The message describing the data scan job event.
-
#post_scan_actions_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventPostScanActionsResult
Post scan actions result for data scan job.
-
#scope ⇒ String
The scope of the data scan (e.g. full, incremental).
-
#spec_version ⇒ String
A version identifier of the spec which was used to execute this job.
-
#start_time ⇒ String
The time when the data scan job started to run.
-
#state ⇒ String
The status of the data scan job.
-
#trigger ⇒ String
The trigger type of the data scan job.
-
#type ⇒ String
The type of the data scan.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataScanEvent
constructor
A new instance of GoogleCloudDataplexV1DataScanEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataScanEvent
Returns a new instance of GoogleCloudDataplexV1DataScanEvent.
5313 5314 5315 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5313 def initialize(**args) update!(**args) end |
Instance Attribute Details
#catalog_publishing_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanCatalogPublishingStatus
The status of publishing the data scan result as Dataplex Universal Catalog
metadata. Multiple DataScan log events may exist, each with different
publishing information depending on the type of publishing triggered.
Corresponds to the JSON property catalogPublishingStatus
5231 5232 5233 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5231 def catalog_publishing_status @catalog_publishing_status end |
#create_time ⇒ String
The time when the data scan job was created.
Corresponds to the JSON property createTime
5236 5237 5238 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5236 def create_time @create_time end |
#data_profile ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataProfileResult
Data profile result for data scan job.
Corresponds to the JSON property dataProfile
5241 5242 5243 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5241 def data_profile @data_profile end |
#data_profile_configs ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataProfileAppliedConfigs
Applied configs for data profile type data scan job.
Corresponds to the JSON property dataProfileConfigs
5246 5247 5248 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5246 def data_profile_configs @data_profile_configs end |
#data_quality ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataQualityResult
Data quality result for data scan job.
Corresponds to the JSON property dataQuality
5251 5252 5253 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5251 def data_quality @data_quality end |
#data_quality_configs ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataQualityAppliedConfigs
Applied configs for data quality type data scan job.
Corresponds to the JSON property dataQualityConfigs
5256 5257 5258 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5256 def data_quality_configs @data_quality_configs end |
#data_source ⇒ String
The data source of the data scan
Corresponds to the JSON property dataSource
5261 5262 5263 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5261 def data_source @data_source end |
#end_time ⇒ String
The time when the data scan job finished.
Corresponds to the JSON property endTime
5266 5267 5268 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5266 def end_time @end_time end |
#job_id ⇒ String
The identifier of the specific data scan job this log entry is for.
Corresponds to the JSON property jobId
5271 5272 5273 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5271 def job_id @job_id end |
#message ⇒ String
The message describing the data scan job event.
Corresponds to the JSON property message
5276 5277 5278 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5276 def @message end |
#post_scan_actions_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventPostScanActionsResult
Post scan actions result for data scan job.
Corresponds to the JSON property postScanActionsResult
5281 5282 5283 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5281 def post_scan_actions_result @post_scan_actions_result end |
#scope ⇒ String
The scope of the data scan (e.g. full, incremental).
Corresponds to the JSON property scope
5286 5287 5288 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5286 def scope @scope end |
#spec_version ⇒ String
A version identifier of the spec which was used to execute this job.
Corresponds to the JSON property specVersion
5291 5292 5293 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5291 def spec_version @spec_version end |
#start_time ⇒ String
The time when the data scan job started to run.
Corresponds to the JSON property startTime
5296 5297 5298 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5296 def start_time @start_time end |
#state ⇒ String
The status of the data scan job.
Corresponds to the JSON property state
5301 5302 5303 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5301 def state @state end |
#trigger ⇒ String
The trigger type of the data scan job.
Corresponds to the JSON property trigger
5306 5307 5308 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5306 def trigger @trigger end |
#type ⇒ String
The type of the data scan.
Corresponds to the JSON property type
5311 5312 5313 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5311 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5318 5319 5320 5321 5322 5323 5324 5325 5326 5327 5328 5329 5330 5331 5332 5333 5334 5335 5336 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5318 def update!(**args) @catalog_publishing_status = args[:catalog_publishing_status] if args.key?(:catalog_publishing_status) @create_time = args[:create_time] if args.key?(:create_time) @data_profile = args[:data_profile] if args.key?(:data_profile) @data_profile_configs = args[:data_profile_configs] if args.key?(:data_profile_configs) @data_quality = args[:data_quality] if args.key?(:data_quality) @data_quality_configs = args[:data_quality_configs] if args.key?(:data_quality_configs) @data_source = args[:data_source] if args.key?(:data_source) @end_time = args[:end_time] if args.key?(:end_time) @job_id = args[:job_id] if args.key?(:job_id) @message = args[:message] if args.key?(:message) @post_scan_actions_result = args[:post_scan_actions_result] if args.key?(:post_scan_actions_result) @scope = args[:scope] if args.key?(:scope) @spec_version = args[:spec_version] if args.key?(:spec_version) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @trigger = args[:trigger] if args.key?(:trigger) @type = args[:type] if args.key?(:type) end |