Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEvent
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
These messages contain information about the execution of a datascan. The monitored resource is 'DataScan'
Instance Attribute Summary collapse
-
#catalog_publishing_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanCatalogPublishingStatus
The status of publishing the data scan result as Dataplex Universal Catalog metadata.
-
#create_time ⇒ String
The time when the data scan job was created.
-
#data_profile ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataProfileResult
Data profile result for data scan job.
-
#data_profile_configs ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataProfileAppliedConfigs
Applied configs for data profile type data scan job.
-
#data_quality ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataQualityResult
Data quality result for data scan job.
-
#data_quality_configs ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataQualityAppliedConfigs
Applied configs for data quality type data scan job.
-
#data_source ⇒ String
The data source of the data scan Corresponds to the JSON property
dataSource. -
#end_time ⇒ String
The time when the data scan job finished.
-
#job_id ⇒ String
The identifier of the specific data scan job this log entry is for.
-
#message ⇒ String
The message describing the data scan job event.
-
#post_scan_actions_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventPostScanActionsResult
Post scan actions result for data scan job.
-
#scope ⇒ String
The scope of the data scan (e.g. full, incremental).
-
#spec_version ⇒ String
A version identifier of the spec which was used to execute this job.
-
#start_time ⇒ String
The time when the data scan job started to run.
-
#state ⇒ String
The status of the data scan job.
-
#trigger ⇒ String
The trigger type of the data scan job.
-
#type ⇒ String
The type of the data scan.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataScanEvent
constructor
A new instance of GoogleCloudDataplexV1DataScanEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataScanEvent
Returns a new instance of GoogleCloudDataplexV1DataScanEvent.
5299 5300 5301 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5299 def initialize(**args) update!(**args) end |
Instance Attribute Details
#catalog_publishing_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanCatalogPublishingStatus
The status of publishing the data scan result as Dataplex Universal Catalog
metadata. Multiple DataScan log events may exist, each with different
publishing information depending on the type of publishing triggered.
Corresponds to the JSON property catalogPublishingStatus
5217 5218 5219 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5217 def catalog_publishing_status @catalog_publishing_status end |
#create_time ⇒ String
The time when the data scan job was created.
Corresponds to the JSON property createTime
5222 5223 5224 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5222 def create_time @create_time end |
#data_profile ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataProfileResult
Data profile result for data scan job.
Corresponds to the JSON property dataProfile
5227 5228 5229 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5227 def data_profile @data_profile end |
#data_profile_configs ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataProfileAppliedConfigs
Applied configs for data profile type data scan job.
Corresponds to the JSON property dataProfileConfigs
5232 5233 5234 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5232 def data_profile_configs @data_profile_configs end |
#data_quality ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataQualityResult
Data quality result for data scan job.
Corresponds to the JSON property dataQuality
5237 5238 5239 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5237 def data_quality @data_quality end |
#data_quality_configs ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataQualityAppliedConfigs
Applied configs for data quality type data scan job.
Corresponds to the JSON property dataQualityConfigs
5242 5243 5244 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5242 def data_quality_configs @data_quality_configs end |
#data_source ⇒ String
The data source of the data scan
Corresponds to the JSON property dataSource
5247 5248 5249 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5247 def data_source @data_source end |
#end_time ⇒ String
The time when the data scan job finished.
Corresponds to the JSON property endTime
5252 5253 5254 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5252 def end_time @end_time end |
#job_id ⇒ String
The identifier of the specific data scan job this log entry is for.
Corresponds to the JSON property jobId
5257 5258 5259 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5257 def job_id @job_id end |
#message ⇒ String
The message describing the data scan job event.
Corresponds to the JSON property message
5262 5263 5264 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5262 def @message end |
#post_scan_actions_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventPostScanActionsResult
Post scan actions result for data scan job.
Corresponds to the JSON property postScanActionsResult
5267 5268 5269 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5267 def post_scan_actions_result @post_scan_actions_result end |
#scope ⇒ String
The scope of the data scan (e.g. full, incremental).
Corresponds to the JSON property scope
5272 5273 5274 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5272 def scope @scope end |
#spec_version ⇒ String
A version identifier of the spec which was used to execute this job.
Corresponds to the JSON property specVersion
5277 5278 5279 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5277 def spec_version @spec_version end |
#start_time ⇒ String
The time when the data scan job started to run.
Corresponds to the JSON property startTime
5282 5283 5284 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5282 def start_time @start_time end |
#state ⇒ String
The status of the data scan job.
Corresponds to the JSON property state
5287 5288 5289 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5287 def state @state end |
#trigger ⇒ String
The trigger type of the data scan job.
Corresponds to the JSON property trigger
5292 5293 5294 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5292 def trigger @trigger end |
#type ⇒ String
The type of the data scan.
Corresponds to the JSON property type
5297 5298 5299 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5297 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5304 5305 5306 5307 5308 5309 5310 5311 5312 5313 5314 5315 5316 5317 5318 5319 5320 5321 5322 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5304 def update!(**args) @catalog_publishing_status = args[:catalog_publishing_status] if args.key?(:catalog_publishing_status) @create_time = args[:create_time] if args.key?(:create_time) @data_profile = args[:data_profile] if args.key?(:data_profile) @data_profile_configs = args[:data_profile_configs] if args.key?(:data_profile_configs) @data_quality = args[:data_quality] if args.key?(:data_quality) @data_quality_configs = args[:data_quality_configs] if args.key?(:data_quality_configs) @data_source = args[:data_source] if args.key?(:data_source) @end_time = args[:end_time] if args.key?(:end_time) @job_id = args[:job_id] if args.key?(:job_id) @message = args[:message] if args.key?(:message) @post_scan_actions_result = args[:post_scan_actions_result] if args.key?(:post_scan_actions_result) @scope = args[:scope] if args.key?(:scope) @spec_version = args[:spec_version] if args.key?(:spec_version) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @trigger = args[:trigger] if args.key?(:trigger) @type = args[:type] if args.key?(:type) end |