Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

These messages contain information about the execution of a datascan. The monitored resource is 'DataScan'

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataScanEvent

Returns a new instance of GoogleCloudDataplexV1DataScanEvent.



5104
5105
5106
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5104

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#catalog_publishing_statusGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataScanCatalogPublishingStatus

The status of publishing the data scan result as Dataplex Universal Catalog metadata. Multiple DataScan log events may exist, each with different publishing information depending on the type of publishing triggered. Corresponds to the JSON property catalogPublishingStatus



5022
5023
5024
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5022

def catalog_publishing_status
  @catalog_publishing_status
end

#create_timeString

The time when the data scan job was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5027
5028
5029
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5027

def create_time
  @create_time
end

#data_profileGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataProfileResult

Data profile result for data scan job. Corresponds to the JSON property dataProfile



5032
5033
5034
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5032

def data_profile
  @data_profile
end

#data_profile_configsGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataProfileAppliedConfigs

Applied configs for data profile type data scan job. Corresponds to the JSON property dataProfileConfigs



5037
5038
5039
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5037

def data_profile_configs
  @data_profile_configs
end

#data_qualityGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataQualityResult

Data quality result for data scan job. Corresponds to the JSON property dataQuality



5042
5043
5044
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5042

def data_quality
  @data_quality
end

#data_quality_configsGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataQualityAppliedConfigs

Applied configs for data quality type data scan job. Corresponds to the JSON property dataQualityConfigs



5047
5048
5049
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5047

def data_quality_configs
  @data_quality_configs
end

#data_sourceString

The data source of the data scan Corresponds to the JSON property dataSource

Returns:

  • (String)


5052
5053
5054
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5052

def data_source
  @data_source
end

#end_timeString

The time when the data scan job finished. Corresponds to the JSON property endTime

Returns:

  • (String)


5057
5058
5059
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5057

def end_time
  @end_time
end

#job_idString

The identifier of the specific data scan job this log entry is for. Corresponds to the JSON property jobId

Returns:

  • (String)


5062
5063
5064
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5062

def job_id
  @job_id
end

#messageString

The message describing the data scan job event. Corresponds to the JSON property message

Returns:

  • (String)


5067
5068
5069
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5067

def message
  @message
end

#post_scan_actions_resultGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventPostScanActionsResult

Post scan actions result for data scan job. Corresponds to the JSON property postScanActionsResult



5072
5073
5074
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5072

def post_scan_actions_result
  @post_scan_actions_result
end

#scopeString

The scope of the data scan (e.g. full, incremental). Corresponds to the JSON property scope

Returns:

  • (String)


5077
5078
5079
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5077

def scope
  @scope
end

#spec_versionString

A version identifier of the spec which was used to execute this job. Corresponds to the JSON property specVersion

Returns:

  • (String)


5082
5083
5084
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5082

def spec_version
  @spec_version
end

#start_timeString

The time when the data scan job started to run. Corresponds to the JSON property startTime

Returns:

  • (String)


5087
5088
5089
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5087

def start_time
  @start_time
end

#stateString

The status of the data scan job. Corresponds to the JSON property state

Returns:

  • (String)


5092
5093
5094
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5092

def state
  @state
end

#triggerString

The trigger type of the data scan job. Corresponds to the JSON property trigger

Returns:

  • (String)


5097
5098
5099
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5097

def trigger
  @trigger
end

#typeString

The type of the data scan. Corresponds to the JSON property type

Returns:

  • (String)


5102
5103
5104
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5102

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5109
5110
5111
5112
5113
5114
5115
5116
5117
5118
5119
5120
5121
5122
5123
5124
5125
5126
5127
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5109

def update!(**args)
  @catalog_publishing_status = args[:catalog_publishing_status] if args.key?(:catalog_publishing_status)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_profile = args[:data_profile] if args.key?(:data_profile)
  @data_profile_configs = args[:data_profile_configs] if args.key?(:data_profile_configs)
  @data_quality = args[:data_quality] if args.key?(:data_quality)
  @data_quality_configs = args[:data_quality_configs] if args.key?(:data_quality_configs)
  @data_source = args[:data_source] if args.key?(:data_source)
  @end_time = args[:end_time] if args.key?(:end_time)
  @job_id = args[:job_id] if args.key?(:job_id)
  @message = args[:message] if args.key?(:message)
  @post_scan_actions_result = args[:post_scan_actions_result] if args.key?(:post_scan_actions_result)
  @scope = args[:scope] if args.key?(:scope)
  @spec_version = args[:spec_version] if args.key?(:spec_version)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @trigger = args[:trigger] if args.key?(:trigger)
  @type = args[:type] if args.key?(:type)
end