Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataProfileAppliedConfigs
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataProfileAppliedConfigs
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Applied configs for data profile type data scan job.
Instance Attribute Summary collapse
-
#column_filter_applied ⇒ Boolean
(also: #column_filter_applied?)
Boolean indicating whether a column filter was applied in the DataScan job.
-
#row_filter_applied ⇒ Boolean
(also: #row_filter_applied?)
Boolean indicating whether a row filter was applied in the DataScan job.
-
#sampling_percent ⇒ Float
The percentage of the records selected from the dataset for DataScan.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataScanEventDataProfileAppliedConfigs
constructor
A new instance of GoogleCloudDataplexV1DataScanEventDataProfileAppliedConfigs.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataScanEventDataProfileAppliedConfigs
Returns a new instance of GoogleCloudDataplexV1DataScanEventDataProfileAppliedConfigs.
5348 5349 5350 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5348 def initialize(**args) update!(**args) end |
Instance Attribute Details
#column_filter_applied ⇒ Boolean Also known as: column_filter_applied?
Boolean indicating whether a column filter was applied in the DataScan job.
Corresponds to the JSON property columnFilterApplied
5332 5333 5334 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5332 def column_filter_applied @column_filter_applied end |
#row_filter_applied ⇒ Boolean Also known as: row_filter_applied?
Boolean indicating whether a row filter was applied in the DataScan job.
Corresponds to the JSON property rowFilterApplied
5338 5339 5340 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5338 def row_filter_applied @row_filter_applied end |
#sampling_percent ⇒ Float
The percentage of the records selected from the dataset for DataScan. Value
ranges between 0.0 and 100.0. Value 0.0 or 100.0 imply that sampling was not
applied.
Corresponds to the JSON property samplingPercent
5346 5347 5348 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5346 def sampling_percent @sampling_percent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5353 5354 5355 5356 5357 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5353 def update!(**args) @column_filter_applied = args[:column_filter_applied] if args.key?(:column_filter_applied) @row_filter_applied = args[:row_filter_applied] if args.key?(:row_filter_applied) @sampling_percent = args[:sampling_percent] if args.key?(:sampling_percent) end |