Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataProfileAppliedConfigs

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Applied configs for data profile type data scan job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataScanEventDataProfileAppliedConfigs

Returns a new instance of GoogleCloudDataplexV1DataScanEventDataProfileAppliedConfigs.



5153
5154
5155
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5153

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#column_filter_appliedBoolean Also known as: column_filter_applied?

Boolean indicating whether a column filter was applied in the DataScan job. Corresponds to the JSON property columnFilterApplied

Returns:

  • (Boolean)


5137
5138
5139
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5137

def column_filter_applied
  @column_filter_applied
end

#row_filter_appliedBoolean Also known as: row_filter_applied?

Boolean indicating whether a row filter was applied in the DataScan job. Corresponds to the JSON property rowFilterApplied

Returns:

  • (Boolean)


5143
5144
5145
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5143

def row_filter_applied
  @row_filter_applied
end

#sampling_percentFloat

The percentage of the records selected from the dataset for DataScan. Value ranges between 0.0 and 100.0. Value 0.0 or 100.0 imply that sampling was not applied. Corresponds to the JSON property samplingPercent

Returns:

  • (Float)


5151
5152
5153
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5151

def sampling_percent
  @sampling_percent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5158
5159
5160
5161
5162
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5158

def update!(**args)
  @column_filter_applied = args[:column_filter_applied] if args.key?(:column_filter_applied)
  @row_filter_applied = args[:row_filter_applied] if args.key?(:row_filter_applied)
  @sampling_percent = args[:sampling_percent] if args.key?(:sampling_percent)
end