Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataProfileAppliedConfigs

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Applied configs for data profile type data scan job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataScanEventDataProfileAppliedConfigs

Returns a new instance of GoogleCloudDataplexV1DataScanEventDataProfileAppliedConfigs.



3873
3874
3875
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3873

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#column_filter_appliedBoolean Also known as: column_filter_applied?

Boolean indicating whether a column filter was applied in the DataScan job. Corresponds to the JSON property columnFilterApplied

Returns:

  • (Boolean)


3857
3858
3859
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3857

def column_filter_applied
  @column_filter_applied
end

#row_filter_appliedBoolean Also known as: row_filter_applied?

Boolean indicating whether a row filter was applied in the DataScan job. Corresponds to the JSON property rowFilterApplied

Returns:

  • (Boolean)


3863
3864
3865
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3863

def row_filter_applied
  @row_filter_applied
end

#sampling_percentFloat

The percentage of the records selected from the dataset for DataScan. Value ranges between 0.0 and 100.0. Value 0.0 or 100.0 imply that sampling was not applied. Corresponds to the JSON property samplingPercent

Returns:

  • (Float)


3871
3872
3873
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3871

def sampling_percent
  @sampling_percent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3878
3879
3880
3881
3882
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3878

def update!(**args)
  @column_filter_applied = args[:column_filter_applied] if args.key?(:column_filter_applied)
  @row_filter_applied = args[:row_filter_applied] if args.key?(:row_filter_applied)
  @sampling_percent = args[:sampling_percent] if args.key?(:sampling_percent)
end