Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataQualityAppliedConfigs
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataQualityAppliedConfigs
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Applied configs for data quality type data scan job.
Instance Attribute Summary collapse
-
#row_filter_applied ⇒ Boolean
(also: #row_filter_applied?)
Boolean indicating whether a row filter was applied in the DataScan job.
-
#sampling_percent ⇒ Float
The percentage of the records selected from the dataset for DataScan.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataScanEventDataQualityAppliedConfigs
constructor
A new instance of GoogleCloudDataplexV1DataScanEventDataQualityAppliedConfigs.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataScanEventDataQualityAppliedConfigs
Returns a new instance of GoogleCloudDataplexV1DataScanEventDataQualityAppliedConfigs.
5201 5202 5203 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5201 def initialize(**args) update!(**args) end |
Instance Attribute Details
#row_filter_applied ⇒ Boolean Also known as: row_filter_applied?
Boolean indicating whether a row filter was applied in the DataScan job.
Corresponds to the JSON property rowFilterApplied
5191 5192 5193 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5191 def row_filter_applied @row_filter_applied end |
#sampling_percent ⇒ Float
The percentage of the records selected from the dataset for DataScan. Value
ranges between 0.0 and 100.0. Value 0.0 or 100.0 imply that sampling was not
applied.
Corresponds to the JSON property samplingPercent
5199 5200 5201 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5199 def sampling_percent @sampling_percent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5206 5207 5208 5209 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5206 def update!(**args) @row_filter_applied = args[:row_filter_applied] if args.key?(:row_filter_applied) @sampling_percent = args[:sampling_percent] if args.key?(:sampling_percent) end |