Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataQualityAppliedConfigs
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataQualityAppliedConfigs
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Applied configs for data quality type data scan job.
Instance Attribute Summary collapse
-
#row_filter_applied ⇒ Boolean
(also: #row_filter_applied?)
Boolean indicating whether a row filter was applied in the DataScan job.
-
#sampling_percent ⇒ Float
The percentage of the records selected from the dataset for DataScan.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataScanEventDataQualityAppliedConfigs
constructor
A new instance of GoogleCloudDataplexV1DataScanEventDataQualityAppliedConfigs.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataScanEventDataQualityAppliedConfigs
Returns a new instance of GoogleCloudDataplexV1DataScanEventDataQualityAppliedConfigs.
3921 3922 3923 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3921 def initialize(**args) update!(**args) end |
Instance Attribute Details
#row_filter_applied ⇒ Boolean Also known as: row_filter_applied?
Boolean indicating whether a row filter was applied in the DataScan job.
Corresponds to the JSON property rowFilterApplied
3911 3912 3913 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3911 def row_filter_applied @row_filter_applied end |
#sampling_percent ⇒ Float
The percentage of the records selected from the dataset for DataScan. Value
ranges between 0.0 and 100.0. Value 0.0 or 100.0 imply that sampling was not
applied.
Corresponds to the JSON property samplingPercent
3919 3920 3921 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3919 def sampling_percent @sampling_percent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3926 3927 3928 3929 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 3926 def update!(**args) @row_filter_applied = args[:row_filter_applied] if args.key?(:row_filter_applied) @sampling_percent = args[:sampling_percent] if args.key?(:sampling_percent) end |