Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataQualityResult
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanEventDataQualityResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Data quality result for data scan job.
Instance Attribute Summary collapse
-
#column_score ⇒ Hash<String,Float>
The score of each column scanned in the data scan job.
-
#dimension_passed ⇒ Hash<String,Boolean>
The result of each dimension for data quality result.
-
#dimension_score ⇒ Hash<String,Float>
The score of each dimension for data quality result.
-
#passed ⇒ Boolean
(also: #passed?)
Whether the data quality result was pass or not.
-
#row_count ⇒ Fixnum
The count of rows processed in the data scan job.
-
#score ⇒ Float
The table-level data quality score for the data scan job.The data quality score ranges between 0, 100 (up to two decimal points).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataScanEventDataQualityResult
constructor
A new instance of GoogleCloudDataplexV1DataScanEventDataQualityResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataScanEventDataQualityResult
Returns a new instance of GoogleCloudDataplexV1DataScanEventDataQualityResult.
5449 5450 5451 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5449 def initialize(**args) update!(**args) end |
Instance Attribute Details
#column_score ⇒ Hash<String,Float>
The score of each column scanned in the data scan job. The key of the map is
the name of the column. The value is the data quality score for the column.The
score ranges between 0, 100 (up to two decimal points).
Corresponds to the JSON property columnScore
5416 5417 5418 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5416 def column_score @column_score end |
#dimension_passed ⇒ Hash<String,Boolean>
The result of each dimension for data quality result. The key of the map is
the name of the dimension. The value is the bool value depicting whether the
dimension result was pass or not.
Corresponds to the JSON property dimensionPassed
5423 5424 5425 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5423 def dimension_passed @dimension_passed end |
#dimension_score ⇒ Hash<String,Float>
The score of each dimension for data quality result. The key of the map is the
name of the dimension. The value is the data quality score for the dimension.
The score ranges between 0, 100 (up to two decimal points).
Corresponds to the JSON property dimensionScore
5430 5431 5432 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5430 def dimension_score @dimension_score end |
#passed ⇒ Boolean Also known as: passed?
Whether the data quality result was pass or not.
Corresponds to the JSON property passed
5435 5436 5437 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5435 def passed @passed end |
#row_count ⇒ Fixnum
The count of rows processed in the data scan job.
Corresponds to the JSON property rowCount
5441 5442 5443 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5441 def row_count @row_count end |
#score ⇒ Float
The table-level data quality score for the data scan job.The data quality
score ranges between 0, 100 (up to two decimal points).
Corresponds to the JSON property score
5447 5448 5449 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5447 def score @score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5454 5455 5456 5457 5458 5459 5460 5461 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5454 def update!(**args) @column_score = args[:column_score] if args.key?(:column_score) @dimension_passed = args[:dimension_passed] if args.key?(:dimension_passed) @dimension_score = args[:dimension_score] if args.key?(:dimension_score) @passed = args[:passed] if args.key?(:passed) @row_count = args[:row_count] if args.key?(:row_count) @score = args[:score] if args.key?(:score) end |