Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

A DataScanJob represents an instance of DataScan execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataScanJob

Returns a new instance of GoogleCloudDataplexV1DataScanJob.



5669
5670
5671
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5669

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time when the DataScanJob was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5573
5574
5575
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5573

def create_time
  @create_time
end

#data_discovery_resultGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoveryResult

The output of a data discovery scan. Corresponds to the JSON property dataDiscoveryResult



5578
5579
5580
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5578

def data_discovery_result
  @data_discovery_result
end

#data_discovery_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoverySpec

Spec for a data discovery scan. Corresponds to the JSON property dataDiscoverySpec



5583
5584
5585
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5583

def data_discovery_spec
  @data_discovery_spec
end

#data_documentation_resultGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResult

The output of a DataDocumentation scan. Corresponds to the JSON property dataDocumentationResult



5588
5589
5590
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5588

def data_documentation_result
  @data_documentation_result
end

#data_documentation_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationSpec

DataDocumentation scan related spec. Corresponds to the JSON property dataDocumentationSpec



5593
5594
5595
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5593

def data_documentation_spec
  @data_documentation_spec
end

#data_profile_resultGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResult

DataProfileResult defines the output of DataProfileScan. Each field of the table will have field type specific profile result. Corresponds to the JSON property dataProfileResult



5599
5600
5601
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5599

def data_profile_result
  @data_profile_result
end

#data_profile_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileSpec

DataProfileScan related setting. Corresponds to the JSON property dataProfileSpec



5604
5605
5606
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5604

def data_profile_spec
  @data_profile_spec
end

#data_quality_resultGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityResult

The output of a DataQualityScan. Corresponds to the JSON property dataQualityResult



5609
5610
5611
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5609

def data_quality_result
  @data_quality_result
end

#data_quality_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpec

DataQualityScan related setting. Corresponds to the JSON property dataQualitySpec



5614
5615
5616
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5614

def data_quality_spec
  @data_quality_spec
end

#end_timeString

Output only. The time when the DataScanJob ended. Corresponds to the JSON property endTime

Returns:

  • (String)


5619
5620
5621
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5619

def end_time
  @end_time
end

#messageString

Output only. Additional information about the current state. Corresponds to the JSON property message

Returns:

  • (String)


5624
5625
5626
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5624

def message
  @message
end

#nameString

Output only. Identifier. The relative resource name of the DataScanJob, of the form: projects/project/locations/location_id/dataScans/datascan_id/jobs/ job_id, where project refers to a project_id or project_number and location_id refers to a Google Cloud region. Corresponds to the JSON property name

Returns:

  • (String)


5632
5633
5634
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5632

def name
  @name
end

#partial_failure_messageString

Output only. A message indicating partial failure details. Corresponds to the JSON property partialFailureMessage

Returns:

  • (String)


5637
5638
5639
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5637

def partial_failure_message
  @partial_failure_message
end

#start_timeString

Output only. The time when the DataScanJob was started. Corresponds to the JSON property startTime

Returns:

  • (String)


5642
5643
5644
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5642

def start_time
  @start_time
end

#stateString

Output only. Execution state for the DataScanJob. Corresponds to the JSON property state

Returns:

  • (String)


5647
5648
5649
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5647

def state
  @state
end

#typeString

Output only. The type of the parent DataScan. Corresponds to the JSON property type

Returns:

  • (String)


5652
5653
5654
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5652

def type
  @type
end

#uidString

Output only. System generated globally unique ID for the DataScanJob. Corresponds to the JSON property uid

Returns:

  • (String)


5657
5658
5659
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5657

def uid
  @uid
end

#unstructured_data_profile_resultGoogle::Apis::DataplexV1::GoogleCloudDataplexV1UnstructuredDataProfileResult

Contains the result of an unstructured data profile scan. Corresponds to the JSON property unstructuredDataProfileResult



5662
5663
5664
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5662

def unstructured_data_profile_result
  @unstructured_data_profile_result
end

#unstructured_data_profile_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1UnstructuredDataProfileSpec

Contains the specification for an unstructured data profile scan. Corresponds to the JSON property unstructuredDataProfileSpec



5667
5668
5669
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5667

def unstructured_data_profile_spec
  @unstructured_data_profile_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
5684
5685
5686
5687
5688
5689
5690
5691
5692
5693
5694
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5674

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_discovery_result = args[:data_discovery_result] if args.key?(:data_discovery_result)
  @data_discovery_spec = args[:data_discovery_spec] if args.key?(:data_discovery_spec)
  @data_documentation_result = args[:data_documentation_result] if args.key?(:data_documentation_result)
  @data_documentation_spec = args[:data_documentation_spec] if args.key?(:data_documentation_spec)
  @data_profile_result = args[:data_profile_result] if args.key?(:data_profile_result)
  @data_profile_spec = args[:data_profile_spec] if args.key?(:data_profile_spec)
  @data_quality_result = args[:data_quality_result] if args.key?(:data_quality_result)
  @data_quality_spec = args[:data_quality_spec] if args.key?(:data_quality_spec)
  @end_time = args[:end_time] if args.key?(:end_time)
  @message = args[:message] if args.key?(:message)
  @name = args[:name] if args.key?(:name)
  @partial_failure_message = args[:partial_failure_message] if args.key?(:partial_failure_message)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
  @uid = args[:uid] if args.key?(:uid)
  @unstructured_data_profile_result = args[:unstructured_data_profile_result] if args.key?(:unstructured_data_profile_result)
  @unstructured_data_profile_spec = args[:unstructured_data_profile_spec] if args.key?(:unstructured_data_profile_spec)
end