Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanJob
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataScanJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
A DataScanJob represents an instance of DataScan execution.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#data_discovery_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoveryResult
The output of a data discovery scan.
-
#data_discovery_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoverySpec
Spec for a data discovery scan.
-
#data_documentation_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResult
The output of a DataDocumentation scan.
-
#data_documentation_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationSpec
DataDocumentation scan related spec.
-
#data_profile_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResult
DataProfileResult defines the output of DataProfileScan.
-
#data_profile_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileSpec
DataProfileScan related setting.
-
#data_quality_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityResult
The output of a DataQualityScan.
-
#data_quality_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpec
DataQualityScan related setting.
-
#end_time ⇒ String
Output only.
-
#message ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#partial_failure_message ⇒ String
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#type ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#unstructured_data_profile_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1UnstructuredDataProfileResult
Contains the result of an unstructured data profile scan.
-
#unstructured_data_profile_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1UnstructuredDataProfileSpec
Contains the specification for an unstructured data profile scan.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataScanJob
constructor
A new instance of GoogleCloudDataplexV1DataScanJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataScanJob
Returns a new instance of GoogleCloudDataplexV1DataScanJob.
5474 5475 5476 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5474 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time when the DataScanJob was created.
Corresponds to the JSON property createTime
5378 5379 5380 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5378 def create_time @create_time end |
#data_discovery_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoveryResult
The output of a data discovery scan.
Corresponds to the JSON property dataDiscoveryResult
5383 5384 5385 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5383 def data_discovery_result @data_discovery_result end |
#data_discovery_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDiscoverySpec
Spec for a data discovery scan.
Corresponds to the JSON property dataDiscoverySpec
5388 5389 5390 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5388 def data_discovery_spec @data_discovery_spec end |
#data_documentation_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationResult
The output of a DataDocumentation scan.
Corresponds to the JSON property dataDocumentationResult
5393 5394 5395 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5393 def data_documentation_result @data_documentation_result end |
#data_documentation_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataDocumentationSpec
DataDocumentation scan related spec.
Corresponds to the JSON property dataDocumentationSpec
5398 5399 5400 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5398 def data_documentation_spec @data_documentation_spec end |
#data_profile_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileResult
DataProfileResult defines the output of DataProfileScan. Each field of the
table will have field type specific profile result.
Corresponds to the JSON property dataProfileResult
5404 5405 5406 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5404 def data_profile_result @data_profile_result end |
#data_profile_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataProfileSpec
DataProfileScan related setting.
Corresponds to the JSON property dataProfileSpec
5409 5410 5411 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5409 def data_profile_spec @data_profile_spec end |
#data_quality_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityResult
The output of a DataQualityScan.
Corresponds to the JSON property dataQualityResult
5414 5415 5416 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5414 def data_quality_result @data_quality_result end |
#data_quality_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualitySpec
DataQualityScan related setting.
Corresponds to the JSON property dataQualitySpec
5419 5420 5421 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5419 def data_quality_spec @data_quality_spec end |
#end_time ⇒ String
Output only. The time when the DataScanJob ended.
Corresponds to the JSON property endTime
5424 5425 5426 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5424 def end_time @end_time end |
#message ⇒ String
Output only. Additional information about the current state.
Corresponds to the JSON property message
5429 5430 5431 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5429 def @message end |
#name ⇒ String
Output only. Identifier. The relative resource name of the DataScanJob, of the
form: projects/project/locations/location_id/dataScans/datascan_id/jobs/
job_id, where project refers to a project_id or project_number and
location_id refers to a Google Cloud region.
Corresponds to the JSON property name
5437 5438 5439 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5437 def name @name end |
#partial_failure_message ⇒ String
Output only. A message indicating partial failure details.
Corresponds to the JSON property partialFailureMessage
5442 5443 5444 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5442 def @partial_failure_message end |
#start_time ⇒ String
Output only. The time when the DataScanJob was started.
Corresponds to the JSON property startTime
5447 5448 5449 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5447 def start_time @start_time end |
#state ⇒ String
Output only. Execution state for the DataScanJob.
Corresponds to the JSON property state
5452 5453 5454 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5452 def state @state end |
#type ⇒ String
Output only. The type of the parent DataScan.
Corresponds to the JSON property type
5457 5458 5459 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5457 def type @type end |
#uid ⇒ String
Output only. System generated globally unique ID for the DataScanJob.
Corresponds to the JSON property uid
5462 5463 5464 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5462 def uid @uid end |
#unstructured_data_profile_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1UnstructuredDataProfileResult
Contains the result of an unstructured data profile scan.
Corresponds to the JSON property unstructuredDataProfileResult
5467 5468 5469 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5467 def unstructured_data_profile_result @unstructured_data_profile_result end |
#unstructured_data_profile_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1UnstructuredDataProfileSpec
Contains the specification for an unstructured data profile scan.
Corresponds to the JSON property unstructuredDataProfileSpec
5472 5473 5474 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5472 def unstructured_data_profile_spec @unstructured_data_profile_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 5493 5494 5495 5496 5497 5498 5499 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5479 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @data_discovery_result = args[:data_discovery_result] if args.key?(:data_discovery_result) @data_discovery_spec = args[:data_discovery_spec] if args.key?(:data_discovery_spec) @data_documentation_result = args[:data_documentation_result] if args.key?(:data_documentation_result) @data_documentation_spec = args[:data_documentation_spec] if args.key?(:data_documentation_spec) @data_profile_result = args[:data_profile_result] if args.key?(:data_profile_result) @data_profile_spec = args[:data_profile_spec] if args.key?(:data_profile_spec) @data_quality_result = args[:data_quality_result] if args.key?(:data_quality_result) @data_quality_spec = args[:data_quality_spec] if args.key?(:data_quality_spec) @end_time = args[:end_time] if args.key?(:end_time) @message = args[:message] if args.key?(:message) @name = args[:name] if args.key?(:name) @partial_failure_message = args[:partial_failure_message] if args.key?(:partial_failure_message) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @type = args[:type] if args.key?(:type) @uid = args[:uid] if args.key?(:uid) @unstructured_data_profile_result = args[:unstructured_data_profile_result] if args.key?(:unstructured_data_profile_result) @unstructured_data_profile_spec = args[:unstructured_data_profile_spec] if args.key?(:unstructured_data_profile_spec) end |