Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataTaxonomy
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DataTaxonomy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
DataTaxonomy represents a set of hierarchical DataAttributes resources, grouped with a common theme Eg: 'SensitiveDataTaxonomy' can have attributes to manage PII data. It is defined at project level.
Instance Attribute Summary collapse
-
#attribute_count ⇒ Fixnum
Output only.
-
#class_count ⇒ Fixnum
Output only.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up- to-date value before proceeding.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DataTaxonomy
constructor
A new instance of GoogleCloudDataplexV1DataTaxonomy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DataTaxonomy
Returns a new instance of GoogleCloudDataplexV1DataTaxonomy.
5794 5795 5796 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5794 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attribute_count ⇒ Fixnum
Output only. The number of attributes in the DataTaxonomy.
Corresponds to the JSON property attributeCount
5741 5742 5743 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5741 def attribute_count @attribute_count end |
#class_count ⇒ Fixnum
Output only. The number of classes in the DataTaxonomy.
Corresponds to the JSON property classCount
5746 5747 5748 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5746 def class_count @class_count end |
#create_time ⇒ String
Output only. The time when the DataTaxonomy was created.
Corresponds to the JSON property createTime
5751 5752 5753 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5751 def create_time @create_time end |
#description ⇒ String
Optional. Description of the DataTaxonomy.
Corresponds to the JSON property description
5756 5757 5758 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5756 def description @description end |
#display_name ⇒ String
Optional. User friendly display name.
Corresponds to the JSON property displayName
5761 5762 5763 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5761 def display_name @display_name end |
#etag ⇒ String
This checksum is computed by the server based on the value of other fields,
and may be sent on update and delete requests to ensure the client has an up-
to-date value before proceeding.
Corresponds to the JSON property etag
5768 5769 5770 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5768 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. User-defined labels for the DataTaxonomy.
Corresponds to the JSON property labels
5773 5774 5775 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5773 def labels @labels end |
#name ⇒ String
Output only. The relative resource name of the DataTaxonomy, of the form:
projects/project_number/locations/location_id/dataTaxonomies/
data_taxonomy_id.
Corresponds to the JSON property name
5780 5781 5782 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5780 def name @name end |
#uid ⇒ String
Output only. System generated globally unique ID for the dataTaxonomy. This ID
will be different if the DataTaxonomy is deleted and re-created with the same
name.
Corresponds to the JSON property uid
5787 5788 5789 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5787 def uid @uid end |
#update_time ⇒ String
Output only. The time when the DataTaxonomy was last updated.
Corresponds to the JSON property updateTime
5792 5793 5794 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5792 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5799 5800 5801 5802 5803 5804 5805 5806 5807 5808 5809 5810 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5799 def update!(**args) @attribute_count = args[:attribute_count] if args.key?(:attribute_count) @class_count = args[:class_count] if args.key?(:class_count) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |