Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataTaxonomy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

DataTaxonomy represents a set of hierarchical DataAttributes resources, grouped with a common theme Eg: 'SensitiveDataTaxonomy' can have attributes to manage PII data. It is defined at project level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataTaxonomy

Returns a new instance of GoogleCloudDataplexV1DataTaxonomy.



5599
5600
5601
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5599

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attribute_countFixnum

Output only. The number of attributes in the DataTaxonomy. Corresponds to the JSON property attributeCount

Returns:

  • (Fixnum)


5546
5547
5548
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5546

def attribute_count
  @attribute_count
end

#class_countFixnum

Output only. The number of classes in the DataTaxonomy. Corresponds to the JSON property classCount

Returns:

  • (Fixnum)


5551
5552
5553
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5551

def class_count
  @class_count
end

#create_timeString

Output only. The time when the DataTaxonomy was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5556
5557
5558
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5556

def create_time
  @create_time
end

#descriptionString

Optional. Description of the DataTaxonomy. Corresponds to the JSON property description

Returns:

  • (String)


5561
5562
5563
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5561

def description
  @description
end

#display_nameString

Optional. User friendly display name. Corresponds to the JSON property displayName

Returns:

  • (String)


5566
5567
5568
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5566

def display_name
  @display_name
end

#etagString

This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up- to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


5573
5574
5575
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5573

def etag
  @etag
end

#labelsHash<String,String>

Optional. User-defined labels for the DataTaxonomy. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5578
5579
5580
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5578

def labels
  @labels
end

#nameString

Output only. The relative resource name of the DataTaxonomy, of the form: projects/project_number/locations/location_id/dataTaxonomies/ data_taxonomy_id. Corresponds to the JSON property name

Returns:

  • (String)


5585
5586
5587
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5585

def name
  @name
end

#uidString

Output only. System generated globally unique ID for the dataTaxonomy. This ID will be different if the DataTaxonomy is deleted and re-created with the same name. Corresponds to the JSON property uid

Returns:

  • (String)


5592
5593
5594
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5592

def uid
  @uid
end

#update_timeString

Output only. The time when the DataTaxonomy was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


5597
5598
5599
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5597

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5604
5605
5606
5607
5608
5609
5610
5611
5612
5613
5614
5615
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5604

def update!(**args)
  @attribute_count = args[:attribute_count] if args.key?(:attribute_count)
  @class_count = args[:class_count] if args.key?(:class_count)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end