Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DataTaxonomy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

DataTaxonomy represents a set of hierarchical DataAttributes resources, grouped with a common theme Eg: 'SensitiveDataTaxonomy' can have attributes to manage PII data. It is defined at project level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DataTaxonomy

Returns a new instance of GoogleCloudDataplexV1DataTaxonomy.



4299
4300
4301
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4299

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attribute_countFixnum

Output only. The number of attributes in the DataTaxonomy. Corresponds to the JSON property attributeCount

Returns:

  • (Fixnum)


4246
4247
4248
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4246

def attribute_count
  @attribute_count
end

#class_countFixnum

Output only. The number of classes in the DataTaxonomy. Corresponds to the JSON property classCount

Returns:

  • (Fixnum)


4251
4252
4253
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4251

def class_count
  @class_count
end

#create_timeString

Output only. The time when the DataTaxonomy was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4256
4257
4258
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4256

def create_time
  @create_time
end

#descriptionString

Optional. Description of the DataTaxonomy. Corresponds to the JSON property description

Returns:

  • (String)


4261
4262
4263
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4261

def description
  @description
end

#display_nameString

Optional. User friendly display name. Corresponds to the JSON property displayName

Returns:

  • (String)


4266
4267
4268
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4266

def display_name
  @display_name
end

#etagString

This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up- to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


4273
4274
4275
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4273

def etag
  @etag
end

#labelsHash<String,String>

Optional. User-defined labels for the DataTaxonomy. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4278
4279
4280
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4278

def labels
  @labels
end

#nameString

Output only. The relative resource name of the DataTaxonomy, of the form: projects/project_number/locations/location_id/dataTaxonomies/ data_taxonomy_id. Corresponds to the JSON property name

Returns:

  • (String)


4285
4286
4287
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4285

def name
  @name
end

#uidString

Output only. System generated globally unique ID for the dataTaxonomy. This ID will be different if the DataTaxonomy is deleted and re-created with the same name. Corresponds to the JSON property uid

Returns:

  • (String)


4292
4293
4294
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4292

def uid
  @uid
end

#update_timeString

Output only. The time when the DataTaxonomy was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4297
4298
4299
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4297

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4304
4305
4306
4307
4308
4309
4310
4311
4312
4313
4314
4315
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4304

def update!(**args)
  @attribute_count = args[:attribute_count] if args.key?(:attribute_count)
  @class_count = args[:class_count] if args.key?(:class_count)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end