Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DeleteGlossaryRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Delete Glossary Request

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1DeleteGlossaryRequest

Returns a new instance of GoogleCloudDataplexV1DeleteGlossaryRequest.



5697
5698
5699
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5697

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Optional. The etag of the Glossary. If this is provided, it must match the server's etag. If the etag is provided and does not match the server-computed etag, the request must fail with a ABORTED error code. Corresponds to the JSON property etag

Returns:

  • (String)


5689
5690
5691
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5689

def etag
  @etag
end

#nameString

Required. The name of the Glossary to delete. Format: projects/ project_id_or_number/locations/location_id/glossaries/glossary_id Corresponds to the JSON property name

Returns:

  • (String)


5695
5696
5697
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5695

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5702
5703
5704
5705
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5702

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
end