Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEvent
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
The payload associated with Discovery data processing.
Instance Attribute Summary collapse
-
#action ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEventActionDetails
Details about the action.
-
#asset_id ⇒ String
The id of the associated asset.
-
#config ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEventConfigDetails
Details about configuration events.
-
#data_location ⇒ String
The data location associated with the event.
-
#datascan_id ⇒ String
The id of the associated datascan for standalone discovery.
-
#entity ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEventEntityDetails
Details about the entity.
-
#lake_id ⇒ String
The id of the associated lake.
-
#message ⇒ String
The log message.
-
#partition ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEventPartitionDetails
Details about the partition.
-
#table ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEventTableDetails
Details about the published table.
-
#type ⇒ String
The type of the event being logged.
-
#zone_id ⇒ String
The id of the associated zone.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DiscoveryEvent
constructor
A new instance of GoogleCloudDataplexV1DiscoveryEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DiscoveryEvent
Returns a new instance of GoogleCloudDataplexV1DiscoveryEvent.
5793 5794 5795 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5793 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEventActionDetails
Details about the action.
Corresponds to the JSON property action
5736 5737 5738 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5736 def action @action end |
#asset_id ⇒ String
The id of the associated asset.
Corresponds to the JSON property assetId
5741 5742 5743 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5741 def asset_id @asset_id end |
#config ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEventConfigDetails
Details about configuration events.
Corresponds to the JSON property config
5746 5747 5748 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5746 def config @config end |
#data_location ⇒ String
The data location associated with the event.
Corresponds to the JSON property dataLocation
5751 5752 5753 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5751 def data_location @data_location end |
#datascan_id ⇒ String
The id of the associated datascan for standalone discovery.
Corresponds to the JSON property datascanId
5756 5757 5758 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5756 def datascan_id @datascan_id end |
#entity ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEventEntityDetails
Details about the entity.
Corresponds to the JSON property entity
5761 5762 5763 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5761 def entity @entity end |
#lake_id ⇒ String
The id of the associated lake.
Corresponds to the JSON property lakeId
5766 5767 5768 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5766 def lake_id @lake_id end |
#message ⇒ String
The log message.
Corresponds to the JSON property message
5771 5772 5773 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5771 def @message end |
#partition ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEventPartitionDetails
Details about the partition.
Corresponds to the JSON property partition
5776 5777 5778 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5776 def partition @partition end |
#table ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEventTableDetails
Details about the published table.
Corresponds to the JSON property table
5781 5782 5783 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5781 def table @table end |
#type ⇒ String
The type of the event being logged.
Corresponds to the JSON property type
5786 5787 5788 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5786 def type @type end |
#zone_id ⇒ String
The id of the associated zone.
Corresponds to the JSON property zoneId
5791 5792 5793 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5791 def zone_id @zone_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5798 5799 5800 5801 5802 5803 5804 5805 5806 5807 5808 5809 5810 5811 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5798 def update!(**args) @action = args[:action] if args.key?(:action) @asset_id = args[:asset_id] if args.key?(:asset_id) @config = args[:config] if args.key?(:config) @data_location = args[:data_location] if args.key?(:data_location) @datascan_id = args[:datascan_id] if args.key?(:datascan_id) @entity = args[:entity] if args.key?(:entity) @lake_id = args[:lake_id] if args.key?(:lake_id) @message = args[:message] if args.key?(:message) @partition = args[:partition] if args.key?(:partition) @table = args[:table] if args.key?(:table) @type = args[:type] if args.key?(:type) @zone_id = args[:zone_id] if args.key?(:zone_id) end |