Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEvent
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
The payload associated with Discovery data processing.
Instance Attribute Summary collapse
-
#action ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEventActionDetails
Details about the action.
-
#asset_id ⇒ String
The id of the associated asset.
-
#config ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEventConfigDetails
Details about configuration events.
-
#data_location ⇒ String
The data location associated with the event.
-
#datascan_id ⇒ String
The id of the associated datascan for standalone discovery.
-
#entity ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEventEntityDetails
Details about the entity.
-
#lake_id ⇒ String
The id of the associated lake.
-
#message ⇒ String
The log message.
-
#partition ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEventPartitionDetails
Details about the partition.
-
#table ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEventTableDetails
Details about the published table.
-
#type ⇒ String
The type of the event being logged.
-
#zone_id ⇒ String
The id of the associated zone.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1DiscoveryEvent
constructor
A new instance of GoogleCloudDataplexV1DiscoveryEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1DiscoveryEvent
Returns a new instance of GoogleCloudDataplexV1DiscoveryEvent.
4382 4383 4384 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4382 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEventActionDetails
Details about the action.
Corresponds to the JSON property action
4325 4326 4327 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4325 def action @action end |
#asset_id ⇒ String
The id of the associated asset.
Corresponds to the JSON property assetId
4330 4331 4332 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4330 def asset_id @asset_id end |
#config ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEventConfigDetails
Details about configuration events.
Corresponds to the JSON property config
4335 4336 4337 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4335 def config @config end |
#data_location ⇒ String
The data location associated with the event.
Corresponds to the JSON property dataLocation
4340 4341 4342 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4340 def data_location @data_location end |
#datascan_id ⇒ String
The id of the associated datascan for standalone discovery.
Corresponds to the JSON property datascanId
4345 4346 4347 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4345 def datascan_id @datascan_id end |
#entity ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEventEntityDetails
Details about the entity.
Corresponds to the JSON property entity
4350 4351 4352 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4350 def entity @entity end |
#lake_id ⇒ String
The id of the associated lake.
Corresponds to the JSON property lakeId
4355 4356 4357 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4355 def lake_id @lake_id end |
#message ⇒ String
The log message.
Corresponds to the JSON property message
4360 4361 4362 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4360 def @message end |
#partition ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEventPartitionDetails
Details about the partition.
Corresponds to the JSON property partition
4365 4366 4367 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4365 def partition @partition end |
#table ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1DiscoveryEventTableDetails
Details about the published table.
Corresponds to the JSON property table
4370 4371 4372 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4370 def table @table end |
#type ⇒ String
The type of the event being logged.
Corresponds to the JSON property type
4375 4376 4377 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4375 def type @type end |
#zone_id ⇒ String
The id of the associated zone.
Corresponds to the JSON property zoneId
4380 4381 4382 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4380 def zone_id @zone_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4387 4388 4389 4390 4391 4392 4393 4394 4395 4396 4397 4398 4399 4400 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4387 def update!(**args) @action = args[:action] if args.key?(:action) @asset_id = args[:asset_id] if args.key?(:asset_id) @config = args[:config] if args.key?(:config) @data_location = args[:data_location] if args.key?(:data_location) @datascan_id = args[:datascan_id] if args.key?(:datascan_id) @entity = args[:entity] if args.key?(:entity) @lake_id = args[:lake_id] if args.key?(:lake_id) @message = args[:message] if args.key?(:message) @partition = args[:partition] if args.key?(:partition) @table = args[:table] if args.key?(:table) @type = args[:type] if args.key?(:type) @zone_id = args[:zone_id] if args.key?(:zone_id) end |