Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1EncryptionConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1EncryptionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
A Resource designed to manage encryption configurations for customers to support Customer Managed Encryption Keys (CMEK).
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#enable_metastore_encryption ⇒ Boolean
(also: #enable_metastore_encryption?)
Optional.
-
#encryption_state ⇒ String
Output only.
-
#etag ⇒ String
Etag of the EncryptionConfig.
-
#failure_details ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1EncryptionConfigFailureDetails
Details of the failure if anything related to Cmek db fails.
-
#key ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1EncryptionConfig
constructor
A new instance of GoogleCloudDataplexV1EncryptionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1EncryptionConfig
Returns a new instance of GoogleCloudDataplexV1EncryptionConfig.
6000 6001 6002 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6000 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time when the Encryption configuration was created.
Corresponds to the JSON property createTime
5958 5959 5960 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5958 def create_time @create_time end |
#enable_metastore_encryption ⇒ Boolean Also known as: enable_metastore_encryption?
Optional. Represent the state of CMEK opt-in for metastore.
Corresponds to the JSON property enableMetastoreEncryption
5963 5964 5965 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5963 def @enable_metastore_encryption end |
#encryption_state ⇒ String
Output only. The state of encryption of the databases.
Corresponds to the JSON property encryptionState
5969 5970 5971 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5969 def encryption_state @encryption_state end |
#etag ⇒ String
Etag of the EncryptionConfig. This is a strong etag.
Corresponds to the JSON property etag
5974 5975 5976 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5974 def etag @etag end |
#failure_details ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1EncryptionConfigFailureDetails
Details of the failure if anything related to Cmek db fails.
Corresponds to the JSON property failureDetails
5979 5980 5981 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5979 def failure_details @failure_details end |
#key ⇒ String
Optional. If a key is chosen, it means that the customer is using CMEK. If a
key is not chosen, it means that the customer is using Google managed
encryption.
Corresponds to the JSON property key
5986 5987 5988 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5986 def key @key end |
#name ⇒ String
Identifier. The resource name of the EncryptionConfig. Format: organizations/
organization/locations/location/encryptionConfigs/encryption_config
Global location is not supported.
Corresponds to the JSON property name
5993 5994 5995 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5993 def name @name end |
#update_time ⇒ String
Output only. The time when the Encryption configuration was last updated.
Corresponds to the JSON property updateTime
5998 5999 6000 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5998 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6005 6006 6007 6008 6009 6010 6011 6012 6013 6014 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6005 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @enable_metastore_encryption = args[:enable_metastore_encryption] if args.key?(:enable_metastore_encryption) @encryption_state = args[:encryption_state] if args.key?(:encryption_state) @etag = args[:etag] if args.key?(:etag) @failure_details = args[:failure_details] if args.key?(:failure_details) @key = args[:key] if args.key?(:key) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |