Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1EncryptionConfigFailureDetails
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1EncryptionConfigFailureDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Details of the failure if anything related to Cmek db fails.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Output only.
-
#error_message ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1EncryptionConfigFailureDetails
constructor
A new instance of GoogleCloudDataplexV1EncryptionConfigFailureDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1EncryptionConfigFailureDetails
Returns a new instance of GoogleCloudDataplexV1EncryptionConfigFailureDetails.
6032 6033 6034 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6032 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_code ⇒ String
Output only. The error code for the failure.
Corresponds to the JSON property errorCode
6024 6025 6026 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6024 def error_code @error_code end |
#error_message ⇒ String
Output only. The error message will be shown to the user. Set only if the
error code is REQUIRE_USER_ACTION.
Corresponds to the JSON property errorMessage
6030 6031 6032 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6030 def @error_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6037 6038 6039 6040 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6037 def update!(**args) @error_code = args[:error_code] if args.key?(:error_code) @error_message = args[:error_message] if args.key?(:error_message) end |