Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1EncryptionConfigFailureDetails
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1EncryptionConfigFailureDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Details of the failure if anything related to Cmek db fails.
Instance Attribute Summary collapse
-
#error_code ⇒ String
Output only.
-
#error_message ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1EncryptionConfigFailureDetails
constructor
A new instance of GoogleCloudDataplexV1EncryptionConfigFailureDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1EncryptionConfigFailureDetails
Returns a new instance of GoogleCloudDataplexV1EncryptionConfigFailureDetails.
4621 4622 4623 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4621 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_code ⇒ String
Output only. The error code for the failure.
Corresponds to the JSON property errorCode
4613 4614 4615 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4613 def error_code @error_code end |
#error_message ⇒ String
Output only. The error message will be shown to the user. Set only if the
error code is REQUIRE_USER_ACTION.
Corresponds to the JSON property errorMessage
4619 4620 4621 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4619 def @error_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4626 4627 4628 4629 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4626 def update!(**args) @error_code = args[:error_code] if args.key?(:error_code) @error_message = args[:error_message] if args.key?(:error_message) end |