Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1Entity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Represents tables and fileset metadata contained within a zone.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1Entity

Returns a new instance of GoogleCloudDataplexV1Entity.



6151
6152
6153
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6151

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accessGoogle::Apis::DataplexV1::GoogleCloudDataplexV1StorageAccess

Describes the access mechanism of the data within its storage location. Corresponds to the JSON property access



6050
6051
6052
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6050

def access
  @access
end

#assetString

Required. Immutable. The ID of the asset associated with the storage location containing the entity data. The entity must be with in the same zone with the asset. Corresponds to the JSON property asset

Returns:

  • (String)


6057
6058
6059
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6057

def asset
  @asset
end

#catalog_entryString

Output only. The name of the associated Data Catalog entry. Corresponds to the JSON property catalogEntry

Returns:

  • (String)


6062
6063
6064
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6062

def catalog_entry
  @catalog_entry
end

#compatibilityGoogle::Apis::DataplexV1::GoogleCloudDataplexV1EntityCompatibilityStatus

Provides compatibility information for various metadata stores. Corresponds to the JSON property compatibility



6067
6068
6069
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6067

def compatibility
  @compatibility
end

#create_timeString

Output only. The time when the entity was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6072
6073
6074
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6072

def create_time
  @create_time
end

#data_pathString

Required. Immutable. The storage path of the entity data. For Cloud Storage data, this is the fully-qualified path to the entity, such as gs://bucket/path/ to/data. For BigQuery data, this is the name of the table resource, such as projects/project_id/datasets/dataset_id/tables/table_id. Corresponds to the JSON property dataPath

Returns:

  • (String)


6080
6081
6082
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6080

def data_path
  @data_path
end

#data_path_patternString

Optional. The set of items within the data path constituting the data in the entity, represented as a glob path. Example: gs://bucket/path/to/data/*/.csv. Corresponds to the JSON property dataPathPattern

Returns:

  • (String)


6086
6087
6088
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6086

def data_path_pattern
  @data_path_pattern
end

#descriptionString

Optional. User friendly longer description text. Must be shorter than or equal to 1024 characters. Corresponds to the JSON property description

Returns:

  • (String)


6092
6093
6094
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6092

def description
  @description
end

#display_nameString

Optional. Display name must be shorter than or equal to 256 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


6097
6098
6099
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6097

def display_name
  @display_name
end

#etagString

Optional. The etag associated with the entity, which can be retrieved with a GetEntity request. Required for update and delete requests. Corresponds to the JSON property etag

Returns:

  • (String)


6103
6104
6105
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6103

def etag
  @etag
end

#formatGoogle::Apis::DataplexV1::GoogleCloudDataplexV1StorageFormat

Describes the format of the data within its storage location. Corresponds to the JSON property format



6108
6109
6110
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6108

def format
  @format
end

#idString

Required. A user-provided entity ID. It is mutable, and will be used as the published table name. Specifying a new ID in an update entity request will override the existing value. The ID must contain only letters (a-z, A-Z), numbers (0-9), and underscores, and consist of 256 or fewer characters. Corresponds to the JSON property id

Returns:

  • (String)


6116
6117
6118
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6116

def id
  @id
end

#nameString

Output only. The resource name of the entity, of the form: projects/ project_number/locations/location_id/lakes/lake_id/zones/zone_id/ entities/id. Corresponds to the JSON property name

Returns:

  • (String)


6123
6124
6125
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6123

def name
  @name
end

#schemaGoogle::Apis::DataplexV1::GoogleCloudDataplexV1Schema

Schema information describing the structure and layout of the data. Corresponds to the JSON property schema



6128
6129
6130
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6128

def schema
  @schema
end

#systemString

Required. Immutable. Identifies the storage system of the entity data. Corresponds to the JSON property system

Returns:

  • (String)


6133
6134
6135
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6133

def system
  @system
end

#typeString

Required. Immutable. The type of entity. Corresponds to the JSON property type

Returns:

  • (String)


6138
6139
6140
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6138

def type
  @type
end

#uidString

Output only. System generated unique ID for the Entity. This ID will be different if the Entity is deleted and re-created with the same name. Corresponds to the JSON property uid

Returns:

  • (String)


6144
6145
6146
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6144

def uid
  @uid
end

#update_timeString

Output only. The time when the entity was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


6149
6150
6151
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6149

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6156
6157
6158
6159
6160
6161
6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6156

def update!(**args)
  @access = args[:access] if args.key?(:access)
  @asset = args[:asset] if args.key?(:asset)
  @catalog_entry = args[:catalog_entry] if args.key?(:catalog_entry)
  @compatibility = args[:compatibility] if args.key?(:compatibility)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_path = args[:data_path] if args.key?(:data_path)
  @data_path_pattern = args[:data_path_pattern] if args.key?(:data_path_pattern)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @format = args[:format] if args.key?(:format)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @schema = args[:schema] if args.key?(:schema)
  @system = args[:system] if args.key?(:system)
  @type = args[:type] if args.key?(:type)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end