Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1Entity
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1Entity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Represents tables and fileset metadata contained within a zone.
Instance Attribute Summary collapse
-
#access ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1StorageAccess
Describes the access mechanism of the data within its storage location.
-
#asset ⇒ String
Required.
-
#catalog_entry ⇒ String
Output only.
-
#compatibility ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1EntityCompatibilityStatus
Provides compatibility information for various metadata stores.
-
#create_time ⇒ String
Output only.
-
#data_path ⇒ String
Required.
-
#data_path_pattern ⇒ String
Optional.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
Optional.
-
#format ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1StorageFormat
Describes the format of the data within its storage location.
-
#id ⇒ String
Required.
-
#name ⇒ String
Output only.
-
#schema ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1Schema
Schema information describing the structure and layout of the data.
-
#system ⇒ String
Required.
-
#type ⇒ String
Required.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1Entity
constructor
A new instance of GoogleCloudDataplexV1Entity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1Entity
Returns a new instance of GoogleCloudDataplexV1Entity.
4740 4741 4742 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4740 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1StorageAccess
Describes the access mechanism of the data within its storage location.
Corresponds to the JSON property access
4639 4640 4641 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4639 def access @access end |
#asset ⇒ String
Required. Immutable. The ID of the asset associated with the storage location
containing the entity data. The entity must be with in the same zone with the
asset.
Corresponds to the JSON property asset
4646 4647 4648 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4646 def asset @asset end |
#catalog_entry ⇒ String
Output only. The name of the associated Data Catalog entry.
Corresponds to the JSON property catalogEntry
4651 4652 4653 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4651 def catalog_entry @catalog_entry end |
#compatibility ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1EntityCompatibilityStatus
Provides compatibility information for various metadata stores.
Corresponds to the JSON property compatibility
4656 4657 4658 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4656 def compatibility @compatibility end |
#create_time ⇒ String
Output only. The time when the entity was created.
Corresponds to the JSON property createTime
4661 4662 4663 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4661 def create_time @create_time end |
#data_path ⇒ String
Required. Immutable. The storage path of the entity data. For Cloud Storage
data, this is the fully-qualified path to the entity, such as gs://bucket/path/
to/data. For BigQuery data, this is the name of the table resource, such as
projects/project_id/datasets/dataset_id/tables/table_id.
Corresponds to the JSON property dataPath
4669 4670 4671 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4669 def data_path @data_path end |
#data_path_pattern ⇒ String
Optional. The set of items within the data path constituting the data in the
entity, represented as a glob path. Example: gs://bucket/path/to/data/*/.csv.
Corresponds to the JSON property dataPathPattern
4675 4676 4677 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4675 def data_path_pattern @data_path_pattern end |
#description ⇒ String
Optional. User friendly longer description text. Must be shorter than or equal
to 1024 characters.
Corresponds to the JSON property description
4681 4682 4683 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4681 def description @description end |
#display_name ⇒ String
Optional. Display name must be shorter than or equal to 256 characters.
Corresponds to the JSON property displayName
4686 4687 4688 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4686 def display_name @display_name end |
#etag ⇒ String
Optional. The etag associated with the entity, which can be retrieved with a
GetEntity request. Required for update and delete requests.
Corresponds to the JSON property etag
4692 4693 4694 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4692 def etag @etag end |
#format ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1StorageFormat
Describes the format of the data within its storage location.
Corresponds to the JSON property format
4697 4698 4699 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4697 def format @format end |
#id ⇒ String
Required. A user-provided entity ID. It is mutable, and will be used as the
published table name. Specifying a new ID in an update entity request will
override the existing value. The ID must contain only letters (a-z, A-Z),
numbers (0-9), and underscores, and consist of 256 or fewer characters.
Corresponds to the JSON property id
4705 4706 4707 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4705 def id @id end |
#name ⇒ String
Output only. The resource name of the entity, of the form: projects/
project_number/locations/location_id/lakes/lake_id/zones/zone_id/
entities/id.
Corresponds to the JSON property name
4712 4713 4714 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4712 def name @name end |
#schema ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1Schema
Schema information describing the structure and layout of the data.
Corresponds to the JSON property schema
4717 4718 4719 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4717 def schema @schema end |
#system ⇒ String
Required. Immutable. Identifies the storage system of the entity data.
Corresponds to the JSON property system
4722 4723 4724 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4722 def system @system end |
#type ⇒ String
Required. Immutable. The type of entity.
Corresponds to the JSON property type
4727 4728 4729 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4727 def type @type end |
#uid ⇒ String
Output only. System generated unique ID for the Entity. This ID will be
different if the Entity is deleted and re-created with the same name.
Corresponds to the JSON property uid
4733 4734 4735 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4733 def uid @uid end |
#update_time ⇒ String
Output only. The time when the entity was last updated.
Corresponds to the JSON property updateTime
4738 4739 4740 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4738 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4745 4746 4747 4748 4749 4750 4751 4752 4753 4754 4755 4756 4757 4758 4759 4760 4761 4762 4763 4764 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4745 def update!(**args) @access = args[:access] if args.key?(:access) @asset = args[:asset] if args.key?(:asset) @catalog_entry = args[:catalog_entry] if args.key?(:catalog_entry) @compatibility = args[:compatibility] if args.key?(:compatibility) @create_time = args[:create_time] if args.key?(:create_time) @data_path = args[:data_path] if args.key?(:data_path) @data_path_pattern = args[:data_path_pattern] if args.key?(:data_path_pattern) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @format = args[:format] if args.key?(:format) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @schema = args[:schema] if args.key?(:schema) @system = args[:system] if args.key?(:system) @type = args[:type] if args.key?(:type) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |