Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1EntryGroup
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1EntryGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
An Entry Group represents a logical grouping of one or more Entries.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
This checksum is computed by the service, and might be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#transfer_status ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1EntryGroup
constructor
A new instance of GoogleCloudDataplexV1EntryGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1EntryGroup
Returns a new instance of GoogleCloudDataplexV1EntryGroup.
6559 6560 6561 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6559 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time when the EntryGroup was created.
Corresponds to the JSON property createTime
6511 6512 6513 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6511 def create_time @create_time end |
#description ⇒ String
Optional. Description of the EntryGroup.
Corresponds to the JSON property description
6516 6517 6518 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6516 def description @description end |
#display_name ⇒ String
Optional. User friendly display name.
Corresponds to the JSON property displayName
6521 6522 6523 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6521 def display_name @display_name end |
#etag ⇒ String
This checksum is computed by the service, and might be sent on update and
delete requests to ensure the client has an up-to-date value before proceeding.
Corresponds to the JSON property etag
6527 6528 6529 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6527 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. User-defined labels for the EntryGroup.
Corresponds to the JSON property labels
6532 6533 6534 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6532 def labels @labels end |
#name ⇒ String
Output only. The relative resource name of the EntryGroup, in the format
projects/project_id_or_number/locations/location_id/entryGroups/
entry_group_id.
Corresponds to the JSON property name
6539 6540 6541 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6539 def name @name end |
#transfer_status ⇒ String
Output only. Denotes the transfer status of the Entry Group. It is unspecified
for Entry Group created from Dataplex API.
Corresponds to the JSON property transferStatus
6545 6546 6547 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6545 def transfer_status @transfer_status end |
#uid ⇒ String
Output only. System generated globally unique ID for the EntryGroup. If you
delete and recreate the EntryGroup with the same name, this ID will be
different.
Corresponds to the JSON property uid
6552 6553 6554 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6552 def uid @uid end |
#update_time ⇒ String
Output only. The time when the EntryGroup was last updated.
Corresponds to the JSON property updateTime
6557 6558 6559 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6557 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6564 6565 6566 6567 6568 6569 6570 6571 6572 6573 6574 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6564 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @transfer_status = args[:transfer_status] if args.key?(:transfer_status) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |