Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1EntryGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

An Entry Group represents a logical grouping of one or more Entries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1EntryGroup

Returns a new instance of GoogleCloudDataplexV1EntryGroup.



6364
6365
6366
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6364

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time when the EntryGroup was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6316
6317
6318
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6316

def create_time
  @create_time
end

#descriptionString

Optional. Description of the EntryGroup. Corresponds to the JSON property description

Returns:

  • (String)


6321
6322
6323
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6321

def description
  @description
end

#display_nameString

Optional. User friendly display name. Corresponds to the JSON property displayName

Returns:

  • (String)


6326
6327
6328
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6326

def display_name
  @display_name
end

#etagString

This checksum is computed by the service, and might be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


6332
6333
6334
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6332

def etag
  @etag
end

#labelsHash<String,String>

Optional. User-defined labels for the EntryGroup. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


6337
6338
6339
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6337

def labels
  @labels
end

#nameString

Output only. The relative resource name of the EntryGroup, in the format projects/project_id_or_number/locations/location_id/entryGroups/ entry_group_id. Corresponds to the JSON property name

Returns:

  • (String)


6344
6345
6346
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6344

def name
  @name
end

#transfer_statusString

Output only. Denotes the transfer status of the Entry Group. It is unspecified for Entry Group created from Dataplex API. Corresponds to the JSON property transferStatus

Returns:

  • (String)


6350
6351
6352
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6350

def transfer_status
  @transfer_status
end

#uidString

Output only. System generated globally unique ID for the EntryGroup. If you delete and recreate the EntryGroup with the same name, this ID will be different. Corresponds to the JSON property uid

Returns:

  • (String)


6357
6358
6359
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6357

def uid
  @uid
end

#update_timeString

Output only. The time when the EntryGroup was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


6362
6363
6364
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6362

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6369

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @transfer_status = args[:transfer_status] if args.key?(:transfer_status)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end