Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1EntryGroup
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1EntryGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
An Entry Group represents a logical grouping of one or more Entries.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
This checksum is computed by the service, and might be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#transfer_status ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1EntryGroup
constructor
A new instance of GoogleCloudDataplexV1EntryGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1EntryGroup
Returns a new instance of GoogleCloudDataplexV1EntryGroup.
4953 4954 4955 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4953 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time when the EntryGroup was created.
Corresponds to the JSON property createTime
4905 4906 4907 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4905 def create_time @create_time end |
#description ⇒ String
Optional. Description of the EntryGroup.
Corresponds to the JSON property description
4910 4911 4912 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4910 def description @description end |
#display_name ⇒ String
Optional. User friendly display name.
Corresponds to the JSON property displayName
4915 4916 4917 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4915 def display_name @display_name end |
#etag ⇒ String
This checksum is computed by the service, and might be sent on update and
delete requests to ensure the client has an up-to-date value before proceeding.
Corresponds to the JSON property etag
4921 4922 4923 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4921 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. User-defined labels for the EntryGroup.
Corresponds to the JSON property labels
4926 4927 4928 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4926 def labels @labels end |
#name ⇒ String
Output only. The relative resource name of the EntryGroup, in the format
projects/project_id_or_number/locations/location_id/entryGroups/
entry_group_id.
Corresponds to the JSON property name
4933 4934 4935 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4933 def name @name end |
#transfer_status ⇒ String
Output only. Denotes the transfer status of the Entry Group. It is unspecified
for Entry Group created from Dataplex API.
Corresponds to the JSON property transferStatus
4939 4940 4941 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4939 def transfer_status @transfer_status end |
#uid ⇒ String
Output only. System generated globally unique ID for the EntryGroup. If you
delete and recreate the EntryGroup with the same name, this ID will be
different.
Corresponds to the JSON property uid
4946 4947 4948 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4946 def uid @uid end |
#update_time ⇒ String
Output only. The time when the EntryGroup was last updated.
Corresponds to the JSON property updateTime
4951 4952 4953 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4951 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4958 4959 4960 4961 4962 4963 4964 4965 4966 4967 4968 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4958 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @transfer_status = args[:transfer_status] if args.key?(:transfer_status) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |