Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1EntryLink

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

EntryLink represents a link between two Entries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1EntryLink

Returns a new instance of GoogleCloudDataplexV1EntryLink.



6428
6429
6430
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6428

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aspectsHash<String,Google::Apis::DataplexV1::GoogleCloudDataplexV1Aspect>

Optional. The aspects that are attached to the entry link. The format of the aspect key has to be the following: project_id_or_number.location_id. aspect_type_id Currently, only a single aspect of a Dataplex-owned Aspect Type is allowed. Corresponds to the JSON property aspects



6392
6393
6394
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6392

def aspects
  @aspects
end

#create_timeString

Output only. The time when the Entry Link was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6397
6398
6399
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6397

def create_time
  @create_time
end

#entry_link_typeString

Required. Immutable. Relative resource name of the Entry Link Type used to create this Entry Link. For example: Entry link between synonym terms in a glossary: projects/dataplex-types/locations/global/entryLinkTypes/synonym Entry link between related terms in a glossary: projects/dataplex-types/ locations/global/entryLinkTypes/related Entry link between glossary terms and data assets: projects/dataplex-types/locations/global/entryLinkTypes/ definition Corresponds to the JSON property entryLinkType

Returns:

  • (String)


6408
6409
6410
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6408

def entry_link_type
  @entry_link_type
end

#entry_referencesArray<Google::Apis::DataplexV1::GoogleCloudDataplexV1EntryLinkEntryReference>

Required. Immutable. Specifies the Entries referenced in the Entry Link. There should be exactly two entry references. Corresponds to the JSON property entryReferences



6414
6415
6416
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6414

def entry_references
  @entry_references
end

#nameString

Output only. Immutable. Identifier. The relative resource name of the Entry Link, of the form: projects/project_id_or_number/locations/location_id/ entryGroups/entry_group_id/entryLinks/entry_link_id Corresponds to the JSON property name

Returns:

  • (String)


6421
6422
6423
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6421

def name
  @name
end

#update_timeString

Output only. The time when the Entry Link was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


6426
6427
6428
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6426

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6433
6434
6435
6436
6437
6438
6439
6440
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6433

def update!(**args)
  @aspects = args[:aspects] if args.key?(:aspects)
  @create_time = args[:create_time] if args.key?(:create_time)
  @entry_link_type = args[:entry_link_type] if args.key?(:entry_link_type)
  @entry_references = args[:entry_references] if args.key?(:entry_references)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end