Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1EntryLink

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

EntryLink represents a link between two Entries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1EntryLink

Returns a new instance of GoogleCloudDataplexV1EntryLink.



5009
5010
5011
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5009

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time when the Entry Link was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4978
4979
4980
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4978

def create_time
  @create_time
end

#entry_link_typeString

Required. Immutable. Relative resource name of the Entry Link Type used to create this Entry Link. For example: Entry link between synonym terms in a glossary: projects/dataplex-types/locations/global/entryLinkTypes/synonym Entry link between related terms in a glossary: projects/dataplex-types/ locations/global/entryLinkTypes/related Entry link between glossary terms and data assets: projects/dataplex-types/locations/global/entryLinkTypes/ definition Corresponds to the JSON property entryLinkType

Returns:

  • (String)


4989
4990
4991
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4989

def entry_link_type
  @entry_link_type
end

#entry_referencesArray<Google::Apis::DataplexV1::GoogleCloudDataplexV1EntryLinkEntryReference>

Required. Specifies the Entries referenced in the Entry Link. There should be exactly two entry references. Corresponds to the JSON property entryReferences



4995
4996
4997
# File 'lib/google/apis/dataplex_v1/classes.rb', line 4995

def entry_references
  @entry_references
end

#nameString

Output only. Immutable. Identifier. The relative resource name of the Entry Link, of the form: projects/project_id_or_number/locations/location_id/ entryGroups/entry_group_id/entryLinks/entry_link_id Corresponds to the JSON property name

Returns:

  • (String)


5002
5003
5004
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5002

def name
  @name
end

#update_timeString

Output only. The time when the Entry Link was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


5007
5008
5009
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5007

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5014
5015
5016
5017
5018
5019
5020
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5014

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @entry_link_type = args[:entry_link_type] if args.key?(:entry_link_type)
  @entry_references = args[:entry_references] if args.key?(:entry_references)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end