Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1EntryLinkEntryReference
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1EntryLinkEntryReference
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Reference to the Entry that is linked through the Entry Link.
Instance Attribute Summary collapse
-
#name ⇒ String
Required.
-
#path ⇒ String
Immutable.
-
#type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1EntryLinkEntryReference
constructor
A new instance of GoogleCloudDataplexV1EntryLinkEntryReference.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1EntryLinkEntryReference
Returns a new instance of GoogleCloudDataplexV1EntryLinkEntryReference.
6674 6675 6676 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6674 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Required. Immutable. The relative resource name of the referenced Entry, of
the form: projects/project_id_or_number/locations/location_id/entryGroups/
entry_group_id/entries/entry_id
Corresponds to the JSON property name
6661 6662 6663 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6661 def name @name end |
#path ⇒ String
Immutable. The path in the Entry that is referenced in the Entry Link. Empty
path denotes that the Entry itself is referenced in the Entry Link.
Corresponds to the JSON property path
6667 6668 6669 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6667 def path @path end |
#type ⇒ String
Required. Immutable. The reference type of the Entry.
Corresponds to the JSON property type
6672 6673 6674 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6672 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6679 6680 6681 6682 6683 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6679 def update!(**args) @name = args[:name] if args.key?(:name) @path = args[:path] if args.key?(:path) @type = args[:type] if args.key?(:type) end |