Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1EntryLinkEntryReference
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1EntryLinkEntryReference
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Reference to the Entry that is linked through the Entry Link.
Instance Attribute Summary collapse
-
#name ⇒ String
Required.
-
#path ⇒ String
Immutable.
-
#type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1EntryLinkEntryReference
constructor
A new instance of GoogleCloudDataplexV1EntryLinkEntryReference.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1EntryLinkEntryReference
Returns a new instance of GoogleCloudDataplexV1EntryLinkEntryReference.
6465 6466 6467 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6465 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Required. Immutable. The relative resource name of the referenced Entry, of
the form: projects/project_id_or_number/locations/location_id/entryGroups/
entry_group_id/entries/entry_id
Corresponds to the JSON property name
6452 6453 6454 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6452 def name @name end |
#path ⇒ String
Immutable. The path in the Entry that is referenced in the Entry Link. Empty
path denotes that the Entry itself is referenced in the Entry Link.
Corresponds to the JSON property path
6458 6459 6460 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6458 def path @path end |
#type ⇒ String
Required. Immutable. The reference type of the Entry.
Corresponds to the JSON property type
6463 6464 6465 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6463 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6470 6471 6472 6473 6474 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6470 def update!(**args) @name = args[:name] if args.key?(:name) @path = args[:path] if args.key?(:path) @type = args[:type] if args.key?(:type) end |