Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1EntryLinkEntryReference
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1EntryLinkEntryReference
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Reference to the Entry that is linked through the Entry Link.
Instance Attribute Summary collapse
-
#name ⇒ String
Required.
-
#path ⇒ String
Immutable.
-
#type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1EntryLinkEntryReference
constructor
A new instance of GoogleCloudDataplexV1EntryLinkEntryReference.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1EntryLinkEntryReference
Returns a new instance of GoogleCloudDataplexV1EntryLinkEntryReference.
5045 5046 5047 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5045 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Required. Immutable. The relative resource name of the referenced Entry, of
the form: projects/project_id_or_number/locations/location_id/entryGroups/
entry_group_id/entries/entry_id
Corresponds to the JSON property name
5032 5033 5034 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5032 def name @name end |
#path ⇒ String
Immutable. The path in the Entry that is referenced in the Entry Link. Empty
path denotes that the Entry itself is referenced in the Entry Link.
Corresponds to the JSON property path
5038 5039 5040 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5038 def path @path end |
#type ⇒ String
Required. Immutable. The reference type of the Entry.
Corresponds to the JSON property type
5043 5044 5045 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5043 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5050 5051 5052 5053 5054 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5050 def update!(**args) @name = args[:name] if args.key?(:name) @path = args[:path] if args.key?(:path) @type = args[:type] if args.key?(:type) end |