Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1EntrySource
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1EntrySource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Information related to the source system of the data resource that is represented by the entry.
Instance Attribute Summary collapse
-
#ancestors ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1EntrySourceAncestor>
Immutable.
-
#create_time ⇒ String
The time when the resource was created in the source system.
-
#description ⇒ String
A description of the data resource.
-
#display_name ⇒ String
A user-friendly display name.
-
#labels ⇒ Hash<String,String>
User-defined labels.
-
#location ⇒ String
Output only.
-
#platform ⇒ String
The platform containing the source system.
-
#resource ⇒ String
The name of the resource in the source system.
-
#system ⇒ String
The name of the source system.
-
#update_time ⇒ String
The time when the resource was last updated in the source system.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1EntrySource
constructor
A new instance of GoogleCloudDataplexV1EntrySource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1EntrySource
Returns a new instance of GoogleCloudDataplexV1EntrySource.
6812 6813 6814 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6812 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ancestors ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1EntrySourceAncestor>
Immutable. The entries representing the ancestors of the data resource in the
source system.
Corresponds to the JSON property ancestors
6757 6758 6759 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6757 def ancestors @ancestors end |
#create_time ⇒ String
The time when the resource was created in the source system.
Corresponds to the JSON property createTime
6762 6763 6764 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6762 def create_time @create_time end |
#description ⇒ String
A description of the data resource. Maximum length is 2,000 characters.
Corresponds to the JSON property description
6767 6768 6769 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6767 def description @description end |
#display_name ⇒ String
A user-friendly display name. Maximum length is 500 characters.
Corresponds to the JSON property displayName
6772 6773 6774 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6772 def display_name @display_name end |
#labels ⇒ Hash<String,String>
User-defined labels. The maximum size of keys and values is 128 characters
each.
Corresponds to the JSON property labels
6778 6779 6780 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6778 def labels @labels end |
#location ⇒ String
Output only. Location of the resource in the source system. You can search the
entry by this location. By default, this should match the location of the
entry group containing this entry. A different value allows capturing the
source location for data external to Google Cloud.
Corresponds to the JSON property location
6786 6787 6788 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6786 def location @location end |
#platform ⇒ String
The platform containing the source system. Maximum length is 64 characters.
Corresponds to the JSON property platform
6791 6792 6793 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6791 def platform @platform end |
#resource ⇒ String
The name of the resource in the source system. Maximum length is 4,000
characters.
Corresponds to the JSON property resource
6797 6798 6799 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6797 def resource @resource end |
#system ⇒ String
The name of the source system. Maximum length is 64 characters.
Corresponds to the JSON property system
6802 6803 6804 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6802 def system @system end |
#update_time ⇒ String
The time when the resource was last updated in the source system. If the entry
exists in the system and its EntrySource has update_time populated, further
updates to the EntrySource of the entry must provide incremental updates to
its update_time.
Corresponds to the JSON property updateTime
6810 6811 6812 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6810 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6817 6818 6819 6820 6821 6822 6823 6824 6825 6826 6827 6828 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6817 def update!(**args) @ancestors = args[:ancestors] if args.key?(:ancestors) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @labels = args[:labels] if args.key?(:labels) @location = args[:location] if args.key?(:location) @platform = args[:platform] if args.key?(:platform) @resource = args[:resource] if args.key?(:resource) @system = args[:system] if args.key?(:system) @update_time = args[:update_time] if args.key?(:update_time) end |