Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1EntrySource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Information related to the source system of the data resource that is represented by the entry.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1EntrySource

Returns a new instance of GoogleCloudDataplexV1EntrySource.



6767
6768
6769
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6767

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ancestorsArray<Google::Apis::DataplexV1::GoogleCloudDataplexV1EntrySourceAncestor>

Immutable. The entries representing the ancestors of the data resource in the source system. Corresponds to the JSON property ancestors



6712
6713
6714
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6712

def ancestors
  @ancestors
end

#create_timeString

The time when the resource was created in the source system. Corresponds to the JSON property createTime

Returns:

  • (String)


6717
6718
6719
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6717

def create_time
  @create_time
end

#descriptionString

A description of the data resource. Maximum length is 2,000 characters. Corresponds to the JSON property description

Returns:

  • (String)


6722
6723
6724
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6722

def description
  @description
end

#display_nameString

A user-friendly display name. Maximum length is 500 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


6727
6728
6729
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6727

def display_name
  @display_name
end

#labelsHash<String,String>

User-defined labels. The maximum size of keys and values is 128 characters each. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


6733
6734
6735
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6733

def labels
  @labels
end

#locationString

Output only. Location of the resource in the source system. You can search the entry by this location. By default, this should match the location of the entry group containing this entry. A different value allows capturing the source location for data external to Google Cloud. Corresponds to the JSON property location

Returns:

  • (String)


6741
6742
6743
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6741

def location
  @location
end

#platformString

The platform containing the source system. Maximum length is 64 characters. Corresponds to the JSON property platform

Returns:

  • (String)


6746
6747
6748
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6746

def platform
  @platform
end

#resourceString

The name of the resource in the source system. Maximum length is 4,000 characters. Corresponds to the JSON property resource

Returns:

  • (String)


6752
6753
6754
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6752

def resource
  @resource
end

#systemString

The name of the source system. Maximum length is 64 characters. Corresponds to the JSON property system

Returns:

  • (String)


6757
6758
6759
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6757

def system
  @system
end

#update_timeString

The time when the resource was last updated in the source system. If the entry exists in the system and its EntrySource has update_time populated, further updates to the EntrySource of the entry must provide incremental updates to its update_time. Corresponds to the JSON property updateTime

Returns:

  • (String)


6765
6766
6767
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6765

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6772
6773
6774
6775
6776
6777
6778
6779
6780
6781
6782
6783
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6772

def update!(**args)
  @ancestors = args[:ancestors] if args.key?(:ancestors)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @location = args[:location] if args.key?(:location)
  @platform = args[:platform] if args.key?(:platform)
  @resource = args[:resource] if args.key?(:resource)
  @system = args[:system] if args.key?(:system)
  @update_time = args[:update_time] if args.key?(:update_time)
end