Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1EntrySource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Information related to the source system of the data resource that is represented by the entry.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1EntrySource

Returns a new instance of GoogleCloudDataplexV1EntrySource.



6572
6573
6574
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6572

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ancestorsArray<Google::Apis::DataplexV1::GoogleCloudDataplexV1EntrySourceAncestor>

Immutable. The entries representing the ancestors of the data resource in the source system. Corresponds to the JSON property ancestors



6517
6518
6519
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6517

def ancestors
  @ancestors
end

#create_timeString

The time when the resource was created in the source system. Corresponds to the JSON property createTime

Returns:

  • (String)


6522
6523
6524
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6522

def create_time
  @create_time
end

#descriptionString

A description of the data resource. Maximum length is 2,000 characters. Corresponds to the JSON property description

Returns:

  • (String)


6527
6528
6529
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6527

def description
  @description
end

#display_nameString

A user-friendly display name. Maximum length is 500 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


6532
6533
6534
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6532

def display_name
  @display_name
end

#labelsHash<String,String>

User-defined labels. The maximum size of keys and values is 128 characters each. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


6538
6539
6540
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6538

def labels
  @labels
end

#locationString

Output only. Location of the resource in the source system. You can search the entry by this location. By default, this should match the location of the entry group containing this entry. A different value allows capturing the source location for data external to Google Cloud. Corresponds to the JSON property location

Returns:

  • (String)


6546
6547
6548
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6546

def location
  @location
end

#platformString

The platform containing the source system. Maximum length is 64 characters. Corresponds to the JSON property platform

Returns:

  • (String)


6551
6552
6553
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6551

def platform
  @platform
end

#resourceString

The name of the resource in the source system. Maximum length is 4,000 characters. Corresponds to the JSON property resource

Returns:

  • (String)


6557
6558
6559
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6557

def resource
  @resource
end

#systemString

The name of the source system. Maximum length is 64 characters. Corresponds to the JSON property system

Returns:

  • (String)


6562
6563
6564
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6562

def system
  @system
end

#update_timeString

The time when the resource was last updated in the source system. If the entry exists in the system and its EntrySource has update_time populated, further updates to the EntrySource of the entry must provide incremental updates to its update_time. Corresponds to the JSON property updateTime

Returns:

  • (String)


6570
6571
6572
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6570

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6577
6578
6579
6580
6581
6582
6583
6584
6585
6586
6587
6588
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6577

def update!(**args)
  @ancestors = args[:ancestors] if args.key?(:ancestors)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @location = args[:location] if args.key?(:location)
  @platform = args[:platform] if args.key?(:platform)
  @resource = args[:resource] if args.key?(:resource)
  @system = args[:system] if args.key?(:system)
  @update_time = args[:update_time] if args.key?(:update_time)
end