Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1ExecutionIdentityServiceAccount

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

The service account

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1ExecutionIdentityServiceAccount

Returns a new instance of GoogleCloudDataplexV1ExecutionIdentityServiceAccount.



7007
7008
7009
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7007

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#emailString

Required. Service account email. The datascan will execute with this service account's credentials. The user calling this API must have permissions to act as this service account. Dataplex service agent must be granted iam. serviceAccounts.getAccessToken permission on this service account, for example, through the iam.serviceAccountTokenCreator role . Corresponds to the JSON property email

Returns:

  • (String)


7005
7006
7007
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7005

def email
  @email
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7012
7013
7014
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7012

def update!(**args)
  @email = args[:email] if args.key?(:email)
end