Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1GenerateDataQualityRulesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Response details for data quality rule recommendations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1GenerateDataQualityRulesResponse

Returns a new instance of GoogleCloudDataplexV1GenerateDataQualityRulesResponse.



6858
6859
6860
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6858

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ruleArray<Google::Apis::DataplexV1::GoogleCloudDataplexV1DataQualityRule>

The data quality rules that Dataplex Universal Catalog generates based on the results of a data profiling scan. Corresponds to the JSON property rule



6856
6857
6858
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6856

def rule
  @rule
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6863
6864
6865
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6863

def update!(**args)
  @rule = args[:rule] if args.key?(:rule)
end