Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1Glossary
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1Glossary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
A Glossary represents a collection of GlossaryCategories and GlossaryTerms defined by the user. Glossary is a top level resource and is the Google Cloud parent resource of all the GlossaryCategories and GlossaryTerms within it.
Instance Attribute Summary collapse
-
#category_count ⇒ Fixnum
Output only.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#term_count ⇒ Fixnum
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1Glossary
constructor
A new instance of GoogleCloudDataplexV1Glossary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1Glossary
Returns a new instance of GoogleCloudDataplexV1Glossary.
7125 7126 7127 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7125 def initialize(**args) update!(**args) end |
Instance Attribute Details
#category_count ⇒ Fixnum
Output only. The number of GlossaryCategories in the Glossary.
Corresponds to the JSON property categoryCount
7072 7073 7074 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7072 def category_count @category_count end |
#create_time ⇒ String
Output only. The time at which the Glossary was created.
Corresponds to the JSON property createTime
7077 7078 7079 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7077 def create_time @create_time end |
#description ⇒ String
Optional. The user-mutable description of the Glossary.
Corresponds to the JSON property description
7082 7083 7084 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7082 def description @description end |
#display_name ⇒ String
Optional. User friendly display name of the Glossary. This is user-mutable.
This will be same as the GlossaryId, if not specified.
Corresponds to the JSON property displayName
7088 7089 7090 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7088 def display_name @display_name end |
#etag ⇒ String
Optional. Needed for resource freshness validation. This checksum is computed
by the server based on the value of other fields, and may be sent on update
and delete requests to ensure the client has an up-to-date value before
proceeding.
Corresponds to the JSON property etag
7096 7097 7098 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7096 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. User-defined labels for the Glossary.
Corresponds to the JSON property labels
7101 7102 7103 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7101 def labels @labels end |
#name ⇒ String
Output only. Identifier. The resource name of the Glossary. Format: projects/
project_id_or_number/locations/location_id/glossaries/glossary_id
Corresponds to the JSON property name
7107 7108 7109 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7107 def name @name end |
#term_count ⇒ Fixnum
Output only. The number of GlossaryTerms in the Glossary.
Corresponds to the JSON property termCount
7112 7113 7114 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7112 def term_count @term_count end |
#uid ⇒ String
Output only. System generated unique id for the Glossary. This ID will be
different if the Glossary is deleted and re-created with the same name.
Corresponds to the JSON property uid
7118 7119 7120 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7118 def uid @uid end |
#update_time ⇒ String
Output only. The time at which the Glossary was last updated.
Corresponds to the JSON property updateTime
7123 7124 7125 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7123 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7130 7131 7132 7133 7134 7135 7136 7137 7138 7139 7140 7141 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7130 def update!(**args) @category_count = args[:category_count] if args.key?(:category_count) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @term_count = args[:term_count] if args.key?(:term_count) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |