Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1Glossary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

A Glossary represents a collection of GlossaryCategories and GlossaryTerms defined by the user. Glossary is a top level resource and is the Google Cloud parent resource of all the GlossaryCategories and GlossaryTerms within it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1Glossary

Returns a new instance of GoogleCloudDataplexV1Glossary.



6930
6931
6932
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6930

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#category_countFixnum

Output only. The number of GlossaryCategories in the Glossary. Corresponds to the JSON property categoryCount

Returns:

  • (Fixnum)


6877
6878
6879
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6877

def category_count
  @category_count
end

#create_timeString

Output only. The time at which the Glossary was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6882
6883
6884
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6882

def create_time
  @create_time
end

#descriptionString

Optional. The user-mutable description of the Glossary. Corresponds to the JSON property description

Returns:

  • (String)


6887
6888
6889
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6887

def description
  @description
end

#display_nameString

Optional. User friendly display name of the Glossary. This is user-mutable. This will be same as the GlossaryId, if not specified. Corresponds to the JSON property displayName

Returns:

  • (String)


6893
6894
6895
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6893

def display_name
  @display_name
end

#etagString

Optional. Needed for resource freshness validation. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


6901
6902
6903
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6901

def etag
  @etag
end

#labelsHash<String,String>

Optional. User-defined labels for the Glossary. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


6906
6907
6908
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6906

def labels
  @labels
end

#nameString

Output only. Identifier. The resource name of the Glossary. Format: projects/ project_id_or_number/locations/location_id/glossaries/glossary_id Corresponds to the JSON property name

Returns:

  • (String)


6912
6913
6914
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6912

def name
  @name
end

#term_countFixnum

Output only. The number of GlossaryTerms in the Glossary. Corresponds to the JSON property termCount

Returns:

  • (Fixnum)


6917
6918
6919
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6917

def term_count
  @term_count
end

#uidString

Output only. System generated unique id for the Glossary. This ID will be different if the Glossary is deleted and re-created with the same name. Corresponds to the JSON property uid

Returns:

  • (String)


6923
6924
6925
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6923

def uid
  @uid
end

#update_timeString

Output only. The time at which the Glossary was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


6928
6929
6930
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6928

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6935
6936
6937
6938
6939
6940
6941
6942
6943
6944
6945
6946
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6935

def update!(**args)
  @category_count = args[:category_count] if args.key?(:category_count)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @term_count = args[:term_count] if args.key?(:term_count)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end