Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1Glossary
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1Glossary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
A Glossary represents a collection of GlossaryCategories and GlossaryTerms defined by the user. Glossary is a top level resource and is the Google Cloud parent resource of all the GlossaryCategories and GlossaryTerms within it.
Instance Attribute Summary collapse
-
#category_count ⇒ Fixnum
Output only.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#term_count ⇒ Fixnum
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1Glossary
constructor
A new instance of GoogleCloudDataplexV1Glossary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1Glossary
Returns a new instance of GoogleCloudDataplexV1Glossary.
5697 5698 5699 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5697 def initialize(**args) update!(**args) end |
Instance Attribute Details
#category_count ⇒ Fixnum
Output only. The number of GlossaryCategories in the Glossary.
Corresponds to the JSON property categoryCount
5644 5645 5646 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5644 def category_count @category_count end |
#create_time ⇒ String
Output only. The time at which the Glossary was created.
Corresponds to the JSON property createTime
5649 5650 5651 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5649 def create_time @create_time end |
#description ⇒ String
Optional. The user-mutable description of the Glossary.
Corresponds to the JSON property description
5654 5655 5656 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5654 def description @description end |
#display_name ⇒ String
Optional. User friendly display name of the Glossary. This is user-mutable.
This will be same as the GlossaryId, if not specified.
Corresponds to the JSON property displayName
5660 5661 5662 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5660 def display_name @display_name end |
#etag ⇒ String
Optional. Needed for resource freshness validation. This checksum is computed
by the server based on the value of other fields, and may be sent on update
and delete requests to ensure the client has an up-to-date value before
proceeding.
Corresponds to the JSON property etag
5668 5669 5670 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5668 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. User-defined labels for the Glossary.
Corresponds to the JSON property labels
5673 5674 5675 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5673 def labels @labels end |
#name ⇒ String
Output only. Identifier. The resource name of the Glossary. Format: projects/
project_id_or_number/locations/location_id/glossaries/glossary_id
Corresponds to the JSON property name
5679 5680 5681 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5679 def name @name end |
#term_count ⇒ Fixnum
Output only. The number of GlossaryTerms in the Glossary.
Corresponds to the JSON property termCount
5684 5685 5686 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5684 def term_count @term_count end |
#uid ⇒ String
Output only. System generated unique id for the Glossary. This ID will be
different if the Glossary is deleted and re-created with the same name.
Corresponds to the JSON property uid
5690 5691 5692 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5690 def uid @uid end |
#update_time ⇒ String
Output only. The time at which the Glossary was last updated.
Corresponds to the JSON property updateTime
5695 5696 5697 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5695 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5702 5703 5704 5705 5706 5707 5708 5709 5710 5711 5712 5713 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5702 def update!(**args) @category_count = args[:category_count] if args.key?(:category_count) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @term_count = args[:term_count] if args.key?(:term_count) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |