Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1GlossaryCategory
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1GlossaryCategory
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
A GlossaryCategory represents a collection of GlossaryCategories and GlossaryTerms within a Glossary that are related to each other.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#parent ⇒ String
Required.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1GlossaryCategory
constructor
A new instance of GoogleCloudDataplexV1GlossaryCategory.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1GlossaryCategory
Returns a new instance of GoogleCloudDataplexV1GlossaryCategory.
7003 7004 7005 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7003 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which the GlossaryCategory was created.
Corresponds to the JSON property createTime
6957 6958 6959 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6957 def create_time @create_time end |
#description ⇒ String
Optional. The user-mutable description of the GlossaryCategory.
Corresponds to the JSON property description
6962 6963 6964 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6962 def description @description end |
#display_name ⇒ String
Optional. User friendly display name of the GlossaryCategory. This is user-
mutable. This will be same as the GlossaryCategoryId, if not specified.
Corresponds to the JSON property displayName
6968 6969 6970 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6968 def display_name @display_name end |
#labels ⇒ Hash<String,String>
Optional. User-defined labels for the GlossaryCategory.
Corresponds to the JSON property labels
6973 6974 6975 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6973 def labels @labels end |
#name ⇒ String
Output only. Identifier. The resource name of the GlossaryCategory. Format:
projects/project_id_or_number/locations/location_id/glossaries/
glossary_id/categories/category_id
Corresponds to the JSON property name
6980 6981 6982 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6980 def name @name end |
#parent ⇒ String
Required. The immediate parent of the GlossaryCategory in the resource-
hierarchy. It can either be a Glossary or a GlossaryCategory. Format: projects/
project_id_or_number/locations/location_id/glossaries/glossary_id OR
projects/project_id_or_number/locations/location_id/glossaries/
glossary_id/categories/category_id
Corresponds to the JSON property parent
6989 6990 6991 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6989 def parent @parent end |
#uid ⇒ String
Output only. System generated unique id for the GlossaryCategory. This ID will
be different if the GlossaryCategory is deleted and re-created with the same
name.
Corresponds to the JSON property uid
6996 6997 6998 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6996 def uid @uid end |
#update_time ⇒ String
Output only. The time at which the GlossaryCategory was last updated.
Corresponds to the JSON property updateTime
7001 7002 7003 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7001 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7008 7009 7010 7011 7012 7013 7014 7015 7016 7017 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7008 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @parent = args[:parent] if args.key?(:parent) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |