Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1GlossaryCategory
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1GlossaryCategory
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
A GlossaryCategory represents a collection of GlossaryCategories and GlossaryTerms within a Glossary that are related to each other.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#parent ⇒ String
Required.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1GlossaryCategory
constructor
A new instance of GoogleCloudDataplexV1GlossaryCategory.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1GlossaryCategory
Returns a new instance of GoogleCloudDataplexV1GlossaryCategory.
5770 5771 5772 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5770 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which the GlossaryCategory was created.
Corresponds to the JSON property createTime
5724 5725 5726 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5724 def create_time @create_time end |
#description ⇒ String
Optional. The user-mutable description of the GlossaryCategory.
Corresponds to the JSON property description
5729 5730 5731 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5729 def description @description end |
#display_name ⇒ String
Optional. User friendly display name of the GlossaryCategory. This is user-
mutable. This will be same as the GlossaryCategoryId, if not specified.
Corresponds to the JSON property displayName
5735 5736 5737 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5735 def display_name @display_name end |
#labels ⇒ Hash<String,String>
Optional. User-defined labels for the GlossaryCategory.
Corresponds to the JSON property labels
5740 5741 5742 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5740 def labels @labels end |
#name ⇒ String
Output only. Identifier. The resource name of the GlossaryCategory. Format:
projects/project_id_or_number/locations/location_id/glossaries/
glossary_id/categories/category_id
Corresponds to the JSON property name
5747 5748 5749 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5747 def name @name end |
#parent ⇒ String
Required. The immediate parent of the GlossaryCategory in the resource-
hierarchy. It can either be a Glossary or a GlossaryCategory. Format: projects/
project_id_or_number/locations/location_id/glossaries/glossary_id OR
projects/project_id_or_number/locations/location_id/glossaries/
glossary_id/categories/category_id
Corresponds to the JSON property parent
5756 5757 5758 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5756 def parent @parent end |
#uid ⇒ String
Output only. System generated unique id for the GlossaryCategory. This ID will
be different if the GlossaryCategory is deleted and re-created with the same
name.
Corresponds to the JSON property uid
5763 5764 5765 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5763 def uid @uid end |
#update_time ⇒ String
Output only. The time at which the GlossaryCategory was last updated.
Corresponds to the JSON property updateTime
5768 5769 5770 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5768 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5775 5776 5777 5778 5779 5780 5781 5782 5783 5784 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5775 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @parent = args[:parent] if args.key?(:parent) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |