Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1GlossaryTerm
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1GlossaryTerm
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
GlossaryTerms are the core of Glossary. A GlossaryTerm holds a rich text description that can be attached to Entries or specific columns to enrich them.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#parent ⇒ String
Required.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1GlossaryTerm
constructor
A new instance of GoogleCloudDataplexV1GlossaryTerm.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1GlossaryTerm
Returns a new instance of GoogleCloudDataplexV1GlossaryTerm.
7268 7269 7270 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7268 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which the GlossaryTerm was created.
Corresponds to the JSON property createTime
7223 7224 7225 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7223 def create_time @create_time end |
#description ⇒ String
Optional. The user-mutable description of the GlossaryTerm.
Corresponds to the JSON property description
7228 7229 7230 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7228 def description @description end |
#display_name ⇒ String
Optional. User friendly display name of the GlossaryTerm. This is user-mutable.
This will be same as the GlossaryTermId, if not specified.
Corresponds to the JSON property displayName
7234 7235 7236 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7234 def display_name @display_name end |
#labels ⇒ Hash<String,String>
Optional. User-defined labels for the GlossaryTerm.
Corresponds to the JSON property labels
7239 7240 7241 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7239 def labels @labels end |
#name ⇒ String
Output only. Identifier. The resource name of the GlossaryTerm. Format:
projects/project_id_or_number/locations/location_id/glossaries/
glossary_id/terms/term_id
Corresponds to the JSON property name
7246 7247 7248 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7246 def name @name end |
#parent ⇒ String
Required. The immediate parent of the GlossaryTerm in the resource-hierarchy.
It can either be a Glossary or a GlossaryCategory. Format: projects/
project_id_or_number/locations/location_id/glossaries/glossary_id OR
projects/project_id_or_number/locations/location_id/glossaries/
glossary_id/categories/category_id
Corresponds to the JSON property parent
7255 7256 7257 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7255 def parent @parent end |
#uid ⇒ String
Output only. System generated unique id for the GlossaryTerm. This ID will be
different if the GlossaryTerm is deleted and re-created with the same name.
Corresponds to the JSON property uid
7261 7262 7263 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7261 def uid @uid end |
#update_time ⇒ String
Output only. The time at which the GlossaryTerm was last updated.
Corresponds to the JSON property updateTime
7266 7267 7268 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7266 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7273 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @parent = args[:parent] if args.key?(:parent) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |