Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1GlossaryTerm

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

GlossaryTerms are the core of Glossary. A GlossaryTerm holds a rich text description that can be attached to Entries or specific columns to enrich them.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1GlossaryTerm

Returns a new instance of GoogleCloudDataplexV1GlossaryTerm.



7073
7074
7075
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7073

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which the GlossaryTerm was created. Corresponds to the JSON property createTime

Returns:

  • (String)


7028
7029
7030
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7028

def create_time
  @create_time
end

#descriptionString

Optional. The user-mutable description of the GlossaryTerm. Corresponds to the JSON property description

Returns:

  • (String)


7033
7034
7035
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7033

def description
  @description
end

#display_nameString

Optional. User friendly display name of the GlossaryTerm. This is user-mutable. This will be same as the GlossaryTermId, if not specified. Corresponds to the JSON property displayName

Returns:

  • (String)


7039
7040
7041
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7039

def display_name
  @display_name
end

#labelsHash<String,String>

Optional. User-defined labels for the GlossaryTerm. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


7044
7045
7046
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7044

def labels
  @labels
end

#nameString

Output only. Identifier. The resource name of the GlossaryTerm. Format: projects/project_id_or_number/locations/location_id/glossaries/ glossary_id/terms/term_id Corresponds to the JSON property name

Returns:

  • (String)


7051
7052
7053
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7051

def name
  @name
end

#parentString

Required. The immediate parent of the GlossaryTerm in the resource-hierarchy. It can either be a Glossary or a GlossaryCategory. Format: projects/ project_id_or_number/locations/location_id/glossaries/glossary_id OR projects/project_id_or_number/locations/location_id/glossaries/ glossary_id/categories/category_id Corresponds to the JSON property parent

Returns:

  • (String)


7060
7061
7062
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7060

def parent
  @parent
end

#uidString

Output only. System generated unique id for the GlossaryTerm. This ID will be different if the GlossaryTerm is deleted and re-created with the same name. Corresponds to the JSON property uid

Returns:

  • (String)


7066
7067
7068
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7066

def uid
  @uid
end

#update_timeString

Output only. The time at which the GlossaryTerm was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


7071
7072
7073
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7071

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7078
7079
7080
7081
7082
7083
7084
7085
7086
7087
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7078

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @parent = args[:parent] if args.key?(:parent)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end