Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1GlossaryTerm

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

GlossaryTerms are the core of Glossary. A GlossaryTerm holds a rich text description that can be attached to Entries or specific columns to enrich them.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1GlossaryTerm

Returns a new instance of GoogleCloudDataplexV1GlossaryTerm.



5840
5841
5842
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5840

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which the GlossaryTerm was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5795
5796
5797
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5795

def create_time
  @create_time
end

#descriptionString

Optional. The user-mutable description of the GlossaryTerm. Corresponds to the JSON property description

Returns:

  • (String)


5800
5801
5802
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5800

def description
  @description
end

#display_nameString

Optional. User friendly display name of the GlossaryTerm. This is user-mutable. This will be same as the GlossaryTermId, if not specified. Corresponds to the JSON property displayName

Returns:

  • (String)


5806
5807
5808
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5806

def display_name
  @display_name
end

#labelsHash<String,String>

Optional. User-defined labels for the GlossaryTerm. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5811
5812
5813
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5811

def labels
  @labels
end

#nameString

Output only. Identifier. The resource name of the GlossaryTerm. Format: projects/project_id_or_number/locations/location_id/glossaries/ glossary_id/terms/term_id Corresponds to the JSON property name

Returns:

  • (String)


5818
5819
5820
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5818

def name
  @name
end

#parentString

Required. The immediate parent of the GlossaryTerm in the resource-hierarchy. It can either be a Glossary or a GlossaryCategory. Format: projects/ project_id_or_number/locations/location_id/glossaries/glossary_id OR projects/project_id_or_number/locations/location_id/glossaries/ glossary_id/categories/category_id Corresponds to the JSON property parent

Returns:

  • (String)


5827
5828
5829
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5827

def parent
  @parent
end

#uidString

Output only. System generated unique id for the GlossaryTerm. This ID will be different if the GlossaryTerm is deleted and re-created with the same name. Corresponds to the JSON property uid

Returns:

  • (String)


5833
5834
5835
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5833

def uid
  @uid
end

#update_timeString

Output only. The time at which the GlossaryTerm was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


5838
5839
5840
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5838

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5845
5846
5847
5848
5849
5850
5851
5852
5853
5854
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5845

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @parent = args[:parent] if args.key?(:parent)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end