Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1GovernanceEvent
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1GovernanceEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Payload associated with Governance related log events.
Instance Attribute Summary collapse
-
#entity ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1GovernanceEventEntity
Information about Entity resource that the log event is associated with.
-
#event_type ⇒ String
The type of the event.
-
#message ⇒ String
The log message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1GovernanceEvent
constructor
A new instance of GoogleCloudDataplexV1GovernanceEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1GovernanceEvent
Returns a new instance of GoogleCloudDataplexV1GovernanceEvent.
5876 5877 5878 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5876 def initialize(**args) update!(**args) end |
Instance Attribute Details
#entity ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1GovernanceEventEntity
Information about Entity resource that the log event is associated with.
Corresponds to the JSON property entity
5864 5865 5866 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5864 def entity @entity end |
#event_type ⇒ String
The type of the event.
Corresponds to the JSON property eventType
5869 5870 5871 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5869 def event_type @event_type end |
#message ⇒ String
The log message.
Corresponds to the JSON property message
5874 5875 5876 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5874 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5881 5882 5883 5884 5885 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 5881 def update!(**args) @entity = args[:entity] if args.key?(:entity) @event_type = args[:event_type] if args.key?(:event_type) @message = args[:message] if args.key?(:message) end |