Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1ImportItem
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1ImportItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
An object that describes the values that you want to set for an entry and its attached aspects when you import metadata. Used when you run a metadata import job. See CreateMetadataJob.You provide a collection of import items in a metadata import file. For more information about how to create a metadata import file, see Metadata import file (https://cloud.google.com/dataplex/docs/ import-metadata#metadata-import-file).
Instance Attribute Summary collapse
-
#aspect_keys ⇒ Array<String>
The aspects to modify.
-
#entry ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1Entry
An entry is a representation of a data resource that can be described by various metadata.
-
#entry_link ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1EntryLink
EntryLink represents a link between two Entries.
-
#update_mask ⇒ String
The fields to update, in paths that are relative to the Entry resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1ImportItem
constructor
A new instance of GoogleCloudDataplexV1ImportItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1ImportItem
Returns a new instance of GoogleCloudDataplexV1ImportItem.
7752 7753 7754 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7752 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aspect_keys ⇒ Array<String>
The aspects to modify. Supports the following syntaxes: aspect_type_reference
: matches aspects that belong to the specified aspect type and are attached
directly to the entry. aspect_type_reference@path: matches aspects that
belong to the specified aspect type and path. aspect_type_reference@* :
matches aspects of the given type for all paths. *@path : matches aspects of
all types on the given path.Replace aspect_type_reference with a reference
to the aspect type, in the format project_id_or_number.location_id.
aspect_type_id.In FULL entry sync mode, if you leave this field empty, it is
treated as specifying exactly those aspects that are present within the
specified entry. Dataplex Universal Catalog implicitly adds the keys for all
of the required aspects of an entry.
Corresponds to the JSON property aspectKeys
7721 7722 7723 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7721 def aspect_keys @aspect_keys end |
#entry ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1Entry
An entry is a representation of a data resource that can be described by
various metadata.
Corresponds to the JSON property entry
7727 7728 7729 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7727 def entry @entry end |
#entry_link ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1EntryLink
EntryLink represents a link between two Entries.
Corresponds to the JSON property entryLink
7732 7733 7734 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7732 def entry_link @entry_link end |
#update_mask ⇒ String
The fields to update, in paths that are relative to the Entry resource.
Separate each field with a comma.In FULL entry sync mode, Dataplex Universal
Catalog includes the paths of all of the fields for an entry that can be
modified, including aspects. This means that Dataplex Universal Catalog
replaces the existing entry with the entry in the metadata import file. All
modifiable fields are updated, regardless of the fields that are listed in the
update mask, and regardless of whether a field is present in the entry object.
The update_mask field is ignored when an entry is created or re-created.In an
aspect-only metadata job (when entry sync mode is NONE), set this value to
aspects.Dataplex Universal Catalog also determines which entries and aspects
to modify by comparing the values and timestamps that you provide in the
metadata import file with the values and timestamps that exist in your project.
For more information, see Comparison logic (https://cloud.google.com/dataplex/
docs/import-metadata#data-modification-logic).
Corresponds to the JSON property updateMask
7750 7751 7752 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7750 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7757 7758 7759 7760 7761 7762 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7757 def update!(**args) @aspect_keys = args[:aspect_keys] if args.key?(:aspect_keys) @entry = args[:entry] if args.key?(:entry) @entry_link = args[:entry_link] if args.key?(:entry_link) @update_mask = args[:update_mask] if args.key?(:update_mask) end |