Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1JobEvent
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1JobEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
The payload associated with Job logs that contains events describing jobs that have run within a Lake.
Instance Attribute Summary collapse
-
#end_time ⇒ String
The time when the job ended running.
-
#execution_trigger ⇒ String
Job execution trigger.
-
#job_id ⇒ String
The unique id identifying the job.
-
#message ⇒ String
The log message.
-
#retries ⇒ Fixnum
The number of retries.
-
#service ⇒ String
The service used to execute the job.
-
#service_job ⇒ String
The reference to the job within the service.
-
#start_time ⇒ String
The time when the job started running.
-
#state ⇒ String
The job state on completion.
-
#type ⇒ String
The type of the job.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1JobEvent
constructor
A new instance of GoogleCloudDataplexV1JobEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1JobEvent
Returns a new instance of GoogleCloudDataplexV1JobEvent.
7668 7669 7670 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7668 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
The time when the job ended running.
Corresponds to the JSON property endTime
7621 7622 7623 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7621 def end_time @end_time end |
#execution_trigger ⇒ String
Job execution trigger.
Corresponds to the JSON property executionTrigger
7626 7627 7628 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7626 def execution_trigger @execution_trigger end |
#job_id ⇒ String
The unique id identifying the job.
Corresponds to the JSON property jobId
7631 7632 7633 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7631 def job_id @job_id end |
#message ⇒ String
The log message.
Corresponds to the JSON property message
7636 7637 7638 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7636 def @message end |
#retries ⇒ Fixnum
The number of retries.
Corresponds to the JSON property retries
7641 7642 7643 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7641 def retries @retries end |
#service ⇒ String
The service used to execute the job.
Corresponds to the JSON property service
7646 7647 7648 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7646 def service @service end |
#service_job ⇒ String
The reference to the job within the service.
Corresponds to the JSON property serviceJob
7651 7652 7653 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7651 def service_job @service_job end |
#start_time ⇒ String
The time when the job started running.
Corresponds to the JSON property startTime
7656 7657 7658 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7656 def start_time @start_time end |
#state ⇒ String
The job state on completion.
Corresponds to the JSON property state
7661 7662 7663 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7661 def state @state end |
#type ⇒ String
The type of the job.
Corresponds to the JSON property type
7666 7667 7668 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7666 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7673 7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7673 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @execution_trigger = args[:execution_trigger] if args.key?(:execution_trigger) @job_id = args[:job_id] if args.key?(:job_id) @message = args[:message] if args.key?(:message) @retries = args[:retries] if args.key?(:retries) @service = args[:service] if args.key?(:service) @service_job = args[:service_job] if args.key?(:service_job) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @type = args[:type] if args.key?(:type) end |