Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1Lake

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

A lake is a centralized repository for managing enterprise data across the organization distributed across many cloud projects, and stored in a variety of storage services such as Google Cloud Storage and BigQuery. The resources attached to a lake are referred to as managed resources. Data within these managed resources can be structured or unstructured. A lake provides data admins with tools to organize, secure and manage their data at scale, and provides data scientists and data engineers an integrated experience to easily search, discover, analyze and transform data and associated metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1Lake

Returns a new instance of GoogleCloudDataplexV1Lake.



7956
7957
7958
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7956

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asset_statusGoogle::Apis::DataplexV1::GoogleCloudDataplexV1AssetStatus

Aggregated status of the underlying assets of a lake or zone. Corresponds to the JSON property assetStatus



7896
7897
7898
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7896

def asset_status
  @asset_status
end

#create_timeString

Output only. The time when the lake was created. Corresponds to the JSON property createTime

Returns:

  • (String)


7901
7902
7903
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7901

def create_time
  @create_time
end

#descriptionString

Optional. Description of the lake. Corresponds to the JSON property description

Returns:

  • (String)


7906
7907
7908
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7906

def description
  @description
end

#display_nameString

Optional. User friendly display name. Corresponds to the JSON property displayName

Returns:

  • (String)


7911
7912
7913
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7911

def display_name
  @display_name
end

#labelsHash<String,String>

Optional. User-defined labels for the lake. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


7916
7917
7918
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7916

def labels
  @labels
end

#metastoreGoogle::Apis::DataplexV1::GoogleCloudDataplexV1LakeMetastore

Settings to manage association of Dataproc Metastore with a lake. Corresponds to the JSON property metastore



7921
7922
7923
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7921

def metastore
  @metastore
end

#metastore_statusGoogle::Apis::DataplexV1::GoogleCloudDataplexV1LakeMetastoreStatus

Status of Lake and Dataproc Metastore service instance association. Corresponds to the JSON property metastoreStatus



7926
7927
7928
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7926

def metastore_status
  @metastore_status
end

#nameString

Output only. The relative resource name of the lake, of the form: projects/ project_number/locations/location_id/lakes/lake_id. Corresponds to the JSON property name

Returns:

  • (String)


7932
7933
7934
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7932

def name
  @name
end

#service_accountString

Output only. Service account associated with this lake. This service account must be authorized to access or operate on resources managed by the lake. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


7938
7939
7940
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7938

def 
  @service_account
end

#stateString

Output only. Current state of the lake. Corresponds to the JSON property state

Returns:

  • (String)


7943
7944
7945
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7943

def state
  @state
end

#uidString

Output only. System generated globally unique ID for the lake. This ID will be different if the lake is deleted and re-created with the same name. Corresponds to the JSON property uid

Returns:

  • (String)


7949
7950
7951
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7949

def uid
  @uid
end

#update_timeString

Output only. The time when the lake was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


7954
7955
7956
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7954

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7961
7962
7963
7964
7965
7966
7967
7968
7969
7970
7971
7972
7973
7974
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7961

def update!(**args)
  @asset_status = args[:asset_status] if args.key?(:asset_status)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @metastore = args[:metastore] if args.key?(:metastore)
  @metastore_status = args[:metastore_status] if args.key?(:metastore_status)
  @name = args[:name] if args.key?(:name)
  @service_account = args[:service_account] if args.key?(:service_account)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end