Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1Lake
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1Lake
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
A lake is a centralized repository for managing enterprise data across the organization distributed across many cloud projects, and stored in a variety of storage services such as Google Cloud Storage and BigQuery. The resources attached to a lake are referred to as managed resources. Data within these managed resources can be structured or unstructured. A lake provides data admins with tools to organize, secure and manage their data at scale, and provides data scientists and data engineers an integrated experience to easily search, discover, analyze and transform data and associated metadata.
Instance Attribute Summary collapse
-
#asset_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetStatus
Aggregated status of the underlying assets of a lake or zone.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#metastore ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1LakeMetastore
Settings to manage association of Dataproc Metastore with a lake.
-
#metastore_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1LakeMetastoreStatus
Status of Lake and Dataproc Metastore service instance association.
-
#name ⇒ String
Output only.
-
#service_account ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1Lake
constructor
A new instance of GoogleCloudDataplexV1Lake.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1Lake
Returns a new instance of GoogleCloudDataplexV1Lake.
7761 7762 7763 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7761 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetStatus
Aggregated status of the underlying assets of a lake or zone.
Corresponds to the JSON property assetStatus
7701 7702 7703 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7701 def asset_status @asset_status end |
#create_time ⇒ String
Output only. The time when the lake was created.
Corresponds to the JSON property createTime
7706 7707 7708 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7706 def create_time @create_time end |
#description ⇒ String
Optional. Description of the lake.
Corresponds to the JSON property description
7711 7712 7713 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7711 def description @description end |
#display_name ⇒ String
Optional. User friendly display name.
Corresponds to the JSON property displayName
7716 7717 7718 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7716 def display_name @display_name end |
#labels ⇒ Hash<String,String>
Optional. User-defined labels for the lake.
Corresponds to the JSON property labels
7721 7722 7723 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7721 def labels @labels end |
#metastore ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1LakeMetastore
Settings to manage association of Dataproc Metastore with a lake.
Corresponds to the JSON property metastore
7726 7727 7728 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7726 def @metastore end |
#metastore_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1LakeMetastoreStatus
Status of Lake and Dataproc Metastore service instance association.
Corresponds to the JSON property metastoreStatus
7731 7732 7733 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7731 def @metastore_status end |
#name ⇒ String
Output only. The relative resource name of the lake, of the form: projects/
project_number/locations/location_id/lakes/lake_id.
Corresponds to the JSON property name
7737 7738 7739 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7737 def name @name end |
#service_account ⇒ String
Output only. Service account associated with this lake. This service account
must be authorized to access or operate on resources managed by the lake.
Corresponds to the JSON property serviceAccount
7743 7744 7745 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7743 def service_account @service_account end |
#state ⇒ String
Output only. Current state of the lake.
Corresponds to the JSON property state
7748 7749 7750 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7748 def state @state end |
#uid ⇒ String
Output only. System generated globally unique ID for the lake. This ID will be
different if the lake is deleted and re-created with the same name.
Corresponds to the JSON property uid
7754 7755 7756 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7754 def uid @uid end |
#update_time ⇒ String
Output only. The time when the lake was last updated.
Corresponds to the JSON property updateTime
7759 7760 7761 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7759 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7766 def update!(**args) @asset_status = args[:asset_status] if args.key?(:asset_status) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @labels = args[:labels] if args.key?(:labels) @metastore = args[:metastore] if args.key?(:metastore) @metastore_status = args[:metastore_status] if args.key?(:metastore_status) @name = args[:name] if args.key?(:name) @service_account = args[:service_account] if args.key?(:service_account) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |