Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1Lake
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1Lake
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
A lake is a centralized repository for managing enterprise data across the organization distributed across many cloud projects, and stored in a variety of storage services such as Google Cloud Storage and BigQuery. The resources attached to a lake are referred to as managed resources. Data within these managed resources can be structured or unstructured. A lake provides data admins with tools to organize, secure and manage their data at scale, and provides data scientists and data engineers an integrated experience to easily search, discover, analyze and transform data and associated metadata.
Instance Attribute Summary collapse
-
#asset_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetStatus
Aggregated status of the underlying assets of a lake or zone.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#metastore ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1LakeMetastore
Settings to manage association of Dataproc Metastore with a lake.
-
#metastore_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1LakeMetastoreStatus
Status of Lake and Dataproc Metastore service instance association.
-
#name ⇒ String
Output only.
-
#service_account ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1Lake
constructor
A new instance of GoogleCloudDataplexV1Lake.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1Lake
Returns a new instance of GoogleCloudDataplexV1Lake.
6217 6218 6219 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6217 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetStatus
Aggregated status of the underlying assets of a lake or zone.
Corresponds to the JSON property assetStatus
6157 6158 6159 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6157 def asset_status @asset_status end |
#create_time ⇒ String
Output only. The time when the lake was created.
Corresponds to the JSON property createTime
6162 6163 6164 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6162 def create_time @create_time end |
#description ⇒ String
Optional. Description of the lake.
Corresponds to the JSON property description
6167 6168 6169 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6167 def description @description end |
#display_name ⇒ String
Optional. User friendly display name.
Corresponds to the JSON property displayName
6172 6173 6174 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6172 def display_name @display_name end |
#labels ⇒ Hash<String,String>
Optional. User-defined labels for the lake.
Corresponds to the JSON property labels
6177 6178 6179 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6177 def labels @labels end |
#metastore ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1LakeMetastore
Settings to manage association of Dataproc Metastore with a lake.
Corresponds to the JSON property metastore
6182 6183 6184 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6182 def @metastore end |
#metastore_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1LakeMetastoreStatus
Status of Lake and Dataproc Metastore service instance association.
Corresponds to the JSON property metastoreStatus
6187 6188 6189 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6187 def @metastore_status end |
#name ⇒ String
Output only. The relative resource name of the lake, of the form: projects/
project_number/locations/location_id/lakes/lake_id.
Corresponds to the JSON property name
6193 6194 6195 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6193 def name @name end |
#service_account ⇒ String
Output only. Service account associated with this lake. This service account
must be authorized to access or operate on resources managed by the lake.
Corresponds to the JSON property serviceAccount
6199 6200 6201 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6199 def service_account @service_account end |
#state ⇒ String
Output only. Current state of the lake.
Corresponds to the JSON property state
6204 6205 6206 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6204 def state @state end |
#uid ⇒ String
Output only. System generated globally unique ID for the lake. This ID will be
different if the lake is deleted and re-created with the same name.
Corresponds to the JSON property uid
6210 6211 6212 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6210 def uid @uid end |
#update_time ⇒ String
Output only. The time when the lake was last updated.
Corresponds to the JSON property updateTime
6215 6216 6217 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6215 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6222 6223 6224 6225 6226 6227 6228 6229 6230 6231 6232 6233 6234 6235 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 6222 def update!(**args) @asset_status = args[:asset_status] if args.key?(:asset_status) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @labels = args[:labels] if args.key?(:labels) @metastore = args[:metastore] if args.key?(:metastore) @metastore_status = args[:metastore_status] if args.key?(:metastore_status) @name = args[:name] if args.key?(:name) @service_account = args[:service_account] if args.key?(:service_account) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |