Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1ListMetadataFeedsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1ListMetadataFeedsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Response message for ListMetadataFeeds.
Instance Attribute Summary collapse
-
#metadata_feeds ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataFeed>
List of metadata feeds under the specified parent location.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1ListMetadataFeedsResponse
constructor
A new instance of GoogleCloudDataplexV1ListMetadataFeedsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1ListMetadataFeedsResponse
Returns a new instance of GoogleCloudDataplexV1ListMetadataFeedsResponse.
8734 8735 8736 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8734 def initialize(**args) update!(**args) end |
Instance Attribute Details
#metadata_feeds ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataFeed>
List of metadata feeds under the specified parent location.
Corresponds to the JSON property metadataFeeds
8721 8722 8723 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8721 def @metadata_feeds end |
#next_page_token ⇒ String
A token to retrieve the next page of results. If there are no more results in
the list, the value is empty.
Corresponds to the JSON property nextPageToken
8727 8728 8729 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8727 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Unordered list. Locations that the service couldn't reach.
Corresponds to the JSON property unreachable
8732 8733 8734 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8732 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8739 8740 8741 8742 8743 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8739 def update!(**args) @metadata_feeds = args[:metadata_feeds] if args.key?(:metadata_feeds) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |