Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1ListMetadataFeedsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1ListMetadataFeedsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Response message for ListMetadataFeeds.
Instance Attribute Summary collapse
-
#metadata_feeds ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataFeed>
List of metadata feeds under the specified parent location.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1ListMetadataFeedsResponse
constructor
A new instance of GoogleCloudDataplexV1ListMetadataFeedsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1ListMetadataFeedsResponse
Returns a new instance of GoogleCloudDataplexV1ListMetadataFeedsResponse.
8489 8490 8491 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8489 def initialize(**args) update!(**args) end |
Instance Attribute Details
#metadata_feeds ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataFeed>
List of metadata feeds under the specified parent location.
Corresponds to the JSON property metadataFeeds
8476 8477 8478 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8476 def @metadata_feeds end |
#next_page_token ⇒ String
A token to retrieve the next page of results. If there are no more results in
the list, the value is empty.
Corresponds to the JSON property nextPageToken
8482 8483 8484 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8482 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Unordered list. Locations that the service couldn't reach.
Corresponds to the JSON property unreachable
8487 8488 8489 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8487 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8494 8495 8496 8497 8498 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8494 def update!(**args) @metadata_feeds = args[:metadata_feeds] if args.key?(:metadata_feeds) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |