Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1LookupContextRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1LookupContextRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Lookup Context using permissions in the source system.
Instance Attribute Summary collapse
-
#context ⇒ String
Optional.
-
#options ⇒ Hash<String,String>
Optional.
-
#resources ⇒ Array<String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1LookupContextRequest
constructor
A new instance of GoogleCloudDataplexV1LookupContextRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1LookupContextRequest
Returns a new instance of GoogleCloudDataplexV1LookupContextRequest.
8646 8647 8648 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8646 def initialize(**args) update!(**args) end |
Instance Attribute Details
#context ⇒ String
Optional. The text representing contextual information for which metadata
context is being requested.
Corresponds to the JSON property context
8625 8626 8627 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8625 def context @context end |
#options ⇒ Hash<String,String>
Optional. Allows to configure the context.Supported options: format - The
format of the context (one of yaml, xml, json, default is yaml).
context_budget - If provided, the output will be intelligently truncated on a
best-effort basis to contain approximately the desired amount of characters.
There is no guarantee to achieve the specific amount. all_schema_fields - If
set to true, all schema fields will be returned in the context (regardless of
context_budget value). Otherwise, the list of schema fields is truncated.
Default is false.
Corresponds to the JSON property options
8637 8638 8639 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8637 def @options end |
#resources ⇒ Array<String>
Required. The entry names to look up the context for. The maximum number of
resources for a request is limited to 10.Examples:projects/project/locations/
location/entryGroups/entry_group/entries/entry
Corresponds to the JSON property resources
8644 8645 8646 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8644 def resources @resources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8651 8652 8653 8654 8655 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8651 def update!(**args) @context = args[:context] if args.key?(:context) @options = args[:options] if args.key?(:options) @resources = args[:resources] if args.key?(:resources) end |