Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1LookupContextResponse
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1LookupContextResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Lookup Context response.
Instance Attribute Summary collapse
-
#context ⇒ String
Pre-formatted block of text containing the context for the requested resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1LookupContextResponse
constructor
A new instance of GoogleCloudDataplexV1LookupContextResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1LookupContextResponse
Returns a new instance of GoogleCloudDataplexV1LookupContextResponse.
8667 8668 8669 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8667 def initialize(**args) update!(**args) end |
Instance Attribute Details
#context ⇒ String
Pre-formatted block of text containing the context for the requested resources.
Corresponds to the JSON property context
8665 8666 8667 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8665 def context @context end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8672 8673 8674 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8672 def update!(**args) @context = args[:context] if args.key?(:context) end |