Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1LookupEntryLinksResponse
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1LookupEntryLinksResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Response message for LookupEntryLinks.
Instance Attribute Summary collapse
-
#entry_links ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1EntryLink>
List of entry links that reference the specified entry.
-
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more results in the list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1LookupEntryLinksResponse
constructor
A new instance of GoogleCloudDataplexV1LookupEntryLinksResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1LookupEntryLinksResponse
Returns a new instance of GoogleCloudDataplexV1LookupEntryLinksResponse.
8692 8693 8694 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8692 def initialize(**args) update!(**args) end |
Instance Attribute Details
#entry_links ⇒ Array<Google::Apis::DataplexV1::GoogleCloudDataplexV1EntryLink>
List of entry links that reference the specified entry.
Corresponds to the JSON property entryLinks
8684 8685 8686 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8684 def entry_links @entry_links end |
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more
results in the list.
Corresponds to the JSON property nextPageToken
8690 8691 8692 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8690 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8697 8698 8699 8700 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8697 def update!(**args) @entry_links = args[:entry_links] if args.key?(:entry_links) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |