Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataFeed

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

MetadataFeed contains information related to the metadata feed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataFeed

Returns a new instance of GoogleCloudDataplexV1MetadataFeed.



8996
8997
8998
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8996

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time when the feed was created. Corresponds to the JSON property createTime

Returns:

  • (String)


8948
8949
8950
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8948

def create_time
  @create_time
end

#filtersGoogle::Apis::DataplexV1::GoogleCloudDataplexV1MetadataFeedFilters

Filters defines the type of changes that you want to listen to. You can have multiple entry type filters and multiple aspect type filters. All of the entry type filters are OR'ed together. All of the aspect type filters are OR'ed together. All of the entry type filters and aspect type filters are AND'ed together. Corresponds to the JSON property filters



8957
8958
8959
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8957

def filters
  @filters
end

#labelsHash<String,String>

Optional. User-defined labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


8962
8963
8964
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8962

def labels
  @labels
end

#nameString

Identifier. The resource name of the metadata feed, in the format projects/ project_id_or_number/locations/location_id/metadataFeeds/metadata_feed_id. Corresponds to the JSON property name

Returns:

  • (String)


8968
8969
8970
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8968

def name
  @name
end

#pubsub_topicString

Optional. The pubsub topic that you want the metadata feed messages to publish to. Please grant Dataplex service account the permission to publish messages to the topic. The service account is: service-PROJECT_NUMBER@gcp-sa-dataplex. iam.gserviceaccount.com. Corresponds to the JSON property pubsubTopic

Returns:

  • (String)


8976
8977
8978
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8976

def pubsub_topic
  @pubsub_topic
end

#scopeGoogle::Apis::DataplexV1::GoogleCloudDataplexV1MetadataFeedScope

Scope defines the scope of the metadata feed. Scopes are exclusive. Only one of the scopes can be specified. Corresponds to the JSON property scope



8982
8983
8984
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8982

def scope
  @scope
end

#uidString

Output only. A system-generated, globally unique ID for the metadata job. If the metadata job is deleted and then re-created with the same name, this ID is different. Corresponds to the JSON property uid

Returns:

  • (String)


8989
8990
8991
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8989

def uid
  @uid
end

#update_timeString

Output only. The time when the feed was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


8994
8995
8996
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8994

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9001
9002
9003
9004
9005
9006
9007
9008
9009
9010
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9001

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @filters = args[:filters] if args.key?(:filters)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @pubsub_topic = args[:pubsub_topic] if args.key?(:pubsub_topic)
  @scope = args[:scope] if args.key?(:scope)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end