Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataFeed

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

MetadataFeed contains information related to the metadata feed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataFeed

Returns a new instance of GoogleCloudDataplexV1MetadataFeed.



8758
8759
8760
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8758

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time when the feed was created. Corresponds to the JSON property createTime

Returns:

  • (String)


8710
8711
8712
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8710

def create_time
  @create_time
end

#filtersGoogle::Apis::DataplexV1::GoogleCloudDataplexV1MetadataFeedFilters

Filters defines the type of changes that you want to listen to. You can have multiple entry type filters and multiple aspect type filters. All of the entry type filters are OR'ed together. All of the aspect type filters are OR'ed together. All of the entry type filters and aspect type filters are AND'ed together. Corresponds to the JSON property filters



8719
8720
8721
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8719

def filters
  @filters
end

#labelsHash<String,String>

Optional. User-defined labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


8724
8725
8726
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8724

def labels
  @labels
end

#nameString

Identifier. The resource name of the metadata feed, in the format projects/ project_id_or_number/locations/location_id/metadataFeeds/metadata_feed_id. Corresponds to the JSON property name

Returns:

  • (String)


8730
8731
8732
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8730

def name
  @name
end

#pubsub_topicString

Optional. The pubsub topic that you want the metadata feed messages to publish to. Please grant Dataplex service account the permission to publish messages to the topic. The service account is: service-PROJECT_NUMBER@gcp-sa-dataplex. iam.gserviceaccount.com. Corresponds to the JSON property pubsubTopic

Returns:

  • (String)


8738
8739
8740
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8738

def pubsub_topic
  @pubsub_topic
end

#scopeGoogle::Apis::DataplexV1::GoogleCloudDataplexV1MetadataFeedScope

Scope defines the scope of the metadata feed. Scopes are exclusive. Only one of the scopes can be specified. Corresponds to the JSON property scope



8744
8745
8746
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8744

def scope
  @scope
end

#uidString

Output only. A system-generated, globally unique ID for the metadata job. If the metadata job is deleted and then re-created with the same name, this ID is different. Corresponds to the JSON property uid

Returns:

  • (String)


8751
8752
8753
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8751

def uid
  @uid
end

#update_timeString

Output only. The time when the feed was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


8756
8757
8758
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8756

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8763
8764
8765
8766
8767
8768
8769
8770
8771
8772
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8763

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @filters = args[:filters] if args.key?(:filters)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @pubsub_topic = args[:pubsub_topic] if args.key?(:pubsub_topic)
  @scope = args[:scope] if args.key?(:scope)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end