Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataFeedFilters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Filters defines the type of changes that you want to listen to. You can have multiple entry type filters and multiple aspect type filters. All of the entry type filters are OR'ed together. All of the aspect type filters are OR'ed together. All of the entry type filters and aspect type filters are AND'ed together.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataFeedFilters

Returns a new instance of GoogleCloudDataplexV1MetadataFeedFilters.



8804
8805
8806
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8804

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aspect_typesArray<String>

Optional. The aspect types that you want to listen to. Depending on how the aspect is attached to the entry, in the format: projects/project_id_or_number /locations/location/aspectTypes/aspect_type_id. Corresponds to the JSON property aspectTypes

Returns:

  • (Array<String>)


8788
8789
8790
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8788

def aspect_types
  @aspect_types
end

#change_typesArray<String>

Optional. The type of change that you want to listen to. If not specified, all changes are published. Corresponds to the JSON property changeTypes

Returns:

  • (Array<String>)


8794
8795
8796
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8794

def change_types
  @change_types
end

#entry_typesArray<String>

Optional. The entry types that you want to listen to, specified as relative resource names in the format projects/project_id_or_number/locations/ location/entryTypes/entry_type_id. Only entries that belong to the specified entry types are published. Corresponds to the JSON property entryTypes

Returns:

  • (Array<String>)


8802
8803
8804
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8802

def entry_types
  @entry_types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8809
8810
8811
8812
8813
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8809

def update!(**args)
  @aspect_types = args[:aspect_types] if args.key?(:aspect_types)
  @change_types = args[:change_types] if args.key?(:change_types)
  @entry_types = args[:entry_types] if args.key?(:entry_types)
end