Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataFeedScope

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Scope defines the scope of the metadata feed. Scopes are exclusive. Only one of the scopes can be specified.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataFeedScope

Returns a new instance of GoogleCloudDataplexV1MetadataFeedScope.



8844
8845
8846
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8844

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entry_groupsArray<String>

Optional. The entry groups whose entries you want to listen to. Must be in the format: projects/project_id_or_number/locations/location_id/entryGroups/ entry_group_id. Corresponds to the JSON property entryGroups

Returns:

  • (Array<String>)


8826
8827
8828
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8826

def entry_groups
  @entry_groups
end

#organization_levelBoolean Also known as: organization_level?

Optional. Whether the metadata feed is at the organization-level. If true, all changes happened to the entries in the same organization as the feed are published. If false, you must specify a list of projects or a list of entry groups whose entries you want to listen to.The default is false. Corresponds to the JSON property organizationLevel

Returns:

  • (Boolean)


8834
8835
8836
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8834

def organization_level
  @organization_level
end

#projectsArray<String>

Optional. The projects whose entries you want to listen to. Must be in the same organization as the feed. Must be in the format: projects/ project_id_or_number. Corresponds to the JSON property projects

Returns:

  • (Array<String>)


8842
8843
8844
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8842

def projects
  @projects
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8849
8850
8851
8852
8853
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8849

def update!(**args)
  @entry_groups = args[:entry_groups] if args.key?(:entry_groups)
  @organization_level = args[:organization_level] if args.key?(:organization_level)
  @projects = args[:projects] if args.key?(:projects)
end