Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJob
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
A metadata job resource.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#export_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobExportJobResult
Summary results from a metadata export job.
-
#export_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobExportJobSpec
Job specification for a metadata export job.
-
#import_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobImportJobResult
Results from a metadata import job.
-
#import_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobImportJobSpec
Job specification for a metadata import job.You can run the following kinds of metadata import jobs: Full sync of entries with incremental import of their aspects.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobStatus
Metadata job status.
-
#type ⇒ String
Required.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataJob
constructor
A new instance of GoogleCloudDataplexV1MetadataJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataJob
Returns a new instance of GoogleCloudDataplexV1MetadataJob.
9164 9165 9166 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9164 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time when the metadata job was created.
Corresponds to the JSON property createTime
9101 9102 9103 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9101 def create_time @create_time end |
#export_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobExportJobResult
Summary results from a metadata export job. The results are a snapshot of the
metadata at the time when the job was created. The exported entries are saved
to a Cloud Storage bucket.
Corresponds to the JSON property exportResult
9108 9109 9110 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9108 def export_result @export_result end |
#export_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobExportJobSpec
Job specification for a metadata export job.
Corresponds to the JSON property exportSpec
9113 9114 9115 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9113 def export_spec @export_spec end |
#import_result ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobImportJobResult
Results from a metadata import job.
Corresponds to the JSON property importResult
9118 9119 9120 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9118 def import_result @import_result end |
#import_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobImportJobSpec
Job specification for a metadata import job.You can run the following kinds of
metadata import jobs: Full sync of entries with incremental import of their
aspects. Supported for custom entries. Incremental import of aspects only.
Supported for aspects that belong to custom entries and system entries. For
custom entries, you can modify both optional aspects and required aspects. For
system entries, you can modify optional aspects.
Corresponds to the JSON property importSpec
9128 9129 9130 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9128 def import_spec @import_spec end |
#labels ⇒ Hash<String,String>
Optional. User-defined labels.
Corresponds to the JSON property labels
9133 9134 9135 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9133 def labels @labels end |
#name ⇒ String
Output only. Identifier. The name of the resource that the configuration is
applied to, in the format projects/project_number/locations/location_id/
metadataJobs/metadata_job_id.
Corresponds to the JSON property name
9140 9141 9142 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9140 def name @name end |
#status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobStatus
Metadata job status.
Corresponds to the JSON property status
9145 9146 9147 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9145 def status @status end |
#type ⇒ String
Required. Metadata job type.
Corresponds to the JSON property type
9150 9151 9152 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9150 def type @type end |
#uid ⇒ String
Output only. A system-generated, globally unique ID for the metadata job. If
the metadata job is deleted and then re-created with the same name, this ID is
different.
Corresponds to the JSON property uid
9157 9158 9159 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9157 def uid @uid end |
#update_time ⇒ String
Output only. The time when the metadata job was updated.
Corresponds to the JSON property updateTime
9162 9163 9164 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9162 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9169 9170 9171 9172 9173 9174 9175 9176 9177 9178 9179 9180 9181 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9169 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @export_result = args[:export_result] if args.key?(:export_result) @export_spec = args[:export_spec] if args.key?(:export_spec) @import_result = args[:import_result] if args.key?(:import_result) @import_spec = args[:import_spec] if args.key?(:import_spec) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @status = args[:status] if args.key?(:status) @type = args[:type] if args.key?(:type) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |