Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

A metadata job resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataJob

Returns a new instance of GoogleCloudDataplexV1MetadataJob.



8926
8927
8928
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8926

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time when the metadata job was created. Corresponds to the JSON property createTime

Returns:

  • (String)


8863
8864
8865
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8863

def create_time
  @create_time
end

#export_resultGoogle::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobExportJobResult

Summary results from a metadata export job. The results are a snapshot of the metadata at the time when the job was created. The exported entries are saved to a Cloud Storage bucket. Corresponds to the JSON property exportResult



8870
8871
8872
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8870

def export_result
  @export_result
end

#export_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobExportJobSpec

Job specification for a metadata export job. Corresponds to the JSON property exportSpec



8875
8876
8877
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8875

def export_spec
  @export_spec
end

#import_resultGoogle::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobImportJobResult

Results from a metadata import job. Corresponds to the JSON property importResult



8880
8881
8882
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8880

def import_result
  @import_result
end

#import_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobImportJobSpec

Job specification for a metadata import job.You can run the following kinds of metadata import jobs: Full sync of entries with incremental import of their aspects. Supported for custom entries. Incremental import of aspects only. Supported for aspects that belong to custom entries and system entries. For custom entries, you can modify both optional aspects and required aspects. For system entries, you can modify optional aspects. Corresponds to the JSON property importSpec



8890
8891
8892
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8890

def import_spec
  @import_spec
end

#labelsHash<String,String>

Optional. User-defined labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


8895
8896
8897
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8895

def labels
  @labels
end

#nameString

Output only. Identifier. The name of the resource that the configuration is applied to, in the format projects/project_number/locations/location_id/ metadataJobs/metadata_job_id. Corresponds to the JSON property name

Returns:

  • (String)


8902
8903
8904
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8902

def name
  @name
end

#statusGoogle::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobStatus

Metadata job status. Corresponds to the JSON property status



8907
8908
8909
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8907

def status
  @status
end

#typeString

Required. Metadata job type. Corresponds to the JSON property type

Returns:

  • (String)


8912
8913
8914
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8912

def type
  @type
end

#uidString

Output only. A system-generated, globally unique ID for the metadata job. If the metadata job is deleted and then re-created with the same name, this ID is different. Corresponds to the JSON property uid

Returns:

  • (String)


8919
8920
8921
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8919

def uid
  @uid
end

#update_timeString

Output only. The time when the metadata job was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


8924
8925
8926
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8924

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8931
8932
8933
8934
8935
8936
8937
8938
8939
8940
8941
8942
8943
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8931

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @export_result = args[:export_result] if args.key?(:export_result)
  @export_spec = args[:export_spec] if args.key?(:export_spec)
  @import_result = args[:import_result] if args.key?(:import_result)
  @import_spec = args[:import_spec] if args.key?(:import_spec)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @status = args[:status] if args.key?(:status)
  @type = args[:type] if args.key?(:type)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end