Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

A metadata job resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataJob

Returns a new instance of GoogleCloudDataplexV1MetadataJob.



7100
7101
7102
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7100

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time when the metadata job was created. Corresponds to the JSON property createTime

Returns:

  • (String)


7037
7038
7039
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7037

def create_time
  @create_time
end

#export_resultGoogle::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobExportJobResult

Summary results from a metadata export job. The results are a snapshot of the metadata at the time when the job was created. The exported entries are saved to a Cloud Storage bucket. Corresponds to the JSON property exportResult



7044
7045
7046
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7044

def export_result
  @export_result
end

#export_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobExportJobSpec

Job specification for a metadata export job. Corresponds to the JSON property exportSpec



7049
7050
7051
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7049

def export_spec
  @export_spec
end

#import_resultGoogle::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobImportJobResult

Results from a metadata import job. Corresponds to the JSON property importResult



7054
7055
7056
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7054

def import_result
  @import_result
end

#import_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobImportJobSpec

Job specification for a metadata import job.You can run the following kinds of metadata import jobs: Full sync of entries with incremental import of their aspects. Supported for custom entries. Incremental import of aspects only. Supported for aspects that belong to custom entries and system entries. For custom entries, you can modify both optional aspects and required aspects. For system entries, you can modify optional aspects. Corresponds to the JSON property importSpec



7064
7065
7066
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7064

def import_spec
  @import_spec
end

#labelsHash<String,String>

Optional. User-defined labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


7069
7070
7071
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7069

def labels
  @labels
end

#nameString

Output only. Identifier. The name of the resource that the configuration is applied to, in the format projects/project_number/locations/location_id/ metadataJobs/metadata_job_id. Corresponds to the JSON property name

Returns:

  • (String)


7076
7077
7078
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7076

def name
  @name
end

#statusGoogle::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobStatus

Metadata job status. Corresponds to the JSON property status



7081
7082
7083
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7081

def status
  @status
end

#typeString

Required. Metadata job type. Corresponds to the JSON property type

Returns:

  • (String)


7086
7087
7088
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7086

def type
  @type
end

#uidString

Output only. A system-generated, globally unique ID for the metadata job. If the metadata job is deleted and then re-created with the same name, this ID is different. Corresponds to the JSON property uid

Returns:

  • (String)


7093
7094
7095
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7093

def uid
  @uid
end

#update_timeString

Output only. The time when the metadata job was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


7098
7099
7100
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7098

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7105
7106
7107
7108
7109
7110
7111
7112
7113
7114
7115
7116
7117
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7105

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @export_result = args[:export_result] if args.key?(:export_result)
  @export_spec = args[:export_spec] if args.key?(:export_spec)
  @import_result = args[:import_result] if args.key?(:import_result)
  @import_spec = args[:import_spec] if args.key?(:import_spec)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @status = args[:status] if args.key?(:status)
  @type = args[:type] if args.key?(:type)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end