Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobExportJobResult
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobExportJobResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Summary results from a metadata export job. The results are a snapshot of the metadata at the time when the job was created. The exported entries are saved to a Cloud Storage bucket.
Instance Attribute Summary collapse
-
#error_message ⇒ String
Output only.
-
#exported_entries ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataJobExportJobResult
constructor
A new instance of GoogleCloudDataplexV1MetadataJobExportJobResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataJobExportJobResult
Returns a new instance of GoogleCloudDataplexV1MetadataJobExportJobResult.
8962 8963 8964 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8962 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_message ⇒ String
Output only. The error message if the metadata export job failed.
Corresponds to the JSON property errorMessage
8955 8956 8957 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8955 def @error_message end |
#exported_entries ⇒ Fixnum
Output only. The number of entries that were exported.
Corresponds to the JSON property exportedEntries
8960 8961 8962 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8960 def exported_entries @exported_entries end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8967 8968 8969 8970 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8967 def update!(**args) @error_message = args[:error_message] if args.key?(:error_message) @exported_entries = args[:exported_entries] if args.key?(:exported_entries) end |