Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobExportJobResult
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobExportJobResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Summary results from a metadata export job. The results are a snapshot of the metadata at the time when the job was created. The exported entries are saved to a Cloud Storage bucket.
Instance Attribute Summary collapse
-
#error_message ⇒ String
Output only.
-
#exported_entries ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataJobExportJobResult
constructor
A new instance of GoogleCloudDataplexV1MetadataJobExportJobResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataJobExportJobResult
Returns a new instance of GoogleCloudDataplexV1MetadataJobExportJobResult.
7136 7137 7138 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7136 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_message ⇒ String
Output only. The error message if the metadata export job failed.
Corresponds to the JSON property errorMessage
7129 7130 7131 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7129 def @error_message end |
#exported_entries ⇒ Fixnum
Output only. The number of entries that were exported.
Corresponds to the JSON property exportedEntries
7134 7135 7136 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7134 def exported_entries @exported_entries end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7141 7142 7143 7144 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7141 def update!(**args) @error_message = args[:error_message] if args.key?(:error_message) @exported_entries = args[:exported_entries] if args.key?(:exported_entries) end |