Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobExportJobSpec
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobExportJobSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Job specification for a metadata export job.
Instance Attribute Summary collapse
-
#output_path ⇒ String
Required.
-
#scope ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobExportJobSpecExportJobScope
The scope of the export job.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataJobExportJobSpec
constructor
A new instance of GoogleCloudDataplexV1MetadataJobExportJobSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataJobExportJobSpec
Returns a new instance of GoogleCloudDataplexV1MetadataJobExportJobSpec.
9238 9239 9240 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9238 def initialize(**args) update!(**args) end |
Instance Attribute Details
#output_path ⇒ String
Required. The root path of the Cloud Storage bucket to export the metadata to,
in the format gs://bucket/. You can optionally specify a custom prefix after
the bucket name, in the format gs://bucket/prefix/. The maximum length of
the custom prefix is 128 characters. Dataplex Universal Catalog constructs the
object path for the exported files by using the bucket name and prefix that
you provide, followed by a system-generated path.The bucket must be in the
same VPC Service Controls perimeter as the job.
Corresponds to the JSON property outputPath
9231 9232 9233 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9231 def output_path @output_path end |
#scope ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobExportJobSpecExportJobScope
The scope of the export job.
Corresponds to the JSON property scope
9236 9237 9238 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9236 def scope @scope end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9243 9244 9245 9246 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9243 def update!(**args) @output_path = args[:output_path] if args.key?(:output_path) @scope = args[:scope] if args.key?(:scope) end |