Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobExportJobSpecExportJobScope
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobExportJobSpecExportJobScope
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
The scope of the export job.
Instance Attribute Summary collapse
-
#aspect_types ⇒ Array<String>
The aspect types that are in scope for the export job, specified as relative resource names in the format projects/
project_id_or_number/locations/location/aspectTypes/aspect_type_id. -
#entry_groups ⇒ Array<String>
The entry groups whose metadata you want to export, in the format projects/
project_id_or_number/locations/location_id/entryGroups/entry_group_id. -
#entry_types ⇒ Array<String>
The entry types that are in scope for the export job, specified as relative resource names in the format projects/
project_id_or_number/locations/location/entryTypes/entry_type_id. -
#organization_level ⇒ Boolean
(also: #organization_level?)
Whether the metadata export job is an organization-level export job.
-
#projects ⇒ Array<String>
The projects whose metadata you want to export, in the format projects/
project_id_or_number.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataJobExportJobSpecExportJobScope
constructor
A new instance of GoogleCloudDataplexV1MetadataJobExportJobSpecExportJobScope.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataJobExportJobSpecExportJobScope
Returns a new instance of GoogleCloudDataplexV1MetadataJobExportJobSpecExportJobScope.
9301 9302 9303 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9301 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aspect_types ⇒ Array<String>
The aspect types that are in scope for the export job, specified as relative
resource names in the format projects/project_id_or_number/locations/
location/aspectTypes/aspect_type_id. Only aspects that belong to the
specified aspect types are affected by the job.
Corresponds to the JSON property aspectTypes
9259 9260 9261 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9259 def aspect_types @aspect_types end |
#entry_groups ⇒ Array<String>
The entry groups whose metadata you want to export, in the format projects/
project_id_or_number/locations/location_id/entryGroups/entry_group_id.
Only the entries in the specified entry groups are exported.The entry groups
must be in the same location and the same VPC Service Controls perimeter as
the job.If you set the job scope to be a list of entry groups, then set the
organization-level export flag to false and don't provide a list of projects.
Corresponds to the JSON property entryGroups
9269 9270 9271 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9269 def entry_groups @entry_groups end |
#entry_types ⇒ Array<String>
The entry types that are in scope for the export job, specified as relative
resource names in the format projects/project_id_or_number/locations/
location/entryTypes/entry_type_id. Only entries that belong to the
specified entry types are affected by the job.
Corresponds to the JSON property entryTypes
9277 9278 9279 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9277 def entry_types @entry_types end |
#organization_level ⇒ Boolean Also known as: organization_level?
Whether the metadata export job is an organization-level export job. If true,
the job exports the entries from the same organization and VPC Service
Controls perimeter as the job. The project that the job belongs to determines
the VPC Service Controls perimeter. If you set the job scope to be at the
organization level, then don't provide a list of projects or entry groups. If
false, you must specify a list of projects or a list of entry groups whose
entries you want to export.The default is false.
Corresponds to the JSON property organizationLevel
9288 9289 9290 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9288 def organization_level @organization_level end |
#projects ⇒ Array<String>
The projects whose metadata you want to export, in the format projects/
project_id_or_number. Only the entries from the specified projects are
exported.The projects must be in the same organization and VPC Service
Controls perimeter as the job.If you set the job scope to be a list of
projects, then set the organization-level export flag to false and don't
provide a list of entry groups.
Corresponds to the JSON property projects
9299 9300 9301 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9299 def projects @projects end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9306 9307 9308 9309 9310 9311 9312 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9306 def update!(**args) @aspect_types = args[:aspect_types] if args.key?(:aspect_types) @entry_groups = args[:entry_groups] if args.key?(:entry_groups) @entry_types = args[:entry_types] if args.key?(:entry_types) @organization_level = args[:organization_level] if args.key?(:organization_level) @projects = args[:projects] if args.key?(:projects) end |