Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobExportJobSpecExportJobScope

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

The scope of the export job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataJobExportJobSpecExportJobScope

Returns a new instance of GoogleCloudDataplexV1MetadataJobExportJobSpecExportJobScope.



9056
9057
9058
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9056

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aspect_typesArray<String>

The aspect types that are in scope for the export job, specified as relative resource names in the format projects/project_id_or_number/locations/ location/aspectTypes/aspect_type_id. Only aspects that belong to the specified aspect types are affected by the job. Corresponds to the JSON property aspectTypes

Returns:

  • (Array<String>)


9014
9015
9016
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9014

def aspect_types
  @aspect_types
end

#entry_groupsArray<String>

The entry groups whose metadata you want to export, in the format projects/ project_id_or_number/locations/location_id/entryGroups/entry_group_id. Only the entries in the specified entry groups are exported.The entry groups must be in the same location and the same VPC Service Controls perimeter as the job.If you set the job scope to be a list of entry groups, then set the organization-level export flag to false and don't provide a list of projects. Corresponds to the JSON property entryGroups

Returns:

  • (Array<String>)


9024
9025
9026
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9024

def entry_groups
  @entry_groups
end

#entry_typesArray<String>

The entry types that are in scope for the export job, specified as relative resource names in the format projects/project_id_or_number/locations/ location/entryTypes/entry_type_id. Only entries that belong to the specified entry types are affected by the job. Corresponds to the JSON property entryTypes

Returns:

  • (Array<String>)


9032
9033
9034
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9032

def entry_types
  @entry_types
end

#organization_levelBoolean Also known as: organization_level?

Whether the metadata export job is an organization-level export job. If true, the job exports the entries from the same organization and VPC Service Controls perimeter as the job. The project that the job belongs to determines the VPC Service Controls perimeter. If you set the job scope to be at the organization level, then don't provide a list of projects or entry groups. If false, you must specify a list of projects or a list of entry groups whose entries you want to export.The default is false. Corresponds to the JSON property organizationLevel

Returns:

  • (Boolean)


9043
9044
9045
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9043

def organization_level
  @organization_level
end

#projectsArray<String>

The projects whose metadata you want to export, in the format projects/ project_id_or_number. Only the entries from the specified projects are exported.The projects must be in the same organization and VPC Service Controls perimeter as the job.If you set the job scope to be a list of projects, then set the organization-level export flag to false and don't provide a list of entry groups. Corresponds to the JSON property projects

Returns:

  • (Array<String>)


9054
9055
9056
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9054

def projects
  @projects
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9061
9062
9063
9064
9065
9066
9067
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9061

def update!(**args)
  @aspect_types = args[:aspect_types] if args.key?(:aspect_types)
  @entry_groups = args[:entry_groups] if args.key?(:entry_groups)
  @entry_types = args[:entry_types] if args.key?(:entry_types)
  @organization_level = args[:organization_level] if args.key?(:organization_level)
  @projects = args[:projects] if args.key?(:projects)
end