Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobImportJobResult
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobImportJobResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Results from a metadata import job.
Instance Attribute Summary collapse
-
#created_entries ⇒ Fixnum
Output only.
-
#created_entry_links ⇒ Fixnum
Output only.
-
#deleted_entries ⇒ Fixnum
Output only.
-
#deleted_entry_links ⇒ Fixnum
Output only.
-
#recreated_entries ⇒ Fixnum
Output only.
-
#unchanged_entries ⇒ Fixnum
Output only.
-
#unchanged_entry_links ⇒ Fixnum
Output only.
-
#update_time ⇒ String
Output only.
-
#updated_entries ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataJobImportJobResult
constructor
A new instance of GoogleCloudDataplexV1MetadataJobImportJobResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataJobImportJobResult
Returns a new instance of GoogleCloudDataplexV1MetadataJobImportJobResult.
9364 9365 9366 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9364 def initialize(**args) update!(**args) end |
Instance Attribute Details
#created_entries ⇒ Fixnum
Output only. The total number of entries that were created.
Corresponds to the JSON property createdEntries
9322 9323 9324 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9322 def created_entries @created_entries end |
#created_entry_links ⇒ Fixnum
Output only. The total number of entry links that were successfully created.
Corresponds to the JSON property createdEntryLinks
9327 9328 9329 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9327 def created_entry_links @created_entry_links end |
#deleted_entries ⇒ Fixnum
Output only. The total number of entries that were deleted.
Corresponds to the JSON property deletedEntries
9332 9333 9334 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9332 def deleted_entries @deleted_entries end |
#deleted_entry_links ⇒ Fixnum
Output only. The total number of entry links that were successfully deleted.
Corresponds to the JSON property deletedEntryLinks
9337 9338 9339 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9337 def deleted_entry_links @deleted_entry_links end |
#recreated_entries ⇒ Fixnum
Output only. The total number of entries that were recreated.
Corresponds to the JSON property recreatedEntries
9342 9343 9344 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9342 def recreated_entries @recreated_entries end |
#unchanged_entries ⇒ Fixnum
Output only. The total number of entries that were unchanged.
Corresponds to the JSON property unchangedEntries
9347 9348 9349 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9347 def unchanged_entries @unchanged_entries end |
#unchanged_entry_links ⇒ Fixnum
Output only. The total number of entry links that were left unchanged.
Corresponds to the JSON property unchangedEntryLinks
9352 9353 9354 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9352 def unchanged_entry_links @unchanged_entry_links end |
#update_time ⇒ String
Output only. The time when the status was updated.
Corresponds to the JSON property updateTime
9357 9358 9359 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9357 def update_time @update_time end |
#updated_entries ⇒ Fixnum
Output only. The total number of entries that were updated.
Corresponds to the JSON property updatedEntries
9362 9363 9364 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9362 def updated_entries @updated_entries end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9369 9370 9371 9372 9373 9374 9375 9376 9377 9378 9379 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9369 def update!(**args) @created_entries = args[:created_entries] if args.key?(:created_entries) @created_entry_links = args[:created_entry_links] if args.key?(:created_entry_links) @deleted_entries = args[:deleted_entries] if args.key?(:deleted_entries) @deleted_entry_links = args[:deleted_entry_links] if args.key?(:deleted_entry_links) @recreated_entries = args[:recreated_entries] if args.key?(:recreated_entries) @unchanged_entries = args[:unchanged_entries] if args.key?(:unchanged_entries) @unchanged_entry_links = args[:unchanged_entry_links] if args.key?(:unchanged_entry_links) @update_time = args[:update_time] if args.key?(:update_time) @updated_entries = args[:updated_entries] if args.key?(:updated_entries) end |