Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobImportJobResult
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobImportJobResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Results from a metadata import job.
Instance Attribute Summary collapse
-
#created_entries ⇒ Fixnum
Output only.
-
#created_entry_links ⇒ Fixnum
Output only.
-
#deleted_entries ⇒ Fixnum
Output only.
-
#deleted_entry_links ⇒ Fixnum
Output only.
-
#recreated_entries ⇒ Fixnum
Output only.
-
#unchanged_entries ⇒ Fixnum
Output only.
-
#unchanged_entry_links ⇒ Fixnum
Output only.
-
#update_time ⇒ String
Output only.
-
#updated_entries ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataJobImportJobResult
constructor
A new instance of GoogleCloudDataplexV1MetadataJobImportJobResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataJobImportJobResult
Returns a new instance of GoogleCloudDataplexV1MetadataJobImportJobResult.
9119 9120 9121 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9119 def initialize(**args) update!(**args) end |
Instance Attribute Details
#created_entries ⇒ Fixnum
Output only. The total number of entries that were created.
Corresponds to the JSON property createdEntries
9077 9078 9079 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9077 def created_entries @created_entries end |
#created_entry_links ⇒ Fixnum
Output only. The total number of entry links that were successfully created.
Corresponds to the JSON property createdEntryLinks
9082 9083 9084 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9082 def created_entry_links @created_entry_links end |
#deleted_entries ⇒ Fixnum
Output only. The total number of entries that were deleted.
Corresponds to the JSON property deletedEntries
9087 9088 9089 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9087 def deleted_entries @deleted_entries end |
#deleted_entry_links ⇒ Fixnum
Output only. The total number of entry links that were successfully deleted.
Corresponds to the JSON property deletedEntryLinks
9092 9093 9094 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9092 def deleted_entry_links @deleted_entry_links end |
#recreated_entries ⇒ Fixnum
Output only. The total number of entries that were recreated.
Corresponds to the JSON property recreatedEntries
9097 9098 9099 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9097 def recreated_entries @recreated_entries end |
#unchanged_entries ⇒ Fixnum
Output only. The total number of entries that were unchanged.
Corresponds to the JSON property unchangedEntries
9102 9103 9104 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9102 def unchanged_entries @unchanged_entries end |
#unchanged_entry_links ⇒ Fixnum
Output only. The total number of entry links that were left unchanged.
Corresponds to the JSON property unchangedEntryLinks
9107 9108 9109 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9107 def unchanged_entry_links @unchanged_entry_links end |
#update_time ⇒ String
Output only. The time when the status was updated.
Corresponds to the JSON property updateTime
9112 9113 9114 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9112 def update_time @update_time end |
#updated_entries ⇒ Fixnum
Output only. The total number of entries that were updated.
Corresponds to the JSON property updatedEntries
9117 9118 9119 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9117 def updated_entries @updated_entries end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9124 9125 9126 9127 9128 9129 9130 9131 9132 9133 9134 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9124 def update!(**args) @created_entries = args[:created_entries] if args.key?(:created_entries) @created_entry_links = args[:created_entry_links] if args.key?(:created_entry_links) @deleted_entries = args[:deleted_entries] if args.key?(:deleted_entries) @deleted_entry_links = args[:deleted_entry_links] if args.key?(:deleted_entry_links) @recreated_entries = args[:recreated_entries] if args.key?(:recreated_entries) @unchanged_entries = args[:unchanged_entries] if args.key?(:unchanged_entries) @unchanged_entry_links = args[:unchanged_entry_links] if args.key?(:unchanged_entry_links) @update_time = args[:update_time] if args.key?(:update_time) @updated_entries = args[:updated_entries] if args.key?(:updated_entries) end |