Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobImportJobResult
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobImportJobResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Results from a metadata import job.
Instance Attribute Summary collapse
-
#created_entries ⇒ Fixnum
Output only.
-
#created_entry_links ⇒ Fixnum
Output only.
-
#deleted_entries ⇒ Fixnum
Output only.
-
#deleted_entry_links ⇒ Fixnum
Output only.
-
#recreated_entries ⇒ Fixnum
Output only.
-
#unchanged_entries ⇒ Fixnum
Output only.
-
#unchanged_entry_links ⇒ Fixnum
Output only.
-
#update_time ⇒ String
Output only.
-
#updated_entries ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataJobImportJobResult
constructor
A new instance of GoogleCloudDataplexV1MetadataJobImportJobResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataJobImportJobResult
Returns a new instance of GoogleCloudDataplexV1MetadataJobImportJobResult.
7293 7294 7295 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7293 def initialize(**args) update!(**args) end |
Instance Attribute Details
#created_entries ⇒ Fixnum
Output only. The total number of entries that were created.
Corresponds to the JSON property createdEntries
7251 7252 7253 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7251 def created_entries @created_entries end |
#created_entry_links ⇒ Fixnum
Output only. The total number of entry links that were successfully created.
Corresponds to the JSON property createdEntryLinks
7256 7257 7258 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7256 def created_entry_links @created_entry_links end |
#deleted_entries ⇒ Fixnum
Output only. The total number of entries that were deleted.
Corresponds to the JSON property deletedEntries
7261 7262 7263 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7261 def deleted_entries @deleted_entries end |
#deleted_entry_links ⇒ Fixnum
Output only. The total number of entry links that were successfully deleted.
Corresponds to the JSON property deletedEntryLinks
7266 7267 7268 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7266 def deleted_entry_links @deleted_entry_links end |
#recreated_entries ⇒ Fixnum
Output only. The total number of entries that were recreated.
Corresponds to the JSON property recreatedEntries
7271 7272 7273 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7271 def recreated_entries @recreated_entries end |
#unchanged_entries ⇒ Fixnum
Output only. The total number of entries that were unchanged.
Corresponds to the JSON property unchangedEntries
7276 7277 7278 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7276 def unchanged_entries @unchanged_entries end |
#unchanged_entry_links ⇒ Fixnum
Output only. The total number of entry links that were left unchanged.
Corresponds to the JSON property unchangedEntryLinks
7281 7282 7283 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7281 def unchanged_entry_links @unchanged_entry_links end |
#update_time ⇒ String
Output only. The time when the status was updated.
Corresponds to the JSON property updateTime
7286 7287 7288 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7286 def update_time @update_time end |
#updated_entries ⇒ Fixnum
Output only. The total number of entries that were updated.
Corresponds to the JSON property updatedEntries
7291 7292 7293 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7291 def updated_entries @updated_entries end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7298 7299 7300 7301 7302 7303 7304 7305 7306 7307 7308 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7298 def update!(**args) @created_entries = args[:created_entries] if args.key?(:created_entries) @created_entry_links = args[:created_entry_links] if args.key?(:created_entry_links) @deleted_entries = args[:deleted_entries] if args.key?(:deleted_entries) @deleted_entry_links = args[:deleted_entry_links] if args.key?(:deleted_entry_links) @recreated_entries = args[:recreated_entries] if args.key?(:recreated_entries) @unchanged_entries = args[:unchanged_entries] if args.key?(:unchanged_entries) @unchanged_entry_links = args[:unchanged_entry_links] if args.key?(:unchanged_entry_links) @update_time = args[:update_time] if args.key?(:update_time) @updated_entries = args[:updated_entries] if args.key?(:updated_entries) end |