Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobImportJobSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Job specification for a metadata import job.You can run the following kinds of metadata import jobs: Full sync of entries with incremental import of their aspects. Supported for custom entries. Incremental import of aspects only. Supported for aspects that belong to custom entries and system entries. For custom entries, you can modify both optional aspects and required aspects. For system entries, you can modify optional aspects.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataJobImportJobSpec

Returns a new instance of GoogleCloudDataplexV1MetadataJobImportJobSpec.



7366
7367
7368
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7366

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aspect_sync_modeString

Required. The sync mode for aspects. Corresponds to the JSON property aspectSyncMode

Returns:

  • (String)


7323
7324
7325
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7323

def aspect_sync_mode
  @aspect_sync_mode
end

#entry_sync_modeString

Required. The sync mode for entries. Corresponds to the JSON property entrySyncMode

Returns:

  • (String)


7328
7329
7330
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7328

def entry_sync_mode
  @entry_sync_mode
end

#log_levelString

Optional. The level of logs to write to Cloud Logging for this job.Debug-level logs provide highly-detailed information for troubleshooting, but their increased verbosity could incur additional costs (https://cloud.google.com/ stackdriver/pricing) that might not be merited for all jobs.If unspecified, defaults to INFO. Corresponds to the JSON property logLevel

Returns:

  • (String)


7337
7338
7339
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7337

def log_level
  @log_level
end

#scopeGoogle::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobImportJobSpecImportJobScope

A boundary on the scope of impact that the metadata import job can have. Corresponds to the JSON property scope



7342
7343
7344
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7342

def scope
  @scope
end

#source_create_timeString

Optional. The time when the process that created the metadata import files began. Corresponds to the JSON property sourceCreateTime

Returns:

  • (String)


7348
7349
7350
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7348

def source_create_time
  @source_create_time
end

#source_storage_uriString

Optional. The URI of a Cloud Storage bucket or folder (beginning with gs:// and ending with /) that contains the metadata import files for this job.A metadata import file defines the values to set for each of the entries and aspects in a metadata import job. For more information about how to create a metadata import file and the file requirements, see Metadata import file ( https://cloud.google.com/dataplex/docs/import-metadata#metadata-import-file). You can provide multiple metadata import files in the same metadata job. The bucket or folder must contain at least one metadata import file, in JSON Lines format (either .json or .jsonl file extension).In FULL entry sync mode, don't save the metadata import file in a folder named SOURCE_STORAGE_URI/deletions/. Caution: If the metadata import file contains no data, all entries and aspects that belong to the job's scope are deleted. Corresponds to the JSON property sourceStorageUri

Returns:

  • (String)


7364
7365
7366
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7364

def source_storage_uri
  @source_storage_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7371
7372
7373
7374
7375
7376
7377
7378
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7371

def update!(**args)
  @aspect_sync_mode = args[:aspect_sync_mode] if args.key?(:aspect_sync_mode)
  @entry_sync_mode = args[:entry_sync_mode] if args.key?(:entry_sync_mode)
  @log_level = args[:log_level] if args.key?(:log_level)
  @scope = args[:scope] if args.key?(:scope)
  @source_create_time = args[:source_create_time] if args.key?(:source_create_time)
  @source_storage_uri = args[:source_storage_uri] if args.key?(:source_storage_uri)
end