Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobImportJobSpecImportJobScope

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

A boundary on the scope of impact that the metadata import job can have.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataJobImportJobSpecImportJobScope

Returns a new instance of GoogleCloudDataplexV1MetadataJobImportJobSpecImportJobScope.



9513
9514
9515
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9513

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aspect_typesArray<String>

Optional. The aspect types that are in scope for the import job, specified as relative resource names in the format projects/project_number_or_id/ locations/location_id/aspectTypes/aspect_type_id. The job modifies only the aspects that belong to these aspect types.This field is required when creating an aspect-only import job.If the metadata import file attempts to modify an aspect whose type isn't included in this list, the import job is halted before modifying any entries or aspects.The location of an aspect type must either match the location of the job, or the aspect type must be global. Corresponds to the JSON property aspectTypes

Returns:

  • (Array<String>)


9459
9460
9461
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9459

def aspect_types
  @aspect_types
end

#entry_groupsArray<String>

Required. The entry groups that are in scope for the import job, specified as relative resource names in the format projects/project_number_or_id/ locations/location_id/entryGroups/entry_group_id. Only entries and aspects that belong to the specified entry groups are affected by the job.The entry groups and the job must be in the same location. Corresponds to the JSON property entryGroups

Returns:

  • (Array<String>)


9468
9469
9470
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9468

def entry_groups
  @entry_groups
end

#entry_link_typesArray<String>

Optional. The entry link types that are in scope for the import job, specified as relative resource names in the format projects/project_number_or_id/ locations/location_id/entryLinkTypes/entry_link_type_id. The job modifies only the entryLinks that belong to these entry link types.If the metadata import file attempts to create or delete an entry link whose entry link type isn't included in this list, the import job will skip those entry links. Corresponds to the JSON property entryLinkTypes

Returns:

  • (Array<String>)


9478
9479
9480
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9478

def entry_link_types
  @entry_link_types
end

#entry_typesArray<String>

Required. The entry types that are in scope for the import job, specified as relative resource names in the format projects/project_number_or_id/ locations/location_id/entryTypes/entry_type_id. The job modifies only the entries and aspects that belong to these entry types.If the metadata import file attempts to modify an entry whose type isn't included in this list, the import job is halted before modifying any entries or aspects.The location of an entry type must either match the location of the job, or the entry type must be global. Corresponds to the JSON property entryTypes

Returns:

  • (Array<String>)


9490
9491
9492
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9490

def entry_types
  @entry_types
end

#glossariesArray<String>

Optional. The glossaries that are in scope for the import job, specified as relative resource names in the format projects/project_number_or_id/ locations/location_id/glossaries/glossary_id.While importing Business Glossary entries, the user must provide glossaries. While importing entries, the user does not have to provide glossaries. If the metadata import file attempts to modify Business Glossary entries whose glossary isn't included in this list, the import job will skip those entries.The location of a glossary must either match the location of the job, or the glossary must be global. Corresponds to the JSON property glossaries

Returns:

  • (Array<String>)


9502
9503
9504
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9502

def glossaries
  @glossaries
end

#referenced_entry_scopesArray<String>

Optional. Defines the scope of entries that can be referenced in the entry links.Currently, projects are supported as valid scopes. Format: projects/ project_number_or_idIf the metadata import file attempts to create an entry link which references an entry that is not in the scope, the import job will skip that entry link. Corresponds to the JSON property referencedEntryScopes

Returns:

  • (Array<String>)


9511
9512
9513
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9511

def referenced_entry_scopes
  @referenced_entry_scopes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9518
9519
9520
9521
9522
9523
9524
9525
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9518

def update!(**args)
  @aspect_types = args[:aspect_types] if args.key?(:aspect_types)
  @entry_groups = args[:entry_groups] if args.key?(:entry_groups)
  @entry_link_types = args[:entry_link_types] if args.key?(:entry_link_types)
  @entry_types = args[:entry_types] if args.key?(:entry_types)
  @glossaries = args[:glossaries] if args.key?(:glossaries)
  @referenced_entry_scopes = args[:referenced_entry_scopes] if args.key?(:referenced_entry_scopes)
end