Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobImportJobSpecImportJobScope
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1MetadataJobImportJobSpecImportJobScope
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
A boundary on the scope of impact that the metadata import job can have.
Instance Attribute Summary collapse
-
#aspect_types ⇒ Array<String>
Optional.
-
#entry_groups ⇒ Array<String>
Required.
-
#entry_link_types ⇒ Array<String>
Optional.
-
#entry_types ⇒ Array<String>
Required.
-
#glossaries ⇒ Array<String>
Optional.
-
#referenced_entry_scopes ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataJobImportJobSpecImportJobScope
constructor
A new instance of GoogleCloudDataplexV1MetadataJobImportJobSpecImportJobScope.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1MetadataJobImportJobSpecImportJobScope
Returns a new instance of GoogleCloudDataplexV1MetadataJobImportJobSpecImportJobScope.
9520 9521 9522 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9520 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aspect_types ⇒ Array<String>
Optional. The aspect types that are in scope for the import job, specified as
relative resource names in the format projects/project_number_or_id/
locations/location_id/aspectTypes/aspect_type_id. The job modifies only
the aspects that belong to these aspect types.This field is required when
creating an aspect-only import job.If the metadata import file attempts to
modify an aspect whose type isn't included in this list, the import job is
halted before modifying any entries or aspects.The location of an aspect type
must either match the location of the job, or the aspect type must be global.
Corresponds to the JSON property aspectTypes
9466 9467 9468 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9466 def aspect_types @aspect_types end |
#entry_groups ⇒ Array<String>
Required. The entry groups that are in scope for the import job, specified as
relative resource names in the format projects/project_number_or_id/
locations/location_id/entryGroups/entry_group_id. Only entries and aspects
that belong to the specified entry groups are affected by the job.The entry
groups and the job must be in the same location.
Corresponds to the JSON property entryGroups
9475 9476 9477 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9475 def entry_groups @entry_groups end |
#entry_link_types ⇒ Array<String>
Optional. The entry link types that are in scope for the import job, specified
as relative resource names in the format projects/project_number_or_id/
locations/location_id/entryLinkTypes/entry_link_type_id. The job modifies
only the entryLinks that belong to these entry link types.If the metadata
import file attempts to create or delete an entry link whose entry link type
isn't included in this list, the import job will skip those entry links.
Corresponds to the JSON property entryLinkTypes
9485 9486 9487 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9485 def entry_link_types @entry_link_types end |
#entry_types ⇒ Array<String>
Required. The entry types that are in scope for the import job, specified as
relative resource names in the format projects/project_number_or_id/
locations/location_id/entryTypes/entry_type_id. The job modifies only the
entries and aspects that belong to these entry types.If the metadata import
file attempts to modify an entry whose type isn't included in this list, the
import job is halted before modifying any entries or aspects.The location of
an entry type must either match the location of the job, or the entry type
must be global.
Corresponds to the JSON property entryTypes
9497 9498 9499 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9497 def entry_types @entry_types end |
#glossaries ⇒ Array<String>
Optional. The glossaries that are in scope for the import job, specified as
relative resource names in the format projects/project_number_or_id/
locations/location_id/glossaries/glossary_id.While importing Business
Glossary entries, the user must provide glossaries. While importing entries,
the user does not have to provide glossaries. If the metadata import file
attempts to modify Business Glossary entries whose glossary isn't included in
this list, the import job will skip those entries.The location of a glossary
must either match the location of the job, or the glossary must be global.
Corresponds to the JSON property glossaries
9509 9510 9511 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9509 def glossaries @glossaries end |
#referenced_entry_scopes ⇒ Array<String>
Optional. Defines the scope of entries that can be referenced in the entry
links.Currently, projects are supported as valid scopes. Format: projects/
project_number_or_idIf the metadata import file attempts to create an entry
link which references an entry that is not in the scope, the import job will
skip that entry link.
Corresponds to the JSON property referencedEntryScopes
9518 9519 9520 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9518 def referenced_entry_scopes @referenced_entry_scopes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9525 9526 9527 9528 9529 9530 9531 9532 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9525 def update!(**args) @aspect_types = args[:aspect_types] if args.key?(:aspect_types) @entry_groups = args[:entry_groups] if args.key?(:entry_groups) @entry_link_types = args[:entry_link_types] if args.key?(:entry_link_types) @entry_types = args[:entry_types] if args.key?(:entry_types) @glossaries = args[:glossaries] if args.key?(:glossaries) @referenced_entry_scopes = args[:referenced_entry_scopes] if args.key?(:referenced_entry_scopes) end |