Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1ModifyEntryRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Modify Entry request using permissions in the source system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1ModifyEntryRequest

Returns a new instance of GoogleCloudDataplexV1ModifyEntryRequest.



9609
9610
9611
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9609

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aspect_keysArray<String>

Optional. The aspect keys which the service should modify. It supports the following syntaxes: - matches an aspect of the given type and empty path. @ path - matches an aspect of the given type and specified path. For example, to attach an aspect to a field that is specified by the schema aspect, the path should have the format Schema.. @* - matches aspects of the given type for all paths. *@path - matches aspects of all types on the given path.The service will not remove existing aspects matching the syntax unless delete_missing_aspects is set to true.If this field is left empty, the service treats it as specifying exactly those Aspects present in the request. Corresponds to the JSON property aspectKeys

Returns:

  • (Array<String>)


9587
9588
9589
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9587

def aspect_keys
  @aspect_keys
end

#delete_missing_aspectsBoolean Also known as: delete_missing_aspects?

Optional. If set to true, any aspects not specified in the request will be deleted. The default is false. Corresponds to the JSON property deleteMissingAspects

Returns:

  • (Boolean)


9593
9594
9595
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9593

def delete_missing_aspects
  @delete_missing_aspects
end

#entryGoogle::Apis::DataplexV1::GoogleCloudDataplexV1Entry

An entry is a representation of a data resource that can be described by various metadata. Corresponds to the JSON property entry



9600
9601
9602
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9600

def entry
  @entry
end

#update_maskString

Optional. Mask of fields to update. To update Aspects, the update_mask must contain the value "aspects".If the update_mask is empty, the service will update all modifiable fields present in the request. Corresponds to the JSON property updateMask

Returns:

  • (String)


9607
9608
9609
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9607

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9614
9615
9616
9617
9618
9619
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9614

def update!(**args)
  @aspect_keys = args[:aspect_keys] if args.key?(:aspect_keys)
  @delete_missing_aspects = args[:delete_missing_aspects] if args.key?(:delete_missing_aspects)
  @entry = args[:entry] if args.key?(:entry)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end