Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1ResourceAccessSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

ResourceAccessSpec holds the access control configuration to be enforced on the resources, for example, Cloud Storage bucket, BigQuery dataset, BigQuery table.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1ResourceAccessSpec

Returns a new instance of GoogleCloudDataplexV1ResourceAccessSpec.



9819
9820
9821
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9819

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ownersArray<String>

Optional. The set of principals to be granted owner role on the resource. Corresponds to the JSON property owners

Returns:

  • (Array<String>)


9805
9806
9807
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9805

def owners
  @owners
end

#readersArray<String>

Optional. The format of strings follows the pattern followed by IAM in the bindings. user:email, serviceAccount:email group:email. The set of principals to be granted reader role on the resource. Corresponds to the JSON property readers

Returns:

  • (Array<String>)


9812
9813
9814
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9812

def readers
  @readers
end

#writersArray<String>

Optional. The set of principals to be granted writer role on the resource. Corresponds to the JSON property writers

Returns:

  • (Array<String>)


9817
9818
9819
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9817

def writers
  @writers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9824
9825
9826
9827
9828
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9824

def update!(**args)
  @owners = args[:owners] if args.key?(:owners)
  @readers = args[:readers] if args.key?(:readers)
  @writers = args[:writers] if args.key?(:writers)
end