Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1ResourceAccessSpec
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1ResourceAccessSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
ResourceAccessSpec holds the access control configuration to be enforced on the resources, for example, Cloud Storage bucket, BigQuery dataset, BigQuery table.
Instance Attribute Summary collapse
-
#owners ⇒ Array<String>
Optional.
-
#readers ⇒ Array<String>
Optional.
-
#writers ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1ResourceAccessSpec
constructor
A new instance of GoogleCloudDataplexV1ResourceAccessSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1ResourceAccessSpec
Returns a new instance of GoogleCloudDataplexV1ResourceAccessSpec.
9574 9575 9576 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9574 def initialize(**args) update!(**args) end |
Instance Attribute Details
#owners ⇒ Array<String>
Optional. The set of principals to be granted owner role on the resource.
Corresponds to the JSON property owners
9560 9561 9562 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9560 def owners @owners end |
#readers ⇒ Array<String>
Optional. The format of strings follows the pattern followed by IAM in the
bindings. user:email, serviceAccount:email group:email. The set of
principals to be granted reader role on the resource.
Corresponds to the JSON property readers
9567 9568 9569 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9567 def readers @readers end |
#writers ⇒ Array<String>
Optional. The set of principals to be granted writer role on the resource.
Corresponds to the JSON property writers
9572 9573 9574 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9572 def writers @writers end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9579 9580 9581 9582 9583 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9579 def update!(**args) @owners = args[:owners] if args.key?(:owners) @readers = args[:readers] if args.key?(:readers) @writers = args[:writers] if args.key?(:writers) end |