Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1ResourceAccessSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

ResourceAccessSpec holds the access control configuration to be enforced on the resources, for example, Cloud Storage bucket, BigQuery dataset, BigQuery table.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1ResourceAccessSpec

Returns a new instance of GoogleCloudDataplexV1ResourceAccessSpec.



7626
7627
7628
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7626

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ownersArray<String>

Optional. The set of principals to be granted owner role on the resource. Corresponds to the JSON property owners

Returns:

  • (Array<String>)


7612
7613
7614
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7612

def owners
  @owners
end

#readersArray<String>

Optional. The format of strings follows the pattern followed by IAM in the bindings. user:email, serviceAccount:email group:email. The set of principals to be granted reader role on the resource. Corresponds to the JSON property readers

Returns:

  • (Array<String>)


7619
7620
7621
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7619

def readers
  @readers
end

#writersArray<String>

Optional. The set of principals to be granted writer role on the resource. Corresponds to the JSON property writers

Returns:

  • (Array<String>)


7624
7625
7626
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7624

def writers
  @writers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7631
7632
7633
7634
7635
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7631

def update!(**args)
  @owners = args[:owners] if args.key?(:owners)
  @readers = args[:readers] if args.key?(:readers)
  @writers = args[:writers] if args.key?(:writers)
end