Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1RunTaskRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1RunTaskRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Instance Attribute Summary collapse
-
#args ⇒ Hash<String,String>
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1RunTaskRequest
constructor
A new instance of GoogleCloudDataplexV1RunTaskRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1RunTaskRequest
Returns a new instance of GoogleCloudDataplexV1RunTaskRequest.
9889 9890 9891 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9889 def initialize(**args) update!(**args) end |
Instance Attribute Details
#args ⇒ Hash<String,String>
Optional. Execution spec arguments. If the map is left empty, the task will
run with existing execution spec args from task definition. If the map
contains an entry with a new key, the same will be added to existing set of
args. If the map contains an entry with an existing arg key in task definition,
the task will run with new arg value for that entry. Clearing an existing arg
will require arg value to be explicitly set to a hyphen "-". The arg value
cannot be empty.
Corresponds to the JSON property args
9876 9877 9878 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9876 def args @args end |
#labels ⇒ Hash<String,String>
Optional. User-defined labels for the task. If the map is left empty, the task
will run with existing labels from task definition. If the map contains an
entry with a new key, the same will be added to existing set of labels. If the
map contains an entry with an existing label key in task definition, the task
will run with new label value for that entry. Clearing an existing label will
require label value to be explicitly set to a hyphen "-". The label value
cannot be empty.
Corresponds to the JSON property labels
9887 9888 9889 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9887 def labels @labels end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9894 9895 9896 9897 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9894 def update!(**args) @args = args[:args] if args.key?(:args) @labels = args[:labels] if args.key?(:labels) end |