Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1ScannedDataIncrementalField

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

A data range denoted by a pair of start/end values of a field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1ScannedDataIncrementalField

Returns a new instance of GoogleCloudDataplexV1ScannedDataIncrementalField.



9958
9959
9960
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9958

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endString

Output only. Value that marks the end of the range. Corresponds to the JSON property end

Returns:

  • (String)


9945
9946
9947
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9945

def end
  @end
end

#fieldString

Output only. The field that contains values which monotonically increases over time (e.g. a timestamp column). Corresponds to the JSON property field

Returns:

  • (String)


9951
9952
9953
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9951

def field
  @field
end

#startString

Output only. Value that marks the start of the range. Corresponds to the JSON property start

Returns:

  • (String)


9956
9957
9958
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9956

def start
  @start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9963
9964
9965
9966
9967
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9963

def update!(**args)
  @end = args[:end] if args.key?(:end)
  @field = args[:field] if args.key?(:field)
  @start = args[:start] if args.key?(:start)
end