Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1ScannedDataIncrementalField
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1ScannedDataIncrementalField
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
A data range denoted by a pair of start/end values of a field.
Instance Attribute Summary collapse
-
#end ⇒ String
Output only.
-
#field ⇒ String
Output only.
-
#start ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1ScannedDataIncrementalField
constructor
A new instance of GoogleCloudDataplexV1ScannedDataIncrementalField.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1ScannedDataIncrementalField
Returns a new instance of GoogleCloudDataplexV1ScannedDataIncrementalField.
9713 9714 9715 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9713 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end ⇒ String
Output only. Value that marks the end of the range.
Corresponds to the JSON property end
9700 9701 9702 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9700 def end @end end |
#field ⇒ String
Output only. The field that contains values which monotonically increases over
time (e.g. a timestamp column).
Corresponds to the JSON property field
9706 9707 9708 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9706 def field @field end |
#start ⇒ String
Output only. Value that marks the start of the range.
Corresponds to the JSON property start
9711 9712 9713 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9711 def start @start end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9718 9719 9720 9721 9722 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9718 def update!(**args) @end = args[:end] if args.key?(:end) @field = args[:field] if args.key?(:field) @start = args[:start] if args.key?(:start) end |