Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1ScannedDataIncrementalField

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

A data range denoted by a pair of start/end values of a field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1ScannedDataIncrementalField

Returns a new instance of GoogleCloudDataplexV1ScannedDataIncrementalField.



7765
7766
7767
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7765

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endString

Output only. Value that marks the end of the range. Corresponds to the JSON property end

Returns:

  • (String)


7752
7753
7754
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7752

def end
  @end
end

#fieldString

Output only. The field that contains values which monotonically increases over time (e.g. a timestamp column). Corresponds to the JSON property field

Returns:

  • (String)


7758
7759
7760
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7758

def field
  @field
end

#startString

Output only. Value that marks the start of the range. Corresponds to the JSON property start

Returns:

  • (String)


7763
7764
7765
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7763

def start
  @start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7770
7771
7772
7773
7774
# File 'lib/google/apis/dataplex_v1/classes.rb', line 7770

def update!(**args)
  @end = args[:end] if args.key?(:end)
  @field = args[:field] if args.key?(:field)
  @start = args[:start] if args.key?(:start)
end