Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1Schema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Schema information describing the structure and layout of the data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1Schema

Returns a new instance of GoogleCloudDataplexV1Schema.



10006
10007
10008
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10006

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fieldsArray<Google::Apis::DataplexV1::GoogleCloudDataplexV1SchemaSchemaField>

Optional. The sequence of fields describing data in table entities. Note: BigQuery SchemaFields are immutable. Corresponds to the JSON property fields



9978
9979
9980
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9978

def fields
  @fields
end

#partition_fieldsArray<Google::Apis::DataplexV1::GoogleCloudDataplexV1SchemaPartitionField>

Optional. The sequence of fields describing the partition structure in entities. If this field is empty, there are no partitions within the data. Corresponds to the JSON property partitionFields



9984
9985
9986
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9984

def partition_fields
  @partition_fields
end

#partition_styleString

Optional. The structure of paths containing partition data within the entity. Corresponds to the JSON property partitionStyle

Returns:

  • (String)


9989
9990
9991
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9989

def partition_style
  @partition_style
end

#user_managedBoolean Also known as: user_managed?

Required. Set to true if user-managed or false if managed by Dataplex Universal Catalog. The default is false (managed by Dataplex Universal Catalog) . Set to falseto enable Dataplex Universal Catalog discovery to update the schema. including new data discovery, schema inference, and schema evolution. Users retain the ability to input and edit the schema. Dataplex Universal Catalog treats schema input by the user as though produced by a previous Dataplex Universal Catalog discovery operation, and it will evolve the schema and take action based on that treatment. Set to true to fully manage the entity schema. This setting guarantees that Dataplex Universal Catalog will not change schema fields. Corresponds to the JSON property userManaged

Returns:

  • (Boolean)


10003
10004
10005
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10003

def user_managed
  @user_managed
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10011
10012
10013
10014
10015
10016
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10011

def update!(**args)
  @fields = args[:fields] if args.key?(:fields)
  @partition_fields = args[:partition_fields] if args.key?(:partition_fields)
  @partition_style = args[:partition_style] if args.key?(:partition_style)
  @user_managed = args[:user_managed] if args.key?(:user_managed)
end