Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1Schema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Schema information describing the structure and layout of the data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1Schema

Returns a new instance of GoogleCloudDataplexV1Schema.



9761
9762
9763
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9761

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fieldsArray<Google::Apis::DataplexV1::GoogleCloudDataplexV1SchemaSchemaField>

Optional. The sequence of fields describing data in table entities. Note: BigQuery SchemaFields are immutable. Corresponds to the JSON property fields



9733
9734
9735
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9733

def fields
  @fields
end

#partition_fieldsArray<Google::Apis::DataplexV1::GoogleCloudDataplexV1SchemaPartitionField>

Optional. The sequence of fields describing the partition structure in entities. If this field is empty, there are no partitions within the data. Corresponds to the JSON property partitionFields



9739
9740
9741
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9739

def partition_fields
  @partition_fields
end

#partition_styleString

Optional. The structure of paths containing partition data within the entity. Corresponds to the JSON property partitionStyle

Returns:

  • (String)


9744
9745
9746
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9744

def partition_style
  @partition_style
end

#user_managedBoolean Also known as: user_managed?

Required. Set to true if user-managed or false if managed by Dataplex Universal Catalog. The default is false (managed by Dataplex Universal Catalog) . Set to falseto enable Dataplex Universal Catalog discovery to update the schema. including new data discovery, schema inference, and schema evolution. Users retain the ability to input and edit the schema. Dataplex Universal Catalog treats schema input by the user as though produced by a previous Dataplex Universal Catalog discovery operation, and it will evolve the schema and take action based on that treatment. Set to true to fully manage the entity schema. This setting guarantees that Dataplex Universal Catalog will not change schema fields. Corresponds to the JSON property userManaged

Returns:

  • (Boolean)


9758
9759
9760
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9758

def user_managed
  @user_managed
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9766
9767
9768
9769
9770
9771
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9766

def update!(**args)
  @fields = args[:fields] if args.key?(:fields)
  @partition_fields = args[:partition_fields] if args.key?(:partition_fields)
  @partition_style = args[:partition_style] if args.key?(:partition_style)
  @user_managed = args[:user_managed] if args.key?(:user_managed)
end