Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1SchemaSchemaField

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Represents a column field within a table schema.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1SchemaSchemaField

Returns a new instance of GoogleCloudDataplexV1SchemaSchemaField.



9835
9836
9837
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9835

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. User friendly field description. Must be less than or equal to 1024 characters. Corresponds to the JSON property description

Returns:

  • (String)


9811
9812
9813
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9811

def description
  @description
end

#fieldsArray<Google::Apis::DataplexV1::GoogleCloudDataplexV1SchemaSchemaField>

Optional. Any nested field for complex types. Corresponds to the JSON property fields



9816
9817
9818
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9816

def fields
  @fields
end

#modeString

Required. Additional field semantics. Corresponds to the JSON property mode

Returns:

  • (String)


9821
9822
9823
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9821

def mode
  @mode
end

#nameString

Required. The name of the field. Must contain only letters, numbers and underscores, with a maximum length of 767 characters, and must begin with a letter or underscore. Corresponds to the JSON property name

Returns:

  • (String)


9828
9829
9830
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9828

def name
  @name
end

#typeString

Required. The type of field. Corresponds to the JSON property type

Returns:

  • (String)


9833
9834
9835
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9833

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9840
9841
9842
9843
9844
9845
9846
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9840

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @fields = args[:fields] if args.key?(:fields)
  @mode = args[:mode] if args.key?(:mode)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end