Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1SessionEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

These messages contain information about sessions within an environment. The monitored resource is 'Environment'.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1SessionEvent

Returns a new instance of GoogleCloudDataplexV1SessionEvent.



8083
8084
8085
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8083

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#event_succeededBoolean Also known as: event_succeeded?

The status of the event. Corresponds to the JSON property eventSucceeded

Returns:

  • (Boolean)


8042
8043
8044
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8042

def event_succeeded
  @event_succeeded
end

#fast_startup_enabledBoolean Also known as: fast_startup_enabled?

If the session is associated with an environment with fast startup enabled, and was created before being assigned to a user. Corresponds to the JSON property fastStartupEnabled

Returns:

  • (Boolean)


8049
8050
8051
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8049

def fast_startup_enabled
  @fast_startup_enabled
end

#messageString

The log message. Corresponds to the JSON property message

Returns:

  • (String)


8055
8056
8057
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8055

def message
  @message
end

#queryGoogle::Apis::DataplexV1::GoogleCloudDataplexV1SessionEventQueryDetail

Execution details of the query. Corresponds to the JSON property query



8060
8061
8062
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8060

def query
  @query
end

#session_idString

Unique identifier for the session. Corresponds to the JSON property sessionId

Returns:

  • (String)


8065
8066
8067
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8065

def session_id
  @session_id
end

#typeString

The type of the event. Corresponds to the JSON property type

Returns:

  • (String)


8070
8071
8072
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8070

def type
  @type
end

#unassigned_durationString

The idle duration of a warm pooled session before it is assigned to user. Corresponds to the JSON property unassignedDuration

Returns:

  • (String)


8075
8076
8077
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8075

def unassigned_duration
  @unassigned_duration
end

#user_idString

The information about the user that created the session. It will be the email address of the user. Corresponds to the JSON property userId

Returns:

  • (String)


8081
8082
8083
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8081

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8088
8089
8090
8091
8092
8093
8094
8095
8096
8097
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8088

def update!(**args)
  @event_succeeded = args[:event_succeeded] if args.key?(:event_succeeded)
  @fast_startup_enabled = args[:fast_startup_enabled] if args.key?(:fast_startup_enabled)
  @message = args[:message] if args.key?(:message)
  @query = args[:query] if args.key?(:query)
  @session_id = args[:session_id] if args.key?(:session_id)
  @type = args[:type] if args.key?(:type)
  @unassigned_duration = args[:unassigned_duration] if args.key?(:unassigned_duration)
  @user_id = args[:user_id] if args.key?(:user_id)
end