Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1StorageFormat
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1StorageFormat
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Describes the format of the data within its storage location.
Instance Attribute Summary collapse
-
#compression_format ⇒ String
Optional.
-
#csv ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1StorageFormatCsvOptions
Describes CSV and similar semi-structured data formats.
-
#format ⇒ String
Output only.
-
#iceberg ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1StorageFormatIcebergOptions
Describes Iceberg data format.
-
#json ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1StorageFormatJsonOptions
Describes JSON data format.
-
#mime_type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1StorageFormat
constructor
A new instance of GoogleCloudDataplexV1StorageFormat.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1StorageFormat
Returns a new instance of GoogleCloudDataplexV1StorageFormat.
10357 10358 10359 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10357 def initialize(**args) update!(**args) end |
Instance Attribute Details
#compression_format ⇒ String
Optional. The compression type associated with the stored data. If unspecified,
the data is uncompressed.
Corresponds to the JSON property compressionFormat
10324 10325 10326 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10324 def compression_format @compression_format end |
#csv ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1StorageFormatCsvOptions
Describes CSV and similar semi-structured data formats.
Corresponds to the JSON property csv
10329 10330 10331 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10329 def csv @csv end |
#format ⇒ String
Output only. The data format associated with the stored data, which represents
content type values. The value is inferred from mime type.
Corresponds to the JSON property format
10335 10336 10337 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10335 def format @format end |
#iceberg ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1StorageFormatIcebergOptions
Describes Iceberg data format.
Corresponds to the JSON property iceberg
10340 10341 10342 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10340 def iceberg @iceberg end |
#json ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1StorageFormatJsonOptions
Describes JSON data format.
Corresponds to the JSON property json
10345 10346 10347 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10345 def json @json end |
#mime_type ⇒ String
Required. The mime type descriptor for the data. Must match the pattern type/
subtype. Supported values: application/x-parquet application/x-avro
application/x-orc application/x-tfrecord application/x-parquet+iceberg
application/x-avro+iceberg application/x-orc+iceberg application/json
application/subtypes text/csv text/ image/image subtype video/video
subtype audio/audio subtype
Corresponds to the JSON property mimeType
10355 10356 10357 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10355 def mime_type @mime_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10362 10363 10364 10365 10366 10367 10368 10369 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10362 def update!(**args) @compression_format = args[:compression_format] if args.key?(:compression_format) @csv = args[:csv] if args.key?(:csv) @format = args[:format] if args.key?(:format) @iceberg = args[:iceberg] if args.key?(:iceberg) @json = args[:json] if args.key?(:json) @mime_type = args[:mime_type] if args.key?(:mime_type) end |