Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1StorageFormatCsvOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Describes CSV and similar semi-structured data formats.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1StorageFormatCsvOptions

Returns a new instance of GoogleCloudDataplexV1StorageFormatCsvOptions.



10407
10408
10409
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10407

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#delimiterString

Optional. The delimiter used to separate values. Defaults to ','. Corresponds to the JSON property delimiter

Returns:

  • (String)


10386
10387
10388
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10386

def delimiter
  @delimiter
end

#encodingString

Optional. The character encoding of the data. Accepts "US-ASCII", "UTF-8", and "ISO-8859-1". Defaults to UTF-8 if unspecified. Corresponds to the JSON property encoding

Returns:

  • (String)


10392
10393
10394
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10392

def encoding
  @encoding
end

#header_rowsFixnum

Optional. The number of rows to interpret as header rows that should be skipped when reading data rows. Defaults to 0. Corresponds to the JSON property headerRows

Returns:

  • (Fixnum)


10398
10399
10400
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10398

def header_rows
  @header_rows
end

#quoteString

Optional. The character used to quote column values. Accepts '"' (double quotation mark) or ''' (single quotation mark). Defaults to '"' (double quotation mark) if unspecified. Corresponds to the JSON property quote

Returns:

  • (String)


10405
10406
10407
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10405

def quote
  @quote
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10412
10413
10414
10415
10416
10417
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10412

def update!(**args)
  @delimiter = args[:delimiter] if args.key?(:delimiter)
  @encoding = args[:encoding] if args.key?(:encoding)
  @header_rows = args[:header_rows] if args.key?(:header_rows)
  @quote = args[:quote] if args.key?(:quote)
end