Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1StorageFormatCsvOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Describes CSV and similar semi-structured data formats.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1StorageFormatCsvOptions

Returns a new instance of GoogleCloudDataplexV1StorageFormatCsvOptions.



10162
10163
10164
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10162

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#delimiterString

Optional. The delimiter used to separate values. Defaults to ','. Corresponds to the JSON property delimiter

Returns:

  • (String)


10141
10142
10143
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10141

def delimiter
  @delimiter
end

#encodingString

Optional. The character encoding of the data. Accepts "US-ASCII", "UTF-8", and "ISO-8859-1". Defaults to UTF-8 if unspecified. Corresponds to the JSON property encoding

Returns:

  • (String)


10147
10148
10149
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10147

def encoding
  @encoding
end

#header_rowsFixnum

Optional. The number of rows to interpret as header rows that should be skipped when reading data rows. Defaults to 0. Corresponds to the JSON property headerRows

Returns:

  • (Fixnum)


10153
10154
10155
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10153

def header_rows
  @header_rows
end

#quoteString

Optional. The character used to quote column values. Accepts '"' (double quotation mark) or ''' (single quotation mark). Defaults to '"' (double quotation mark) if unspecified. Corresponds to the JSON property quote

Returns:

  • (String)


10160
10161
10162
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10160

def quote
  @quote
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10167
10168
10169
10170
10171
10172
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10167

def update!(**args)
  @delimiter = args[:delimiter] if args.key?(:delimiter)
  @encoding = args[:encoding] if args.key?(:encoding)
  @header_rows = args[:header_rows] if args.key?(:header_rows)
  @quote = args[:quote] if args.key?(:quote)
end