Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1StorageFormatCsvOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Describes CSV and similar semi-structured data formats.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1StorageFormatCsvOptions

Returns a new instance of GoogleCloudDataplexV1StorageFormatCsvOptions.



8253
8254
8255
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8253

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#delimiterString

Optional. The delimiter used to separate values. Defaults to ','. Corresponds to the JSON property delimiter

Returns:

  • (String)


8232
8233
8234
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8232

def delimiter
  @delimiter
end

#encodingString

Optional. The character encoding of the data. Accepts "US-ASCII", "UTF-8", and "ISO-8859-1". Defaults to UTF-8 if unspecified. Corresponds to the JSON property encoding

Returns:

  • (String)


8238
8239
8240
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8238

def encoding
  @encoding
end

#header_rowsFixnum

Optional. The number of rows to interpret as header rows that should be skipped when reading data rows. Defaults to 0. Corresponds to the JSON property headerRows

Returns:

  • (Fixnum)


8244
8245
8246
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8244

def header_rows
  @header_rows
end

#quoteString

Optional. The character used to quote column values. Accepts '"' (double quotation mark) or ''' (single quotation mark). Defaults to '"' (double quotation mark) if unspecified. Corresponds to the JSON property quote

Returns:

  • (String)


8251
8252
8253
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8251

def quote
  @quote
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8258
8259
8260
8261
8262
8263
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8258

def update!(**args)
  @delimiter = args[:delimiter] if args.key?(:delimiter)
  @encoding = args[:encoding] if args.key?(:encoding)
  @header_rows = args[:header_rows] if args.key?(:header_rows)
  @quote = args[:quote] if args.key?(:quote)
end