Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1Task

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

A task represents a user-visible job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1Task

Returns a new instance of GoogleCloudDataplexV1Task.



8377
8378
8379
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8377

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time when the task was created. Corresponds to the JSON property createTime

Returns:

  • (String)


8313
8314
8315
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8313

def create_time
  @create_time
end

#descriptionString

Optional. Description of the task. Corresponds to the JSON property description

Returns:

  • (String)


8318
8319
8320
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8318

def description
  @description
end

#display_nameString

Optional. User friendly display name. Corresponds to the JSON property displayName

Returns:

  • (String)


8323
8324
8325
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8323

def display_name
  @display_name
end

#execution_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1TaskExecutionSpec

Execution related settings, like retry and service_account. Corresponds to the JSON property executionSpec



8328
8329
8330
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8328

def execution_spec
  @execution_spec
end

#execution_statusGoogle::Apis::DataplexV1::GoogleCloudDataplexV1TaskExecutionStatus

Status of the task execution (e.g. Jobs). Corresponds to the JSON property executionStatus



8333
8334
8335
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8333

def execution_status
  @execution_status
end

#labelsHash<String,String>

Optional. User-defined labels for the task. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


8338
8339
8340
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8338

def labels
  @labels
end

#nameString

Output only. The relative resource name of the task, of the form: projects/ project_number/locations/location_id/lakes/lake_id/ tasks/task_id. Corresponds to the JSON property name

Returns:

  • (String)


8344
8345
8346
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8344

def name
  @name
end

#notebookGoogle::Apis::DataplexV1::GoogleCloudDataplexV1TaskNotebookTaskConfig

Config for running scheduled notebooks. Corresponds to the JSON property notebook



8349
8350
8351
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8349

def notebook
  @notebook
end

#sparkGoogle::Apis::DataplexV1::GoogleCloudDataplexV1TaskSparkTaskConfig

User-specified config for running a Spark task. Corresponds to the JSON property spark



8354
8355
8356
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8354

def spark
  @spark
end

#stateString

Output only. Current state of the task. Corresponds to the JSON property state

Returns:

  • (String)


8359
8360
8361
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8359

def state
  @state
end

#trigger_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1TaskTriggerSpec

Task scheduling and trigger settings. Corresponds to the JSON property triggerSpec



8364
8365
8366
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8364

def trigger_spec
  @trigger_spec
end

#uidString

Output only. System generated globally unique ID for the task. This ID will be different if the task is deleted and re-created with the same name. Corresponds to the JSON property uid

Returns:

  • (String)


8370
8371
8372
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8370

def uid
  @uid
end

#update_timeString

Output only. The time when the task was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


8375
8376
8377
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8375

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8382
8383
8384
8385
8386
8387
8388
8389
8390
8391
8392
8393
8394
8395
8396
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8382

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @execution_spec = args[:execution_spec] if args.key?(:execution_spec)
  @execution_status = args[:execution_status] if args.key?(:execution_status)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @notebook = args[:notebook] if args.key?(:notebook)
  @spark = args[:spark] if args.key?(:spark)
  @state = args[:state] if args.key?(:state)
  @trigger_spec = args[:trigger_spec] if args.key?(:trigger_spec)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end