Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1TaskInfrastructureSpecVpcNetwork
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1TaskInfrastructureSpecVpcNetwork
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Cloud VPC Network used to run the infrastructure.
Instance Attribute Summary collapse
-
#network ⇒ String
Optional.
-
#network_tags ⇒ Array<String>
Optional.
-
#sub_network ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1TaskInfrastructureSpecVpcNetwork
constructor
A new instance of GoogleCloudDataplexV1TaskInfrastructureSpecVpcNetwork.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1TaskInfrastructureSpecVpcNetwork
Returns a new instance of GoogleCloudDataplexV1TaskInfrastructureSpecVpcNetwork.
10757 10758 10759 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10757 def initialize(**args) update!(**args) end |
Instance Attribute Details
#network ⇒ String
Optional. The Cloud VPC network in which the job is run. By default, the Cloud
VPC network named Default within the project is used.
Corresponds to the JSON property network
10745 10746 10747 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10745 def network @network end |
#network_tags ⇒ Array<String>
Optional. List of network tags to apply to the job.
Corresponds to the JSON property networkTags
10750 10751 10752 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10750 def @network_tags end |
#sub_network ⇒ String
Optional. The Cloud VPC sub-network in which the job is run.
Corresponds to the JSON property subNetwork
10755 10756 10757 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10755 def sub_network @sub_network end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10762 10763 10764 10765 10766 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10762 def update!(**args) @network = args[:network] if args.key?(:network) @network_tags = args[:network_tags] if args.key?(:network_tags) @sub_network = args[:sub_network] if args.key?(:sub_network) end |