Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1TaskInfrastructureSpecVpcNetwork

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Cloud VPC Network used to run the infrastructure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1TaskInfrastructureSpecVpcNetwork

Returns a new instance of GoogleCloudDataplexV1TaskInfrastructureSpecVpcNetwork.



8603
8604
8605
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8603

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#networkString

Optional. The Cloud VPC network in which the job is run. By default, the Cloud VPC network named Default within the project is used. Corresponds to the JSON property network

Returns:

  • (String)


8591
8592
8593
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8591

def network
  @network
end

#network_tagsArray<String>

Optional. List of network tags to apply to the job. Corresponds to the JSON property networkTags

Returns:

  • (Array<String>)


8596
8597
8598
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8596

def network_tags
  @network_tags
end

#sub_networkString

Optional. The Cloud VPC sub-network in which the job is run. Corresponds to the JSON property subNetwork

Returns:

  • (String)


8601
8602
8603
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8601

def sub_network
  @sub_network
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8608
8609
8610
8611
8612
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8608

def update!(**args)
  @network = args[:network] if args.key?(:network)
  @network_tags = args[:network_tags] if args.key?(:network_tags)
  @sub_network = args[:sub_network] if args.key?(:sub_network)
end