Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1UnstructuredDataProfileSpec
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1UnstructuredDataProfileSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Contains the specification for an unstructured data profile scan.
Instance Attribute Summary collapse
-
#customized_prompt ⇒ String
Optional.
-
#global_endpoint_enabled ⇒ Boolean
(also: #global_endpoint_enabled?)
Optional.
-
#graph_profile_publishing_enabled ⇒ Boolean
(also: #graph_profile_publishing_enabled?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1UnstructuredDataProfileSpec
constructor
A new instance of GoogleCloudDataplexV1UnstructuredDataProfileSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1UnstructuredDataProfileSpec
Returns a new instance of GoogleCloudDataplexV1UnstructuredDataProfileSpec.
11123 11124 11125 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11123 def initialize(**args) update!(**args) end |
Instance Attribute Details
#customized_prompt ⇒ String
Optional. Customized prompt for unstructured data profile. The field will be
used as part of the prompt, could be some instruction, specifying skill, or
specific area to focus.
Corresponds to the JSON property customizedPrompt
11109 11110 11111 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11109 def customized_prompt @customized_prompt end |
#global_endpoint_enabled ⇒ Boolean Also known as: global_endpoint_enabled?
Optional. Whether to use the global model.
Corresponds to the JSON property globalEndpointEnabled
11114 11115 11116 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11114 def global_endpoint_enabled @global_endpoint_enabled end |
#graph_profile_publishing_enabled ⇒ Boolean Also known as: graph_profile_publishing_enabled?
Optional. Whether to publish graph-profile as aspect on the catalog entry.
Corresponds to the JSON property graphProfilePublishingEnabled
11120 11121 11122 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11120 def graph_profile_publishing_enabled @graph_profile_publishing_enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11128 11129 11130 11131 11132 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11128 def update!(**args) @customized_prompt = args[:customized_prompt] if args.key?(:customized_prompt) @global_endpoint_enabled = args[:global_endpoint_enabled] if args.key?(:global_endpoint_enabled) @graph_profile_publishing_enabled = args[:graph_profile_publishing_enabled] if args.key?(:graph_profile_publishing_enabled) end |