Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1UnstructuredDataProfileSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Contains the specification for an unstructured data profile scan.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1UnstructuredDataProfileSpec

Returns a new instance of GoogleCloudDataplexV1UnstructuredDataProfileSpec.



11085
11086
11087
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11085

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#customized_promptString

Optional. Customized prompt for unstructured data profile. The field will be used as part of the prompt, could be some instruction, specifying skill, or specific area to focus. Corresponds to the JSON property customizedPrompt

Returns:

  • (String)


11071
11072
11073
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11071

def customized_prompt
  @customized_prompt
end

#global_endpoint_enabledBoolean Also known as: global_endpoint_enabled?

Optional. Whether to use the global model. Corresponds to the JSON property globalEndpointEnabled

Returns:

  • (Boolean)


11076
11077
11078
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11076

def global_endpoint_enabled
  @global_endpoint_enabled
end

#graph_profile_publishing_enabledBoolean Also known as: graph_profile_publishing_enabled?

Optional. Whether to publish graph-profile as aspect on the catalog entry. Corresponds to the JSON property graphProfilePublishingEnabled

Returns:

  • (Boolean)


11082
11083
11084
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11082

def graph_profile_publishing_enabled
  @graph_profile_publishing_enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11090
11091
11092
11093
11094
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11090

def update!(**args)
  @customized_prompt = args[:customized_prompt] if args.key?(:customized_prompt)
  @global_endpoint_enabled = args[:global_endpoint_enabled] if args.key?(:global_endpoint_enabled)
  @graph_profile_publishing_enabled = args[:graph_profile_publishing_enabled] if args.key?(:graph_profile_publishing_enabled)
end