Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1UnstructuredDataProfileSpec
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1UnstructuredDataProfileSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Contains the specification for an unstructured data profile scan.
Instance Attribute Summary collapse
-
#customized_prompt ⇒ String
Optional.
-
#global_endpoint_enabled ⇒ Boolean
(also: #global_endpoint_enabled?)
Optional.
-
#graph_profile_publishing_enabled ⇒ Boolean
(also: #graph_profile_publishing_enabled?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1UnstructuredDataProfileSpec
constructor
A new instance of GoogleCloudDataplexV1UnstructuredDataProfileSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1UnstructuredDataProfileSpec
Returns a new instance of GoogleCloudDataplexV1UnstructuredDataProfileSpec.
10840 10841 10842 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10840 def initialize(**args) update!(**args) end |
Instance Attribute Details
#customized_prompt ⇒ String
Optional. Customized prompt for unstructured data profile. The field will be
used as part of the prompt, could be some instruction, specifying skill, or
specific area to focus.
Corresponds to the JSON property customizedPrompt
10826 10827 10828 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10826 def customized_prompt @customized_prompt end |
#global_endpoint_enabled ⇒ Boolean Also known as: global_endpoint_enabled?
Optional. Whether to use the global model.
Corresponds to the JSON property globalEndpointEnabled
10831 10832 10833 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10831 def global_endpoint_enabled @global_endpoint_enabled end |
#graph_profile_publishing_enabled ⇒ Boolean Also known as: graph_profile_publishing_enabled?
Optional. Whether to publish graph-profile as aspect on the catalog entry.
Corresponds to the JSON property graphProfilePublishingEnabled
10837 10838 10839 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10837 def graph_profile_publishing_enabled @graph_profile_publishing_enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10845 10846 10847 10848 10849 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10845 def update!(**args) @customized_prompt = args[:customized_prompt] if args.key?(:customized_prompt) @global_endpoint_enabled = args[:global_endpoint_enabled] if args.key?(:global_endpoint_enabled) @graph_profile_publishing_enabled = args[:graph_profile_publishing_enabled] if args.key?(:graph_profile_publishing_enabled) end |