Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1UpdateEntryRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1UpdateEntryRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Update Entry request.
Instance Attribute Summary collapse
-
#allow_missing ⇒ Boolean
(also: #allow_missing?)
Optional.
-
#aspect_keys ⇒ Array<String>
Optional.
-
#delete_missing_aspects ⇒ Boolean
(also: #delete_missing_aspects?)
Optional.
-
#entry ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1Entry
An entry is a representation of a data resource that can be described by various metadata.
-
#update_mask ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1UpdateEntryRequest
constructor
A new instance of GoogleCloudDataplexV1UpdateEntryRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1UpdateEntryRequest
Returns a new instance of GoogleCloudDataplexV1UpdateEntryRequest.
11135 11136 11137 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11135 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_missing ⇒ Boolean Also known as: allow_missing?
Optional. If set to true and the entry doesn't exist, the service will create
it.
Corresponds to the JSON property allowMissing
11098 11099 11100 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11098 def allow_missing @allow_missing end |
#aspect_keys ⇒ Array<String>
Optional. The map keys of the Aspects which the service should modify. It
supports the following syntaxes: - matches an aspect of the given type and
empty path. @path - matches an aspect of the given type and specified path.
For example, to attach an aspect to a field that is specified by the schema
aspect, the path should have the format Schema.. @* - matches aspects of the
given type for all paths. *@path - matches aspects of all types on the given
path.The service will not remove existing aspects matching the syntax unless
delete_missing_aspects is set to true.If this field is left empty, the service
treats it as specifying exactly those Aspects present in the request.
Corresponds to the JSON property aspectKeys
11112 11113 11114 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11112 def aspect_keys @aspect_keys end |
#delete_missing_aspects ⇒ Boolean Also known as: delete_missing_aspects?
Optional. If set to true and the aspect_keys specify aspect ranges, the
service deletes any existing aspects from that range that weren't provided in
the request.
Corresponds to the JSON property deleteMissingAspects
11119 11120 11121 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11119 def delete_missing_aspects @delete_missing_aspects end |
#entry ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1Entry
An entry is a representation of a data resource that can be described by
various metadata.
Corresponds to the JSON property entry
11126 11127 11128 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11126 def entry @entry end |
#update_mask ⇒ String
Optional. Mask of fields to update. To update Aspects, the update_mask must
contain the value "aspects".If the update_mask is empty, the service will
update all modifiable fields present in the request.
Corresponds to the JSON property updateMask
11133 11134 11135 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11133 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11140 11141 11142 11143 11144 11145 11146 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11140 def update!(**args) @allow_missing = args[:allow_missing] if args.key?(:allow_missing) @aspect_keys = args[:aspect_keys] if args.key?(:aspect_keys) @delete_missing_aspects = args[:delete_missing_aspects] if args.key?(:delete_missing_aspects) @entry = args[:entry] if args.key?(:entry) @update_mask = args[:update_mask] if args.key?(:update_mask) end |