Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1UpdateGlossaryRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Update Glossary Request

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1UpdateGlossaryRequest

Returns a new instance of GoogleCloudDataplexV1UpdateGlossaryRequest.



10960
10961
10962
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10960

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#glossaryGoogle::Apis::DataplexV1::GoogleCloudDataplexV1Glossary

A Glossary represents a collection of GlossaryCategories and GlossaryTerms defined by the user. Glossary is a top level resource and is the Google Cloud parent resource of all the GlossaryCategories and GlossaryTerms within it. Corresponds to the JSON property glossary



10946
10947
10948
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10946

def glossary
  @glossary
end

#update_maskString

Required. The list of fields to update. Corresponds to the JSON property updateMask

Returns:

  • (String)


10951
10952
10953
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10951

def update_mask
  @update_mask
end

#validate_onlyBoolean Also known as: validate_only?

Optional. Validates the request without actually updating the Glossary. Default: false. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


10957
10958
10959
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10957

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10965
10966
10967
10968
10969
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10965

def update!(**args)
  @glossary = args[:glossary] if args.key?(:glossary)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end