Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1UpdateGlossaryTermRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Update GlossaryTerm Request

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1UpdateGlossaryTermRequest

Returns a new instance of GoogleCloudDataplexV1UpdateGlossaryTermRequest.



10987
10988
10989
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10987

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#termGoogle::Apis::DataplexV1::GoogleCloudDataplexV1GlossaryTerm

GlossaryTerms are the core of Glossary. A GlossaryTerm holds a rich text description that can be attached to Entries or specific columns to enrich them. Corresponds to the JSON property term



10980
10981
10982
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10980

def term
  @term
end

#update_maskString

Required. The list of fields to update. Corresponds to the JSON property updateMask

Returns:

  • (String)


10985
10986
10987
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10985

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10992
10993
10994
10995
# File 'lib/google/apis/dataplex_v1/classes.rb', line 10992

def update!(**args)
  @term = args[:term] if args.key?(:term)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end