Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1Zone
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1Zone
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
A zone represents a logical group of related assets within a lake. A zone can be used to map to organizational structure or represent stages of data readiness from raw to curated. It provides managing behavior that is shared or inherited by all contained assets.
Instance Attribute Summary collapse
-
#asset_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetStatus
Aggregated status of the underlying assets of a lake or zone.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#discovery_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1ZoneDiscoverySpec
Settings to manage the metadata discovery and publishing in a zone.
-
#display_name ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#resource_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1ZoneResourceSpec
Settings for resources attached as assets within a zone.
-
#state ⇒ String
Output only.
-
#type ⇒ String
Required.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1Zone
constructor
A new instance of GoogleCloudDataplexV1Zone.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1Zone
Returns a new instance of GoogleCloudDataplexV1Zone.
11305 11306 11307 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11305 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset_status ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1AssetStatus
Aggregated status of the underlying assets of a lake or zone.
Corresponds to the JSON property assetStatus
11246 11247 11248 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11246 def asset_status @asset_status end |
#create_time ⇒ String
Output only. The time when the zone was created.
Corresponds to the JSON property createTime
11251 11252 11253 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11251 def create_time @create_time end |
#description ⇒ String
Optional. Description of the zone.
Corresponds to the JSON property description
11256 11257 11258 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11256 def description @description end |
#discovery_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1ZoneDiscoverySpec
Settings to manage the metadata discovery and publishing in a zone.
Corresponds to the JSON property discoverySpec
11261 11262 11263 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11261 def discovery_spec @discovery_spec end |
#display_name ⇒ String
Optional. User friendly display name.
Corresponds to the JSON property displayName
11266 11267 11268 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11266 def display_name @display_name end |
#labels ⇒ Hash<String,String>
Optional. User defined labels for the zone.
Corresponds to the JSON property labels
11271 11272 11273 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11271 def labels @labels end |
#name ⇒ String
Output only. The relative resource name of the zone, of the form: projects/
project_number/locations/location_id/lakes/lake_id/zones/zone_id.
Corresponds to the JSON property name
11277 11278 11279 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11277 def name @name end |
#resource_spec ⇒ Google::Apis::DataplexV1::GoogleCloudDataplexV1ZoneResourceSpec
Settings for resources attached as assets within a zone.
Corresponds to the JSON property resourceSpec
11282 11283 11284 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11282 def resource_spec @resource_spec end |
#state ⇒ String
Output only. Current state of the zone.
Corresponds to the JSON property state
11287 11288 11289 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11287 def state @state end |
#type ⇒ String
Required. Immutable. The type of the zone.
Corresponds to the JSON property type
11292 11293 11294 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11292 def type @type end |
#uid ⇒ String
Output only. System generated globally unique ID for the zone. This ID will be
different if the zone is deleted and re-created with the same name.
Corresponds to the JSON property uid
11298 11299 11300 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11298 def uid @uid end |
#update_time ⇒ String
Output only. The time when the zone was last updated.
Corresponds to the JSON property updateTime
11303 11304 11305 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11303 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11310 11311 11312 11313 11314 11315 11316 11317 11318 11319 11320 11321 11322 11323 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11310 def update!(**args) @asset_status = args[:asset_status] if args.key?(:asset_status) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @discovery_spec = args[:discovery_spec] if args.key?(:discovery_spec) @display_name = args[:display_name] if args.key?(:display_name) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @resource_spec = args[:resource_spec] if args.key?(:resource_spec) @state = args[:state] if args.key?(:state) @type = args[:type] if args.key?(:type) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |