Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1Zone

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

A zone represents a logical group of related assets within a lake. A zone can be used to map to organizational structure or represent stages of data readiness from raw to curated. It provides managing behavior that is shared or inherited by all contained assets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1Zone

Returns a new instance of GoogleCloudDataplexV1Zone.



8915
8916
8917
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8915

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asset_statusGoogle::Apis::DataplexV1::GoogleCloudDataplexV1AssetStatus

Aggregated status of the underlying assets of a lake or zone. Corresponds to the JSON property assetStatus



8856
8857
8858
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8856

def asset_status
  @asset_status
end

#create_timeString

Output only. The time when the zone was created. Corresponds to the JSON property createTime

Returns:

  • (String)


8861
8862
8863
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8861

def create_time
  @create_time
end

#descriptionString

Optional. Description of the zone. Corresponds to the JSON property description

Returns:

  • (String)


8866
8867
8868
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8866

def description
  @description
end

#discovery_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1ZoneDiscoverySpec

Settings to manage the metadata discovery and publishing in a zone. Corresponds to the JSON property discoverySpec



8871
8872
8873
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8871

def discovery_spec
  @discovery_spec
end

#display_nameString

Optional. User friendly display name. Corresponds to the JSON property displayName

Returns:

  • (String)


8876
8877
8878
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8876

def display_name
  @display_name
end

#labelsHash<String,String>

Optional. User defined labels for the zone. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


8881
8882
8883
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8881

def labels
  @labels
end

#nameString

Output only. The relative resource name of the zone, of the form: projects/ project_number/locations/location_id/lakes/lake_id/zones/zone_id. Corresponds to the JSON property name

Returns:

  • (String)


8887
8888
8889
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8887

def name
  @name
end

#resource_specGoogle::Apis::DataplexV1::GoogleCloudDataplexV1ZoneResourceSpec

Settings for resources attached as assets within a zone. Corresponds to the JSON property resourceSpec



8892
8893
8894
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8892

def resource_spec
  @resource_spec
end

#stateString

Output only. Current state of the zone. Corresponds to the JSON property state

Returns:

  • (String)


8897
8898
8899
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8897

def state
  @state
end

#typeString

Required. Immutable. The type of the zone. Corresponds to the JSON property type

Returns:

  • (String)


8902
8903
8904
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8902

def type
  @type
end

#uidString

Output only. System generated globally unique ID for the zone. This ID will be different if the zone is deleted and re-created with the same name. Corresponds to the JSON property uid

Returns:

  • (String)


8908
8909
8910
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8908

def uid
  @uid
end

#update_timeString

Output only. The time when the zone was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


8913
8914
8915
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8913

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
8930
8931
8932
8933
# File 'lib/google/apis/dataplex_v1/classes.rb', line 8920

def update!(**args)
  @asset_status = args[:asset_status] if args.key?(:asset_status)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @discovery_spec = args[:discovery_spec] if args.key?(:discovery_spec)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @resource_spec = args[:resource_spec] if args.key?(:resource_spec)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end