Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1ZoneDiscoverySpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Settings to manage the metadata discovery and publishing in a zone.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1ZoneDiscoverySpec

Returns a new instance of GoogleCloudDataplexV1ZoneDiscoverySpec.



11374
11375
11376
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11374

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#csv_optionsGoogle::Apis::DataplexV1::GoogleCloudDataplexV1ZoneDiscoverySpecCsvOptions

Describe CSV and similar semi-structured data formats. Corresponds to the JSON property csvOptions



11333
11334
11335
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11333

def csv_options
  @csv_options
end

#enabledBoolean Also known as: enabled?

Required. Whether discovery is enabled. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


11338
11339
11340
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11338

def enabled
  @enabled
end

#exclude_patternsArray<String>

Optional. The list of patterns to apply for selecting data to exclude during discovery. For Cloud Storage bucket assets, these are interpreted as glob patterns used to match object names. For BigQuery dataset assets, these are interpreted as patterns to match table names. Corresponds to the JSON property excludePatterns

Returns:

  • (Array<String>)


11347
11348
11349
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11347

def exclude_patterns
  @exclude_patterns
end

#include_patternsArray<String>

Optional. The list of patterns to apply for selecting data to include during discovery if only a subset of the data should considered. For Cloud Storage bucket assets, these are interpreted as glob patterns used to match object names. For BigQuery dataset assets, these are interpreted as patterns to match table names. Corresponds to the JSON property includePatterns

Returns:

  • (Array<String>)


11356
11357
11358
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11356

def include_patterns
  @include_patterns
end

#json_optionsGoogle::Apis::DataplexV1::GoogleCloudDataplexV1ZoneDiscoverySpecJsonOptions

Describe JSON data format. Corresponds to the JSON property jsonOptions



11361
11362
11363
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11361

def json_options
  @json_options
end

#scheduleString

Optional. Cron schedule (https://en.wikipedia.org/wiki/Cron) for running discovery periodically. Successive discovery runs must be scheduled at least 60 minutes apart. The default value is to run discovery every 60 minutes.To explicitly set a timezone to the cron tab, apply a prefix in the cron tab: " CRON_TZ=$IANA_TIME_ZONE" or TZ=$IANA_TIME_ZONE". The $IANA_TIME_ZONE may only be a valid string from IANA time zone database. For example, CRON_TZ= America/New_York 1 * * * *, or TZ=America/New_York 1 * * * *. Corresponds to the JSON property schedule

Returns:

  • (String)


11372
11373
11374
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11372

def schedule
  @schedule
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11379
11380
11381
11382
11383
11384
11385
11386
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11379

def update!(**args)
  @csv_options = args[:csv_options] if args.key?(:csv_options)
  @enabled = args[:enabled] if args.key?(:enabled)
  @exclude_patterns = args[:exclude_patterns] if args.key?(:exclude_patterns)
  @include_patterns = args[:include_patterns] if args.key?(:include_patterns)
  @json_options = args[:json_options] if args.key?(:json_options)
  @schedule = args[:schedule] if args.key?(:schedule)
end