Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1ZoneDiscoverySpecCsvOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Describe CSV and similar semi-structured data formats.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1ZoneDiscoverySpecCsvOptions

Returns a new instance of GoogleCloudDataplexV1ZoneDiscoverySpecCsvOptions.



9026
9027
9028
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9026

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#delimiterString

Optional. The delimiter being used to separate values. This defaults to ','. Corresponds to the JSON property delimiter

Returns:

  • (String)


9006
9007
9008
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9006

def delimiter
  @delimiter
end

#disable_type_inferenceBoolean Also known as: disable_type_inference?

Optional. Whether to disable the inference of data type for CSV data. If true, all columns will be registered as strings. Corresponds to the JSON property disableTypeInference

Returns:

  • (Boolean)


9012
9013
9014
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9012

def disable_type_inference
  @disable_type_inference
end

#encodingString

Optional. The character encoding of the data. The default is UTF-8. Corresponds to the JSON property encoding

Returns:

  • (String)


9018
9019
9020
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9018

def encoding
  @encoding
end

#header_rowsFixnum

Optional. The number of rows to interpret as header rows that should be skipped when reading data rows. Corresponds to the JSON property headerRows

Returns:

  • (Fixnum)


9024
9025
9026
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9024

def header_rows
  @header_rows
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9031
9032
9033
9034
9035
9036
# File 'lib/google/apis/dataplex_v1/classes.rb', line 9031

def update!(**args)
  @delimiter = args[:delimiter] if args.key?(:delimiter)
  @disable_type_inference = args[:disable_type_inference] if args.key?(:disable_type_inference)
  @encoding = args[:encoding] if args.key?(:encoding)
  @header_rows = args[:header_rows] if args.key?(:header_rows)
end