Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1ZoneDiscoverySpecJsonOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb

Overview

Describe JSON data format.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDataplexV1ZoneDiscoverySpecJsonOptions

Returns a new instance of GoogleCloudDataplexV1ZoneDiscoverySpecJsonOptions.



11453
11454
11455
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11453

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disable_type_inferenceBoolean Also known as: disable_type_inference?

Optional. Whether to disable the inference of data type for Json data. If true, all columns will be registered as their primitive types (strings, number or boolean). Corresponds to the JSON property disableTypeInference

Returns:

  • (Boolean)


11445
11446
11447
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11445

def disable_type_inference
  @disable_type_inference
end

#encodingString

Optional. The character encoding of the data. The default is UTF-8. Corresponds to the JSON property encoding

Returns:

  • (String)


11451
11452
11453
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11451

def encoding
  @encoding
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11458
11459
11460
11461
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11458

def update!(**args)
  @disable_type_inference = args[:disable_type_inference] if args.key?(:disable_type_inference)
  @encoding = args[:encoding] if args.key?(:encoding)
end