Class: Google::Apis::DataplexV1::GoogleCloudDataplexV1ZoneDiscoverySpecJsonOptions
- Inherits:
-
Object
- Object
- Google::Apis::DataplexV1::GoogleCloudDataplexV1ZoneDiscoverySpecJsonOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataplex_v1/classes.rb,
lib/google/apis/dataplex_v1/representations.rb,
lib/google/apis/dataplex_v1/representations.rb
Overview
Describe JSON data format.
Instance Attribute Summary collapse
-
#disable_type_inference ⇒ Boolean
(also: #disable_type_inference?)
Optional.
-
#encoding ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDataplexV1ZoneDiscoverySpecJsonOptions
constructor
A new instance of GoogleCloudDataplexV1ZoneDiscoverySpecJsonOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDataplexV1ZoneDiscoverySpecJsonOptions
Returns a new instance of GoogleCloudDataplexV1ZoneDiscoverySpecJsonOptions.
11208 11209 11210 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11208 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disable_type_inference ⇒ Boolean Also known as: disable_type_inference?
Optional. Whether to disable the inference of data type for Json data. If true,
all columns will be registered as their primitive types (strings, number or
boolean).
Corresponds to the JSON property disableTypeInference
11200 11201 11202 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11200 def disable_type_inference @disable_type_inference end |
#encoding ⇒ String
Optional. The character encoding of the data. The default is UTF-8.
Corresponds to the JSON property encoding
11206 11207 11208 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11206 def encoding @encoding end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11213 11214 11215 11216 |
# File 'lib/google/apis/dataplex_v1/classes.rb', line 11213 def update!(**args) @disable_type_inference = args[:disable_type_inference] if args.key?(:disable_type_inference) @encoding = args[:encoding] if args.key?(:encoding) end |